@@ -1,23 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
- *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
- *  Author: Guillaume Roguez <guillaume.roguez@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "media/media_codec.h"
@@ -38,7 +33,6 @@
 #include "manager.h"
 
 #include <opendht/rng.h>
-using random_device = dht::crypto::random_device;
 
 #include "client/ring_signal.h"
 #include "account_schema.h"
@@ -47,6 +41,7 @@ using random_device = dht::crypto::random_device;
 #include "fileutils.h"
 #include "config/yamlparser.h"
 #include "system_codec_container.h"
+#include "vcard.h"
 
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
@@ -65,16 +60,17 @@ using namespace std::literals;
 
 namespace jami {
 
-// For portability, do not specify the absolute file name of the ringtone.
+// For portability, do not specify the absolute filename of the ringtone.
 // Instead, specify its base name to be looked in
 // JAMI_DATADIR/ringtones/, where JAMI_DATADIR is a preprocessor macro denoting
 // the data directory prefix that must be set at build time.
 const std::string Account::DEFAULT_USER_AGENT = Account::getDefaultUserAgent();
 
-Account::Account(const std::string& accountID)
-    : rand(dht::crypto::getSeededRandomEngine<std::mt19937_64>())
-    , accountID_(accountID)
+Account::Account(const std::string& accountId)
+    : rand(Manager::instance().getSeededRandomEngine())
+    , accountID_(accountId)
     , systemCodecContainer_(getSystemCodecContainer())
+    , idPath_(fileutils::get_data_dir() / accountId)
 {
     // Initialize the codec order, used when creating a new account
     loadDefaultCodecs();
@@ -92,7 +88,7 @@ Account::hangupCalls()
 void
 Account::updateUpnpController()
 {
-    std::lock_guard<std::mutex> lk {upnp_mtx};
+    std::lock_guard lk {upnp_mtx};
 
     if (not config().upnpEnabled or not isUsable()) {
         upnpCtrl_.reset();
@@ -109,9 +105,7 @@ Account::updateUpnpController()
 }
 
 void
-Account::setRegistrationState(RegistrationState state,
-                              int detail_code,
-                              const std::string& detail_str)
+Account::setRegistrationState(RegistrationState state, int detail_code, const std::string& detail_str)
 {
     if (state != registrationState_) {
         registrationState_ = state;
@@ -122,9 +116,9 @@ Account::setRegistrationState(RegistrationState state,
                          detail_str,
                          details = getVolatileAccountDetails()] {
             emitSignal<libjami::ConfigurationSignal::RegistrationStateChanged>(accountId,
-                                                                             state,
-                                                                             detail_code,
-                                                                             detail_str);
+                                                                               state,
+                                                                               detail_code,
+                                                                               detail_str);
 
             emitSignal<libjami::ConfigurationSignal::VolatileDetailsChanged>(accountId, details);
         });
@@ -144,21 +138,25 @@ Account::loadDefaultCodecs()
             continue;
 
         if (systemCodec->mediaType & MEDIA_AUDIO) {
-            accountCodecInfoList_.emplace_back(std::make_shared<SystemAudioCodecInfo>(
-                *std::static_pointer_cast<SystemAudioCodecInfo>(systemCodec)));
+            accountCodecInfoList_.emplace_back(
+                std::make_shared<SystemAudioCodecInfo>(*std::static_pointer_cast<SystemAudioCodecInfo>(systemCodec)));
         }
 
         if (systemCodec->mediaType & MEDIA_VIDEO) {
-            accountCodecInfoList_.emplace_back(std::make_shared<SystemVideoCodecInfo>(
-                *std::static_pointer_cast<SystemVideoCodecInfo>(systemCodec)));
+            accountCodecInfoList_.emplace_back(
+                std::make_shared<SystemVideoCodecInfo>(*std::static_pointer_cast<SystemVideoCodecInfo>(systemCodec)));
         }
     }
 }
 
 void
-Account::loadConfig() {
+Account::loadConfig()
+{
     setActiveCodecs(config_->activeCodecs);
-    auto ringtoneDir = fmt::format("{}/{}", JAMI_DATADIR, RINGDIR);
+
+    // Try to get the client-defined resource base directory, if any. If not set, use the default
+    // JAMI_DATADIR that was set at build time.
+    auto ringtoneDir = fileutils::get_resource_dir_path() / RINGDIR;
     ringtonePath_ = fileutils::getFullPath(ringtoneDir, config_->ringtonePath);
     // If the user defined a custom ringtone, the file may not exists
     // In this case, fallback on the default ringtone path
@@ -183,6 +181,20 @@ Account::getVolatileAccountDetails() const
             {libjami::Account::VolatileProperties::ACTIVE, active_ ? TRUE_STR : FALSE_STR}};
 }
 
+vCard::utils::VCardData
+Account::getProfileVcard() const
+{
+    try {
+        auto path = idPath_ / "profile.vcf";
+        if (!std::filesystem::exists(path))
+            return {};
+        return vCard::utils::toMap(fileutils::loadTextFile(path));
+    } catch (const std::exception& e) {
+        JAMI_ERROR("Error reading profile: {}", e.what());
+        return {};
+    }
+}
+
 bool
 Account::hasActiveCodec(MediaType mediaType) const
 {
@@ -217,8 +229,9 @@ Account::sortCodec()
 {
     std::sort(std::begin(accountCodecInfoList_),
               std::end(accountCodecInfoList_),
-              [](const std::shared_ptr<SystemCodecInfo>& a,
-                 const std::shared_ptr<SystemCodecInfo>& b) { return a->order < b->order; });
+              [](const std::shared_ptr<SystemCodecInfo>& a, const std::shared_ptr<SystemCodecInfo>& b) {
+                  return a->order < b->order;
+              });
 }
 
 std::string
@@ -277,7 +290,7 @@ Account::getDefaultCodecDetails(const unsigned& codecId)
 dhtnet::IpAddr
 Account::getUPnPIpAddress() const
 {
-    std::lock_guard<std::mutex> lk(upnp_mtx);
+    std::lock_guard lk(upnp_mtx);
     if (upnpCtrl_)
         return upnpCtrl_->getExternalIP();
     return {};
@@ -290,7 +303,7 @@ Account::getUPnPIpAddress() const
 bool
 Account::getUPnPActive() const
 {
-    std::lock_guard<std::mutex> lk(upnp_mtx);
+    std::lock_guard lk(upnp_mtx);
     if (upnpCtrl_)
         return upnpCtrl_->isReady();
     return false;
@@ -305,8 +318,7 @@ Account::searchCodecById(unsigned codecId, MediaType mediaType)
 {
     if (mediaType != MEDIA_NONE) {
         for (auto& codecIt : accountCodecInfoList_) {
-            if ((codecIt->id == codecId)
-                && (codecIt->mediaType & mediaType))
+            if ((codecIt->id == codecId) && (codecIt->mediaType & mediaType))
                 return codecIt;
         }
     }
@@ -318,8 +330,7 @@ Account::searchCodecByName(const std::string& name, MediaType mediaType)
 {
     if (mediaType != MEDIA_NONE) {
         for (auto& codecIt : accountCodecInfoList_) {
-            if (codecIt->name == name
-                && (codecIt->mediaType & mediaType))
+            if (codecIt->name == name && (codecIt->mediaType & mediaType))
                 return codecIt;
         }
     }
@@ -331,8 +342,7 @@ Account::searchCodecByPayload(unsigned payload, MediaType mediaType)
 {
     if (mediaType != MEDIA_NONE) {
         for (auto& codecIt : accountCodecInfoList_) {
-            if ((codecIt->payloadType == payload)
-                && (codecIt->mediaType & mediaType))
+            if ((codecIt->payloadType == payload) && (codecIt->mediaType & mediaType))
                 return codecIt;
         }
     }
@@ -421,7 +431,7 @@ Account::getUserAgentName()
 std::string
 Account::getDefaultUserAgent()
 {
-    return fmt::format("{:s} {:s} ({:s})", PACKAGE_NAME, libjami::version(), libjami::platform());
+    return fmt::format("{:s} {:s} ({:s})", PACKAGE_NAME, libjami::version(), jami::platform());
 }
 
 void
@@ -452,7 +462,7 @@ Account::meetMinimumRequiredVersion(const std::vector<unsigned>& version,
 bool
 Account::setPushNotificationConfig(const std::map<std::string, std::string>& data)
 {
-    std::lock_guard<std::recursive_mutex> lock(configurationMutex_);
+    std::lock_guard lock(configurationMutex_);
     auto platform = data.find("platform");
     auto topic = data.find("topic");
     auto token = data.find("token");
