@@ -1,23 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
- *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
- *  Author: Guillaume Roguez <guillaume.roguez@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 #pragma once
 
@@ -31,13 +26,16 @@
 #include "config/serializable.h"
 #include "registration_states.h"
 #include "im/message_engine.h"
-#include "connectivity/ip_utils.h"
-#include "media_codec.h"
+#include "media/media_codec.h"
 #include "media/media_attribute.h"
 #include "logger.h"
 #include "compiler_intrinsics.h" // include the "UNUSED" macro
 #include "call_set.h"
 #include "account_config.h"
+#include "vcard.h"
+
+#include <dhtnet/ip_utils.h>
+#include <dhtnet/upnp/upnp_control.h>
 
 #include <functional>
 #include <string>
@@ -55,17 +53,18 @@ namespace Json {
 class Value;
 }
 
+namespace dht {
+namespace crypto {
+struct Certificate;
+}
+} // namespace dht
+
 namespace jami {
 static constexpr uint64_t JAMI_ID_MAX_VAL = 9007199254740992;
 constexpr static const char RINGDIR[] = "ringtones";
 
-namespace upnp {
-class Controller;
-} // namespace upnp
-
 class Call;
 class SystemCodecContainer;
-struct IceTransportOptions;
 
 class VoipLinkException : public std::runtime_error
 {
@@ -102,7 +101,7 @@ public:
 
     void setConfig(std::unique_ptr<AccountConfig>&& config)
     {
-        std::lock_guard<std::recursive_mutex> lock(configurationMutex_);
+        std::lock_guard lock(configurationMutex_);
         config_ = std::move(config);
         loadConfig();
     }
@@ -122,7 +121,7 @@ public:
 
     inline void editConfig(std::function<void(AccountConfig& config)>&& edit)
     {
-        std::lock_guard<std::recursive_mutex> lock(configurationMutex_);
+        std::lock_guard lock(configurationMutex_);
         edit(*config_);
         saveConfig();
     }
@@ -131,7 +130,7 @@ public:
 
     void setAccountDetails(const std::map<std::string, std::string>& details)
     {
-        std::lock_guard<std::recursive_mutex> lock(configurationMutex_);
+        std::lock_guard lock(configurationMutex_);
         if (not config_)
             config_ = buildConfig();
         config_->fromMap(details);
@@ -141,7 +140,7 @@ public:
 
     std::map<std::string, std::string> getAccountDetails() const
     {
-        std::lock_guard<std::recursive_mutex> lock(configurationMutex_);
+        std::lock_guard lock(configurationMutex_);
         return config().toMap();
     }
 
@@ -153,10 +152,12 @@ public:
      * Get the account ID
      * @return constant account id
      */
-    const std::string& getAccountID() const { return accountID_; }
+    inline const std::string& getAccountID() const { return accountID_; }
 
     virtual std::string_view getAccountType() const = 0;
 
+    const std::filesystem::path& getPath() const { return idPath_; }
+
     /**
      * Returns true if this is the IP2IP account
      */
@@ -172,7 +173,7 @@ public:
      * Unregister the account.
      * This should update the getRegistrationState() return value.
      */
-    virtual void doUnregister(std::function<void(bool)> cb = std::function<void(bool)>()) = 0;
+    virtual void doUnregister(bool forceShutdownConnections = false) = 0;
 
     RegistrationState getRegistrationState() const { return registrationState_; }
 
@@ -209,26 +210,28 @@ public:
         return false;
     };
 
-    virtual std::vector<libjami::Message> getLastMessages(const uint64_t& /*base_timestamp*/)
-    {
-        return {};
-    }
+    virtual std::vector<libjami::Message> getLastMessages(const uint64_t& /*base_timestamp*/) { return {}; }
 
     virtual std::map<std::string, std::string> getNearbyPeers() const { return {}; }
 
+    virtual void updateProfile(const std::string& /*displayName*/,
+                               const std::string& /*avatar*/,
+                               const std::string& /*fileType*/,
+                               int32_t /*flag*/)
+        = 0;
+
+    vCard::utils::VCardData getProfileVcard() const;
+
     /**
      * Return the status corresponding to the token.
      */
-    virtual im::MessageStatus getMessageStatus(uint64_t /*id*/) const
-    {
-        return im::MessageStatus::UNKNOWN;
-    }
+    virtual im::MessageStatus getMessageStatus(uint64_t /*id*/) const { return im::MessageStatus::UNKNOWN; }
 
     virtual bool cancelMessage(uint64_t /*id*/) { return false; }
 
     virtual bool setPushNotificationToken(const std::string& pushDeviceToken = "")
     {
-        std::lock_guard<std::recursive_mutex> lock(configurationMutex_);
+        std::lock_guard lock(configurationMutex_);
         if (config_ && config_->deviceKey != pushDeviceToken) {
             config_->deviceKey = pushDeviceToken;
             saveConfig();
@@ -239,7 +242,7 @@ public:
 
     virtual bool setPushNotificationTopic(const std::string& topic = "")
     {
-        std::lock_guard<std::recursive_mutex> lock(configurationMutex_);
+        std::lock_guard lock(configurationMutex_);
         if (config_ && config_->notificationTopic != topic) {
             config_->notificationTopic = topic;
             saveConfig();
@@ -256,7 +259,14 @@ public:
      */
     bool isEnabled() const { return config().enabled; }
 
-    void setEnabled(bool enable) { config_->enabled = enable; }
+    void setEnabled(bool enable)
+    {
+        config_->enabled = enable;
+        // Update the UPnP controller to make sure it's in the correct state since this
+        // depends on whether the account is enabled or not (in particular, we don't want
+        // disabled accounts to generate UPnP activity).
+        updateUpnpController();
+    }
 
     /**
      * Tell if the account is activated
@@ -278,9 +288,7 @@ public:
      * Set the registration state of the specified link
      * @param state The registration state of underlying VoIPLink
      */
-    virtual void setRegistrationState(RegistrationState state,
-                                      int detail_code = 0,
-                                      const std::string& detail_str = {});
+    virtual void setRegistrationState(RegistrationState state, int detail_code = 0, const std::string& detail_str = {});
 
     const std::string& getUsername() const { return config().username; }
     const std::string& getHostname() const { return config().hostname; }
@@ -300,19 +308,20 @@ public:
      * SDP offer and configuration respectively
      */
     virtual void setActiveCodecs(const std::vector<unsigned>& list);
-    std::shared_ptr<AccountCodecInfo> searchCodecById(unsigned codecId, MediaType mediaType);
-    std::vector<std::shared_ptr<AccountCodecInfo>> getActiveAccountCodecInfoList(
-        MediaType mediaType) const;
-    std::shared_ptr<AccountCodecInfo> searchCodecByPayload(unsigned payload, MediaType mediaType);
+    std::shared_ptr<SystemCodecInfo> searchCodecById(unsigned codecId, MediaType mediaType);
+    std::vector<std::shared_ptr<SystemCodecInfo>> getActiveAccountCodecInfoList(MediaType mediaType) const;
+    std::shared_ptr<SystemCodecInfo> searchCodecByPayload(unsigned payload, MediaType mediaType);
 
-    std::string getRingtonePath() const { return ringtonePath_; }
+    std::filesystem::path getRingtonePath() const { return ringtonePath_; }
     bool getRingtoneEnabled() const { return config().ringtoneEnabled; }
     std::string getDisplayName() const { return config().displayName; }
     std::string getMailBox() const { return config().mailbox; }
 
     bool isRendezVous() const { return config().isRendezVous; }
     bool isAutoAnswerEnabled() const { return config().autoAnswerEnabled; }
+    bool isDenySecondCallEnabled() const { return config().denySecondCallEnabled; }
     bool isReadReceiptEnabled() const { return config().sendReadReceipt; }
+    bool isComposingEnabled() const { return config().sendComposing; }
 
     /**
      * returns whether or not UPnP is enabled and active
@@ -324,7 +333,7 @@ public:
      * Get the UPnP IP (external router) address.
      * If use UPnP is set to false, the address will be empty.
      */
-    IpAddr getUPnPIpAddress() const;
+    dhtnet::IpAddr getUPnPIpAddress() const;
 
     /**
      * Random generator engine
@@ -337,7 +346,8 @@ public:
      */
     virtual void connectivityChanged() {};
 
-    virtual bool handleMessage(const std::string& /*from*/,
+    virtual bool handleMessage(const std::shared_ptr<dht::crypto::Certificate>& /*cert*/,
+                               const std::string& /*from*/,
                                const std::pair<std::string, std::string>& /*message*/)
     {
         return false;
@@ -393,11 +403,9 @@ public:
     // once the  backward compatibility is no more required.
     bool isIceCompIdRfc5245Compliant() const { return iceCompIdRfc5245Compliant_; }
     void enableIceCompIdRfc5245Compliance(bool enable) { iceCompIdRfc5245Compliant_ = enable; }
+    void enableAutoLoadConversations(bool enable) { autoLoadConversations_ = enable; }
 
-    std::shared_ptr<Call> getCall(const std::string& callId) const
-    {
-        return callSet_.getCall(callId);
-    }
+    std::shared_ptr<Call> getCall(const std::string& callId) const { return callSet_.getCall(callId); }
     std::vector<std::string> getCallList() const { return callSet_.getCallIds(); }
     std::shared_ptr<Conference> getConference(const std::string& confId) const
     {
@@ -421,7 +429,7 @@ public:
      * This method is called to request removal of possible account traces on the system,
      * like internal account setup files.
      */
-    virtual void flush() {/* nothing to do here - overload */};
+    virtual void flush() { /* nothing to do here - overload */ };
 
 private:
     NON_COPYABLE(Account);
@@ -432,7 +440,7 @@ private:
     CallSet callSet_;
 
 protected:
-    void updateUpnpController();
+    virtual void updateUpnpController();
 
     std::unique_ptr<AccountConfig> config_ {};
 
@@ -474,27 +482,35 @@ protected:
     /**
      * Vector containing all account codecs (set of system codecs with custom parameters)
      */
-    std::vector<std::shared_ptr<AccountCodecInfo>> accountCodecInfoList_;
+    std::vector<std::shared_ptr<SystemCodecInfo>> accountCodecInfoList_;
+
+    /**
+     * path to account
+     */
+    std::filesystem::path idPath_ {};
 
     /**
      * Ringtone .au file used for this account
      */
-    std::string ringtonePath_;
+    std::filesystem::path ringtonePath_;
 
     /**
      * UPnP IGD controller and the mutex to access it
      */
     mutable std::mutex upnp_mtx {};
-    std::shared_ptr<jami::upnp::Controller> upnpCtrl_;
+    std::shared_ptr<dhtnet::upnp::Controller> upnpCtrl_;
 
     bool iceForMediaEnabled_ {true};
     bool iceCompIdRfc5245Compliant_ {false};
+    /**
+     * Auto load conversations when creatinf convModule()
+     */
+    bool autoLoadConversations_ {true};
 
     /**
      * private account codec searching functions
      */
-    std::shared_ptr<AccountCodecInfo> searchCodecByName(const std::string& name,
-                                                        MediaType mediaType);
+    std::shared_ptr<SystemCodecInfo> searchCodecByName(const std::string& name, MediaType mediaType);
     std::vector<unsigned> getAccountCodecInfoIdList(MediaType mediaType) const;
     void setAllCodecsActive(MediaType mediaType, bool active);
     void sortCodec();
