@@ -1,22 +1,18 @@
 /*
- *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Alexandre Savard  <alexandre.savard@savoirfairelinux.com>
- *  Author: Adrien Béraud <adrien.beraud@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 #pragma once
 
@@ -139,19 +135,14 @@ struct ParticipantInfo
 
     friend bool operator==(const ParticipantInfo& p1, const ParticipantInfo& p2)
     {
-        return p1.uri == p2.uri and p1.device == p2.device and p1.sinkId == p2.sinkId
-               and p1.active == p2.active and p1.x == p2.x and p1.y == p2.y and p1.w == p2.w
-               and p1.h == p2.h and p1.videoMuted == p2.videoMuted
-               and p1.audioLocalMuted == p2.audioLocalMuted
-               and p1.audioModeratorMuted == p2.audioModeratorMuted
+        return p1.uri == p2.uri and p1.device == p2.device and p1.sinkId == p2.sinkId and p1.active == p2.active
+               and p1.x == p2.x and p1.y == p2.y and p1.w == p2.w and p1.h == p2.h and p1.videoMuted == p2.videoMuted
+               and p1.audioLocalMuted == p2.audioLocalMuted and p1.audioModeratorMuted == p2.audioModeratorMuted
                and p1.isModerator == p2.isModerator and p1.handRaised == p2.handRaised
                and p1.voiceActivity == p2.voiceActivity and p1.recording == p2.recording;
     }
 
-    friend bool operator!=(const ParticipantInfo& p1, const ParticipantInfo& p2)
-    {
-        return !(p1 == p2);
-    }
+    friend bool operator!=(const ParticipantInfo& p1, const ParticipantInfo& p2) { return !(p1 == p2); }
 };
 
 struct ConfInfo : public std::vector<ParticipantInfo>
@@ -169,9 +160,7 @@ struct ConfInfo : public std::vector<ParticipantInfo>
             return false;
 
         for (auto& p1 : c1) {
-            auto it = std::find_if(c2.begin(), c2.end(), [&p1](const ParticipantInfo& p2) {
-                return p1 == p2;
-            });
+            auto it = std::find_if(c2.begin(), c2.end(), [&p1](const ParticipantInfo& p2) { return p1 == p2; });
             if (it != c2.end())
                 continue;
             else
@@ -186,7 +175,7 @@ struct ConfInfo : public std::vector<ParticipantInfo>
     std::string toString() const;
 };
 
-using ParticipantSet = std::set<std::string>;
+using CallIdSet = std::set<std::string>;
 using clock = std::chrono::steady_clock;
 
 class Conference : public Recordable, public std::enable_shared_from_this<Conference>
@@ -197,10 +186,7 @@ public:
     /**
      * Constructor for this class, increment static counter
      */
-    explicit Conference(const std::shared_ptr<Account>&,
-                        const std::string& confId = "",
-                        bool attachHost = true,
-                        const std::vector<MediaAttribute>& hostAttr = {});
+    explicit Conference(const std::shared_ptr<Account>&, const std::string& confId = "");
 
     /**
      * Destructor for this class, decrement static counter
@@ -250,11 +236,6 @@ public:
 
     const char* getStateStr() const { return getStateStr(confState_); }
 
-    /**
-     * Set default media source for the local host
-     */
-    void setLocalHostDefaultMediaSource();
-
     /**
      * Set the mute state of the local host
      */
@@ -265,14 +246,6 @@ public:
      */
     bool isMediaSourceMuted(MediaType type) const;
 
-    /**
-     * Take over media control from the call.
-     * When a call joins a conference, the media control (mainly mute/un-mute
-     * state of the local media source) will be handled by the conference and
-     * the mixer.
-     */
-    void takeOverMediaSourceControl(const std::string& callId);
-
     /**
      * Process a media change request.
      * Used to change the media attributes of the host.
@@ -292,49 +265,29 @@ public:
                                   const std::vector<libjami::MediaMap>& remoteMediaList);
 
     /**
-     * Add a new participant to the conference
+     * Add a new subcall to the conference
      */
-    void addParticipant(const std::string& participant_id);
+    void addSubCall(const std::string& callId);
 
     /**
-     * Remove a participant from the conference
+     * Remove a subcall from the conference
      */
-    void removeParticipant(const std::string& participant_id);
+    void removeSubCall(const std::string& callId);
 
     /**
-     * Attach local audio/video to the conference
+     * Attach host
      */
-    void attachLocalParticipant();
+    void attachHost(const std::vector<libjami::MediaMap>& mediaList);
 
     /**
      * Detach local audio/video from the conference
      */
-    void detachLocalParticipant();
-
-    /**
-     * Bind a participant to the conference
-     */
-    void bindParticipant(const std::string& participant_id);
-
-    /**
-     * Bind host to the conference
-     */
-    void bindHost();
-
-    /**
-     * unbind a participant from the conference
-     */
-    void unbindParticipant(const std::string& participant_id);
-
-    /**
-     * unbind host from conference
-     */
-    void unbindHost();
+    void detachHost();
 
     /**
      * Get the participant list for this conference
      */
-    ParticipantSet getParticipantList() const;
+    CallIdSet getSubCalls() const;
 
     /**
      * Start/stop recording toggle
@@ -404,6 +357,12 @@ public:
      */
     std::vector<libjami::MediaMap> currentMediaList() const;
 
+    /**
+     * Return the last media list before the host was detached
+     * @return Last media list
+     */
+    std::vector<libjami::MediaMap> getLastMediaList() const { return lastMediaList_; }
+
     // Update layout if recording changes
     void stopRecording() override;
     bool startRecording(const std::string& path) override;
@@ -415,15 +374,11 @@ public:
     {
         return duration_start_ == clock::time_point::min()
                    ? std::chrono::milliseconds::zero()
-                   : std::chrono::duration_cast<std::chrono::milliseconds>(clock::now()
-                                                                           - duration_start_);
+                   : std::chrono::duration_cast<std::chrono::milliseconds>(clock::now() - duration_start_);
     }
 
 private:
-    std::weak_ptr<Conference> weak()
-    {
-        return std::static_pointer_cast<Conference>(shared_from_this());
-    }
+    std::weak_ptr<Conference> weak() { return std::static_pointer_cast<Conference>(shared_from_this()); }
 
     static std::shared_ptr<Call> getCall(const std::string& callId);
     bool isModerator(std::string_view uri) const;
@@ -438,9 +393,9 @@ private:
 
     std::string id_;
     std::weak_ptr<Account> account_;
-    State confState_ {State::ACTIVE_ATTACHED};
-    mutable std::mutex participantsMtx_ {};
-    ParticipantSet participants_;
+    State confState_ {State::ACTIVE_DETACHED};
+    mutable std::mutex subcallsMtx_ {};
+    CallIdSet subCalls_;
     std::string mediaPlayerId_ {};
 
     mutable std::mutex confInfoMutex_ {};
@@ -460,8 +415,6 @@ private:
     std::set<std::string, std::less<>> participantsMuted_ {};
     std::set<std::string, std::less<>> handsRaised_;
 
-    bool attachHost_;
-
     // stream IDs
     std::set<std::string, std::less<>> streamsVoiceActive {};
 
@@ -480,6 +433,11 @@ private:
      * of the local host.
      */
     std::vector<MediaAttribute> hostSources_;
+    // Because host doesn't have a call, we need to store the audio inputs
+    std::map<std::string, std::shared_ptr<jami::AudioInput>> hostAudioInputs_;
+
+    // Last media list before detaching from a conference
+    std::vector<libjami::MediaMap> lastMediaList_ = {};
 
     bool localModAdded_ {false};
 
@@ -487,8 +445,7 @@ private:
 #ifdef ENABLE_VIDEO
     void resizeRemoteParticipants(ConfInfo& confInfo, std::string_view peerURI);
 #endif
-    std::string_view findHostforRemoteParticipant(std::string_view uri,
-                                                  std::string_view deviceId = "");
+    std::string_view findHostforRemoteParticipant(std::string_view uri, std::string_view deviceId = "");
 
     std::shared_ptr<Call> getCallWith(const std::string& accountUri, const std::string& deviceId);
 
@@ -537,6 +494,39 @@ private:
 
     std::function<void(int)> shutdownCb_;
     clock::time_point duration_start_;
+
+    /**
+     * Initialize sources for host (takes default camera/audio)
+     */
+    void initSourcesForHost();
+
+    /**
+     * Take over media control from the call.
+     * When a call joins a conference, the media control (mainly mute/un-mute
+     * state of the local media source) will be handled by the conference and
+     * the mixer.
+     */
+    void takeOverMediaSourceControl(const std::string& callId);
+
+    /**
+     * Bind host's audio
+     */
+    void bindHostAudio();
+
+    /**
+     * Unbind host's audio
+     */
+    void unbindHostAudio();
+
+    /**
+     * Bind call's audio to the conference
+     */
+    void bindSubCallAudio(const std::string& callId);
+
+    /**
+     * Unbind call's audio from the conference
+     */
+    void unbindSubCallAudio(const std::string& callId);
 };
 
 } // namespace jami
