@@ -1,21 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "data_transfer.h"
@@ -23,16 +20,10 @@
 #include "base64.h"
 #include "fileutils.h"
 #include "manager.h"
-#include "map_utils.h"
-#include "string_utils.h"
 #include "client/ring_signal.h"
 
-#include <thread>
-#include <stdexcept>
 #include <mutex>
-#include <future>
-#include <charconv> // std::from_chars
-#include <cstdlib>  // mkstemp
+#include <cstdlib> // mkstemp
 #include <filesystem>
 
 #include <opendht/rng.h>
@@ -41,13 +32,12 @@
 namespace jami {
 
 libjami::DataTransferId
-generateUID()
+generateUID(std::mt19937_64& engine)
 {
-    thread_local dht::crypto::random_device rd;
-    return std::uniform_int_distribution<libjami::DataTransferId> {1, JAMI_ID_MAX_VAL}(rd);
+    return std::uniform_int_distribution<libjami::DataTransferId> {1, JAMI_ID_MAX_VAL}(engine);
 }
 
-FileInfo::FileInfo(const std::shared_ptr<ChannelSocket>& channel,
+FileInfo::FileInfo(const std::shared_ptr<dhtnet::ChannelSocket>& channel,
                    const std::string& fileId,
                    const std::string& interactionId,
                    const libjami::DataTransferInfo& info)
@@ -74,7 +64,7 @@ FileInfo::emit(libjami::DataTransferEventCode code)
     }
 }
 
-OutgoingFile::OutgoingFile(const std::shared_ptr<ChannelSocket>& channel,
+OutgoingFile::OutgoingFile(const std::shared_ptr<dhtnet::ChannelSocket>& channel,
                            const std::string& fileId,
                            const std::string& interactionId,
                            const libjami::DataTransferInfo& info,
@@ -84,13 +74,14 @@ OutgoingFile::OutgoingFile(const std::shared_ptr<ChannelSocket>& channel,
     , start_(start)
     , end_(end)
 {
-    if (!fileutils::isFile(info_.path)) {
-        channel_->shutdown();
+    std::filesystem::path fpath(info_.path);
+    if (!std::filesystem::is_regular_file(fpath)) {
+        dht::ThreadPool::io().run([channel = std::move(channel_)] { channel->shutdown(); });
         return;
     }
-    fileutils::openStream(stream_, info_.path, std::ios::binary | std::ios::in);
+    stream_.open(fpath, std::ios::binary | std::ios::in);
     if (!stream_ || !stream_.is_open()) {
-        channel_->shutdown();
+        dht::ThreadPool::io().run([channel = std::move(channel_)] { channel->shutdown(); });
         return;
     }
 }
@@ -99,8 +90,9 @@ OutgoingFile::~OutgoingFile()
 {
     if (stream_ && stream_.is_open())
         stream_.close();
-    if (channel_)
-        channel_->shutdown();
+    if (channel_) {
+        dht::ThreadPool::io().run([channel = std::move(channel_)] { channel->shutdown(); });
+    }
 }
 
 void
@@ -115,8 +107,7 @@ OutgoingFile::process()
         std::error_code ec;
         auto pos = start_;
         while (!stream_.eof()) {
-            stream_.read(buffer.data(),
-                         end_ > start_ ? std::min(end_ - pos, buffer.size()) : buffer.size());
+            stream_.read(buffer.data(), end_ > start_ ? std::min(end_ - pos, buffer.size()) : buffer.size());
             auto gcount = stream_.gcount();
             pos += gcount;
             channel_->write(reinterpret_cast<const uint8_t*>(buffer.data()), gcount, ec);
@@ -135,8 +126,7 @@ OutgoingFile::process()
         // will retry the transfer if they need, so we don't need to show errors.
         if (!interactionId_.empty() && !correct)
             return;
-        auto code = correct ? libjami::DataTransferEventCode::finished
-                            : libjami::DataTransferEventCode::closed_by_peer;
+        auto code = correct ? libjami::DataTransferEventCode::finished : libjami::DataTransferEventCode::closed_by_peer;
         emit(code);
     }
 }
@@ -145,24 +135,23 @@ void
 OutgoingFile::cancel()
 {
     // Remove link, not original file
-    auto path = fileutils::get_data_dir() + DIR_SEPARATOR_STR + "conversation_data"
-                + DIR_SEPARATOR_STR + info_.accountId + DIR_SEPARATOR_STR + info_.conversationId
-                + DIR_SEPARATOR_STR + fileId_;
-    if (fileutils::isSymLink(path))
-        fileutils::remove(path);
+    auto path = fileutils::get_data_dir() / "conversation_data" / info_.accountId / info_.conversationId / fileId_;
+    if (std::filesystem::is_symlink(path))
+        dhtnet::fileutils::remove(path);
     isUserCancelled_ = true;
     emit(libjami::DataTransferEventCode::closed_by_host);
 }
 
-IncomingFile::IncomingFile(const std::shared_ptr<ChannelSocket>& channel,
+IncomingFile::IncomingFile(const std::shared_ptr<dhtnet::ChannelSocket>& channel,
                            const libjami::DataTransferInfo& info,
                            const std::string& fileId,
                            const std::string& interactionId,
                            const std::string& sha3Sum)
     : FileInfo(channel, fileId, interactionId, info)
     , sha3Sum_(sha3Sum)
+    , path_(info.path + ".tmp")
 {
-    fileutils::openStream(stream_, info_.path, std::ios::binary | std::ios::out | std::ios::app);
+    stream_.open(path_, std::ios::binary | std::ios::out | std::ios::app);
     if (!stream_)
         return;
 
@@ -173,8 +162,11 @@ IncomingFile::~IncomingFile()
 {
     if (channel_)
         channel_->setOnRecv({});
-    if (stream_ && stream_.is_open())
-        stream_.close();
+    {
+        std::lock_guard<std::mutex> lk(streamMtx_);
+        if (stream_ && stream_.is_open())
+            stream_.close();
+    }
     if (channel_)
         channel_->shutdown();
 }
@@ -191,38 +183,69 @@ IncomingFile::cancel()
 void
 IncomingFile::process()
 {
-    channel_->setOnRecv([w = weak()](const uint8_t* buf, size_t len) {
+    channel_->setOnRecv([w = weak_from_this()](const uint8_t* buf, size_t len) {
         if (auto shared = w.lock()) {
+            // No need to lock, setOnRecv is resetted before closing
             if (shared->stream_.is_open())
                 shared->stream_.write(reinterpret_cast<const char*>(buf), len);
             shared->info_.bytesProgress = shared->stream_.tellp();
         }
         return len;
     });
-    channel_->onShutdown([w = weak()] {
+    channel_->onShutdown([w = weak_from_this()] {
         auto shared = w.lock();
         if (!shared)
             return;
-        if (shared->stream_ && shared->stream_.is_open())
-            shared->stream_.close();
+        {
+            std::lock_guard<std::mutex> lk(shared->streamMtx_);
+            if (shared->stream_ && shared->stream_.is_open())
+                shared->stream_.close();
+        }
         auto correct = shared->sha3Sum_.empty();
+        std::error_code ec;
         if (!correct) {
-            // Verify shaSum
-            auto sha3Sum = fileutils::sha3File(shared->info_.path);
             if (shared->isUserCancelled_) {
-                JAMI_WARN() << "Remove file, invalid sha3sum detected for " << shared->info_.path;
-                fileutils::remove(shared->info_.path, true);
-            } else if (shared->sha3Sum_ == sha3Sum) {
-                JAMI_INFO() << "New file received: " << shared->info_.path;
-                correct = true;
+                std::filesystem::remove(shared->path_, ec);
+            } else if (shared->info_.bytesProgress < shared->info_.totalSize) {
+                JAMI_WARNING("Channel for {} shut down before transfer was complete (progress: {}/{})",
+                             shared->info_.path,
+                             shared->info_.bytesProgress,
+                             shared->info_.totalSize);
+            } else if (shared->info_.totalSize != 0 && shared->info_.bytesProgress > shared->info_.totalSize) {
+                JAMI_WARNING("Removing {} larger than announced: {}/{}",
+                             shared->path_,
+                             shared->info_.bytesProgress,
+                             shared->info_.totalSize);
+                std::filesystem::remove(shared->path_, ec);
             } else {
-                JAMI_WARN() << "Invalid sha3sum detected, unfinished file: " << shared->info_.path;
+                auto sha3Sum = fileutils::sha3File(shared->path_);
+                if (shared->sha3Sum_ == sha3Sum) {
+                    JAMI_LOG("New file received: {}", shared->info_.path);
+                    correct = true;
+                } else {
+                    JAMI_WARNING(
+                        "Removing {} with expected size ({} bytes) but invalid sha3sum (expected: {}, actual: {})",
+                        shared->path_,
+                        shared->info_.totalSize,
+                        shared->sha3Sum_,
+                        sha3Sum);
+                    std::filesystem::remove(shared->path_, ec);
+                }
+            }
+            if (ec) {
+                JAMI_ERROR("Failed to remove file {}: {}", shared->path_, ec.message());
+            }
+        }
+        if (correct) {
+            std::filesystem::rename(shared->path_, shared->info_.path, ec);
+            if (ec) {
+                JAMI_ERROR("Failed to rename file from {} to {}: {}", shared->path_, shared->info_.path, ec.message());
+                correct = false;
             }
         }
         if (shared->isUserCancelled_)
             return;
-        auto code = correct ? libjami::DataTransferEventCode::finished
-                            : libjami::DataTransferEventCode::closed_by_host;
+        auto code = correct ? libjami::DataTransferEventCode::finished : libjami::DataTransferEventCode::closed_by_host;
         shared->emit(code);
     });
 }
@@ -232,25 +255,25 @@ IncomingFile::process()
 class TransferManager::Impl
 {
 public:
-    Impl(const std::string& accountId, const std::string& to)
+    Impl(const std::string& accountId, const std::string& accountUri, const std::string& to, const std::mt19937_64& rand)
         : accountId_(accountId)
+        , accountUri_(accountUri)
         , to_(to)
+        , rand_(rand)
     {
         if (!to_.empty()) {
-            conversationDataPath_ = fileutils::get_data_dir() + DIR_SEPARATOR_STR + accountId_
-                                    + DIR_SEPARATOR_STR + "conversation_data" + DIR_SEPARATOR_STR
-                                    + to_;
-            fileutils::check_dir(conversationDataPath_.c_str());
-            waitingPath_ = conversationDataPath_ + DIR_SEPARATOR_STR + "waiting";
+            conversationDataPath_ = fileutils::get_data_dir() / accountId_ / "conversation_data" / to_;
+            dhtnet::fileutils::check_dir(conversationDataPath_);
+            waitingPath_ = conversationDataPath_ / "waiting";
         }
-        profilesPath_ = fileutils::get_data_dir() + DIR_SEPARATOR_STR + accountId_
-                        + DIR_SEPARATOR_STR + "profiles";
+        profilesPath_ = fileutils::get_data_dir() / accountId_ / "profiles";
+        accountProfilePath_ = fileutils::get_data_dir() / accountId / "profile.vcf";
         loadWaiting();
     }
 
     ~Impl()
     {
-        std::lock_guard<std::mutex> lk {mapMutex_};
+        std::lock_guard lk {mapMutex_};
         for (const auto& [channel, _of] : outgoings_) {
             channel->shutdown();
         }
@@ -266,7 +289,7 @@ public:
             auto file = fileutils::loadFile(waitingPath_);
             // load values
             msgpack::object_handle oh = msgpack::unpack((const char*) file.data(), file.size());
-            std::lock_guard<std::mutex> lk {mapMutex_};
+            std::lock_guard lk {mapMutex_};
             oh.get().convert(waitingIds_);
         } catch (const std::exception& e) {
             return;
@@ -279,26 +302,33 @@ public:
     }
 
     std::string accountId_ {};
+    std::string accountUri_ {};
     std::string to_ {};
-    std::string waitingPath_ {};
-    std::string profilesPath_ {};
-    std::string conversationDataPath_ {};
+    std::filesystem::path waitingPath_ {};
+    std::filesystem::path profilesPath_ {};
+    std::filesystem::path accountProfilePath_ {};
+    std::filesystem::path conversationDataPath_ {};
 
     std::mutex mapMutex_ {};
     std::map<std::string, WaitingRequest> waitingIds_ {};
-    std::map<std::shared_ptr<ChannelSocket>, std::shared_ptr<OutgoingFile>> outgoings_ {};
+    std::map<std::shared_ptr<dhtnet::ChannelSocket>, std::shared_ptr<OutgoingFile>> outgoings_ {};
     std::map<std::string, std::shared_ptr<IncomingFile>> incomings_ {};
     std::map<std::pair<std::string, std::string>, std::shared_ptr<IncomingFile>> vcards_ {};
+
+    std::mt19937_64 rand_;
 };
 
-TransferManager::TransferManager(const std::string& accountId, const std::string& to)
-    : pimpl_ {std::make_unique<Impl>(accountId, to)}
+TransferManager::TransferManager(const std::string& accountId,
+                                 const std::string& accountUri,
+                                 const std::string& to,
+                                 const std::mt19937_64& rand)
+    : pimpl_ {std::make_unique<Impl>(accountId, accountUri, to, rand)}
 {}
 
 TransferManager::~TransferManager() {}
 
 void
-TransferManager::transferFile(const std::shared_ptr<ChannelSocket>& channel,
+TransferManager::transferFile(const std::shared_ptr<dhtnet::ChannelSocket>& channel,
                               const std::string& fileId,
                               const std::string& interactionId,
                               const std::string& path,
@@ -306,7 +336,7 @@ TransferManager::transferFile(const std::shared_ptr<ChannelSocket>& channel,
                               size_t end,
                               OnFinishedCb onFinished)
 {
-    std::lock_guard<std::mutex> lk {pimpl_->mapMutex_};
+    std::lock_guard lk {pimpl_->mapMutex_};
     if (pimpl_->outgoings_.find(channel) != pimpl_->outgoings_.end())
         return;
     libjami::DataTransferInfo info;
@@ -322,7 +352,7 @@ TransferManager::transferFile(const std::shared_ptr<ChannelSocket>& channel,
         dht::ThreadPool().computation().run([w, channel] {
             if (auto sthis_ = w.lock()) {
                 auto& pimpl = sthis_->pimpl_;
-                std::lock_guard<std::mutex> lk {pimpl->mapMutex_};
+                std::lock_guard lk {pimpl->mapMutex_};
                 auto itO = pimpl->outgoings_.find(channel);
                 if (itO != pimpl->outgoings_.end())
                     pimpl->outgoings_.erase(itO);
@@ -339,8 +369,7 @@ TransferManager::transferFile(const std::shared_ptr<ChannelSocket>& channel,
 bool
 TransferManager::cancel(const std::string& fileId)
 {
-    std::shared_ptr<ChannelSocket> channel;
-    std::lock_guard<std::mutex> lk {pimpl_->mapMutex_};
+    std::lock_guard lk {pimpl_->mapMutex_};
     // Remove from waiting, this avoid auto-download
     auto itW = pimpl_->waitingIds_.find(fileId);
     if (itW != pimpl_->waitingIds_.end()) {
@@ -356,23 +385,20 @@ TransferManager::cancel(const std::string& fileId)
 }
 
 bool
-TransferManager::info(const std::string& fileId,
-                      std::string& path,
-                      int64_t& total,
-                      int64_t& progress) const noexcept
+TransferManager::info(const std::string& fileId, std::string& path, int64_t& total, int64_t& progress) const noexcept
 {
-    std::unique_lock<std::mutex> lk {pimpl_->mapMutex_};
+    std::unique_lock lk {pimpl_->mapMutex_};
     if (pimpl_->to_.empty())
         return false;
 
     auto itI = pimpl_->incomings_.find(fileId);
     auto itW = pimpl_->waitingIds_.find(fileId);
-    path = this->path(fileId);
+    path = this->path(fileId).string();
     if (itI != pimpl_->incomings_.end()) {
         total = itI->second->info().totalSize;
         progress = itI->second->info().bytesProgress;
         return true;
-    } else if (fileutils::isFile(path)) {
+    } else if (std::filesystem::is_regular_file(path)) {
         std::ifstream transfer(path, std::ios::binary);
         transfer.seekg(0, std::ios::end);
         progress = transfer.tellg();
@@ -400,7 +426,7 @@ TransferManager::waitForTransfer(const std::string& fileId,
                                  const std::string& path,
                                  std::size_t total)
 {
-    std::unique_lock<std::mutex> lk(pimpl_->mapMutex_);
+    std::unique_lock lk(pimpl_->mapMutex_);
     auto itW = pimpl_->waitingIds_.find(fileId);
     if (itW != pimpl_->waitingIds_.end())
         return;
@@ -410,9 +436,10 @@ TransferManager::waitForTransfer(const std::string& fileId,
 
 void
 TransferManager::onIncomingFileTransfer(const std::string& fileId,
-                                        const std::shared_ptr<ChannelSocket>& channel)
+                                        const std::shared_ptr<dhtnet::ChannelSocket>& channel,
+                                        size_t start)
 {
-    std::lock_guard<std::mutex> lk(pimpl_->mapMutex_);
+    std::lock_guard lk(pimpl_->mapMutex_);
     // Check if not already an incoming file for this id and that we are waiting this file
     auto itC = pimpl_->incomings_.find(fileId);
     if (itC != pimpl_->incomings_.end()) {
@@ -421,7 +448,7 @@ TransferManager::onIncomingFileTransfer(const std::string& fileId,
     }
     auto itW = pimpl_->waitingIds_.find(fileId);
     if (itW == pimpl_->waitingIds_.end()) {
-        channel->shutdown();
+        dht::ThreadPool().io().run([channel] { channel->shutdown(); });
         return;
     }
 
@@ -430,21 +457,19 @@ TransferManager::onIncomingFileTransfer(const std::string& fileId,
     info.conversationId = pimpl_->to_;
     info.path = itW->second.path;
     info.totalSize = itW->second.totalSize;
+    info.bytesProgress = start;
 
     // Generate the file path within the conversation data directory
     // using the file id if no path has been specified, otherwise create
     // a symlink(Note: this will not work on Windows).
     auto filePath = path(fileId);
     if (info.path.empty()) {
-        info.path = filePath;
+        info.path = filePath.string();
     } else {
         // We don't need to check if this is an existing symlink here, as
         // the attempt to create one should report the error string correctly.
         fileutils::createFileLink(filePath, info.path);
     }
-    info.bytesProgress = fileutils::size(info.path);
-    if (info.bytesProgress < 0)
-        info.bytesProgress = 0;
 
     auto ifile = std::make_shared<IncomingFile>(std::move(channel),
                                                 info,
@@ -458,7 +483,7 @@ TransferManager::onIncomingFileTransfer(const std::string& fileId,
             dht::ThreadPool().computation().run([w, fileId, code] {
                 if (auto sthis_ = w.lock()) {
                     auto& pimpl = sthis_->pimpl_;
-                    std::lock_guard<std::mutex> lk {pimpl->mapMutex_};
+                    std::lock_guard lk {pimpl->mapMutex_};
                     auto itO = pimpl->incomings_.find(fileId);
                     if (itO != pimpl->incomings_.end())
                         pimpl->incomings_.erase(itO);
@@ -476,21 +501,21 @@ TransferManager::onIncomingFileTransfer(const std::string& fileId,
     }
 }
 
-std::string
+std::filesystem::path
 TransferManager::path(const std::string& fileId) const
 {
-    return pimpl_->conversationDataPath_ + DIR_SEPARATOR_STR + fileId;
+    return pimpl_->conversationDataPath_ / fileId;
 }
 
 void
-TransferManager::onIncomingProfile(const std::shared_ptr<ChannelSocket>& channel, const std::string& sha3Sum)
+TransferManager::onIncomingProfile(const std::shared_ptr<dhtnet::ChannelSocket>& channel, const std::string& sha3Sum)
 {
     if (!channel)
         return;
 
-    auto name = channel->name();
+    auto chName = channel->name();
+    std::string_view name = chName;
     auto sep = name.find_last_of('?');
-    std::string arguments;
     if (sep != std::string::npos)
         name = name.substr(0, sep);
 
@@ -503,10 +528,10 @@ TransferManager::onIncomingProfile(const std::shared_ptr<ChannelSocket>& channel
         return;
 
     auto uri = fileId == "profile.vcf" ? cert->issuer->getId().toString()
-                                       : fileId.substr(0, fileId.size() - 4 /*.vcf*/);
+                                       : std::string(fileId.substr(0, fileId.size() - 4 /*.vcf*/));
 
-    std::lock_guard<std::mutex> lk(pimpl_->mapMutex_);
-    auto idx = std::pair<std::string, std::string> {deviceId, uri};
+    std::lock_guard lk(pimpl_->mapMutex_);
+    auto idx = std::make_pair(deviceId, uri);
     // Check if not already an incoming file for this id and that we are waiting this file
     auto itV = pimpl_->vcards_.find(idx);
     if (itV != pimpl_->vcards_.end()) {
@@ -514,14 +539,14 @@ TransferManager::onIncomingProfile(const std::shared_ptr<ChannelSocket>& channel
         return;
     }
 
-    auto tid = generateUID();
+    auto tid = generateUID(pimpl_->rand_);
     libjami::DataTransferInfo info;
     info.accountId = pimpl_->accountId_;
     info.conversationId = pimpl_->to_;
 
-    auto recvDir = fmt::format("{:s}/{:s}/vcard/", fileutils::get_cache_dir(), pimpl_->accountId_);
-    fileutils::recursive_mkdir(recvDir);
-    info.path =  fmt::format("{:s}{:s}_{:s}_{}", recvDir, deviceId, uri, tid);
+    auto recvDir = fileutils::get_cache_dir() / pimpl_->accountId_ / "vcard";
+    dhtnet::fileutils::recursive_mkdir(recvDir);
+    info.path = (recvDir / fmt::format("{:s}_{:s}_{}", deviceId, uri, tid)).string();
 
     auto ifile = std::make_shared<IncomingFile>(std::move(channel), info, "profile.vcf", "", sha3Sum);
     auto res = pimpl_->vcards_.emplace(idx, std::move(ifile));
@@ -532,24 +557,38 @@ TransferManager::onIncomingProfile(const std::shared_ptr<ChannelSocket>& channel
                                        accountId = pimpl_->accountId_,
                                        cert = std::move(cert),
                                        path = info.path](uint32_t code) {
-            // schedule destroy transfer as not needed
             dht::ThreadPool().computation().run([w,
                                                  uri = std::move(uri),
                                                  deviceId = std::move(deviceId),
                                                  accountId = std::move(accountId),
-                                                 cert = std::move(cert),
                                                  path = std::move(path),
                                                  code] {
                 if (auto sthis_ = w.lock()) {
                     auto& pimpl = sthis_->pimpl_;
-                    std::lock_guard<std::mutex> lk {pimpl->mapMutex_};
+
+                    auto destPath = sthis_->profilePath(uri);
+                    try {
+                        // Move profile to destination path
+                        std::lock_guard lock(dhtnet::fileutils::getFileLock(destPath));
+                        dhtnet::fileutils::recursive_mkdir(destPath.parent_path());
+                        std::filesystem::rename(path, destPath);
+                        if (!pimpl->accountUri_.empty() && uri == pimpl->accountUri_) {
+                            // If this is the account profile, link or copy it to the account profile path
+                            if (!fileutils::createFileLink(pimpl->accountProfilePath_, destPath)) {
+                                std::error_code ec;
+                                std::filesystem::copy_file(destPath, pimpl->accountProfilePath_, ec);
+                            }
+                        }
+                    } catch (const std::exception& e) {
+                        JAMI_ERROR("{}", e.what());
+                    }
+
+                    std::lock_guard lk {pimpl->mapMutex_};
                     auto itO = pimpl->vcards_.find({deviceId, uri});
                     if (itO != pimpl->vcards_.end())
                         pimpl->vcards_.erase(itO);
                     if (code == uint32_t(libjami::DataTransferEventCode::finished)) {
-                        emitSignal<libjami::ConfigurationSignal::ProfileReceived>(accountId,
-                                                                                  uri,
-                                                                                  path);
+                        emitSignal<libjami::ConfigurationSignal::ProfileReceived>(accountId, uri, destPath.string());
                     }
                 }
             });
@@ -558,18 +597,17 @@ TransferManager::onIncomingProfile(const std::shared_ptr<ChannelSocket>& channel
     }
 }
 
-std::string
+std::filesystem::path
 TransferManager::profilePath(const std::string& contactId) const
 {
-    // TODO iOS?
-    return fmt::format("{}/{}.vcf", pimpl_->profilesPath_, base64::encode(contactId));
+    return pimpl_->profilesPath_ / fmt::format("{}.vcf", base64::encode(contactId));
 }
 
 std::vector<WaitingRequest>
 TransferManager::waitingRequests() const
 {
     std::vector<WaitingRequest> res;
-    std::lock_guard<std::mutex> lk(pimpl_->mapMutex_);
+    std::lock_guard lk(pimpl_->mapMutex_);
     for (const auto& [fileId, req] : pimpl_->waitingIds_) {
         auto itC = pimpl_->incomings_.find(fileId);
         if (itC == pimpl_->incomings_.end())
@@ -581,7 +619,7 @@ TransferManager::waitingRequests() const
 bool
 TransferManager::isWaiting(const std::string& fileId) const
 {
-    std::lock_guard<std::mutex> lk(pimpl_->mapMutex_);
+    std::lock_guard lk(pimpl_->mapMutex_);
     return pimpl_->waitingIds_.find(fileId) != pimpl_->waitingIds_.end();
 }
 
