@@ -1,15 +1,14 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
- *  Author : Adrien Béraud <adrien.beraud@savoirfairelinux.com>
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
@@ -36,9 +35,9 @@ ContactList::ContactList(const std::string& accountId,
                          const std::shared_ptr<crypto::Certificate>& cert,
                          const std::filesystem::path& path,
                          OnChangeCallback cb)
-    : path_(path)
+    : accountId_(accountId)
+    , path_(path)
     , callbacks_(std::move(cb))
-    , accountId_(accountId)
 {
     if (cert) {
         trust_ = std::make_unique<dhtnet::tls::TrustStore>(jami::Manager::instance().certStore(accountId_));
@@ -65,11 +64,12 @@ ContactList::save()
 }
 
 bool
-ContactList::setCertificateStatus(const std::string& cert_id,
-                                  const dhtnet::tls::TrustStore::PermissionStatus status)
+ContactList::setCertificateStatus(const std::string& cert_id, const dhtnet::tls::TrustStore::PermissionStatus status)
 {
     if (contacts_.find(dht::InfoHash(cert_id)) != contacts_.end()) {
-        JAMI_DBG("Can't set certificate status for existing contacts %s", cert_id.c_str());
+        JAMI_LOG("[Account {}] [Contacts] Unable to set certificate status for existing contacts {}",
+                 accountId_,
+                 cert_id);
         return false;
     }
     return trust_->setCertificateStatus(cert_id, status);
@@ -77,8 +77,8 @@ ContactList::setCertificateStatus(const std::string& cert_id,
 
 bool
 ContactList::setCertificateStatus(const std::shared_ptr<crypto::Certificate>& cert,
-                            dhtnet::tls::TrustStore::PermissionStatus status,
-                            bool local)
+                                  dhtnet::tls::TrustStore::PermissionStatus status,
+                                  bool local)
 {
     return trust_->setCertificateStatus(cert, status, local);
 }
@@ -86,7 +86,7 @@ ContactList::setCertificateStatus(const std::shared_ptr<crypto::Certificate>& ce
 bool
 ContactList::addContact(const dht::InfoHash& h, bool confirmed, const std::string& conversationId)
 {
-    JAMI_WARN("[Contacts] addContact: %s, conversation: %s", h.to_c_str(), conversationId.c_str());
+    JAMI_WARNING("[Account {}] [Contacts] addContact: {}, conversation: {}", accountId_, h, conversationId);
     auto c = contacts_.find(h);
     if (c == contacts_.end())
         c = contacts_.emplace(h, Contact {}).first;
@@ -107,11 +107,14 @@ ContactList::addContact(const dht::InfoHash& h, bool confirmed, const std::strin
 }
 
 void
-ContactList::updateConversation(const dht::InfoHash& h, const std::string& conversationId)
+ContactList::updateConversation(const dht::InfoHash& h, const std::string& conversationId, bool added)
 {
     auto c = contacts_.find(h);
-    if (c != contacts_.end()) {
+    if (c != contacts_.end() && c->second.conversationId != conversationId) {
         c->second.conversationId = conversationId;
+        if (added) {
+            c->second.added = std::time(nullptr);
+        }
         saveContacts();
     }
 }
@@ -119,7 +122,8 @@ ContactList::updateConversation(const dht::InfoHash& h, const std::string& conve
 bool
 ContactList::removeContact(const dht::InfoHash& h, bool ban)
 {
-    JAMI_WARN("[Contacts] removeContact: %s", h.to_c_str());
+    std::unique_lock lk(mutex_);
+    JAMI_WARNING("[Account {}] [Contacts] removeContact: {} (banned: {})", accountId_, h, ban);
     auto c = contacts_.find(h);
     if (c == contacts_.end())
         c = contacts_.emplace(h, Contact {}).first;
@@ -128,17 +132,15 @@ ContactList::removeContact(const dht::InfoHash& h, bool ban)
     c->second.banned = ban;
     auto uri = h.toString();
     trust_->setCertificateStatus(uri,
-                                ban ? dhtnet::tls::TrustStore::PermissionStatus::BANNED
-                                    : dhtnet::tls::TrustStore::PermissionStatus::UNDEFINED);
+                                 ban ? dhtnet::tls::TrustStore::PermissionStatus::BANNED
+                                     : dhtnet::tls::TrustStore::PermissionStatus::UNDEFINED);
     if (trustRequests_.erase(h) > 0)
         saveTrustRequests();
     saveContacts();
+    lk.unlock();
 #ifdef ENABLE_PLUGIN
     auto filename = path_.filename().string();
-    jami::Manager::instance()
-        .getJamiPluginManager()
-        .getChatServicesManager()
-        .cleanChatSubjects(filename, uri);
+    jami::Manager::instance().getJamiPluginManager().getChatServicesManager().cleanChatSubjects(filename, uri);
 #endif
     callbacks_.contactRemoved(uri, ban);
     return true;
@@ -160,7 +162,7 @@ ContactList::getContactDetails(const dht::InfoHash& h) const
 {
     const auto c = contacts_.find(h);
     if (c == std::end(contacts_)) {
-        JAMI_WARN("[Contacts] contact '%s' not found", h.to_c_str());
+        JAMI_WARNING("[Account {}] [Contacts] Contact '{}' not found", accountId_, h.to_view());
         return {};
     }
 
@@ -171,6 +173,17 @@ ContactList::getContactDetails(const dht::InfoHash& h) const
     return details;
 }
 
+std::optional<Contact>
+ContactList::getContactInfo(const dht::InfoHash& h) const
+{
+    const auto c = contacts_.find(h);
+    if (c == std::end(contacts_)) {
+        JAMI_WARNING("[Account {}] [Contacts] Contact '{}' not found", accountId_, h.to_view());
+        return {};
+    }
+    return c->second;
+}
+
 const std::map<dht::InfoHash, Contact>&
 ContactList::getContacts() const
 {
@@ -180,6 +193,10 @@ ContactList::getContacts() const
 void
 ContactList::setContacts(const std::map<dht::InfoHash, Contact>& contacts)
 {
+    JAMI_LOG("[Account {}] [Contacts] replacing contact list (old: {} new: {})",
+             accountId_,
+             contacts_.size(),
+             contacts.size());
     contacts_ = contacts;
     saveContacts();
     // Set contacts is used when creating a new device, so just announce new contacts
@@ -189,33 +206,37 @@ ContactList::setContacts(const std::map<dht::InfoHash, Contact>& contacts)
 }
 
 void
-ContactList::updateContact(const dht::InfoHash& id, const Contact& contact)
+ContactList::updateContact(const dht::InfoHash& id, const Contact& contact, bool emit)
 {
     if (not id) {
-        JAMI_ERR("[Contacts] updateContact: invalid contact ID");
+        JAMI_ERROR("[Account {}] [Contacts] updateContact: invalid contact ID", accountId_);
         return;
     }
     bool stateChanged {false};
     auto c = contacts_.find(id);
     if (c == contacts_.end()) {
-        // JAMI_DBG("[Contacts] new contact: %s", id.toString().c_str());
+        // JAMI_DBG("[Contacts] New contact: %s", id.toString().c_str());
         c = contacts_.emplace(id, contact).first;
         stateChanged = c->second.isActive() or c->second.isBanned();
     } else {
-        JAMI_DBG("[Contacts] updated contact: %s", id.toString().c_str());
+        // JAMI_DBG("[Contacts] Updated contact: %s", id.toString().c_str());
         stateChanged = c->second.update(contact);
     }
     if (stateChanged) {
-        if (trustRequests_.erase(id) > 0)
-            saveTrustRequests();
+        {
+            std::lock_guard lk(mutex_);
+            if (trustRequests_.erase(id) > 0)
+                saveTrustRequests();
+        }
         if (c->second.isActive()) {
             trust_->setCertificateStatus(id.toString(), dhtnet::tls::TrustStore::PermissionStatus::ALLOWED);
-            callbacks_.contactAdded(id.toString(), c->second.confirmed);
+            if (emit)
+                callbacks_.contactAdded(id.toString(), c->second.confirmed);
         } else {
             if (c->second.banned)
-                trust_->setCertificateStatus(id.toString(),
-                                            dhtnet::tls::TrustStore::PermissionStatus::BANNED);
-            callbacks_.contactRemoved(id.toString(), c->second.banned);
+                trust_->setCertificateStatus(id.toString(), dhtnet::tls::TrustStore::PermissionStatus::BANNED);
+            if (emit)
+                callbacks_.contactRemoved(id.toString(), c->second.banned);
         }
     }
 }
@@ -231,17 +252,19 @@ ContactList::loadContacts()
         msgpack::object_handle oh = msgpack::unpack((const char*) file.data(), file.size());
         oh.get().convert(contacts);
     } catch (const std::exception& e) {
-        JAMI_WARN("[Contacts] error loading contacts: %s", e.what());
+        JAMI_WARNING("[Account {}] [Contacts] Error loading contacts: {}", accountId_, e.what());
         return;
     }
 
+    JAMI_WARNING("[Account {}] [Contacts] Loaded {} contacts", accountId_, contacts.size());
     for (auto& peer : contacts)
-        updateContact(peer.first, peer.second);
+        updateContact(peer.first, peer.second, false);
 }
 
 void
 ContactList::saveContacts() const
 {
+    JAMI_LOG("[Account {}] [Contacts] saving {} contacts", accountId_, contacts_.size());
     std::ofstream file(path_ / "contacts", std::ios::trunc | std::ios::binary);
     msgpack::pack(file, contacts_);
 }
@@ -249,8 +272,8 @@ ContactList::saveContacts() const
 void
 ContactList::saveTrustRequests() const
 {
-    std::ofstream file(path_ / "incomingTrustRequests",
-                       std::ios::trunc | std::ios::binary);
+    // mutex_ MUST BE locked
+    std::ofstream file(path_ / "incomingTrustRequests", std::ios::trunc | std::ios::binary);
     msgpack::pack(file, trustRequests_);
 }
 
@@ -267,10 +290,11 @@ ContactList::loadTrustRequests()
         msgpack::object_handle oh = msgpack::unpack((const char*) file.data(), file.size());
         oh.get().convert(requests);
     } catch (const std::exception& e) {
-        JAMI_WARN("[Contacts] error loading trust requests: %s", e.what());
+        JAMI_WARNING("[Account {}] [Contacts] Error loading trust requests: {}", accountId_, e.what());
         return;
     }
 
+    JAMI_WARNING("[Account {}] [Contacts] Loaded {} contact requests", accountId_, requests.size());
     for (auto& tr : requests)
         onTrustRequest(tr.first,
                        tr.second.device,
@@ -290,6 +314,7 @@ ContactList::onTrustRequest(const dht::InfoHash& peer_account,
 {
     bool accept = false;
     // Check existing contact
+    std::unique_lock lk(mutex_);
     auto contact = contacts_.find(peer_account);
     bool active = false;
     if (contact != contacts_.end()) {
@@ -304,6 +329,7 @@ ContactList::onTrustRequest(const dht::InfoHash& peer_account,
                 accept = true;
             if (not contact->second.confirmed) {
                 contact->second.confirmed = true;
+                saveContacts();
                 callbacks_.contactAdded(peer_account.toString(), true);
             }
         }
@@ -312,29 +338,25 @@ ContactList::onTrustRequest(const dht::InfoHash& peer_account,
         auto req = trustRequests_.find(peer_account);
         if (req == trustRequests_.end()) {
             // Add trust request
-            req = trustRequests_
-                      .emplace(peer_account,
-                               TrustRequest {peer_device, conversationId, received, payload})
+            req = trustRequests_.emplace(peer_account, TrustRequest {peer_device, conversationId, received, payload})
                       .first;
         } else {
             // Update trust request
-            if (received < req->second.received) {
+            if (received > req->second.received) {
                 req->second.device = peer_device;
+                req->second.conversationId = conversationId;
                 req->second.received = received;
                 req->second.payload = payload;
             } else {
-                JAMI_DBG("[Contacts] Ignoring outdated trust request from %s",
-                         peer_account.toString().c_str());
+                JAMI_LOG("[Account {}] [Contacts] Ignoring outdated trust request from {}", accountId_, peer_account);
             }
         }
         saveTrustRequests();
     }
+    lk.unlock();
     // Note: call JamiAccount's callback to build ConversationRequest anyway
     if (!confirm)
-        callbacks_.trustRequest(peer_account.toString(),
-                                conversationId,
-                                std::move(payload),
-                                received);
+        callbacks_.trustRequest(peer_account.toString(), conversationId, std::move(payload), received);
     else if (active) {
         // Only notify if confirmed + not removed
         callbacks_.onConfirmation(peer_account.toString(), conversationId);
@@ -349,14 +371,14 @@ ContactList::getTrustRequests() const
 {
     using Map = std::map<std::string, std::string>;
     std::vector<Map> ret;
+    std::lock_guard lk(mutex_);
     ret.reserve(trustRequests_.size());
     for (const auto& r : trustRequests_) {
-        ret.emplace_back(
-            Map {{libjami::Account::TrustRequest::FROM, r.first.toString()},
-                 {libjami::Account::TrustRequest::RECEIVED, std::to_string(r.second.received)},
-                 {libjami::Account::TrustRequest::CONVERSATIONID, r.second.conversationId},
-                 {libjami::Account::TrustRequest::PAYLOAD,
-                  std::string(r.second.payload.begin(), r.second.payload.end())}});
+        ret.emplace_back(Map {{libjami::Account::TrustRequest::FROM, r.first.toString()},
+                              {libjami::Account::TrustRequest::RECEIVED, std::to_string(r.second.received)},
+                              {libjami::Account::TrustRequest::CONVERSATIONID, r.second.conversationId},
+                              {libjami::Account::TrustRequest::PAYLOAD,
+                               std::string(r.second.payload.begin(), r.second.payload.end())}});
     }
     return ret;
 }
@@ -365,6 +387,7 @@ std::map<std::string, std::string>
 ContactList::getTrustRequest(const dht::InfoHash& from) const
 {
     using Map = std::map<std::string, std::string>;
+    std::lock_guard lk(mutex_);
     auto r = trustRequests_.find(from);
     if (r == trustRequests_.end())
         return {};
@@ -379,26 +402,30 @@ bool
 ContactList::acceptTrustRequest(const dht::InfoHash& from)
 {
     // The contact sent us a TR so we are in its contact list
+    std::unique_lock lk(mutex_);
     auto i = trustRequests_.find(from);
     if (i == trustRequests_.end())
         return false;
-    addContact(from, true, i->second.conversationId);
+    auto convId = i->second.conversationId;
     // Clear trust request
     trustRequests_.erase(i);
     saveTrustRequests();
+    lk.unlock();
+    addContact(from, true, convId);
     return true;
 }
 
 void
-ContactList::acceptConversation(const std::string& convId)
+ContactList::acceptConversation(const std::string& convId, const std::string& deviceId)
 {
     if (callbacks_.acceptConversation)
-        callbacks_.acceptConversation(convId);
+        callbacks_.acceptConversation(convId, deviceId);
 }
 
 bool
 ContactList::discardTrustRequest(const dht::InfoHash& from)
 {
+    std::lock_guard lk(mutex_);
     if (trustRequests_.erase(from) > 0) {
         saveTrustRequests();
         return true;
@@ -409,6 +436,7 @@ ContactList::discardTrustRequest(const dht::InfoHash& from)
 void
 ContactList::loadKnownDevices()
 {
+    auto& certStore = jami::Manager::instance().certStore(accountId_);
     try {
         // read file
         auto file = fileutils::loadFile("knownDevices", path_);
@@ -418,32 +446,18 @@ ContactList::loadKnownDevices()
         std::map<dht::PkId, std::pair<std::string, uint64_t>> knownDevices;
         oh.get().convert(knownDevices);
         for (const auto& d : knownDevices) {
-            if (auto crt = jami::Manager::instance().certStore(accountId_).getCertificate(d.first.toString())) {
-                if (not foundAccountDevice(crt, d.second.first, clock::from_time_t(d.second.second)))
-                    JAMI_WARN("[Contacts] can't add device %s", d.first.toString().c_str());
+            if (auto crt = certStore.getCertificate(d.first.toString())) {
+                if (not foundAccountDevice(crt, d.second.first, clock::from_time_t(d.second.second), false))
+                    JAMI_WARNING("[Account {}] [Contacts] Unable to add device {}", accountId_, d.first);
             } else {
-                JAMI_WARN("[Contacts] can't find certificate for device %s",
-                          d.first.toString().c_str());
+                JAMI_WARNING("[Account {}] [Contacts] Unable to find certificate for device {}", accountId_, d.first);
             }
         }
+        if (not knownDevices.empty()) {
+            callbacks_.devicesChanged(knownDevices_);
+        }
     } catch (const std::exception& e) {
-        // Legacy fallback
-        try {
-            auto file = fileutils::loadFile("knownDevicesNames", path_);
-            msgpack::object_handle oh = msgpack::unpack((const char*) file.data(), file.size());
-            std::map<dht::InfoHash, std::pair<std::string, uint64_t>> knownDevices;
-            oh.get().convert(knownDevices);
-            for (const auto& d : knownDevices) {
-                if (auto crt = jami::Manager::instance().certStore(accountId_).getCertificate(d.first.toString())) {
-                    if (not foundAccountDevice(crt,
-                                               d.second.first,
-                                               clock::from_time_t(d.second.second)))
-                        JAMI_WARN("[Contacts] can't add device %s", d.first.toString().c_str());
-                }
-            }
-        } catch (const std::exception& e) {
-            JAMI_WARN("[Contacts] error loading devices: %s", e.what());
-        }
+        JAMI_WARNING("[Account {}] [Contacts] Error loading devices: {}", accountId_, e.what());
         return;
     }
 }
@@ -454,30 +468,26 @@ ContactList::saveKnownDevices() const
     std::ofstream file(path_ / "knownDevices", std::ios::trunc | std::ios::binary);
 
     std::map<dht::PkId, std::pair<std::string, uint64_t>> devices;
-    for (const auto& id : knownDevices_)
-        devices.emplace(id.first,
-                        std::make_pair(id.second.name, clock::to_time_t(id.second.last_sync)));
+    for (const auto& id : knownDevices_) {
+        devices.emplace(id.first, std::make_pair(id.second.name, clock::to_time_t(id.second.last_sync)));
+    }
 
     msgpack::pack(file, devices);
 }
 
 void
-ContactList::foundAccountDevice(const dht::PkId& device,
-                                const std::string& name,
-                                const time_point& updated)
+ContactList::foundAccountDevice(const dht::PkId& device, const std::string& name, const time_point& updated)
 {
     // insert device
     auto it = knownDevices_.emplace(device, KnownDevice {{}, name, updated});
     if (it.second) {
-        JAMI_DBG("[Contacts] Found account device: %s %s", name.c_str(), device.toString().c_str());
+        JAMI_LOG("[Account {}] [Contacts] Found account device: {} {}", accountId_, name, device);
         saveKnownDevices();
         callbacks_.devicesChanged(knownDevices_);
     } else {
         // update device name
         if (not name.empty() and it.first->second.name != name) {
-            JAMI_DBG("[Contacts] updating device name: %s %s",
-                     name.c_str(),
-                     device.toString().c_str());
+            JAMI_LOG("[Account {}] [Contacts] Updating device name: {} {}", accountId_, name, device);
             it.first->second.name = name;
             saveKnownDevices();
             callbacks_.devicesChanged(knownDevices_);
@@ -488,7 +498,8 @@ ContactList::foundAccountDevice(const dht::PkId& device,
 bool
 ContactList::foundAccountDevice(const std::shared_ptr<dht::crypto::Certificate>& crt,
                                 const std::string& name,
-                                const time_point& updated)
+                                const time_point& updated,
+                                bool notify)
 {
     if (not crt)
         return false;
@@ -498,33 +509,38 @@ ContactList::foundAccountDevice(const std::shared_ptr<dht::crypto::Certificate>&
     // match certificate chain
     auto verifyResult = accountTrust_.verify(*crt);
     if (not verifyResult) {
-        JAMI_WARN("[Contacts] Found invalid account device: %s: %s",
-                  id.toString().c_str(),
-                  verifyResult.toString().c_str());
+        JAMI_WARNING("[Account {}] [Contacts] Found invalid account device: {:s}: {:s}",
+                     accountId_,
+                     id,
+                     verifyResult.toString());
         return false;
     }
 
     // insert device
     auto it = knownDevices_.emplace(id, KnownDevice {crt, name, updated});
     if (it.second) {
-        JAMI_DBG("[Contacts] Found account device: %s %s", name.c_str(), id.toString().c_str());
+        JAMI_LOG("[Account {}] [Contacts] Found account device: {} {}", accountId_, name, id);
         jami::Manager::instance().certStore(accountId_).pinCertificate(crt);
         if (crt->ocspResponse) {
             unsigned int status = crt->ocspResponse->getCertificateStatus();
             if (status == GNUTLS_OCSP_CERT_REVOKED) {
-                JAMI_ERR("Certificate %s has revoked OCSP status", id.to_c_str());
+                JAMI_ERROR("[Account {}] Certificate {} has revoked OCSP status", accountId_, id);
                 trust_->setCertificateStatus(crt, dhtnet::tls::TrustStore::PermissionStatus::BANNED, false);
             }
         }
-        saveKnownDevices();
-        callbacks_.devicesChanged(knownDevices_);
+        if (notify) {
+            saveKnownDevices();
+            callbacks_.devicesChanged(knownDevices_);
+        }
     } else {
         // update device name
         if (not name.empty() and it.first->second.name != name) {
-            JAMI_DBG("[Contacts] updating device name: %s %s", name.c_str(), id.to_c_str());
+            JAMI_LOG("[Account {}] [Contacts] updating device name: {} {}", accountId_, name, id);
             it.first->second.name = name;
-            saveKnownDevices();
-            callbacks_.devicesChanged(knownDevices_);
+            if (notify) {
+                saveKnownDevices();
+                callbacks_.devicesChanged(knownDevices_);
+            }
         }
     }
     return true;
@@ -572,32 +588,31 @@ ContactList::getSyncData() const
     sync_data.peers = getContacts();
 
     static constexpr size_t MAX_TRUST_REQUESTS = 20;
+    std::lock_guard lk(mutex_);
     if (trustRequests_.size() <= MAX_TRUST_REQUESTS)
         for (const auto& req : trustRequests_)
-            sync_data.trust_requests.emplace(req.first,
-                                             TrustRequest {req.second.device,
-                                                           req.second.conversationId,
-                                                           req.second.received,
-                                                           {}});
+            sync_data.trust_requests
+                .emplace(req.first,
+                         TrustRequest {req.second.device, req.second.conversationId, req.second.received, {}});
     else {
         size_t inserted = 0;
         auto req = trustRequests_.lower_bound(dht::InfoHash::getRandom());
         while (inserted++ < MAX_TRUST_REQUESTS) {
             if (req == trustRequests_.end())
                 req = trustRequests_.begin();
-            sync_data.trust_requests.emplace(req->first,
-                                             TrustRequest {req->second.device,
-                                                           req->second.conversationId,
-                                                           req->second.received,
-                                                           {}});
+            sync_data.trust_requests
+                .emplace(req->first,
+                         TrustRequest {req->second.device, req->second.conversationId, req->second.received, {}});
             ++req;
         }
     }
 
     for (const auto& dev : knownDevices_) {
-        sync_data.devices.emplace(dev.second.certificate->getLongId(),
-                                  KnownDeviceSync {dev.second.name,
-                                                   dev.second.certificate->getId()});
+        if (!dev.second.certificate) {
+            JAMI_WARNING("[Account {}] [Contacts] No certificate found for {}", accountId_, dev.first);
+            continue;
+        }
+        sync_data.devices.emplace(dev.second.certificate->getLongId(), KnownDeviceSync {dev.second.name});
     }
     return sync_data;
 }
@@ -607,11 +622,11 @@ ContactList::syncDevice(const dht::PkId& device, const time_point& syncDate)
 {
     auto it = knownDevices_.find(device);
     if (it == knownDevices_.end()) {
-        JAMI_WARN("[Contacts] dropping sync data from unknown device");
+        JAMI_WARNING("[Account {}] [Contacts] Dropping sync data from unknown device", accountId_);
         return false;
     }
     if (it->second.last_sync >= syncDate) {
-        JAMI_DBG("[Contacts] dropping outdated sync data");
+        JAMI_LOG("[Account {}] [Contacts] Dropping outdated sync data", accountId_);
         return false;
     }
     it->second.last_sync = syncDate;
