@@ -1,27 +1,27 @@
 /*
- *  Copyright (C) 2014-2023 Savoir-faire Linux Inc.
+ * Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Adrien Béraud <adrien.beraud@savoirfairelinux.com>
- *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
- *  (at your option) any later version.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program. If not, see <https://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
+
 #pragma once
 
 #include "jamidht/conversationrepository.h"
 #include "conversationrepository.h"
 #include "swarm/swarm_protocol.h"
+#include "jami/conversation_interface.h"
+#include "jamidht/typers.h"
 
 #include <json/json.h>
 #include <msgpack.hpp>
@@ -35,6 +35,10 @@
 
 #include <asio.hpp>
 
+namespace dhtnet {
+class ChannelSocket;
+} // namespace dhtnet
+
 namespace jami {
 
 namespace ConversationMapKeys {
@@ -87,10 +91,12 @@ struct ConversationRequest
         return m.size() == om.size() && std::equal(m.begin(), m.end(), om.begin());
     }
 
-    bool isOneToOne() const {
+    bool isOneToOne() const
+    {
         try {
             return metadatas.at("mode") == "0";
-        } catch (...) {}
+        } catch (...) {
+        }
         return true;
     }
 
@@ -103,11 +109,20 @@ struct ConvInfo
     time_t created {0};
     time_t removed {0};
     time_t erased {0};
-    std::vector<std::string> members;
+    std::set<std::string> members;
     std::string lastDisplayed {};
 
     ConvInfo() = default;
-    ConvInfo(const Json::Value& json);
+    ConvInfo(const ConvInfo&) = default;
+    ConvInfo(ConvInfo&&) = default;
+    ConvInfo(const std::string& id)
+        : id(id) {};
+    explicit ConvInfo(const Json::Value& json);
+
+    bool isRemoved() const { return removed >= created; }
+
+    ConvInfo& operator=(const ConvInfo&) = default;
+    ConvInfo& operator=(ConvInfo&&) = default;
 
     Json::Value toJson() const;
 
@@ -117,20 +132,19 @@ struct ConvInfo
 class JamiAccount;
 class ConversationRepository;
 class TransferManager;
-class ChannelSocket;
 enum class ConversationMode;
 
 using OnPullCb = std::function<void(bool fetchOk)>;
-using OnLoadMessages
-    = std::function<void(std::vector<std::map<std::string, std::string>>&& messages)>;
+using OnLoadMessages = std::function<void(std::vector<std::map<std::string, std::string>>&& messages)>;
+using OnLoadMessages2 = std::function<void(std::vector<libjami::SwarmMessage>&& messages)>;
 using OnCommitCb = std::function<void(const std::string&)>;
 using OnDoneCb = std::function<void(bool, const std::string&)>;
 using OnMultiDoneCb = std::function<void(const std::vector<std::string>&)>;
+using OnMembersChanged = std::function<void(const std::set<std::string>&)>;
 using DeviceId = dht::PkId;
-using GitSocketList = std::map<DeviceId, std::shared_ptr<ChannelSocket>>;
-using ChannelCb = std::function<bool(const std::shared_ptr<ChannelSocket>&)>;
-using NeedSocketCb
-    = std::function<void(const std::string&, const std::string&, ChannelCb&&, const std::string&)>;
+using GitSocketList = std::map<DeviceId, std::shared_ptr<dhtnet::ChannelSocket>>;
+using ChannelCb = std::function<bool(const std::shared_ptr<dhtnet::ChannelSocket>&)>;
+using NeedSocketCb = std::function<void(const std::string&, const std::string&, ChannelCb&&, const std::string&)>;
 
 class Conversation : public std::enable_shared_from_this<Conversation>
 {
@@ -138,8 +152,7 @@ public:
     Conversation(const std::shared_ptr<JamiAccount>& account,
                  ConversationMode mode,
                  const std::string& otherMember = "");
-    Conversation(const std::shared_ptr<JamiAccount>& account,
-                 const std::string& conversationId = "");
+    Conversation(const std::shared_ptr<JamiAccount>& account, const std::string& conversationId = "");
     Conversation(const std::shared_ptr<JamiAccount>& account,
                  const std::string& remoteDevice,
                  const std::string& conversationId);
@@ -150,7 +163,7 @@ public:
      */
     void monitor();
 
-#ifdef LIBJAMI_TESTABLE
+#ifdef LIBJAMI_TEST
     enum class BootstrapStatus { FAILED, FALLBACK, SUCCESS };
     /**
      * Used by the tests to get whenever the DRT is connected/disconnected
@@ -160,10 +173,10 @@ public:
 
     /**
      * Bootstrap swarm manager to other peers
-     * @param onBootstraped     Callback called when connection is successfully established
-     * @param knownDevices      List of account's known devices
+     * @param onBootstrapped     Callback called when connection is established successfully
+     * @param knownDevices       List of account's known devices
      */
-    void bootstrap(std::function<void()> onBootstraped, const std::vector<DeviceId>& knownDevices);
+    void bootstrap(std::function<void()> onBootstrapped, const std::vector<DeviceId>& knownDevices);
 
     /**
      * Refresh active calls.
@@ -171,15 +184,9 @@ public:
      * and commit all the crashed calls
      * @return  Commits added
      */
-    std::vector<std::string> refreshActiveCalls();
+    std::vector<std::string> commitsEndedCalls();
 
-    /**
-     * Add a callback to update upper layers
-     * @note to call after the construction (and before ConversationReady)
-     * @param lastDisplayedUpdatedCb    Triggered when last displayed for account is updated
-     */
-    void onLastDisplayedUpdated(
-        std::function<void(const std::string&, const std::string&)>&& lastDisplayedUpdatedCb);
+    void onMembersChanged(OnMembersChanged&& cb);
 
     /**
      * Set the callback that will be called whenever a new socket will be needed
@@ -190,7 +197,7 @@ public:
      * Add swarm connection to the DRT
      * @param channel       Related channel
      */
-    void addSwarmChannel(std::shared_ptr<ChannelSocket> channel);
+    void addSwarmChannel(std::shared_ptr<dhtnet::ChannelSocket> channel);
 
     /**
      * Get conversation's id
@@ -227,11 +234,10 @@ public:
      * @param filteredRoles    If we want to ignore some roles
      * @return members' uris
      */
-    std::vector<std::string> memberUris(
-        std::string_view filter = {},
-        const std::set<MemberRole>& filteredRoles = {MemberRole::INVITED,
-                                                     MemberRole::LEFT,
-                                                     MemberRole::BANNED}) const;
+    std::set<std::string> memberUris(std::string_view filter = {},
+                                     const std::set<MemberRole>& filteredRoles = {MemberRole::INVITED,
+                                                                                  MemberRole::LEFT,
+                                                                                  MemberRole::BANNED}) const;
 
     /**
      * Get peers to sync with. This is mostly managed by the DRT
@@ -242,7 +248,7 @@ public:
      * Check if we're at least connected to one node
      * @return if the DRT is connected
      */
-    bool isBootstraped() const;
+    bool isBootstrapped() const;
     /**
      * Retrieve the uri from a deviceId
      * @note used by swarm manager (peersToSyncWith)
@@ -282,7 +288,17 @@ public:
      * @param cb        The callback when loaded
      * @param options   The log options
      */
-    void loadMessages(const OnLoadMessages& cb, const LogOptions& options);
+    void loadMessages(OnLoadMessages cb, const LogOptions& options);
+    /**
+     * Get a range of messages
+     * @param cb        The callback when loaded
+     * @param options   The log options
+     */
+    void loadMessages2(const OnLoadMessages2& cb, const LogOptions& options);
+    /**
+     * Clear all cached messages
+     */
+    void clearCache();
     /**
      * Retrieve one commit
      * @param   commitId
@@ -300,8 +316,9 @@ public:
      * @param deviceId  Peer device
      * @param cb        On pulled callback
      * @param commitId  Commit id that triggered this fetch
+     * @return true if callback will be called later
      */
-    void pull(const std::string& deviceId, OnPullCb&& cb, std::string commitId = "");
+    bool pull(const std::string& deviceId, OnPullCb&& cb, std::string commitId = "");
     /**
      * Fetch new commits and re-ask for waiting files
      * @param member
@@ -309,10 +326,7 @@ public:
      * @param cb        cf pull()
      * @param commitId  cf pull()
      */
-    void sync(const std::string& member,
-              const std::string& deviceId,
-              OnPullCb&& cb,
-              std::string commitId = "");
+    void sync(const std::string& member, const std::string& deviceId, OnPullCb&& cb, std::string commitId = "");
 
     /**
      * Generate an invitation to send to new contacts
@@ -399,7 +413,8 @@ public:
      */
     bool onFileChannelRequest(const std::string& member,
                               const std::string& fileId,
-                              bool verifyShaSum = true) const;
+                              std::filesystem::path& path,
+                              std::string& sha3sum) const;
     /**
      * Adds a file to the waiting list and ask members
      * @param interactionId     Related interaction id
@@ -407,29 +422,20 @@ public:
      * @param path              Destination
      * @param member            Member if we know from who to pull file
      * @param deviceId          Device if we know from who to pull file
-     * @param start             Offset (unused for now)
-     * @param end               Offset (unused)
      * @return id of the file
      */
     bool downloadFile(const std::string& interactionId,
                       const std::string& fileId,
                       const std::string& path,
                       const std::string& member = "",
-                      const std::string& deviceId = "",
-                      std::size_t start = 0,
-                      std::size_t end = 0);
+                      const std::string& deviceId = "");
 
     /**
-     * Reset fetched informations
+     * Reset fetched information
      */
     void clearFetched();
     /**
-     * Check if a device has fetched last commit
-     * @param deviceId
-     */
-    bool needsFetch(const std::string& deviceId) const;
-    /**
-     * Store informations about who fetch or not. This simplify sync (sync when a device without the
+     * Store information about who fetch or not. This simplify sync (sync when a device without the
      * last fetch is detected)
      * @param deviceId
      * @param commitId
@@ -443,24 +449,32 @@ public:
      * @return if updated
      */
     bool setMessageDisplayed(const std::string& uri, const std::string& interactionId);
-
     /**
-     * Compute, with multi device support the last message displayed of a conversation
-     * @param lastDisplayed      Latest displayed interaction
+     * Retrieve last displayed and fetch status per member
+     * @return A map with the following structure:
+     * {uri, {
+     *          {"fetch", "commitId"},
+     *          {"fetched_ts", "timestamp"},
+     *          {"read", "commitId"},
+     *          {"read_ts", "timestamp"}
+     *       }
+     * }
      */
-    void updateLastDisplayed(const std::string& lastDisplayed);
-
+    std::map<std::string, std::map<std::string, std::string>> messageStatus() const;
     /**
-     * Change last displayed for multiple uris
-     * @param map       New last displayed
+     * Update fetch/read status
+     * @param messageStatus     A map with the following structure:
+     * {uri, {
+     *          {"fetch", "commitId"},
+     *          {"fetched_ts", "timestamp"},
+     *          {"read", "commitId"},
+     *          {"read_ts", "timestamp"}
+     *       }
+     * }
      */
-    void updateLastDisplayed(const std::map<std::string, std::string>& map);
-    /**
-     * Retrieve last displayed id
-     * @return displayed
-     */
-    std::map<std::string, std::string> displayed() const;
-
+    void updateMessageStatus(const std::map<std::string, std::map<std::string, std::string>>& messageStatus);
+    void onMessageStatusChanged(
+        const std::function<void(const std::map<std::string, std::map<std::string, std::string>>&)>& cb);
     /**
      * Retrieve how many interactions there is from HEAD to interactionId
      * @param toId      "" for getting the whole history
@@ -471,7 +485,6 @@ public:
     uint32_t countInteractions(const std::string& toId,
                                const std::string& fromId = "",
                                const std::string& authorUri = "") const;
-
     /**
      * Search in the conversation via a filter
      * @param req       Id of the request
@@ -479,9 +492,7 @@ public:
      * @param flag      To check when search is finished
      * @note triggers messagesFound
      */
-    void search(uint32_t req,
-                const Filter& filter,
-                const std::shared_ptr<std::atomic_int>& flag) const;
+    void search(uint32_t req, const Filter& filter, const std::shared_ptr<std::atomic_int>& flag) const;
     /**
      * Host a conference in the conversation
      * @note the message must have "confId"
@@ -515,8 +526,8 @@ public:
      * Because libgit2 is a C library, we store the pointer in the corresponding conversation
      * and the GitTransport will inject to libgit2 whenever needed
      */
-    std::shared_ptr<ChannelSocket> gitSocket(const DeviceId& deviceId) const;
-    void addGitSocket(const DeviceId& deviceId, const std::shared_ptr<ChannelSocket>& socket);
+    std::shared_ptr<dhtnet::ChannelSocket> gitSocket(const DeviceId& deviceId) const;
+    void addGitSocket(const DeviceId& deviceId, const std::shared_ptr<dhtnet::ChannelSocket>& socket);
     void removeGitSocket(const DeviceId& deviceId);
 
     /**
@@ -535,19 +546,24 @@ public:
      */
     void connectivityChanged();
 
+    /**
+     * @return getAllNodes()    Nodes that are linked to the conversation
+     */
+    std::vector<jami::DeviceId> getDeviceIdList() const;
+
+    /**
+     * Get Typers object
+     * @return Typers object
+     */
+    std::shared_ptr<Typers> typers() const;
+
 private:
-    std::shared_ptr<Conversation> shared()
-    {
-        return std::static_pointer_cast<Conversation>(shared_from_this());
-    }
+    std::shared_ptr<Conversation> shared() { return std::static_pointer_cast<Conversation>(shared_from_this()); }
     std::shared_ptr<Conversation const> shared() const
     {
         return std::static_pointer_cast<Conversation const>(shared_from_this());
     }
-    std::weak_ptr<Conversation> weak()
-    {
-        return std::static_pointer_cast<Conversation>(shared_from_this());
-    }
+    std::weak_ptr<Conversation> weak() { return std::static_pointer_cast<Conversation>(shared_from_this()); }
     std::weak_ptr<Conversation const> weak() const
     {
         return std::static_pointer_cast<Conversation const>(shared_from_this());
@@ -559,8 +575,7 @@ private:
      * @param ec
      * @param members       Members to try to connect
      */
-    void checkBootstrapMember(const asio::error_code& ec,
-                              std::vector<std::map<std::string, std::string>> members);
+    void checkBootstrapMember(const asio::error_code& ec, std::vector<std::map<std::string, std::string>> members);
 
     class Impl;
     std::unique_ptr<Impl> pimpl_;
