@@ -1,74 +1,67 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Adrien Béraud <adrien.beraud@savoirfairelinux.com>
- *  Author: Simon Désaulniers <simon.desaulniers@gmail.com>
- *  Author: Guillaume Roguez <guillaume.roguez@savoirfairelinux.com>
- *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
-
 #pragma once
 
+#include "def.h"
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include "connectivity/security/tls_session.h"
-#include "connectivity/security/diffie-hellman.h"
 #include "sip/sipaccountbase.h"
 #include "jami/datatransfer_interface.h"
 #include "jamidht/conversation.h"
-#include "connectivity/multiplexed_socket.h"
 #include "data_transfer.h"
 #include "uri.h"
 #include "jamiaccount_config.h"
-#include "connectivity/peer_connection.h"
 
 #include "noncopyable.h"
-#include "connectivity/ip_utils.h"
 #include "ring_types.h" // enable_if_base_of
-#include "connectivity/security/certstore.h"
 #include "scheduled_executor.h"
-#include "connectivity/connectionmanager.h"
 #include "gitserver.h"
 #include "channel_handler.h"
 #include "conversation_module.h"
 #include "sync_module.h"
 #include "conversationrepository.h"
+#include "namedirectory.h"
+
+#include <dhtnet/diffie-hellman.h>
+#include <dhtnet/tls_session.h>
+#include <dhtnet/multiplexed_socket.h>
+#include <dhtnet/certstore.h>
+#include <dhtnet/connectionmanager.h>
+#include <dhtnet/upnp/mapping.h>
+#include <dhtnet/ip_utils.h>
+#include <dhtnet/fileutils.h>
 
 #include <opendht/dhtrunner.h>
 #include <opendht/default_types.h>
 
-#include "connectivity/upnp/protocol/mapping.h"
-
 #include <pjsip/sip_types.h>
+#include <json/json.h>
 
 #include <chrono>
 #include <functional>
 #include <future>
-#include <json/json.h>
 #include <list>
 #include <map>
 #include <optional>
 #include <vector>
-
-#if HAVE_RINGNS
-#include "namedirectory.h"
-#endif
+#include <filesystem>
+#include <shared_mutex>
 
 namespace dev {
 template<unsigned N>
@@ -88,9 +81,10 @@ struct AccountInfo;
 class SipTransport;
 class ChanneledOutgoingTransfer;
 class SyncModule;
-struct TextMessageCtx;
 
-using SipConnectionKey = std::pair<std::string /* accountId */, DeviceId>;
+using SipConnectionKey = std::pair<std::string /* uri */, DeviceId>;
+
+static constexpr const char MIME_TYPE_IM_COMPOSING[] {"application/im-iscomposing+xml"};
 
 /**
  * @brief Ring Account is build on top of SIPAccountBase and uses DHT to handle call connectivity.
@@ -105,28 +99,23 @@ public:
 
     std::string_view getAccountType() const override { return ACCOUNT_TYPE; }
 
-    std::shared_ptr<JamiAccount> shared()
-    {
-        return std::static_pointer_cast<JamiAccount>(shared_from_this());
-    }
+    std::shared_ptr<JamiAccount> shared() { return std::static_pointer_cast<JamiAccount>(shared_from_this()); }
     std::shared_ptr<JamiAccount const> shared() const
     {
         return std::static_pointer_cast<JamiAccount const>(shared_from_this());
     }
-    std::weak_ptr<JamiAccount> weak()
-    {
-        return std::static_pointer_cast<JamiAccount>(shared_from_this());
-    }
+    std::weak_ptr<JamiAccount> weak() { return std::static_pointer_cast<JamiAccount>(shared_from_this()); }
     std::weak_ptr<JamiAccount const> weak() const
     {
         return std::static_pointer_cast<JamiAccount const>(shared_from_this());
     }
 
-    const std::string& getPath() const { return idPath_; }
+    const JamiAccountConfig& config() const { return *static_cast<const JamiAccountConfig*>(&Account::config()); }
 
-    const JamiAccountConfig& config() const
+    JamiAccountConfig::Credentials consumeConfigCredentials()
     {
-        return *static_cast<const JamiAccountConfig*>(&Account::config());
+        auto conf = static_cast<JamiAccountConfig*>(config_.get());
+        return std::move(conf->credentials);
     }
 
     void loadConfig() override;
@@ -176,15 +165,13 @@ public:
     /**
      * Disconnect from the DHT.
      */
-    void doUnregister(std::function<void(bool)> cb = {}) override;
+    void doUnregister(bool forceShutdownConnections = false) override;
 
     /**
      * Set the registration state of the specified link
      * @param state The registration state of underlying VoIPLink
      */
-    void setRegistrationState(RegistrationState state,
-                              int detail_code = 0,
-                              const std::string& detail_str = {}) override;
+    void setRegistrationState(RegistrationState state, int detail_code = 0, const std::string& detail_str = {}) override;
 
     /**
      * @return pj_str_t "From" uri based on account information.
@@ -219,9 +206,7 @@ public:
 
     void setIsComposing(const std::string& conversationUri, bool isWriting) override;
 
-    bool setMessageDisplayed(const std::string& conversationUri,
-                             const std::string& messageId,
-                             int status) override;
+    bool setMessageDisplayed(const std::string& conversationUri, const std::string& messageId, int status) override;
 
     /**
      * Get the contact header for
@@ -252,34 +237,32 @@ public:
      * @param sipTr: SIP Transport
      * @return A shared pointer on the created call.
      */
-    std::shared_ptr<SIPCall> newIncomingCall(
-        const std::string& from,
-        const std::vector<libjami::MediaMap>& mediaList,
-        const std::shared_ptr<SipTransport>& sipTr = {}) override;
+    std::shared_ptr<SIPCall> newIncomingCall(const std::string& from,
+                                             const std::vector<libjami::MediaMap>& mediaList,
+                                             const std::shared_ptr<SipTransport>& sipTr = {}) override;
 
     void onTextMessage(const std::string& id,
                        const std::string& from,
-                       const std::string& deviceId,
+                       const std::shared_ptr<dht::crypto::Certificate>& peerCert,
                        const std::map<std::string, std::string>& payloads) override;
+    void loadConversation(const std::string& convId);
 
     virtual bool isTlsEnabled() const override { return true; }
     bool isSrtpEnabled() const override { return true; }
 
     virtual bool getSrtpFallback() const override { return false; }
 
-    bool setCertificateStatus(const std::string& cert_id, tls::TrustStore::PermissionStatus status);
+    bool setCertificateStatus(const std::string& cert_id, dhtnet::tls::TrustStore::PermissionStatus status);
     bool setCertificateStatus(const std::shared_ptr<crypto::Certificate>& cert,
-                              tls::TrustStore::PermissionStatus status,
+                              dhtnet::tls::TrustStore::PermissionStatus status,
                               bool local = true);
-    std::vector<std::string> getCertificatesByStatus(tls::TrustStore::PermissionStatus status);
+    std::vector<std::string> getCertificatesByStatus(dhtnet::tls::TrustStore::PermissionStatus status);
 
     bool findCertificate(const std::string& id);
-    bool findCertificate(
-        const dht::InfoHash& h,
-        std::function<void(const std::shared_ptr<dht::crypto::Certificate>&)>&& cb = {});
-    bool findCertificate(
-        const dht::PkId& h,
-        std::function<void(const std::shared_ptr<dht::crypto::Certificate>&)>&& cb = {});
+    bool findCertificate(const dht::InfoHash& h,
+                         std::function<void(const std::shared_ptr<dht::crypto::Certificate>&)>&& cb = {});
+    bool findCertificate(const dht::PkId& h,
+                         std::function<void(const std::shared_ptr<dht::crypto::Certificate>&)>&& cb = {});
 
     /* contact requests */
     std::vector<std::map<std::string, std::string>> getTrustRequests() const;
@@ -294,23 +277,13 @@ public:
      */
     void addContact(const std::string& uri, bool confirmed = false);
     void removeContact(const std::string& uri, bool banned = true);
-    std::vector<std::map<std::string, std::string>> getContacts() const;
-
-    /**
-     * Replace in contact's details related conversation
-     * @param uri           Of the contact
-     * @param oldConv       Current conversation
-     * @param newConv
-     * @return if replaced
-     */
-    bool updateConvForContact(const std::string& uri,
-                              const std::string& oldConv,
-                              const std::string& newConv);
+    std::vector<std::map<std::string, std::string>> getContacts(bool includeRemoved = false) const;
 
     ///
     /// Obtain details about one account contact in serializable form.
     ///
     std::map<std::string, std::string> getContactDetails(const std::string& uri) const;
+    std::optional<Contact> getContactInfo(const std::string& uri) const;
 
     void sendTrustRequest(const std::string& to, const std::vector<uint8_t>& payload);
     void sendMessage(const std::string& to,
@@ -325,12 +298,30 @@ public:
                              const std::map<std::string, std::string>& payloads,
                              uint64_t refreshToken = 0,
                              bool onlyConnected = false) override;
-    void sendInstantMessage(const std::string& convId,
-                            const std::map<std::string, std::string>& msg);
-    void onIsComposing(const std::string& conversationId, const std::string& peer, bool isWriting);
+    void sendInstantMessage(const std::string& convId, const std::map<std::string, std::string>& msg);
+
+    /**
+     * Create and return ICE options.
+     */
+    dhtnet::IceTransportOptions getIceOptions() const override;
+    void getIceOptions(std::function<void(dhtnet::IceTransportOptions&&)> cb) const;
+    dhtnet::IpAddr getPublishedIpAddress(uint16_t family = PF_UNSPEC) const override;
+
+    /* Devices - existing device */
+    /**
+     * Initiates the process of adding a new device to this account
+     * @param uriProvided The URI provided by the new device to be added
+     * @return A positive operation ID if successful, or a negative value indicating an AddDeviceError:
+     *         - INVALID_URI (-1): The provided URI is invalid
+     *         - ALREADY_LINKING (-2): A device linking operation is already in progress
+     *         - GENERIC (-3): A generic error occurred during the process
+     */
+    int32_t addDevice(const std::string& uriProvided);
+    bool cancelAddDevice(uint32_t op_token);
+    bool confirmAddDevice(uint32_t op_token);
+    /* Devices - new device */
+    bool provideAccountAuthentication(const std::string& credentialsFromUser, const std::string& scheme);
 
-    /* Devices */
-    void addDevice(const std::string& password);
     /**
      * Export the archive to a file
      * @param destinationPath
@@ -338,11 +329,14 @@ public:
      * doesn't have a password
      * @return if the archive was exported
      */
-    bool exportArchive(const std::string& destinationPath, const std::string& password = {});
-    bool revokeDevice(const std::string& password, const std::string& device);
+    bool exportArchive(const std::string& destinationPath,
+                       std::string_view scheme = {},
+                       const std::string& password = {});
+    bool revokeDevice(const std::string& device, std::string_view scheme = {}, const std::string& password = {});
     std::map<std::string, std::string> getKnownDevices() const;
 
     bool isPasswordValid(const std::string& password);
+    std::vector<uint8_t> getPasswordKey(const std::string& password);
 
     bool changeArchivePassword(const std::string& password_old, const std::string& password_new);
 
@@ -351,32 +345,19 @@ public:
     // overloaded methods
     void flush() override;
 
-#if HAVE_RINGNS
     void lookupName(const std::string& name);
     void lookupAddress(const std::string& address);
-    void registerName(const std::string& password, const std::string& name);
-#endif
+    void registerName(const std::string& name, const std::string& scheme, const std::string& password);
     bool searchUser(const std::string& nameQuery);
 
     /// \return true if the given DHT message identifier has been treated
     /// \note if message has not been treated yet this method store this id and returns true at
     /// further calls
-    bool isMessageTreated(std::string_view id);
+    bool isMessageTreated(dht::Value::Id id);
 
-    std::shared_ptr<dht::DhtRunner> dht()
-    {
-        return dht_;
-    }
+    std::shared_ptr<dht::DhtRunner> dht() { return dht_; }
 
-    const dht::crypto::Identity& identity() const
-    {
-        return id_;
-    }
-
-    const std::shared_future<tls::DhParams> dhParams() const
-    {
-        return dhParams_;
-    }
+    const dht::crypto::Identity& identity() const { return id_; }
 
     void forEachDevice(const dht::InfoHash& to,
                        std::function<void(const std::shared_ptr<dht::crypto::PublicKey>&)>&& op,
@@ -389,8 +370,7 @@ public:
     /**
      * To be called by clients with relevant data when a push notification is received.
      */
-    void pushNotificationReceived(const std::string& from,
-                                  const std::map<std::string, std::string>& data);
+    void pushNotificationReceived(const std::string& from, const std::map<std::string, std::string>& data);
 
     std::string getUserUri() const override;
 
@@ -414,8 +394,7 @@ public:
 
     inline void editConfig(std::function<void(JamiAccountConfig& conf)>&& edit)
     {
-        Account::editConfig(
-            [&](AccountConfig& conf) { edit(*static_cast<JamiAccountConfig*>(&conf)); });
+        Account::editConfig([&](AccountConfig& conf) { edit(*static_cast<JamiAccountConfig*>(&conf)); });
     }
 
     /**
@@ -423,30 +402,29 @@ public:
      */
     std::map<std::string, std::string> getNearbyPeers() const override;
 
-    /**
-     * Store the local/public addresses used to register
-     */
-    void storeActiveIpAddress(std::function<void()>&& cb = {});
+    void sendProfileToPeers();
 
     /**
-     * Create and return ICE options.
+     * Update the profile vcard and send it to peers
+     * @param displayName Current or new display name
+     * @param avatar Current or new avatar
+     * @param flag  0 for path to avatar, 1 for base64 avatar
      */
-    void getIceOptions(std::function<void(IceTransportOptions&&)> cb) noexcept;
+    void updateProfile(const std::string& displayName,
+                       const std::string& avatar,
+                       const std::string& fileType,
+                       int32_t flag) override;
 
-#ifdef LIBJAMI_TESTABLE
-    ConnectionManager& connectionManager()
-    {
-        return *connectionManager_;
-    }
+#ifdef LIBJAMI_TEST
+    dhtnet::ConnectionManager& connectionManager() { return *connectionManager_; }
 
     /**
      * Only used for tests, disable sha3sum verification for transfers.
      * @param newValue
      */
-    void noSha3sumVerification(bool newValue)
-    {
-        noSha3sumVerification_ = newValue;
-    }
+    void noSha3sumVerification(bool newValue);
+
+    void publishPresence(bool newValue) { publishPresence_ = newValue; }
 #endif
 
     /**
@@ -457,26 +435,22 @@ public:
 
     std::string_view currentDeviceId() const;
 
-    // Member management
-    void saveMembers(const std::string& convId,
-                     const std::vector<std::string>& members); // Save confInfos
-
     // Received a new commit notification
 
-    bool handleMessage(const std::string& from,
+    bool handleMessage(const std::shared_ptr<dht::crypto::Certificate>& cert,
+                       const std::string& from,
                        const std::pair<std::string, std::string>& message) override;
 
     void monitor();
+    // conversationId optional
+    std::vector<std::map<std::string, std::string>> getConnectionList(const std::string& conversationId = "");
+    std::vector<std::map<std::string, std::string>> getChannelList(const std::string& connectionId);
 
     // File transfer
     void sendFile(const std::string& conversationId,
-                  const std::string& path,
+                  const std::filesystem::path& path,
                   const std::string& name,
                   const std::string& replyTo);
-    // non-swarm version
-    libjami::DataTransferId sendFile(const std::string& peer,
-                                     const std::string& path,
-                                     const InternalCompletionCb& icb = {});
 
     void transferFile(const std::string& conversationId,
                       const std::string& path,
@@ -496,9 +470,7 @@ public:
                            size_t start = 0,
                            size_t end = 0);
 
-    void askForProfile(const std::string& conversationId,
-                       const std::string& deviceId,
-                       const std::string& memberUri);
+    void askForProfile(const std::string& conversationId, const std::string& deviceId, const std::string& memberUri);
 
     /**
      * Retrieve linked transfer manager
@@ -507,7 +479,13 @@ public:
      */
     std::shared_ptr<TransferManager> dataTransfer(const std::string& id = "");
 
-    ConversationModule* convModule();
+    /**
+     *   Used to get the instance of the ConversationModule class which is
+     *  responsible for managing conversations and messages between users.
+     * @param noCreate    whether or not to create a new instance
+     * @return conversationModule instance
+     */
+    ConversationModule* convModule(bool noCreation = false);
     SyncModule* syncModule();
 
     /**
@@ -517,18 +495,14 @@ public:
      * @param sha3Sum       SHA3 hash of the profile
      */
     // Note: when swarm will be merged, this can be moved in transferManager
-    bool needToSendProfile(const std::string& peerUri,
-                           const std::string& deviceId,
-                           const std::string& sha3Sum);
+    bool needToSendProfile(const std::string& peerUri, const std::string& deviceId, const std::string& sha3Sum);
     /**
      * Send Profile via cached SIP connection
      * @param convId        Conversation's identifier (can be empty for self profile on sync)
      * @param peerUri       Uri that will receive the profile
      * @param deviceId      Device that will receive the profile
      */
-    void sendProfile(const std::string& convId,
-                     const std::string& peerUri,
-                     const std::string& deviceId);
+    void sendProfile(const std::string& convId, const std::string& peerUri, const std::string& deviceId);
     /**
      * Send profile via cached SIP connection
      * @param peerUri       Uri that will receive the profile
@@ -541,17 +515,11 @@ public:
      */
     void clearProfileCache(const std::string& peerUri);
 
-    std::string profilePath() const;
+    std::filesystem::path profilePath() const;
 
-    AccountManager* accountManager()
-    {
-        return accountManager_.get();
-    }
+    const std::shared_ptr<AccountManager>& accountManager() { return accountManager_; }
 
-    bool sha3SumVerify() const
-    {
-        return !noSha3sumVerification_;
-    }
+    bool sha3SumVerify() const;
 
     /**
      * Change certificate's validity period
@@ -560,14 +528,16 @@ public:
      * @param validity  New validity
      * @note forceReloadAccount may be necessary to retrigger the migration
      */
-    bool setValidity(const std::string& pwd, const dht::InfoHash& id, int64_t validity);
+    bool setValidity(std::string_view scheme, const std::string& pwd, const dht::InfoHash& id, int64_t validity);
     /**
      * Try to reload the account to force the identity to be updated
      */
     void forceReloadAccount();
 
+    void reloadContacts();
+
     /**
-     * Make sure appdata/contacts.yml contains correct informations
+     * Make sure appdata/contacts.yml contains correct information
      * @param removedConv   The current removed conversations
      */
     void unlinkConversations(const std::set<std::string>& removedConv);
@@ -586,22 +556,25 @@ public:
      * connected. This kind of node corresponds to devices with push notifications & proxy and are
      * stored in the mobile nodes
      */
-    bool isMobile() const
-    {
-        return config().proxyEnabled and not config().deviceKey.empty();
-    }
+    bool isMobile() const { return config().proxyEnabled and not config().deviceKey.empty(); }
 
-#ifdef LIBJAMI_TESTABLE
-    std::map<Uri::Scheme, std::unique_ptr<ChannelHandlerInterface>>& channelHandlers()
-    {
-        return channelHandlers_;
-    };
+#ifdef LIBJAMI_TEST
+    std::map<Uri::Scheme, std::unique_ptr<ChannelHandlerInterface>>& channelHandlers() { return channelHandlers_; };
 #endif
 
-    tls::CertificateStore& certStore() const
-    {
-        return *certStore_;
-    }
+    dhtnet::tls::CertificateStore& certStore() const { return *certStore_; }
+    /**
+     * Check if a Device is connected
+     * @param deviceId
+     * @return true if connected
+     */
+    bool isConnectedWith(const DeviceId& deviceId) const;
+
+    /**
+     * Send a presence note
+     * @param note
+     */
+    void sendPresenceNote(const std::string& note);
 
 private:
     NON_COPYABLE(JamiAccount);
@@ -626,11 +599,12 @@ private:
     /**
      * Compute archive encryption key and DHT storage location from password and PIN.
      */
-    static std::pair<std::vector<uint8_t>, dht::InfoHash> computeKeys(const std::string& password,
-                                                                      const std::string& pin,
-                                                                      bool previous = false);
+    /* static std::pair<std::vector<uint8_t>, dht::InfoHash> computeKeys(const std::string&
+       password, const std::string& pin, bool previous = false);
+                                      */
 
     void trackPresence(const dht::InfoHash& h, BuddyInfo& buddy);
+    void onPeerConnected(const std::string& peerId, bool connected);
 
     void doRegister_();
 
@@ -638,16 +612,14 @@ private:
 
     void startOutgoingCall(const std::shared_ptr<SIPCall>& call, const std::string& toUri);
 
-    void onConnectedOutgoingCall(const std::shared_ptr<SIPCall>& call,
-                                 const std::string& to_id,
-                                 IpAddr target);
+    void onConnectedOutgoingCall(const std::shared_ptr<SIPCall>& call, const std::string& to_id, dhtnet::IpAddr target);
 
     /**
      * Start a SIP Call
      * @param call  The current call
      * @return true if all is correct
      */
-    bool SIPStartCall(SIPCall& call, const IpAddr& target);
+    bool SIPStartCall(SIPCall& call, const dhtnet::IpAddr& target);
 
     /**
      * Update tracking info when buddy appears offline.
@@ -667,25 +639,18 @@ private:
      * Add port mapping callback function.
      */
     void onPortMappingAdded(uint16_t port_used, bool success);
-    void forEachPendingCall(const DeviceId& deviceId,
-                            const std::function<void(const std::shared_ptr<SIPCall>&)>& cb);
+    void forEachPendingCall(const DeviceId& deviceId, const std::function<void(const std::shared_ptr<SIPCall>&)>& cb);
 
-    void loadAccountFromFile(const std::string& archive_path, const std::string& archive_password);
-    void loadAccountFromDHT(const std::string& archive_password, const std::string& archive_pin);
-    void loadAccountFromArchive(AccountArchive&& archive, const std::string& archive_password);
-    void loadAccount(const std::string& archive_password = {},
-                     const std::string& archive_pin = {},
+    void loadAccount(const std::string& archive_password_scheme = {},
+                     const std::string& archive_password = {},
                      const std::string& archive_path = {});
 
     std::vector<std::string> loadBootstrap() const;
 
     static std::pair<std::string, std::string> saveIdentity(const dht::crypto::Identity id,
-                                                            const std::string& path,
+                                                            const std::filesystem::path& path,
                                                             const std::string& name);
 
-    void loadTreatedMessages();
-    void saveTreatedMessages() const;
-
     void replyToIncomingIceMsg(const std::shared_ptr<SIPCall>&,
                                const std::shared_ptr<IceTransport>&,
                                const std::shared_ptr<IceTransport>&,
@@ -693,10 +658,8 @@ private:
                                const std::shared_ptr<dht::crypto::Certificate>& from_cert,
                                const dht::InfoHash& from);
 
-    static tls::DhParams loadDhParams(std::string path);
-
     void loadCachedUrl(const std::string& url,
-                       const std::string& cachePath,
+                       const std::filesystem::path& cachePath,
                        const std::chrono::seconds& cacheDuration,
                        std::function<void(const dht::http::Response& response)>);
 
@@ -708,41 +671,49 @@ private:
      */
     void generateDhParams();
 
-    template<class... Args>
-    std::shared_ptr<IceTransport> createIceTransport(const Args&... args);
     void newOutgoingCallHelper(const std::shared_ptr<SIPCall>& call, const Uri& uri);
-    void newSwarmOutgoingCallHelper(const std::shared_ptr<SIPCall>& call, const Uri& uri);
+    std::shared_ptr<SIPCall> newSwarmOutgoingCallHelper(const Uri& uri, const std::vector<libjami::MediaMap>& mediaList);
     std::shared_ptr<SIPCall> createSubCall(const std::shared_ptr<SIPCall>& mainCall);
 
-#if HAVE_RINGNS
+    std::filesystem::path cachePath_ {};
+    std::filesystem::path dataPath_ {};
+
+    mutable std::mutex registeredNameMutex_;
     std::string registeredName_;
-#endif
+
+    bool setRegisteredName(const std::string& name)
+    {
+        std::lock_guard<std::mutex> lock(registeredNameMutex_);
+        if (registeredName_ != name) {
+            registeredName_ = name;
+            return true;
+        }
+        return false;
+    }
+    std::string getRegisteredName() const
+    {
+        std::lock_guard<std::mutex> lock(registeredNameMutex_);
+        return registeredName_;
+    }
+
     std::shared_ptr<dht::Logger> logger_;
+    std::shared_ptr<dhtnet::tls::CertificateStore> certStore_;
 
     std::shared_ptr<dht::DhtRunner> dht_ {};
-    std::unique_ptr<AccountManager> accountManager_;
+    std::shared_ptr<AccountManager> accountManager_;
     dht::crypto::Identity id_ {};
 
     mutable std::mutex messageMutex_ {};
     std::map<dht::Value::Id, PendingMessage> sentMessages_;
-    std::set<std::string, std::less<>> treatedMessages_ {};
-
-    std::string idPath_ {};
-    std::string cachePath_ {};
-    std::string dataPath_ {};
+    dhtnet::fileutils::IdList treatedMessages_;
 
     /* tracked buddies presence */
     mutable std::mutex buddyInfoMtx;
     std::map<dht::InfoHash, BuddyInfo> trackedBuddies_;
 
     mutable std::mutex dhtValuesMtx_;
-    bool dhtPublicInCalls_ {true};
 
     std::atomic_int syncCnt_ {0};
-    /**
-     * DHT port preference
-     */
-    in_port_t dhtDefaultPort_ {0};
 
     /**
      * DHT port actually used.
@@ -751,22 +722,17 @@ private:
      */
     in_port_t dhtPortUsed()
     {
-        return (upnpCtrl_ and dhtUpnpMapping_.isValid()) ? dhtUpnpMapping_.getExternalPort()
-                                                         : dhtDefaultPort_;
+        return (upnpCtrl_ and dhtUpnpMapping_.isValid()) ? dhtUpnpMapping_.getExternalPort() : config().dhtPort;
     }
 
     /* Current UPNP mapping */
-    upnp::Mapping dhtUpnpMapping_ {upnp::PortType::UDP};
+    dhtnet::upnp::Mapping dhtUpnpMapping_ {dhtnet::upnp::PortType::UDP};
 
     /**
      * Proxy
      */
     std::string proxyServerCached_ {};
 
-    std::mutex dhParamsMtx_ {};
-    std::shared_future<tls::DhParams> dhParams_;
-    std::condition_variable dhParamsCv_;
-
     /**
      * Optional: via_addr construct from received parameters
      */
@@ -774,40 +740,28 @@ private:
 
     pjsip_transport* via_tp_ {nullptr};
 
-    mutable std::mutex connManagerMtx_ {};
-    std::unique_ptr<ConnectionManager> connectionManager_;
+    /** ConnectionManager is thread-safe.
+     * The shared mutex protects the pointer while allowing
+     * multiple threads to access the ConnectionManager concurrently  */
+    mutable std::shared_mutex connManagerMtx_ {};
+    std::unique_ptr<dhtnet::ConnectionManager> connectionManager_;
+
+    virtual void updateUpnpController() override;
 
     std::mutex discoveryMapMtx_;
     std::shared_ptr<dht::PeerDiscovery> peerDiscovery_;
     std::map<dht::InfoHash, DiscoveredPeer> discoveredPeers_;
     std::map<std::string, std::string> discoveredPeerMap_;
 
-    /**
-     * Avoid to refresh the cache multiple times
-     */
-    std::atomic_bool isRefreshing_ {false};
-    /**
-     * This will cache the turn server resolution each time we launch
-     * Jami, or for each connectivityChange()
-     */
-    // TODO move in separate class
-    void testTurn(IpAddr server);
-    void cacheTurnServers();
-    std::unique_ptr<TurnTransport> testTurnV4_;
-    std::unique_ptr<TurnTransport> testTurnV6_;
-    void refreshTurnDelay(bool scheduleNext);
-
-    std::chrono::seconds turnRefreshDelay_ {std::chrono::seconds(10)};
-
     std::set<std::shared_ptr<dht::http::Request>> requests_;
 
-    std::mutex sipConnsMtx_ {};
+    mutable std::mutex sipConnsMtx_ {};
     struct SipConnection
     {
         std::shared_ptr<SipTransport> transport;
         // Needs to keep track of that channel to access underlying ICE
-        // informations, as the SipTransport use a generic transport
-        std::shared_ptr<ChannelSocket> channel;
+        // information, as the SipTransport use a generic transport
+        std::shared_ptr<dhtnet::ChannelSocket> channel;
     };
     // NOTE: here we use a vector to avoid race conditions. In fact the contact
     // can ask for a SIP channel when we are creating a new SIP Channel with this
@@ -846,7 +800,7 @@ private:
      * @param peerId    The contact who owns the device
      * @param deviceId  Device linked to that transport
      */
-    void cacheSIPConnection(std::shared_ptr<ChannelSocket>&& channel,
+    void cacheSIPConnection(std::shared_ptr<dhtnet::ChannelSocket>&& channel,
                             const std::string& peerId,
                             const DeviceId& deviceId);
     /**
@@ -855,10 +809,14 @@ private:
      * @param peerId    The contact who owns the device
      * @param deviceId  Device linked to that transport
      */
-    void shutdownSIPConnection(const std::shared_ptr<ChannelSocket>& channel,
+    void shutdownSIPConnection(const std::shared_ptr<dhtnet::ChannelSocket>& channel,
                                const std::string& peerId,
                                const DeviceId& deviceId);
 
+    void requestMessageConnection(const std::string& peerId,
+                                  const DeviceId& deviceId,
+                                  const std::string& connectionType);
+
     // File transfers
     std::mutex transfersMtx_ {};
     std::set<std::string> incomingFileTransfers_ {};
@@ -880,7 +838,8 @@ private:
                         uint64_t token,
                         const std::map<std::string, std::string>& data,
                         pjsip_endpt_send_callback cb);
-    void onSIPMessageSent(const std::shared_ptr<TextMessageCtx>& ctx, int code);
+    void onMessageSent(
+        const std::string& to, uint64_t id, const std::string& deviceId, bool success, bool onlyConnected, bool retry);
 
     std::mutex gitServersMtx_ {};
     std::map<dht::Value::Id, std::unique_ptr<GitServer>> gitServers_ {};
@@ -889,8 +848,9 @@ private:
     std::shared_ptr<TransferManager> nonSwarmTransferManager_;
 
     std::atomic_bool deviceAnnounced_ {false};
+    std::atomic_bool noSha3sumVerification_ {false};
 
-    bool noSha3sumVerification_ {false};
+    bool publishPresence_ {true};
 
     std::map<Uri::Scheme, std::unique_ptr<ChannelHandlerInterface>> channelHandlers_ {};
 
@@ -898,9 +858,15 @@ private:
     std::mutex moduleMtx_;
     std::unique_ptr<SyncModule> syncModule_;
 
+    std::mutex rdvMtx_;
+
+    int dhtBoundPort_ {0};
+
     void initConnectionManager();
 
-    std::unique_ptr<tls::CertificateStore> certStore_;
+    enum class PresenceState : int { DISCONNECTED = 0, AVAILABLE, CONNECTED };
+    std::map<std::string, PresenceState> presenceState_;
+    std::string presenceNote_;
 };
 
 static inline std::ostream&
