@@ -1,21 +1,18 @@
 /*
- *  Copyright (C) 2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Fadi Shehadeh <fadi.shehadeh@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "routing_table.h"
@@ -30,7 +27,6 @@
 #include <stdlib.h>
 #include <time.h>
 
-constexpr const std::chrono::minutes FIND_PERIOD {10};
 using namespace std::placeholders;
 
 namespace jami {
@@ -162,7 +158,7 @@ Bucket::getNodeTimer(const std::shared_ptr<dhtnet::ChannelSocketInterface>& sock
 {
     auto node = nodes.find(socket->deviceId());
     if (node == nodes.end()) {
-        throw std::range_error("Can't find timer " + socket->deviceId().toString());
+        throw std::range_error("Unable to find timer " + socket->deviceId().toString());
     }
     return node->second.refresh_timer;
 }
@@ -187,9 +183,8 @@ Bucket::shutdownAllNodes()
 {
     while (not nodes.empty()) {
         auto it = nodes.begin();
-        auto socket = it->second.socket;
-        auto nodeId = socket->deviceId();
-        socket->shutdown();
+        it->second.socket->shutdown();
+        auto nodeId = it->first;
         removeNode(nodeId);
     }
 }
@@ -201,7 +196,10 @@ Bucket::printBucket(unsigned number) const
 
     unsigned nodeNum = 1;
     for (auto it = nodes.begin(); it != nodes.end(); ++it) {
-        JAMI_DEBUG("Node {:s}   Id: {:s}  isMobile: {:s}", std::to_string(nodeNum), it->first.toString(), std::to_string(it->second.isMobile_));
+        JAMI_DEBUG("Node {:s}   Id: {:s}  isMobile: {:s}",
+                   std::to_string(nodeNum),
+                   it->first.toString(),
+                   std::to_string(it->second.isMobile_));
         nodeNum++;
     }
     JAMI_ERROR("Mobile Nodes");
@@ -300,12 +298,10 @@ RoutingTable::addKnownNode(const NodeId& nodeId)
         return false;
 
     auto bucket = findBucket(nodeId);
-
     if (bucket == buckets.end())
-        return 0;
+        return false;
 
-    bucket->addKnownNode(nodeId);
-    return 1;
+    return bucket->addKnownNode(nodeId);
 }
 
 bool
@@ -383,11 +379,9 @@ RoutingTable::closestNodes(const NodeId& nodeId, unsigned count)
         auto nodes = b->getNodeIds();
         for (auto n : nodes) {
             if (n != nodeId) {
-                auto here = std::find_if(closestNodes.begin(),
-                                         closestNodes.end(),
-                                         [&nodeId, &n](NodeId& NodeId) {
-                                             return nodeId.xorCmp(n, NodeId) < 0;
-                                         });
+                auto here = std::find_if(closestNodes.begin(), closestNodes.end(), [&nodeId, &n](NodeId& NodeId) {
+                    return nodeId.xorCmp(n, NodeId) < 0;
+                });
 
                 closestNodes.insert(here, n);
             }
@@ -435,7 +429,7 @@ RoutingTable::shutdownNode(const NodeId& nodeId)
 std::vector<NodeId>
 RoutingTable::getNodes() const
 {
-    std::lock_guard<std::mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
     std::vector<NodeId> ret;
     for (const auto& b : buckets) {
         const auto& nodes = b.getNodeIds();
@@ -492,8 +486,7 @@ bool
 RoutingTable::contains(const std::list<Bucket>::iterator& bucket, const NodeId& nodeId) const
 {
     return NodeId::cmp(bucket->getLowerLimit(), nodeId) <= 0
-           && (std::next(bucket) == buckets.end()
-               || NodeId::cmp(nodeId, std::next(bucket)->getLowerLimit()) < 0);
+           && (std::next(bucket) == buckets.end() || NodeId::cmp(nodeId, std::next(bucket)->getLowerLimit()) < 0);
 }
 
 std::vector<NodeId>
@@ -505,7 +498,7 @@ RoutingTable::getAllNodes() const
         const auto& knownNodes = b.getKnownNodes();
         const auto& mobileNodes = b.getMobileNodes();
         const auto& connectingNodes = b.getConnectingNodes();
-
+        ret.reserve(nodes.size() + knownNodes.size() + mobileNodes.size() + connectingNodes.size());
         ret.insert(ret.end(), nodes.begin(), nodes.end());
         ret.insert(ret.end(), knownNodes.begin(), knownNodes.end());
         ret.insert(ret.end(), mobileNodes.begin(), mobileNodes.end());
@@ -540,8 +533,7 @@ unsigned
 RoutingTable::depth(std::list<Bucket>::iterator& bucket) const
 {
     int bit1 = bucket->getLowerLimit().lowbit();
-    int bit2 = std::next(bucket) != buckets.end() ? std::next(bucket)->getLowerLimit().lowbit()
-                                                  : -1;
+    int bit2 = std::next(bucket) != buckets.end() ? std::next(bucket)->getLowerLimit().lowbit() : -1;
     return std::max(bit1, bit2) + 1;
 }
 
