@@ -1,36 +1,32 @@
 /*
- *  Copyright (C) 2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Fadi Shehadeh <fadi.shehadeh@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "swarm_manager.h"
 #include <dhtnet/multiplexed_socket.h>
 #include <opendht/thread_pool.h>
 
-constexpr const std::chrono::minutes FIND_PERIOD {10};
-
 namespace jami {
 
 using namespace swarm_protocol;
 
-SwarmManager::SwarmManager(const NodeId& id)
+SwarmManager::SwarmManager(const NodeId& id, const std::mt19937_64& rand, ToConnectCb&& toConnectCb)
     : id_(id)
-    , rd(dht::crypto::getSeededRandomEngine<std::mt19937_64>())
+    , rd(rand)
+    , toConnectCb_(toConnectCb)
 {
     routing_table.setId(id);
 }
@@ -41,23 +37,45 @@ SwarmManager::~SwarmManager()
         shutdown();
 }
 
-void
+bool
 SwarmManager::setKnownNodes(const std::vector<NodeId>& known_nodes)
 {
     isShutdown_ = false;
+    std::vector<NodeId> newNodes;
     {
-        std::lock_guard<std::mutex> lock(mutex);
-        for (const auto& NodeId : known_nodes)
-            addKnownNodes(std::move(NodeId));
+        std::lock_guard lock(mutex);
+        for (const auto& nodeId : known_nodes) {
+            if (addKnownNode(nodeId)) {
+                newNodes.emplace_back(nodeId);
+            }
+        }
     }
-    maintainBuckets();
+
+    if (newNodes.empty())
+        return false;
+
+    dht::ThreadPool::io().run([w = weak(), newNodes = std::move(newNodes)] {
+        auto shared = w.lock();
+        if (!shared)
+            return;
+        // If we detect a new node which already got a TCP link
+        // we can use it to speed-up the bootstrap (because opening
+        // a new channel will be easy)
+        std::set<NodeId> toConnect;
+        for (const auto& nodeId : newNodes) {
+            if (shared->toConnectCb_ && shared->toConnectCb_(nodeId))
+                toConnect.emplace(nodeId);
+        }
+        shared->maintainBuckets(toConnect);
+    });
+    return true;
 }
 
 void
 SwarmManager::setMobileNodes(const std::vector<NodeId>& mobile_nodes)
 {
     {
-        std::lock_guard<std::mutex> lock(mutex);
+        std::lock_guard lock(mutex);
         for (const auto& nodeId : mobile_nodes)
             addMobileNodes(nodeId);
     }
@@ -70,8 +88,8 @@ SwarmManager::addChannel(const std::shared_ptr<dhtnet::ChannelSocketInterface>&
     if (channel) {
         auto emit = false;
         {
-            std::lock_guard<std::mutex> lock(mutex);
-            emit = routing_table.findBucket(getId())->getNodeIds().size() == 0;
+            std::lock_guard lock(mutex);
+            emit = routing_table.findBucket(getId())->isEmpty();
             auto bucket = routing_table.findBucket(channel->deviceId());
             if (routing_table.addNode(channel, bucket)) {
                 std::error_code ec;
@@ -90,7 +108,7 @@ SwarmManager::addChannel(const std::shared_ptr<dhtnet::ChannelSocketInterface>&
 void
 SwarmManager::removeNode(const NodeId& nodeId)
 {
-    std::unique_lock<std::mutex> lk(mutex);
+    std::unique_lock lk(mutex);
     if (isConnectedWith(nodeId)) {
         removeNodeInternal(nodeId);
         lk.unlock();
@@ -101,7 +119,7 @@ SwarmManager::removeNode(const NodeId& nodeId)
 void
 SwarmManager::changeMobility(const NodeId& nodeId, bool isMobile)
 {
-    std::lock_guard<std::mutex> lock(mutex);
+    std::lock_guard lock(mutex);
     auto bucket = routing_table.findBucket(nodeId);
     bucket->changeMobility(nodeId, isMobile);
 }
@@ -119,16 +137,20 @@ SwarmManager::shutdown()
         return;
     }
     isShutdown_ = true;
-    std::lock_guard<std::mutex> lock(mutex);
+    std::lock_guard lock(mutex);
     routing_table.shutdownAllNodes();
 }
 
 void
-SwarmManager::addKnownNodes(const NodeId& nodeId)
+SwarmManager::restart()
 {
-    if (id_ != nodeId) {
-        routing_table.addKnownNode(nodeId);
-    }
+    isShutdown_ = false;
+}
+
+bool
+SwarmManager::addKnownNode(const NodeId& nodeId)
+{
+    return routing_table.addKnownNode(nodeId);
 }
 
 void
@@ -140,10 +162,10 @@ SwarmManager::addMobileNodes(const NodeId& nodeId)
 }
 
 void
-SwarmManager::maintainBuckets()
+SwarmManager::maintainBuckets(const std::set<NodeId>& toConnect)
 {
-    std::set<NodeId> nodes;
-    std::unique_lock<std::mutex> lock(mutex);
+    std::set<NodeId> nodes = toConnect;
+    std::unique_lock lock(mutex);
     auto& buckets = routing_table.getBuckets();
     for (auto it = buckets.begin(); it != buckets.end(); ++it) {
         auto& bucket = *it;
@@ -151,8 +173,7 @@ SwarmManager::maintainBuckets()
         auto connecting_nodes = myBucket ? bucket.getConnectingNodesSize()
                                          : bucket.getConnectingNodesSize() + bucket.getNodesSize();
         if (connecting_nodes < Bucket::BUCKET_MAX_SIZE) {
-            auto nodesToTry = bucket.getKnownNodesRandom(Bucket::BUCKET_MAX_SIZE - connecting_nodes,
-                                                         rd);
+            auto nodesToTry = bucket.getKnownNodesRandom(Bucket::BUCKET_MAX_SIZE - connecting_nodes, rd);
             for (auto& node : nodesToTry)
                 routing_table.addConnectingNode(node);
 
@@ -166,33 +187,30 @@ SwarmManager::maintainBuckets()
 
 void
 SwarmManager::sendRequest(const std::shared_ptr<dhtnet::ChannelSocketInterface>& socket,
-                          NodeId& nodeId,
+                          const NodeId& nodeId,
                           Query q,
                           int numberNodes)
 {
-    msgpack::sbuffer buffer;
-    msgpack::packer<msgpack::sbuffer> pk(&buffer);
-    std::error_code ec;
+    dht::ThreadPool::io().run([socket, isMobile = isMobile_, nodeId, q, numberNodes] {
+        msgpack::sbuffer buffer;
+        msgpack::packer<msgpack::sbuffer> pk(&buffer);
+        Message msg;
+        msg.is_mobile = isMobile;
+        msg.request = Request {q, numberNodes, nodeId};
+        pk.pack(msg);
 
-    Request toRequest {q, numberNodes, nodeId};
-    Message msg;
-    msg.is_mobile = isMobile_;
-    msg.request = std::move(toRequest);
-
-    pk.pack(msg);
-
-    socket->write(reinterpret_cast<const unsigned char*>(buffer.data()), buffer.size(), ec);
-
-    if (ec) {
-        JAMI_ERROR("{}", ec.message());
-        return;
-    }
+        std::error_code ec;
+        socket->write(reinterpret_cast<const unsigned char*>(buffer.data()), buffer.size(), ec);
+        if (ec) {
+            JAMI_ERROR("{}", ec.message());
+        }
+    });
 }
 
 void
 SwarmManager::sendAnswer(const std::shared_ptr<dhtnet::ChannelSocketInterface>& socket, const Message& msg_)
 {
-    std::lock_guard<std::mutex> lock(mutex);
+    std::lock_guard lock(mutex);
 
     if (msg_.request->q == Query::FIND) {
         auto nodes = routing_table.closestNodes(msg_.request->nodeId, msg_.request->num);
@@ -209,16 +227,12 @@ SwarmManager::sendAnswer(const std::shared_ptr<dhtnet::ChannelSocketInterface>&
         pk.pack(msg);
 
         std::error_code ec;
-
         socket->write(reinterpret_cast<const unsigned char*>(buffer.data()), buffer.size(), ec);
         if (ec) {
             JAMI_ERROR("{}", ec.message());
             return;
         }
     }
-
-    else {
-    }
 }
 
 void
@@ -226,9 +240,7 @@ SwarmManager::receiveMessage(const std::shared_ptr<dhtnet::ChannelSocketInterfac
 {
     struct DecodingContext
     {
-        msgpack::unpacker pac {[](msgpack::type::object_type, std::size_t, void*) { return true; },
-                               nullptr,
-                               512};
+        msgpack::unpacker pac {[](msgpack::type::object_type, std::size_t, void*) { return true; }, nullptr, 512};
     };
 
     socket->setOnRecv([w = weak(),
@@ -318,22 +330,21 @@ SwarmManager::tryConnect(const NodeId& nodeId)
         needSocketCb_(nodeId.toString(),
                       [w = weak(), nodeId](const std::shared_ptr<dhtnet::ChannelSocketInterface>& socket) {
                           auto shared = w.lock();
-                          if (!shared)
+                          if (!shared || shared->isShutdown_)
                               return true;
                           if (socket) {
                               shared->addChannel(socket);
                               return true;
                           }
-                          std::unique_lock<std::mutex> lk(shared->mutex);
+                          std::unique_lock lk(shared->mutex);
                           auto bucket = shared->routing_table.findBucket(nodeId);
                           bucket->removeConnectingNode(nodeId);
                           bucket->addKnownNode(nodeId);
                           bucket = shared->routing_table.findBucket(shared->getId());
-                          if (bucket->getConnectingNodesSize() == 0
-                              && bucket->getNodeIds().size() == 0 && shared->onConnectionChanged_) {
+                          if (bucket->getConnectingNodesSize() == 0 && bucket->isEmpty()
+                              && shared->onConnectionChanged_) {
                               lk.unlock();
-                              JAMI_WARNING("[SwarmManager {:p}] Bootstrap: all connections failed",
-                                           fmt::ptr(shared.get()));
+                              JAMI_LOG("[SwarmManager {:p}] Bootstrap: all connections failed", fmt::ptr(shared.get()));
                               shared->onConnectionChanged_(false);
                           }
                           return true;
@@ -349,19 +360,15 @@ SwarmManager::removeNodeInternal(const NodeId& nodeId)
 std::vector<NodeId>
 SwarmManager::getAllNodes() const
 {
-    std::lock_guard<std::mutex> lock(mutex);
-    std::vector<NodeId> nodes;
-    const auto& rtNodes = routing_table.getAllNodes();
-    nodes.insert(nodes.end(), rtNodes.begin(), rtNodes.end());
-
-    return nodes;
+    std::lock_guard lock(mutex);
+    return routing_table.getAllNodes();
 }
 
 void
 SwarmManager::deleteNode(std::vector<NodeId> nodes)
 {
     {
-        std::lock_guard<std::mutex> lock(mutex);
+        std::lock_guard lock(mutex);
         for (const auto& node : nodes) {
             routing_table.deleteNode(node);
         }
