@@ -1,25 +1,23 @@
 /*
- *  Copyright (C) 2021-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "jamidht/transfer_channel_handler.h"
 
+#include <opendht/thread_pool.h>
 #include <charconv>
 
 #include "fileutils.h"
@@ -41,12 +39,13 @@ TransferChannelHandler::~TransferChannelHandler() {}
 void
 TransferChannelHandler::connect(const DeviceId& deviceId,
                                 const std::string& channelName,
-                                ConnectCb&& cb)
+                                ConnectCb&& cb,
+                                const std::string& connectionType,
+                                bool forceNewConnection)
 {}
 
 bool
-TransferChannelHandler::onRequest(const std::shared_ptr<dht::crypto::Certificate>& cert,
-                                  const std::string& name)
+TransferChannelHandler::onRequest(const std::shared_ptr<dht::crypto::Certificate>& cert, const std::string& name)
 {
     auto acc = account_.lock();
     if (!acc || !cert || !cert->issuer)
@@ -76,17 +75,13 @@ TransferChannelHandler::onRequest(const std::shared_ptr<dht::crypto::Certificate
     if (fileId == fmt::format("{}.vcf", acc->getUsername()) || fileId == "profile.vcf") {
         // Or a member from the conversation
         auto members = cm->getConversationMembers(conversationId);
-        return std::find_if(members.begin(), members.end(), [&](auto m) { return m["uri"] == uri; })
-               != members.end();
+        return std::find_if(members.begin(), members.end(), [&](auto m) { return m["uri"] == uri; }) != members.end();
     } else if (fileHost == "profile") {
         // If a profile is sent, check if it's from another device
         return uri == acc->getUsername();
     }
 
-    return cm->onFileChannelRequest(conversationId,
-                                                   uri,
-                                                   std::string(fileId),
-                                                   acc->sha3SumVerify());
+    return cm->onFileChannelRequest(conversationId, uri, std::string(fileId), acc->sha3SumVerify());
 }
 
 void
@@ -122,32 +117,37 @@ TransferChannelHandler::onReady(const std::shared_ptr<dht::crypto::Certificate>&
                 sha3Sum = keyVal[1];
             } else if (keyVal[0] == "modified") {
                 try {
-                    lastModified = std::stoull(std::string(keyVal[1]));
-                } catch (...) {}
+                    lastModified = to_int<uint64_t>(keyVal[1]);
+                } catch (const std::exception& e) {
+                    JAMI_WARNING("TransferChannel: Unable to parse modified date: {}: {}", keyVal[1], e.what());
+                }
             }
         }
     }
 
     // Check if profile
     if (idstr == "profile.vcf") {
-        if (!channel->isInitiator()) {
-            // Only accept newest profiles
-            if (lastModified == 0
-                || lastModified > fileutils::lastWriteTimeInSeconds(acc->profilePath()))
-                acc->dataTransfer()->onIncomingProfile(channel, sha3Sum);
-            else
-                channel->shutdown();
-        } else {
-            // If it's a profile from sync
-            auto path = idPath_ / "profile.vcf";
-            acc->dataTransfer()->transferFile(channel, idstr, "", path.string());
-        }
+        dht::ThreadPool::io().run(
+            [wacc = acc->weak(), path = idPath_ / "profile.vcf", channel, idstr, lastModified, sha3Sum] {
+                if (auto acc = wacc.lock()) {
+                    if (!channel->isInitiator()) {
+                        // Only accept newest profiles
+                        if (lastModified == 0 || lastModified > fileutils::lastWriteTimeInSeconds(acc->profilePath()))
+                            acc->dataTransfer()->onIncomingProfile(channel, sha3Sum);
+                        else
+                            channel->shutdown();
+                    } else {
+                        // If it's a profile from sync
+                        acc->dataTransfer()->transferFile(channel, idstr, "", path.string());
+                    }
+                }
+            });
         return;
     }
 
     auto splitted_id = split_string(idstr, '/');
     if (splitted_id.size() < 3) {
-        JAMI_ERR() << "Unsupported ID detected " << name;
+        JAMI_ERROR("Unsupported ID detected {}", name);
         channel->shutdown();
         return;
     }
@@ -161,28 +161,40 @@ TransferChannelHandler::onReady(const std::shared_ptr<dht::crypto::Certificate>&
         return;
 
     // Profile for a member in the conversation
-    if (fileId == fmt::format("{}.vcf", acc->getUsername())) {
-        auto path = idPath_ / "profile.vcf";
-        acc->dataTransfer()->transferFile(channel, fileId, "", path.string());
-        return;
-    } else if (isContactProfile && fileId.find(".vcf") != std::string::npos) {
-        auto path = acc->dataTransfer()->profilePath(fileId.substr(0, fileId.size() - 4));
-        acc->dataTransfer()->transferFile(channel, fileId, "", path.string());
-        return;
-    } else if (fileId == "profile.vcf") {
-        acc->dataTransfer()->onIncomingProfile(channel, sha3Sum);
-        return;
-    }
-    // Check if it's a file in a conversation
-    auto dt = acc->dataTransfer(conversationId);
-    sep = fileId.find('_');
-    if (!dt or sep == std::string::npos) {
-        channel->shutdown();
-        return;
-    }
-    auto interactionId = fileId.substr(0, sep);
-    auto path = dt->path(fileId);
-    dt->transferFile(channel, fileId, interactionId, path.string(), start, end);
+    dht::ThreadPool::io().run([wacc = acc->weak(),
+                               profilePath = idPath_ / "profile.vcf",
+                               channel,
+                               conversationId,
+                               fileId,
+                               isContactProfile,
+                               idstr,
+                               start,
+                               end,
+                               sha3Sum] {
+        if (auto acc = wacc.lock()) {
+            if (fileId == fmt::format("{}.vcf", acc->getUsername())) {
+                acc->dataTransfer()->transferFile(channel, fileId, "", profilePath.string());
+                return;
+            } else if (isContactProfile && fileId.find(".vcf") != std::string::npos) {
+                auto path = acc->dataTransfer()->profilePath(fileId.substr(0, fileId.size() - 4));
+                acc->dataTransfer()->transferFile(channel, fileId, "", path.string());
+                return;
+            } else if (fileId == "profile.vcf") {
+                acc->dataTransfer()->onIncomingProfile(channel, sha3Sum);
+                return;
+            }
+            // Check if it's a file in a conversation
+            auto dt = acc->dataTransfer(conversationId);
+            auto sep = fileId.find('_');
+            if (!dt or sep == std::string::npos) {
+                channel->shutdown();
+                return;
+            }
+            auto interactionId = fileId.substr(0, sep);
+            auto path = dt->path(fileId);
+            dt->transferFile(channel, fileId, interactionId, path.string(), start, end);
+        }
+    });
 }
 
-} // namespace jami
\ No newline at end of file
+} // namespace jami
