@@ -66,6 +66,7 @@ class JamiPluginManager;
 class LIBJAMI_TEST_EXPORT Manager
 {
 private:
+    std::mutex randMutex_;
     std::mt19937_64 rand_;
 
 public:
@@ -128,8 +129,8 @@ public:
 
     void monitor(bool continuous);
 
-    std::vector<std::map<std::string, std::string>> getConnectionList(
-        const std::string& accountId, const std::string& conversationId);
+    std::vector<std::map<std::string, std::string>> getConnectionList(const std::string& accountId,
+                                                                      const std::string& conversationId);
     std::vector<std::map<std::string, std::string>> getChannelList(const std::string& accountId,
                                                                    const std::string& connectionId);
 
@@ -248,9 +249,9 @@ public:
      * @param the conference id
      */
     bool addSubCall(const std::string& accountId,
-                        const std::string& callId,
-                        const std::string& account2Id,
-                        const std::string& confId);
+                    const std::string& callId,
+                    const std::string& account2Id,
+                    const std::string& confId);
     bool addSubCall(Call& call, Conference& conference);
     void bindCallToConference(Call& call, Conference& conf);
 
@@ -275,8 +276,7 @@ public:
      * Create a conference from a list of participant
      * @param A vector containing the list of participant
      */
-    void createConfFromParticipantList(const std::string& accountId,
-                                       const std::vector<std::string>&);
+    void createConfFromParticipantList(const std::string& accountId, const std::vector<std::string>&);
 
     /**
      * Detach a participant from a conference, put the call on hold, do not hangup it
@@ -430,15 +430,10 @@ public:
      * @param accountID   The account identifier
      * @param details     The account parameters
      */
-    void setAccountDetails(const std::string& accountID,
-                           const std::map<std::string, std::string>& details);
+    void setAccountDetails(const std::string& accountID, const std::map<std::string, std::string>& details);
 
-    void setAccountActive(const std::string& accountID,
-                          bool active,
-                          bool shutdownConnections);
-    void loadAccountAndConversation(const std::string& accountId,
-                                    bool loadAll,
-                                    const std::string& convId);
+    void setAccountActive(const std::string& accountID, bool active, bool shutdownConnections);
+    void loadAccountAndConversation(const std::string& accountId, bool loadAll, const std::string& convId);
 
     std::mt19937_64 getSeededRandomEngine();
 
@@ -454,8 +449,7 @@ public:
      * @param accountId optionnal predetermined accountid to use
      * @return The account Id given to the new account
      */
-    std::string addAccount(const std::map<std::string, std::string>& details,
-                           const std::string& accountId = {});
+    std::string addAccount(const std::map<std::string, std::string>& details, const std::string& accountId = {});
 
     /**
      * Delete an existing account, unregister VoIPLink associated, and
@@ -526,6 +520,32 @@ public:
      */
     void setNoiseSuppressState(const std::string& state);
 
+    /**
+     * Get the echo cancellation engine state in
+     * the current audio layer.
+     * @return std::string The current state of echoCancel
+     */
+    std::string getEchoCancellationState() const;
+
+    /**
+     * Get the echo cancellation engine state from
+     * the current audio layer.
+     */
+    void setEchoCancellationState(const std::string& state);
+
+    /**
+     * Get the voice activity detection engine state from
+     * the current audio layer.
+     * @return bool The current state of voice activity detection
+     */
+    bool getVoiceActivityDetectionState() const;
+
+    /**
+     * Set the voice activity detection engine state in the current
+     * audio layer.
+     */
+    void setVoiceActivityDetectionState(bool state);
+
     bool isAGCEnabled() const;
     void setAGCState(bool enabled);
 
@@ -820,8 +840,7 @@ public:
      * @param mixer true if the SinkCient is the sink of a VideoMixer node. Default is false.
      * @return share_ptr<SinkClient> A shared pointer on the created instance.
      */
-    std::shared_ptr<video::SinkClient> createSinkClient(const std::string& id = "",
-                                                        bool mixer = false);
+    std::shared_ptr<video::SinkClient> createSinkClient(const std::string& id = "", bool mixer = false);
 
     /**
      * Create a SinkClient instance for each participant in a conference, store it in an internal
@@ -831,12 +850,11 @@ public:
      * @param videoStream the the VideoFrameActiveWriter to which the sinks should be attached
      * @param sinksMap A map between sink ids and the respective shared pointer.
      */
-    void createSinkClients(
-        const std::string& callId,
-        const ConfInfo& infos,
-        const std::vector<std::shared_ptr<video::VideoFrameActiveWriter>>& videoStreams,
-        std::map<std::string, std::shared_ptr<video::SinkClient>>& sinksMap,
-        const std::string& accountId = "");
+    void createSinkClients(const std::string& callId,
+                           const ConfInfo& infos,
+                           const std::vector<std::shared_ptr<video::VideoFrameActiveWriter>>& videoStreams,
+                           std::map<std::string, std::shared_ptr<video::SinkClient>>& sinksMap,
+                           const std::string& accountId = "");
 
     /**
      * Return an existing SinkClient instance as a shared_ptr associated to the given identifier.
@@ -852,8 +870,7 @@ public:
     unsigned dhtLogLevel {0}; // default = disable
     AccountFactory accountFactory;
 
-    std::vector<libjami::Message> getLastMessages(const std::string& accountID,
-                                                  const uint64_t& base_timestamp);
+    std::vector<libjami::Message> getLastMessages(const std::string& accountID, const uint64_t& base_timestamp);
 
     SIPVoIPLink& sipVoIPLink() const;
 #ifdef ENABLE_PLUGIN
