@@ -1,21 +1,19 @@
 /*
- *  Copyright (C) 2021-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
-
 #pragma once
 
 #include "noncopyable.h"
@@ -39,7 +37,8 @@ public:
     AudioProcessor(AudioFormat format, unsigned frameSize)
         : playbackQueue_(format, (int) frameSize)
         , recordQueue_(format, (int) frameSize)
-        , resampler_(new Resampler)
+        , inputResampler_(new Resampler)
+        , outputResampler_(new Resampler)
         , format_(format)
         , frameSize_(frameSize)
         , frameDurationMs_((unsigned int) (frameSize_ * (1.0 / format_.sample_rate) * 1000))
@@ -91,7 +90,8 @@ public:
 protected:
     AudioFrameResizer playbackQueue_;
     AudioFrameResizer recordQueue_;
-    std::unique_ptr<Resampler> resampler_;
+    std::unique_ptr<Resampler> inputResampler_;
+    std::unique_ptr<Resampler> outputResampler_;
     std::atomic_bool playbackStarted_;
     std::atomic_bool recordStarted_;
     AudioFormat format_;
@@ -118,21 +118,42 @@ protected:
      */
     bool tidyQueues()
     {
+        // We should track the overflows and log them infrequently (every 10 frames)
+        static int recordOverflowCount = 0;
+        static int playbackOverflowCount = 0;
+        const int overflowCountMax = 10;
+
         auto recordFrameSize = recordQueue_.frameSize();
         auto playbackFrameSize = playbackQueue_.frameSize();
         while (recordQueue_.samples() > recordFrameSize * 10
-            && 2 * playbackQueue_.samples() * recordFrameSize < recordQueue_.samples() * playbackFrameSize) {
-            JAMI_LOG("record overflow {:d} / {:d} - playback: {:d}", recordQueue_.samples(), frameSize_, playbackQueue_.samples());
+               && 2 * playbackQueue_.samples() * recordFrameSize < recordQueue_.samples() * playbackFrameSize) {
+            recordOverflowCount++;
             recordQueue_.dequeue();
         }
         while (playbackQueue_.samples() > playbackFrameSize * 10
-            && 2 * recordQueue_.samples() * playbackFrameSize < playbackQueue_.samples() * recordFrameSize) {
-            JAMI_LOG("playback overflow {:d} / {:d} - record: {:d}", playbackQueue_.samples(), frameSize_, recordQueue_.samples());
+               && 2 * recordQueue_.samples() * playbackFrameSize < playbackQueue_.samples() * recordFrameSize) {
+            playbackOverflowCount++;
             playbackQueue_.dequeue();
         }
-        if (recordQueue_.samples() < recordFrameSize
-            || playbackQueue_.samples() < playbackFrameSize) {
-            // If there are not enough samples in either queue, we can't
+
+        if (recordOverflowCount > overflowCountMax) {
+            JAMI_LOG("record overflow {:d} / {:d} - playback: {:d}",
+                     recordQueue_.samples(),
+                     frameSize_,
+                     playbackQueue_.samples());
+            recordOverflowCount = 0;
+        }
+
+        if (playbackOverflowCount > overflowCountMax) {
+            JAMI_LOG("playback overflow {:d} / {:d} - record: {:d}",
+                     playbackQueue_.samples(),
+                     frameSize_,
+                     recordQueue_.samples());
+            playbackOverflowCount = 0;
+        }
+
+        if (recordQueue_.samples() < recordFrameSize || playbackQueue_.samples() < playbackFrameSize) {
+            // If there are not enough samples in either queue, we are unable to
             // process anything.
             return true;
         }
@@ -180,9 +201,12 @@ private:
     void enqueue(AudioFrameResizer& frameResizer, std::shared_ptr<AudioFrame>&& buf)
     {
         if (buf->getFormat() != format_) {
-            frameResizer.enqueue(resampler_->resample(std::move(buf), format_));
-        } else
+            auto resampled = &frameResizer == &recordQueue_ ? inputResampler_->resample(std::move(buf), format_)
+                                                            : outputResampler_->resample(std::move(buf), format_);
+            frameResizer.enqueue(std::move(resampled));
+        } else {
             frameResizer.enqueue(std::move(buf));
+        }
     };
 };
 
