@@ -1,22 +1,18 @@
 /*
- *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Tristan Matthews <tristan.matthews@savoirfairelinux.com>
- *  Author: Philippe Gorley <philippe.gorley@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "libav_deps.h" // MUST BE INCLUDED FIRST
@@ -45,6 +41,7 @@
 #include "observer.h"
 
 #include <asio/io_context.hpp>
+#include <asio/post.hpp>
 #include <sstream>
 
 namespace jami {
@@ -74,9 +71,7 @@ void
 AudioRtpSession::startSender()
 {
     std::lock_guard lock(mutex_);
-    JAMI_DEBUG("Start audio RTP sender: input [{}] - muted [{}]",
-             input_,
-             muteState_ ? "YES" : "NO");
+    JAMI_DEBUG("Start audio RTP sender: input [{}] - muted [{}]", input_, muteState_ ? "YES" : "NO");
 
     if (not send_.enabled or send_.onHold) {
         JAMI_WARNING("Audio sending disabled");
@@ -109,20 +104,18 @@ AudioRtpSession::startSender()
 
     // sender sets up input correctly, we just keep a reference in case startSender is called
     audioInput_ = jami::getAudioInput(audioInputId);
-    audioInput_->setRecorderCallback(
-            [w=weak_from_this()](const MediaStream& ms) {
-                Manager::instance().ioContext()->post([w=std::move(w), ms]() {
-                    if (auto shared = w.lock())
-                        shared->attachLocalRecorder(ms);
-                });
-            });
+    audioInput_->setRecorderCallback([w = weak_from_this()](const MediaStream& ms) {
+        asio::post(*Manager::instance().ioContext(), [w = std::move(w), ms]() {
+            if (auto shared = w.lock())
+                shared->attachLocalRecorder(ms);
+        });
+    });
     audioInput_->setMuted(muteState_);
     audioInput_->setSuccessfulSetupCb(onSuccessfulSetup_);
     if (!fileAudio) {
         auto newParams = audioInput_->switchInput(input_);
         try {
-            if (newParams.valid()
-                && newParams.wait_for(NEWPARAMS_TIMEOUT) == std::future_status::ready) {
+            if (newParams.valid() && newParams.wait_for(NEWPARAMS_TIMEOUT) == std::future_status::ready) {
                 localAudioParams_ = newParams.get();
             } else {
                 JAMI_ERROR("No valid new audio parameters");
@@ -191,13 +184,11 @@ AudioRtpSession::startReceiver()
         JAMI_WARNING("Restarting audio receiver");
 
     auto accountAudioCodec = std::static_pointer_cast<SystemAudioCodecInfo>(receive_.codec);
-    receiveThread_.reset(new AudioReceiveThread(streamId_,
-                                                accountAudioCodec->audioformat,
-                                                receive_.receiving_sdp,
-                                                mtu_));
+    receiveThread_.reset(
+        new AudioReceiveThread(streamId_, accountAudioCodec->audioformat, receive_.receiving_sdp, mtu_));
 
-    receiveThread_->setRecorderCallback([w=weak_from_this()](const MediaStream& ms) {
-        Manager::instance().ioContext()->post([w=std::move(w), ms]() {
+    receiveThread_->setRecorderCallback([w = weak_from_this()](const MediaStream& ms) {
+        asio::post(*Manager::instance().ioContext(), [w = std::move(w), ms]() {
             if (auto shared = w.lock())
                 shared->attachRemoteRecorder(ms);
         });
@@ -280,7 +271,7 @@ AudioRtpSession::stop()
 void
 AudioRtpSession::setMuted(bool muted, Direction dir)
 {
-    Manager::instance().ioContext()->post([w=weak_from_this(), muted, dir]() {
+    asio::post(*Manager::instance().ioContext(), [w = weak_from_this(), muted, dir]() {
         if (auto shared = w.lock()) {
             std::lock_guard lock(shared->mutex_);
             if (dir == Direction::SEND) {
@@ -429,20 +420,18 @@ AudioRtpSession::initRecorder()
     if (!recorder_)
         return;
     if (receiveThread_)
-        receiveThread_->setRecorderCallback(
-            [w=weak_from_this()](const MediaStream& ms) {
-                Manager::instance().ioContext()->post([w=std::move(w), ms]() {
-                    if (auto shared = w.lock())
-                        shared->attachRemoteRecorder(ms);
-                });
+        receiveThread_->setRecorderCallback([w = weak_from_this()](const MediaStream& ms) {
+            asio::post(*Manager::instance().ioContext(), [w = std::move(w), ms]() {
+                if (auto shared = w.lock())
+                    shared->attachRemoteRecorder(ms);
+            });
         });
     if (audioInput_)
-        audioInput_->setRecorderCallback(
-            [w=weak_from_this()](const MediaStream& ms) {
-                Manager::instance().ioContext()->post([w=std::move(w), ms]() {
-                    if (auto shared = w.lock())
-                        shared->attachLocalRecorder(ms);
-                });
+        audioInput_->setRecorderCallback([w = weak_from_this()](const MediaStream& ms) {
+            asio::post(*Manager::instance().ioContext(), [w = std::move(w), ms]() {
+                if (auto shared = w.lock())
+                    shared->attachLocalRecorder(ms);
+            });
         });
 }
 
