@@ -1,24 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
- *  Author: Jerome Oufella <jerome.oufella@savoirfairelinux.com>
- *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
- *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 #pragma once
 
@@ -104,7 +98,7 @@ public:
     template<class Rep, class Period>
     bool waitForStart(const std::chrono::duration<Rep, Period>& rel_time) const
     {
-        std::unique_lock<std::mutex> lk(mutex_);
+        std::unique_lock lk(mutex_);
         startedCv_.wait_for(lk, rel_time, [this] { return isStarted(); });
         return isStarted();
     }
@@ -114,7 +108,7 @@ public:
      * Copy data in the urgent buffer.
      * @param buffer The buffer containing the data to be played ( ringtones )
      */
-    void putUrgent(AudioBuffer& buffer);
+    void putUrgent(std::shared_ptr<AudioFrame> buffer);
 
     /**
      * Start/Stop playing the incoming call notification sound (beep)
@@ -307,8 +301,7 @@ private:
     /**
      * Time of the last incoming call notification
      */
-    std::chrono::system_clock::time_point lastNotificationTime_ {
-        std::chrono::system_clock::time_point::min()};
+    std::chrono::system_clock::time_point lastNotificationTime_ {std::chrono::system_clock::time_point::min()};
 };
 
 } // namespace jami
