@@ -1,26 +1,18 @@
 /*
- *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
- *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
- *  Author: Laurielle Lea <laurielle.lea@savoirfairelinux.com>
- *  Author: Adrien Beraud <adrien.beraud@gmail.com>
- *
- *  Portions (c) Dominic Mazzoni (Audacity)
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "ringbuffer.h"
@@ -73,6 +65,16 @@ RingBuffer::flushAll()
         offset.second.offset = endPos_;
 }
 
+std::vector<std::string>
+RingBuffer::getSubscribers()
+{
+    std::vector<std::string> subscribers;
+    for (const auto& offset : readoffsets_) {
+        subscribers.push_back(offset.first);
+    }
+    return subscribers;
+}
+
 size_t
 RingBuffer::putLength() const
 {
@@ -243,7 +245,7 @@ RingBuffer::get(const std::string& ringbufferId)
 size_t
 RingBuffer::waitForDataAvailable(const std::string& ringbufferId, const time_point& deadline) const
 {
-    std::unique_lock<std::mutex> l(lock_);
+    std::unique_lock l(lock_);
 
     if (buffer_.empty())
         return 0;
