@@ -1,21 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Philippe Gorley <philippe.gorley@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "libav_deps.h" // MUST BE INCLUDED FIRST
@@ -25,10 +22,11 @@
 #include "manager.h"
 #include "media_io_handle.h"
 #include "media_recorder.h"
+#include "media_filter.h"
 #include "system_codec_container.h"
 #include "video/filter_transpose.h"
 #ifdef ENABLE_VIDEO
-#ifdef RING_ACCEL
+#ifdef ENABLE_HWACCEL
 #include "video/accel.h"
 #endif
 #endif
@@ -64,8 +62,7 @@ struct MediaRecorder::StreamObserver : public Observer<std::shared_ptr<MediaFram
 {
     const MediaStream info;
 
-    StreamObserver(const MediaStream& ms,
-                   std::function<void(const std::shared_ptr<MediaFrame>&)> func)
+    StreamObserver(const MediaStream& ms, std::function<void(const std::shared_ptr<MediaFrame>&)> func)
         : info(ms)
         , cb_(func) {};
 
@@ -74,26 +71,27 @@ struct MediaRecorder::StreamObserver : public Observer<std::shared_ptr<MediaFram
         while (observablesFrames_.size() > 0) {
             auto obs = observablesFrames_.begin();
             (*obs)->detach(this);
-            // it should be erased from observablesFrames_ in detach. If it does not happens erase frame to avoid infinite loop.
+            // it should be erased from observablesFrames_ in detach. If it does not happens erase frame to avoid
+            // infinite loop.
             auto it = observablesFrames_.find(*obs);
             if (it != observablesFrames_.end())
                 observablesFrames_.erase(it);
         }
     };
 
-    void update(Observable<std::shared_ptr<MediaFrame>>* /*ob*/,
-                const std::shared_ptr<MediaFrame>& m) override
+    void update(Observable<std::shared_ptr<MediaFrame>>* /*ob*/, const std::shared_ptr<MediaFrame>& m) override
     {
+        if (not isEnabled)
+            return;
 #ifdef ENABLE_VIDEO
         if (info.isVideo) {
             std::shared_ptr<VideoFrame> framePtr;
-#ifdef RING_ACCEL
-            auto desc = av_pix_fmt_desc_get(
-                (AVPixelFormat) (std::static_pointer_cast<VideoFrame>(m))->format());
+#ifdef ENABLE_HWACCEL
+            auto desc = av_pix_fmt_desc_get((AVPixelFormat) (std::static_pointer_cast<VideoFrame>(m))->format());
             if (desc && (desc->flags & AV_PIX_FMT_FLAG_HWACCEL)) {
                 try {
-                    framePtr = jami::video::HardwareAccel::transferToMainMemory(
-                        *std::static_pointer_cast<VideoFrame>(m), AV_PIX_FMT_NV12);
+                    framePtr = jami::video::HardwareAccel::transferToMainMemory(*std::static_pointer_cast<VideoFrame>(m),
+                                                                                AV_PIX_FMT_NV12);
                 } catch (const std::runtime_error& e) {
                     JAMI_ERR("Accel failure: %s", e.what());
                     return;
@@ -127,10 +125,7 @@ struct MediaRecorder::StreamObserver : public Observer<std::shared_ptr<MediaFram
 #endif
     }
 
-    void attached(Observable<std::shared_ptr<MediaFrame>>* obs) override
-    {
-        observablesFrames_.insert(obs);
-    }
+    void attached(Observable<std::shared_ptr<MediaFrame>>* obs) override { observablesFrames_.insert(obs); }
 
     void detached(Observable<std::shared_ptr<MediaFrame>>* obs) override
     {
@@ -139,6 +134,8 @@ struct MediaRecorder::StreamObserver : public Observer<std::shared_ptr<MediaFram
             observablesFrames_.erase(it);
     }
 
+    bool isEnabled = false;
+
 private:
     std::function<void(const std::shared_ptr<MediaFrame>&)> cb_;
     std::unique_ptr<MediaFilter> videoRotationFilter_ {};
@@ -195,23 +192,34 @@ MediaRecorder::startRecording()
     startTime_ = *std::localtime(&t);
     startTimeStamp_ = av_gettime();
 
-    std::lock_guard<std::mutex> lk(encoderMtx_);
+    std::lock_guard lk(encoderMtx_);
     encoder_.reset(new MediaEncoder);
 
-    JAMI_DBG() << "Start recording '" << getPath() << "'";
+    JAMI_LOG("Start recording '{}'", getPath());
     if (initRecord() >= 0) {
         isRecording_ = true;
+        {
+            std::lock_guard lk(mutexStreamSetup_);
+            for (auto& media : streams_) {
+                if (media.second->info.isVideo) {
+                    std::lock_guard lk2(mutexFilterVideo_);
+                    setupVideoOutput();
+                } else {
+                    std::lock_guard lk2(mutexFilterAudio_);
+                    setupAudioOutput();
+                }
+                media.second->isEnabled = true;
+            }
+        }
         // start thread after isRecording_ is set to true
         dht::ThreadPool::computation().run([rec = shared_from_this()] {
-            std::lock_guard<std::mutex> lk(rec->encoderMtx_);
+            std::lock_guard lk(rec->encoderMtx_);
             while (rec->isRecording()) {
                 std::shared_ptr<MediaFrame> frame;
                 // get frame from queue
                 {
-                    std::unique_lock<std::mutex> lk(rec->mutexFrameBuff_);
-                    rec->cv_.wait(lk, [rec] {
-                        return rec->interrupted_ or not rec->frameBuff_.empty();
-                    });
+                    std::unique_lock lk(rec->mutexFrameBuff_);
+                    rec->cv_.wait(lk, [rec] { return rec->interrupted_ or not rec->frameBuff_.empty(); });
                     if (rec->interrupted_) {
                         break;
                     }
@@ -223,8 +231,7 @@ MediaRecorder::startRecording()
                     if (rec->encoder_ && frame && frame->pointer()) {
 #ifdef ENABLE_VIDEO
                         bool isVideo = (frame->pointer()->width > 0 && frame->pointer()->height > 0);
-                        rec->encoder_->encode(frame->pointer(),
-                                              isVideo ? rec->videoIdx_ : rec->audioIdx_);
+                        rec->encoder_->encode(frame->pointer(), isVideo ? rec->videoIdx_ : rec->audioIdx_);
 #else
                         rec->encoder_->encode(frame->pointer(), rec->audioIdx_);
 #endif // ENABLE_VIDEO
@@ -249,6 +256,12 @@ MediaRecorder::stopRecording()
     if (isRecording_) {
         JAMI_DBG() << "Stop recording '" << getPath() << "'";
         isRecording_ = false;
+        {
+            std::lock_guard lk(mutexStreamSetup_);
+            for (auto& media : streams_) {
+                media.second->isEnabled = false;
+            }
+        }
         emitSignal<libjami::CallSignal::RecordPlaybackStopped>(getPath());
     }
 }
@@ -256,40 +269,53 @@ MediaRecorder::stopRecording()
 Observer<std::shared_ptr<MediaFrame>>*
 MediaRecorder::addStream(const MediaStream& ms)
 {
-    std::lock_guard<std::mutex> lk(mutexStreamSetup_);
+    bool streamIsNew = false;
+    std::lock_guard lk(mutexStreamSetup_);
     if (audioOnly_ && ms.isVideo) {
-        JAMI_ERR() << "Trying to add video stream to audio only recording";
+        JAMI_ERR() << "Attempting to add video stream to audio only recording";
         return nullptr;
     }
     if (ms.format < 0 || ms.name.empty()) {
-        JAMI_ERR() << "Trying to add invalid stream to recording";
+        JAMI_ERR() << "Attempting to add invalid stream to recording";
         return nullptr;
     }
 
     auto it = streams_.find(ms.name);
     if (it == streams_.end()) {
-        auto streamPtr = std::make_unique<StreamObserver>(ms,
-                                                          [this,
-                                                           ms](const std::shared_ptr<MediaFrame>& frame) {
-                                                              onFrame(ms.name, frame);
-                                                          });
+        auto streamPtr = std::make_unique<StreamObserver>(ms, [this, ms](const std::shared_ptr<MediaFrame>& frame) {
+            onFrame(ms.name, frame);
+        });
         it = streams_.insert(std::make_pair(ms.name, std::move(streamPtr))).first;
         JAMI_LOG("[Recorder: {:p}] Recorder input #{}: {:s}", fmt::ptr(this), streams_.size(), ms.name);
+        streamIsNew = true;
     } else {
-        JAMI_LOG("[Recorder: {:p}] Recorder already has '{:s}' as input", fmt::ptr(this), ms.name);
+        if (ms == it->second->info)
+            JAMI_LOG("[Recorder: {:p}] Recorder already has '{:s}' as input", fmt::ptr(this), ms.name);
+        else {
+            it->second = std::make_unique<StreamObserver>(ms, [this, ms](const std::shared_ptr<MediaFrame>& frame) {
+                onFrame(ms.name, frame);
+            });
+        }
+        streamIsNew = false;
     }
 
-    if (ms.isVideo)
-        setupVideoOutput();
-    else
-        setupAudioOutput();
+    if (streamIsNew && isRecording_) {
+        if (ms.isVideo) {
+            if (!videoFilter_ || videoFilter_->needsReinitForNewStream(ms.name))
+                setupVideoOutput();
+        } else {
+            if (!audioFilter_ || audioFilter_->needsReinitForNewStream(ms.name))
+                setupAudioOutput();
+        }
+    }
+    it->second->isEnabled = isRecording_;
     return it->second.get();
 }
 
 void
 MediaRecorder::removeStream(const MediaStream& ms)
 {
-    std::lock_guard<std::mutex> lk(mutexStreamSetup_);
+    std::lock_guard lk(mutexStreamSetup_);
 
     auto it = streams_.find(ms.name);
     if (it == streams_.end()) {
@@ -320,20 +346,18 @@ MediaRecorder::onFrame(const std::string& name, const std::shared_ptr<MediaFrame
     if (not isRecording_ || interrupted_)
         return;
 
-    std::lock_guard<std::mutex> lk(mutexStreamSetup_);
+    std::lock_guard lk(mutexStreamSetup_);
 
     // copy frame to not mess with the original frame's pts (does not actually copy frame data)
     std::unique_ptr<MediaFrame> clone;
     const auto& ms = streams_[name]->info;
-#if defined(ENABLE_VIDEO) && defined(RING_ACCEL)
+#if defined(ENABLE_VIDEO) && defined(ENABLE_HWACCEL)
     if (ms.isVideo) {
-        auto desc = av_pix_fmt_desc_get(
-            (AVPixelFormat) (std::static_pointer_cast<VideoFrame>(frame))->format());
+        auto desc = av_pix_fmt_desc_get((AVPixelFormat) (std::static_pointer_cast<VideoFrame>(frame))->format());
         if (desc && (desc->flags & AV_PIX_FMT_FLAG_HWACCEL)) {
             try {
-                clone = video::HardwareAccel::transferToMainMemory(
-                    *std::static_pointer_cast<VideoFrame>(frame),
-                    static_cast<AVPixelFormat>(ms.format));
+                clone = video::HardwareAccel::transferToMainMemory(*std::static_pointer_cast<VideoFrame>(frame),
+                                                                   static_cast<AVPixelFormat>(ms.format));
             } catch (const std::runtime_error& e) {
                 JAMI_ERR("Accel failure: %s", e.what());
                 return;
@@ -343,43 +367,44 @@ MediaRecorder::onFrame(const std::string& name, const std::shared_ptr<MediaFrame
             clone->copyFrom(*frame);
         }
     } else {
-#endif // ENABLE_VIDEO && RING_ACCEL
+#endif // ENABLE_VIDEO && ENABLE_HWACCEL
         clone = std::make_unique<MediaFrame>();
         clone->copyFrom(*frame);
-#if defined(ENABLE_VIDEO) && defined(RING_ACCEL)
+#if defined(ENABLE_VIDEO) && defined(ENABLE_HWACCEL)
     }
-#endif // ENABLE_VIDEO && RING_ACCEL
+#endif // ENABLE_VIDEO && ENABLE_HWACCEL
     clone->pointer()->pts = av_rescale_q_rnd(av_gettime() - startTimeStamp_,
                                              {1, AV_TIME_BASE},
                                              ms.timeBase,
-                                             static_cast<AVRounding>(AV_ROUND_NEAR_INF
-                                                                     | AV_ROUND_PASS_MINMAX));
-    std::unique_ptr<MediaFrame> filteredFrame;
+                                             static_cast<AVRounding>(AV_ROUND_NEAR_INF | AV_ROUND_PASS_MINMAX));
+    std::vector<std::unique_ptr<MediaFrame>> filteredFrames;
 #ifdef ENABLE_VIDEO
     if (ms.isVideo && videoFilter_ && outputVideoFilter_) {
-        std::lock_guard<std::mutex> lk(mutexFilterVideo_);
+        std::lock_guard lk(mutexFilterVideo_);
         videoFilter_->feedInput(clone->pointer(), name);
         auto videoFilterOutput = videoFilter_->readOutput();
         if (videoFilterOutput) {
             outputVideoFilter_->feedInput(videoFilterOutput->pointer(), "input");
-            filteredFrame = outputVideoFilter_->readOutput();
+            while (auto fFrame = outputVideoFilter_->readOutput()) {
+                filteredFrames.emplace_back(std::move(fFrame));
+            }
         }
     } else if (audioFilter_ && outputAudioFilter_) {
 #endif // ENABLE_VIDEO
-        std::lock_guard<std::mutex> lkA(mutexFilterAudio_);
+        std::lock_guard lkA(mutexFilterAudio_);
         audioFilter_->feedInput(clone->pointer(), name);
         auto audioFilterOutput = audioFilter_->readOutput();
         if (audioFilterOutput) {
             outputAudioFilter_->feedInput(audioFilterOutput->pointer(), "input");
-            filteredFrame = outputAudioFilter_->readOutput();
+            filteredFrames.emplace_back(outputAudioFilter_->readOutput());
         }
 #ifdef ENABLE_VIDEO
     }
 #endif // ENABLE_VIDEO
 
-    if (filteredFrame) {
-        std::lock_guard<std::mutex> lk(mutexFrameBuff_);
-        frameBuff_.emplace_back(std::move(filteredFrame));
+    for (auto& fFrame : filteredFrames) {
+        std::lock_guard lk(mutexFrameBuff_);
+        frameBuff_.emplace_back(std::move(fFrame));
         cv_.notify_one();
     }
 }
@@ -406,7 +431,7 @@ MediaRecorder::initRecord()
     encoder_->setMetadata(title_, description_);
     encoder_->openOutput(getPath());
 #ifdef ENABLE_VIDEO
-#ifdef RING_ACCEL
+#ifdef ENABLE_HWACCEL
     encoder_->enableAccel(false); // TODO recorder has problems with hardware encoding
 #endif
 #endif // ENABLE_VIDEO
@@ -468,22 +493,19 @@ MediaRecorder::setupVideoOutput()
 {
     MediaStream encoderStream, peer, local, mixer;
     auto it = std::find_if(streams_.begin(), streams_.end(), [](const auto& pair) {
-        return pair.second->info.isVideo
-               && pair.second->info.name.find("remote") != std::string::npos;
+        return pair.second->info.isVideo && pair.second->info.name.find("remote") != std::string::npos;
     });
     if (it != streams_.end())
         peer = it->second->info;
 
     it = std::find_if(streams_.begin(), streams_.end(), [](const auto& pair) {
-        return pair.second->info.isVideo
-               && pair.second->info.name.find("local") != std::string::npos;
+        return pair.second->info.isVideo && pair.second->info.name.find("local") != std::string::npos;
     });
     if (it != streams_.end())
         local = it->second->info;
 
     it = std::find_if(streams_.begin(), streams_.end(), [](const auto& pair) {
-        return pair.second->info.isVideo
-               && pair.second->info.name.find("mixer") != std::string::npos;
+        return pair.second->info.isVideo && pair.second->info.name.find("mixer") != std::string::npos;
     });
     if (it != streams_.end())
         mixer = it->second->info;
@@ -494,7 +516,7 @@ MediaRecorder::setupVideoOutput()
     int streams = peer.isValid() + local.isValid() + mixer.isValid();
     switch (streams) {
     case 0: {
-        JAMI_WARN() << "Trying to record a video stream but none is valid";
+        JAMI_WARN() << "Attempting to record a video stream but none is valid";
         return;
     }
     case 1: {
@@ -506,7 +528,7 @@ MediaRecorder::setupVideoOutput()
         else if (mixer.isValid())
             inputStream = mixer;
         else {
-            JAMI_ERR("Trying to record a stream but none is valid");
+            JAMI_ERR("Attempting to record a stream but none is valid");
             break;
         }
 
@@ -538,14 +560,15 @@ MediaRecorder::setupVideoOutput()
 
     outputVideoFilter_.reset(new MediaFilter);
 
-    float scaledHeight = 1280 * (float)secondaryFilter.height / (float)secondaryFilter.width;
+    float scaledHeight = 1280 * (float) secondaryFilter.height / (float) secondaryFilter.width;
     std::string scaleFilter = "scale=1280:-2";
     if (scaledHeight > 720)
         scaleFilter += ",scale=-2:720";
 
-    ret = outputVideoFilter_->initialize(
-        "[input]" + scaleFilter + ",pad=1280:720:(ow-iw)/2:(oh-ih)/2,format=pix_fmts=yuv420p,fps=30",
-        {secondaryFilter});
+    std::ostringstream f;
+    f << "[input]" << scaleFilter << ",pad=1280:720:(ow-iw)/2:(oh-ih)/2,format=pix_fmts=yuv420p,fps=30";
+
+    ret = outputVideoFilter_->initialize(f.str(), {secondaryFilter});
 
     if (ret < 0) {
         JAMI_ERR() << "Failed to initialize output video filter";
@@ -557,8 +580,7 @@ MediaRecorder::setupVideoOutput()
 }
 
 std::string
-MediaRecorder::buildVideoFilter(const std::vector<MediaStream>& peers,
-                                const MediaStream& local) const
+MediaRecorder::buildVideoFilter(const std::vector<MediaStream>& peers, const MediaStream& local) const
 {
     std::ostringstream v;
 
@@ -569,21 +591,18 @@ MediaRecorder::buildVideoFilter(const std::vector<MediaStream>& peers,
     case 1: {
         auto p = peers[0];
         const constexpr int minHeight = 720;
-        const auto newFps = std::max(p.frameRate, local.frameRate);
         const bool needScale = (p.height < minHeight);
         const int newHeight = (needScale ? minHeight : p.height);
 
         // NOTE -2 means preserve aspect ratio and have the new number be even
         if (needScale)
-            v << "[" << p.name << "] fps=" << newFps << ", scale=-2:" << newHeight << " [v:m]; ";
+            v << "[" << p.name << "] fps=30, scale=-2:" << newHeight << " [v:m]; ";
         else
-            v << "[" << p.name << "] fps=" << newFps << " [v:m]; ";
+            v << "[" << p.name << "] fps=30 [v:m]; ";
 
-        v << "[" << local.name << "] fps=" << newFps << ", scale=-2:" << newHeight / 5
-          << " [v:o]; ";
+        v << "[" << local.name << "] fps=30, scale=-2:" << newHeight / 5 << " [v:o]; ";
 
-        v << "[v:m] [v:o] overlay=main_w-overlay_w:main_h-overlay_h"
-          << ", format=pix_fmts=yuv420p";
+        v << "[v:m] [v:o] overlay=main_w-overlay_w:main_h-overlay_h" << ", format=pix_fmts=yuv420p";
     } break;
     default:
         JAMI_ERR() << "Video recordings with more than 2 video streams are not supported";
@@ -596,60 +615,25 @@ MediaRecorder::buildVideoFilter(const std::vector<MediaStream>& peers,
 void
 MediaRecorder::setupAudioOutput()
 {
-    MediaStream encoderStream, peer, local, mixer;
-    auto it = std::find_if(streams_.begin(), streams_.end(), [](const auto& pair) {
-        return !pair.second->info.isVideo
-               && pair.second->info.name.find("remote") != std::string::npos;
-    });
-    if (it != streams_.end())
-        peer = it->second->info;
-
-    it = std::find_if(streams_.begin(), streams_.end(), [](const auto& pair) {
-        return !pair.second->info.isVideo
-               && pair.second->info.name.find("local") != std::string::npos;
-    });
-    if (it != streams_.end())
-        local = it->second->info;
-
-    it = std::find_if(streams_.begin(), streams_.end(), [](const auto& pair) {
-        return !pair.second->info.isVideo
-               && pair.second->info.name.find("mixer") != std::string::npos;
-    });
-    if (it != streams_.end())
-        local = it->second->info;
+    MediaStream encoderStream;
 
     // resample to common audio format, so any player can play the file
     audioFilter_.reset(new MediaFilter);
     int ret = -1;
-    int streams = peer.isValid() + local.isValid() + mixer.isValid();
-    switch (streams) {
-    case 0: {
-        JAMI_WARN() << "Trying to record a audio stream but none is valid";
+
+    if (streams_.empty()) {
+        JAMI_WARN() << "Attempting to record a audio stream but none is valid";
         return;
     }
-    case 1: {
-        MediaStream inputStream;
-        if (peer.isValid())
-            inputStream = peer;
-        else if (local.isValid())
-            inputStream = local;
-        else if (mixer.isValid())
-            inputStream = mixer;
-        else {
-            JAMI_ERR("Trying to record a stream but none is valid");
-            break;
-        }
-        ret = audioFilter_->initialize(buildAudioFilter({}, inputStream), {inputStream});
-        break;
-    }
-    case 2: // mix both audio streams
-        ret = audioFilter_->initialize(buildAudioFilter({peer}, local), {peer, local});
-        break;
-    default:
-        JAMI_ERR() << "Recording more than 2 audio streams is not supported";
-        break;
+
+    std::vector<MediaStream> peers {};
+    for (const auto& media : streams_) {
+        if (!media.second->info.isVideo && media.second->info.isValid())
+            peers.emplace_back(media.second->info);
     }
 
+    ret = audioFilter_->initialize(buildAudioFilter(peers), peers);
+
     if (ret < 0) {
         JAMI_ERR() << "Failed to initialize audio filter";
         return;
@@ -666,9 +650,8 @@ MediaRecorder::setupAudioOutput()
     }
 
     outputAudioFilter_.reset(new MediaFilter);
-    ret = outputAudioFilter_
-            ->initialize("[input]aformat=sample_fmts=s16:sample_rates=48000:channel_layouts=stereo",
-                                       {secondaryFilter});
+    ret = outputAudioFilter_->initialize("[input]aformat=sample_fmts=s16:sample_rates=48000:channel_layouts=stereo",
+                                         {secondaryFilter});
 
     if (ret < 0) {
         JAMI_ERR() << "Failed to initialize output audio filter";
@@ -678,40 +661,33 @@ MediaRecorder::setupAudioOutput()
 }
 
 std::string
-MediaRecorder::buildAudioFilter(const std::vector<MediaStream>& peers,
-                                const MediaStream& local) const
+MediaRecorder::buildAudioFilter(const std::vector<MediaStream>& peers) const
 {
     std::string baseFilter = "aresample=osr=48000:ochl=stereo:osf=s16";
     std::ostringstream a;
 
-    switch (peers.size()) {
-    case 0:
-        a << "[" << local.name << "] " << baseFilter;
-        break;
-    default:
-        a << "[" << local.name << "] ";
-        for (const auto& ms : peers)
-            a << "[" << ms.name << "] ";
-        a << " amix=inputs=" << peers.size() + (local.isValid() ? 1 : 0) << ", " << baseFilter;
-        break;
-    }
-
+    for (const auto& ms : peers)
+        a << "[" << ms.name << "] ";
+    a << " amix=inputs=" << peers.size() << ", " << baseFilter;
     return a.str();
 }
 
 void
 MediaRecorder::flush()
 {
-    if (videoFilter_) {
-        std::lock_guard<std::mutex> lk(mutexFilterVideo_);
-        videoFilter_->flush();
-        outputVideoFilter_->flush();
+    {
+        std::lock_guard lk(mutexFilterVideo_);
+        if (videoFilter_)
+            videoFilter_->flush();
+        if (outputVideoFilter_)
+            outputVideoFilter_->flush();
     }
-
-    if (audioFilter_) {
-        std::lock_guard<std::mutex> lk(mutexFilterAudio_);
-        audioFilter_->flush();
-        outputAudioFilter_->flush();
+    {
+        std::lock_guard lk(mutexFilterAudio_);
+        if (audioFilter_)
+            audioFilter_->flush();
+        if (outputAudioFilter_)
+            outputAudioFilter_->flush();
     }
     if (encoder_)
         encoder_->flush();
@@ -721,14 +697,23 @@ void
 MediaRecorder::reset()
 {
     {
-        std::lock_guard<std::mutex> lk(mutexFrameBuff_);
+        std::lock_guard lk(mutexFrameBuff_);
         frameBuff_.clear();
     }
     videoIdx_ = audioIdx_ = -1;
-    videoFilter_.reset();
-    audioFilter_.reset();
-    outputAudioFilter_.reset();
-    outputVideoFilter_.reset();
+    {
+        std::lock_guard lk(mutexStreamSetup_);
+        {
+            std::lock_guard lk2(mutexFilterVideo_);
+            videoFilter_.reset();
+            outputVideoFilter_.reset();
+        }
+        {
+            std::lock_guard lk2(mutexFilterAudio_);
+            audioFilter_.reset();
+            outputAudioFilter_.reset();
+        }
+    }
     encoder_.reset();
 }
 
