@@ -1,21 +1,18 @@
 /*
- *  Copyright (C) 2020-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Aline Gondim Santos <aline.gondimsantos@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "jamipluginmanager.h"
@@ -31,7 +28,7 @@
 #include <stdexcept>
 #include <msgpack.hpp>
 
-#define FAILURE                        -1
+#define FAILURE                         -1
 #define SUCCESS                         0
 #define PLUGIN_ALREADY_INSTALLED        100 /* Plugin already installed with the same version */
 #define PLUGIN_OLD_VERSION              200 /* Plugin already installed with a newer version */
@@ -39,7 +36,6 @@
 #define CERTIFICATE_VERIFICATION_FAILED 400
 #define INVALID_PLUGIN                  500
 
-
 #ifdef WIN32
 #define LIB_TYPE   ".dll"
 #define LIB_PREFIX ""
@@ -69,7 +65,7 @@ JamiPluginManager::getPluginAuthor(const std::string& rootPath, const std::strin
 {
     auto cert = PluginUtils::readPluginCertificate(rootPath, pluginId);
     if (!cert) {
-        JAMI_ERROR("Could not read plugin certificate");
+        JAMI_ERROR("Unable to read plugin certificate");
         return {};
     }
     return cert->getIssuerName();
@@ -85,8 +81,8 @@ JamiPluginManager::getPluginDetails(const std::string& rootPath, bool reset)
         pluginDetailsMap_.erase(detailsIt);
     }
 
-    std::map<std::string, std::string> details = PluginUtils::parseManifestFile(
-        PluginUtils::manifestPath(rootPath), rootPath);
+    std::map<std::string, std::string> details = PluginUtils::parseManifestFile(PluginUtils::manifestPath(rootPath),
+                                                                                rootPath);
     if (!details.empty()) {
         auto itIcon = details.find("iconPath");
         itIcon->second.insert(0, rootPath + DIR_SEPARATOR_CH + "data" + DIR_SEPARATOR_CH);
@@ -116,8 +112,7 @@ JamiPluginManager::getInstalledPlugins()
     }
 
     // Gets plugins installed in non standard path
-    std::vector<std::string> nonStandardInstalls = jami::Manager::instance()
-                                                       .pluginPreferences.getInstalledPlugins();
+    std::vector<std::string> nonStandardInstalls = jami::Manager::instance().pluginPreferences.getInstalledPlugins();
     for (auto& path : nonStandardInstalls) {
         if (PluginUtils::checkPluginValidity(path))
             pluginsPaths.emplace_back(path);
@@ -129,12 +124,12 @@ JamiPluginManager::getInstalledPlugins()
 bool
 JamiPluginManager::checkPluginCertificatePublicKey(const std::string& oldJplPath, const std::string& newJplPath)
 {
-    std::map<std::string, std::string> oldDetails = PluginUtils::parseManifestFile(PluginUtils::manifestPath(oldJplPath), oldJplPath);
-    if (
-        oldDetails.empty() ||
-        !std::filesystem::is_regular_file(oldJplPath + DIR_SEPARATOR_CH + oldDetails["id"] + ".crt") ||
-        !std::filesystem::is_regular_file(newJplPath)
-    )
+    std::map<std::string, std::string> oldDetails = PluginUtils::parseManifestFile(PluginUtils::manifestPath(oldJplPath),
+                                                                                   oldJplPath);
+    std::error_code ec;
+    if (oldDetails.empty()
+        || !std::filesystem::is_regular_file(oldJplPath + DIR_SEPARATOR_CH + oldDetails["id"] + ".crt", ec)
+        || !std::filesystem::is_regular_file(newJplPath, ec))
         return false;
     try {
         auto oldCert = PluginUtils::readPluginCertificate(oldJplPath, oldDetails["id"]);
@@ -153,8 +148,14 @@ JamiPluginManager::checkPluginCertificatePublicKey(const std::string& oldJplPath
 bool
 JamiPluginManager::checkPluginCertificateValidity(dht::crypto::Certificate* cert)
 {
+    if (!cert || !*cert)
+        return false;
     trust_.add(crypto::Certificate(store_ca_crt, sizeof(store_ca_crt)));
-    return cert && *cert && trust_.verify(*cert);
+    auto result = trust_.verify(*cert);
+    if (!result) {
+        JAMI_ERROR("Certificate verification failed: {}", result.toString());
+    }
+    return (bool) result;
 }
 
 std::map<std::string, std::string>
@@ -167,7 +168,8 @@ bool
 JamiPluginManager::checkPluginSignatureFile(const std::string& jplPath)
 {
     // check if the file exists
-    if (!std::filesystem::is_regular_file(jplPath)){
+    std::error_code ec;
+    if (!std::filesystem::is_regular_file(jplPath, ec)) {
         return false;
     }
     try {
@@ -198,7 +200,7 @@ JamiPluginManager::checkPluginSignatureValidity(const std::string& jplPath, dht:
 {
     if (!std::filesystem::is_regular_file(jplPath))
         return false;
-    try{
+    try {
         const auto& pk = cert->getPublicKey();
         auto signaturesData = archiver::readFileFromArchive(jplPath, "signatures");
         auto signatureFile = PluginUtils::readSignatureFileFromArchive(jplPath);
@@ -207,7 +209,7 @@ JamiPluginManager::checkPluginSignatureValidity(const std::string& jplPath, dht:
         auto signatures = PluginUtils::readPluginSignatureFromArchive(jplPath);
         for (const auto& signature : signatures) {
             auto file = archiver::readFileFromArchive(jplPath, signature.first);
-            if (!pk.checkSignature(file, signature.second)){
+            if (!pk.checkSignature(file, signature.second)) {
                 JAMI_ERROR("{} not correctly signed", signature.first);
                 return false;
             }
@@ -225,8 +227,7 @@ JamiPluginManager::checkPluginSignature(const std::string& jplPath, dht::crypto:
     if (!std::filesystem::is_regular_file(jplPath) || !cert || !*cert)
         return false;
     try {
-        return  checkPluginSignatureValidity(jplPath, cert) &&
-                checkPluginSignatureFile(jplPath);
+        return checkPluginSignatureValidity(jplPath, cert) && checkPluginSignatureFile(jplPath);
     } catch (const std::exception& e) {
         return false;
     }
@@ -239,7 +240,7 @@ JamiPluginManager::checkPluginCertificate(const std::string& jplPath, bool force
         return {};
     try {
         auto cert = PluginUtils::readPluginCertificateFromArchive(jplPath);
-        if(checkPluginCertificateValidity(cert.get()) || force){
+        if (checkPluginCertificateValidity(cert.get()) || force) {
             return cert;
         }
         return {};
@@ -252,7 +253,8 @@ int
 JamiPluginManager::installPlugin(const std::string& jplPath, bool force)
 {
     int r {SUCCESS};
-    if (std::filesystem::is_regular_file(jplPath)) {
+    std::error_code ec;
+    if (std::filesystem::is_regular_file(jplPath, ec)) {
         try {
             auto manifestMap = PluginUtils::readPluginManifestFromArchive(jplPath);
             const std::string& name = manifestMap["id"];
@@ -261,32 +263,29 @@ JamiPluginManager::installPlugin(const std::string& jplPath, bool force)
             auto cert = checkPluginCertificate(jplPath, force);
             if (!cert)
                 return CERTIFICATE_VERIFICATION_FAILED;
-            if(!checkPluginSignature(jplPath, cert.get()))
+            if (!checkPluginSignature(jplPath, cert.get()))
                 return SIGNATURE_VERIFICATION_FAILED;
             const std::string& version = manifestMap["version"];
             auto destinationDir = (fileutils::get_data_dir() / "plugins" / name).string();
             // Find if there is an existing version of this plugin
-            const auto alreadyInstalledManifestMap = PluginUtils::parseManifestFile(
-                PluginUtils::manifestPath(destinationDir), destinationDir);
+            const auto alreadyInstalledManifestMap = PluginUtils::parseManifestFile(PluginUtils::manifestPath(
+                                                                                        destinationDir),
+                                                                                    destinationDir);
 
             if (!alreadyInstalledManifestMap.empty()) {
                 if (force) {
                     r = uninstallPlugin(destinationDir);
                     if (r == SUCCESS) {
-                        archiver::uncompressArchive(jplPath,
-                                                    destinationDir,
-                                                    PluginUtils::uncompressJplFunction);
+                        archiver::uncompressArchive(jplPath, destinationDir, PluginUtils::uncompressJplFunction);
                     }
                 } else {
                     std::string installedVersion = alreadyInstalledManifestMap.at("version");
                     if (version > installedVersion) {
-                        if(!checkPluginCertificatePublicKey(destinationDir, jplPath))
+                        if (!checkPluginCertificatePublicKey(destinationDir, jplPath))
                             return CERTIFICATE_VERIFICATION_FAILED;
                         r = uninstallPlugin(destinationDir);
                         if (r == SUCCESS) {
-                            archiver::uncompressArchive(jplPath,
-                                                        destinationDir,
-                                                        PluginUtils::uncompressJplFunction);
+                            archiver::uncompressArchive(jplPath, destinationDir, PluginUtils::uncompressJplFunction);
                         }
                     } else if (version == installedVersion) {
                         r = PLUGIN_ALREADY_INSTALLED;
@@ -295,9 +294,7 @@ JamiPluginManager::installPlugin(const std::string& jplPath, bool force)
                     }
                 }
             } else {
-                archiver::uncompressArchive(jplPath,
-                                            destinationDir,
-                                            PluginUtils::uncompressJplFunction);
+                archiver::uncompressArchive(jplPath, destinationDir, PluginUtils::uncompressJplFunction);
             }
             if (!libjami::getPluginsEnabled()) {
                 libjami::setPluginsEnabled(true);
@@ -325,13 +322,13 @@ JamiPluginManager::uninstallPlugin(const std::string& rootPath)
                 JAMI_INFO() << "PLUGIN: unloading before uninstall.";
                 bool status = libjami::unloadPlugin(rootPath);
                 if (!status) {
-                    JAMI_INFO() << "PLUGIN: could not unload, not performing uninstall.";
+                    JAMI_INFO() << "PLUGIN: unable to unload, not performing uninstall.";
                     return FAILURE;
                 }
             }
             for (const auto& accId : jami::Manager::instance().getAccountList())
-                std::filesystem::remove_all(fileutils::get_data_dir() / accId
-                                     / "plugins" / detailsIt->second.at("id"), ec);
+                std::filesystem::remove_all(fileutils::get_data_dir() / accId / "plugins" / detailsIt->second.at("id"),
+                                            ec);
             pluginDetailsMap_.erase(detailsIt);
         }
         return std::filesystem::remove_all(rootPath, ec) ? SUCCESS : FAILURE;
@@ -399,9 +396,7 @@ JamiPluginManager::getLoadedPlugins() const
     std::transform(loadedSoPlugins.begin(),
                    loadedSoPlugins.end(),
                    std::back_inserter(loadedPlugins),
-                   [](const std::string& soPath) {
-                       return PluginUtils::getRootPathFromSoPath(soPath).string();
-                   });
+                   [](const std::string& soPath) { return PluginUtils::getRootPathFromSoPath(soPath).string(); });
     return loadedPlugins;
 }
 
@@ -438,8 +433,8 @@ JamiPluginManager::setPluginPreference(const std::filesystem::path& rootPath,
 
     std::map<std::string, std::string> pluginUserPreferencesMap
         = PluginPreferencesUtils::getUserPreferencesValuesMap(rootPath, acc);
-    std::map<std::string, std::string> pluginPreferencesMap
-        = PluginPreferencesUtils::getPreferencesValuesMap(rootPath, acc);
+    std::map<std::string, std::string> pluginPreferencesMap = PluginPreferencesUtils::getPreferencesValuesMap(rootPath,
+                                                                                                              acc);
 
     // If any plugin handler is active we may have to reload it
     bool force {pm_.checkLoadedPlugin(rootPath.string())};
@@ -456,8 +451,7 @@ JamiPluginManager::setPluginPreference(const std::filesystem::path& rootPath,
     auto find = pluginPreferencesMap.find(key);
     if (find != pluginPreferencesMap.end()) {
         pluginUserPreferencesMap[key] = value;
-        auto preferencesValuesFilePath
-            = PluginPreferencesUtils::valuesFilePath(rootPath, acc);
+        auto preferencesValuesFilePath = PluginPreferencesUtils::valuesFilePath(rootPath, acc);
         std::lock_guard guard(dhtnet::fileutils::getFileLock(preferencesValuesFilePath));
         std::ofstream fs(preferencesValuesFilePath, std::ios::binary);
         if (!fs.good()) {
@@ -483,15 +477,13 @@ JamiPluginManager::setPluginPreference(const std::filesystem::path& rootPath,
 }
 
 std::map<std::string, std::string>
-JamiPluginManager::getPluginPreferencesValuesMap(const std::string& rootPath,
-                                                 const std::string& accountId)
+JamiPluginManager::getPluginPreferencesValuesMap(const std::string& rootPath, const std::string& accountId)
 {
     return PluginPreferencesUtils::getPreferencesValuesMap(rootPath, accountId);
 }
 
 bool
-JamiPluginManager::resetPluginPreferencesValuesMap(const std::string& rootPath,
-                                                   const std::string& accountId)
+JamiPluginManager::resetPluginPreferencesValuesMap(const std::string& rootPath, const std::string& accountId)
 {
     bool acc {accountId.empty()};
     bool loaded {pm_.checkLoadedPlugin(rootPath)};
@@ -511,8 +503,7 @@ JamiPluginManager::registerServices()
     // Register getPluginPreferences so that plugin's can receive it's preferences
     pm_.registerService("getPluginPreferences", [](const DLPlugin* plugin, void* data) {
         auto ppp = static_cast<std::map<std::string, std::string>*>(data);
-        *ppp = PluginPreferencesUtils::getPreferencesValuesMap(
-            PluginUtils::getRootPathFromSoPath(plugin->getPath()));
+        *ppp = PluginPreferencesUtils::getPreferencesValuesMap(PluginUtils::getRootPathFromSoPath(plugin->getPath()));
         return SUCCESS;
     });
 
@@ -530,21 +521,22 @@ JamiPluginManager::registerServices()
         if (!preferencesPtr)
             return FAILURE;
 
-        preferencesPtr->emplace("default",
-                                PluginPreferencesUtils::getPreferencesValuesMap(path, "default"));
+        preferencesPtr->emplace("default", PluginPreferencesUtils::getPreferencesValuesMap(path, "default"));
 
         for (const auto& accId : jami::Manager::instance().getAccountList())
-            preferencesPtr->emplace(accId,
-                                    PluginPreferencesUtils::getPreferencesValuesMap(path, accId));
+            preferencesPtr->emplace(accId, PluginPreferencesUtils::getPreferencesValuesMap(path, accId));
         return SUCCESS;
     };
 
     pm_.registerService("getPluginAccPreferences", getPluginAccPreferences);
 }
 
+#ifdef LIBJAMI_TEST
 void
 JamiPluginManager::addPluginAuthority(const dht::crypto::Certificate& cert)
 {
     trust_.add(cert);
 }
+#endif
+
 } // namespace jami
