@@ -1,26 +1,19 @@
 /*
- *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
- *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
- *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
- *  Author: Pierre-Luc Bacon <pierre-luc.bacon@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
-
 #pragma once
 
 #ifdef HAVE_CONFIG_H
@@ -56,18 +49,12 @@ class SIPAccount : public SIPAccountBase
 public:
     constexpr static auto ACCOUNT_TYPE = ACCOUNT_TYPE_SIP;
 
-    std::shared_ptr<SIPAccount> shared()
-    {
-        return std::static_pointer_cast<SIPAccount>(shared_from_this());
-    }
+    std::shared_ptr<SIPAccount> shared() { return std::static_pointer_cast<SIPAccount>(shared_from_this()); }
     std::shared_ptr<SIPAccount const> shared() const
     {
         return std::static_pointer_cast<SIPAccount const>(shared_from_this());
     }
-    std::weak_ptr<SIPAccount> weak()
-    {
-        return std::static_pointer_cast<SIPAccount>(shared_from_this());
-    }
+    std::weak_ptr<SIPAccount> weak() { return std::static_pointer_cast<SIPAccount>(shared_from_this()); }
     std::weak_ptr<SIPAccount const> weak() const
     {
         return std::static_pointer_cast<SIPAccount const>(shared_from_this());
@@ -81,10 +68,7 @@ public:
 
     ~SIPAccount() noexcept;
 
-    const SipAccountConfig& config() const
-    {
-        return *static_cast<const SipAccountConfig*>(&Account::config());
-    }
+    const SipAccountConfig& config() const { return *static_cast<const SipAccountConfig*>(&Account::config()); }
 
     std::unique_ptr<AccountConfig> buildConfig() const override
     {
@@ -92,8 +76,7 @@ public:
     }
     inline void editConfig(std::function<void(SipAccountConfig& conf)>&& edit)
     {
-        Account::editConfig(
-            [&](AccountConfig& conf) { edit(*static_cast<SipAccountConfig*>(&conf)); });
+        Account::editConfig([&](AccountConfig& conf) { edit(*static_cast<SipAccountConfig*>(&conf)); });
     }
 
     std::string_view getAccountType() const override { return ACCOUNT_TYPE; }
@@ -134,6 +117,14 @@ public:
      */
     void loadConfig() override;
 
+    /**
+     * updates SIP account profile
+     */
+    void updateProfile(const std::string& displayName,
+                       const std::string& avatar,
+                       const std::string& fileType,
+                       int32_t flag) override;
+
     /**
      * Initialize the SIP voip link with the account parameters and send registration
      */
@@ -142,7 +133,7 @@ public:
     /**
      * Send unregistration.
      */
-    void doUnregister(std::function<void(bool)> cb = std::function<void(bool)>()) override;
+    void doUnregister(bool forceShutdownConnections = false) override;
 
     /**
      * Build and send SIP registration request
@@ -167,10 +158,7 @@ public:
 
     bool hasCredentials() const { return not config().credentials.empty(); }
 
-    std::vector<std::map<std::string, std::string>> getCredentials() const
-    {
-        return config().getCredentials();
-    }
+    std::vector<std::map<std::string, std::string>> getCredentials() const { return config().getCredentials(); }
 
     virtual void setRegistrationState(RegistrationState state,
                                       int code = 0,
@@ -390,10 +378,9 @@ public:
      * @param sipTr: SIP Transport
      * @return A shared pointer on the created call.
      */
-    std::shared_ptr<SIPCall> newIncomingCall(
-        const std::string& from,
-        const std::vector<libjami::MediaMap>& mediaList,
-        const std::shared_ptr<SipTransport>& sipTr = {}) override;
+    std::shared_ptr<SIPCall> newIncomingCall(const std::string& from,
+                                             const std::vector<libjami::MediaMap>& mediaList,
+                                             const std::shared_ptr<SipTransport>& sipTr = {}) override;
 
     void onRegister(pjsip_regc_cbparam* param);
 
@@ -415,10 +402,7 @@ public:
     dhtnet::IpAddr createBindingAddress();
 
     void setActiveCodecs(const std::vector<unsigned>& list) override;
-    bool isSrtpEnabled() const override
-    {
-        return config().srtpKeyExchange != KeyExchangeProtocol::NONE;
-    }
+    bool isSrtpEnabled() const override { return config().srtpKeyExchange != KeyExchangeProtocol::NONE; }
 
     bool setPushNotificationToken(const std::string& pushDeviceToken = "") override;
     bool setPushNotificationConfig(const std::map<std::string, std::string>& data) override;
@@ -426,8 +410,7 @@ public:
     /**
      * To be called by clients with relevant data when a push notification is received.
      */
-    void pushNotificationReceived(const std::string& from,
-                                  const std::map<std::string, std::string>& data);
+    void pushNotificationReceived(const std::string& from, const std::map<std::string, std::string>& data);
 
 private:
     void doRegister1_();
@@ -464,8 +447,7 @@ private:
      * Callback called by the transport layer when the registration
      * transport state changes.
      */
-    virtual void onTransportStateChanged(pjsip_transport_state state,
-                                         const pjsip_transport_state_info* info);
+    virtual void onTransportStateChanged(pjsip_transport_state state, const pjsip_transport_state_info* info);
 
     struct
     {
