@@ -1,18 +1,18 @@
 /*
- *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3, or (at your option)
- *  any later version.
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, see <https://www.gnu.org/licenses/>.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 #include "sipaccount_config.h"
 #include "account_const.h"
@@ -37,7 +37,6 @@ constexpr const char* SAME_AS_LOCAL_KEY = "sameasLocal";
 constexpr const char* DTMF_TYPE_KEY = "dtmfType";
 constexpr const char* SERVICE_ROUTE_KEY = "serviceRoute";
 constexpr const char* ALLOW_IP_AUTO_REWRITE = "allowIPAutoRewrite";
-constexpr const char* PRESENCE_ENABLED_KEY = "presenceEnabled";
 constexpr const char* PRESENCE_PUBLISH_SUPPORTED_KEY = "presencePublishSupported";
 constexpr const char* PRESENCE_SUBSCRIBE_SUPPORTED_KEY = "presenceSubscribeSupported";
 constexpr const char* PRESENCE_STATUS_KEY = "presenceStatus";
@@ -70,7 +69,7 @@ constexpr const char* RTP_FALLBACK_KEY = "rtpFallback";
 } // namespace Conf
 
 static const SipAccountConfig DEFAULT_CONFIG {};
-static constexpr unsigned MIN_REGISTRATION_TIME = 60;                  // seconds
+static constexpr unsigned MIN_REGISTRATION_TIME = 60; // seconds
 
 using yaml_utils::parseValueOptional;
 using yaml_utils::parseVectorMap;
@@ -93,11 +92,10 @@ SipAccountConfig::serialize(YAML::Emitter& out) const
 
     out << YAML::Key << Conf::KEEP_ALIVE_ENABLED << YAML::Value << registrationRefreshEnabled;
 
-    //out << YAML::Key << PRESENCE_MODULE_ENABLED_KEY << YAML::Value
-    //    << (presence_ and presence_->isEnabled());
+    // out << YAML::Key << PRESENCE_MODULE_ENABLED_KEY << YAML::Value
+    //     << (presence_ and presence_->isEnabled());
 
-    out << YAML::Key << Conf::CONFIG_ACCOUNT_REGISTRATION_EXPIRE << YAML::Value
-        << registrationExpire;
+    out << YAML::Key << Conf::CONFIG_ACCOUNT_REGISTRATION_EXPIRE << YAML::Value << registrationExpire;
     out << YAML::Key << Conf::SERVICE_ROUTE_KEY << YAML::Value << serviceRoute;
     out << YAML::Key << Conf::ALLOW_IP_AUTO_REWRITE << YAML::Value << allowIPAutoRewrite;
     out << YAML::Key << Conf::STUN_ENABLED_KEY << YAML::Value << stunEnabled;
@@ -123,8 +121,7 @@ SipAccountConfig::serialize(YAML::Emitter& out) const
 
     // srtp submap
     out << YAML::Key << Conf::SRTP_KEY << YAML::Value << YAML::BeginMap;
-    out << YAML::Key << Conf::KEY_EXCHANGE_KEY << YAML::Value
-        << sip_utils::getKeyExchangeName(srtpKeyExchange);
+    out << YAML::Key << Conf::KEY_EXCHANGE_KEY << YAML::Value << sip_utils::getKeyExchangeName(srtpKeyExchange);
     out << YAML::Key << Conf::RTP_FALLBACK_KEY << YAML::Value << srtpFallback;
     out << YAML::EndMap;
 
@@ -154,10 +151,9 @@ SipAccountConfig::unserialize(const YAML::Node& node)
     parseValueOptional(node, Conf::STUN_SERVER_KEY, stunServer);
 
     const auto& credsNode = node[Conf::CRED_KEY];
-    setCredentials(parseVectorMap(credsNode,
-                                  {Conf::CONFIG_ACCOUNT_REALM,
-                                   Conf::CONFIG_ACCOUNT_USERNAME,
-                                   Conf::CONFIG_ACCOUNT_PASSWORD}));
+    setCredentials(
+        parseVectorMap(credsNode,
+                       {Conf::CONFIG_ACCOUNT_REALM, Conf::CONFIG_ACCOUNT_USERNAME, Conf::CONFIG_ACCOUNT_PASSWORD}));
 
     // get tls submap
     try {
@@ -176,7 +172,8 @@ SipAccountConfig::unserialize(const YAML::Node& node)
         parseValueOptional(tlsMap, Conf::VERIFY_SERVER_KEY, tlsVerifyServer);
         parseValueOptional(tlsMap, Conf::DISABLE_SECURE_DLG_CHECK, tlsDisableSecureDlgCheck);
         parseValueOptional(tlsMap, Conf::TIMEOUT_KEY, tlsNegotiationTimeout);
-    } catch (...) {}
+    } catch (...) {
+    }
 
     // get srtp submap
     const auto& srtpMap = node[Conf::SRTP_KEY];
@@ -314,7 +311,8 @@ SipAccountConfig::Credentials::toMap() const
 }
 
 void
-SipAccountConfig::Credentials::computePasswordHash() {
+SipAccountConfig::Credentials::computePasswordHash()
+{
     pj_md5_context pms;
 
     /* Compute md5 hash = MD5(username ":" realm ":" password) */
@@ -356,4 +354,4 @@ SipAccountConfig::setCredentials(const std::vector<std::map<std::string, std::st
         credentials.emplace_back(cred);
 }
 
-}
+} // namespace jami
