@@ -52,8 +52,7 @@ public:
     ConversationRepositoryTest()
     {
         // Init daemon
-        libjami::init(
-            libjami::InitFlag(libjami::LIBJAMI_FLAG_DEBUG | libjami::LIBJAMI_FLAG_CONSOLE_LOG));
+        libjami::init(libjami::InitFlag(libjami::LIBJAMI_FLAG_DEBUG | libjami::LIBJAMI_FLAG_CONSOLE_LOG));
         if (not Manager::instance().initialized)
             CPPUNIT_ASSERT(libjami::start("jami-sample.yml"));
     }
@@ -75,19 +74,23 @@ private:
     void testMerge();
     void testFFMerge();
     void testDiff();
-
     void testMergeProfileWithConflict();
     void testValidSignatureForCommit();
     void testInvalidSignatureForCommit();
     void testMalformedCommit();
+    void testMalformedCommitUri();
+    void testInvalidJoin();
+    void testInvalidFile();
+    void testMergeWithInvalidFile();
     std::string addCommit(git_repository* repo,
                           const std::shared_ptr<JamiAccount> account,
                           const std::string& branch,
                           const std::string& commit_msg);
+    std::string addMergeCommit(git_repository* repo,
+                               const std::shared_ptr<JamiAccount> account,
+                               const std::string& wanted_ref);
     void addAll(git_repository* repo);
-    bool merge_in_main(const std::shared_ptr<JamiAccount> account,
-                       git_repository* repo,
-                       const std::string& commit_ref);
+    bool merge_in_main(const std::shared_ptr<JamiAccount> account, git_repository* repo, const std::string& commit_ref);
     CPPUNIT_TEST_SUITE(ConversationRepositoryTest);
     CPPUNIT_TEST(testCreateRepository);          // Passes
     CPPUNIT_TEST(testAddSomeMessages);           // Passes
@@ -99,11 +102,14 @@ private:
     CPPUNIT_TEST(testValidSignatureForCommit);   // Passes
     CPPUNIT_TEST(testInvalidSignatureForCommit); // Passes
     CPPUNIT_TEST(testMalformedCommit);           // Passes
+    CPPUNIT_TEST(testMalformedCommitUri);        // Passes
+    CPPUNIT_TEST(testInvalidJoin);               // Passes
+    CPPUNIT_TEST(testInvalidFile);               // Passes
+    CPPUNIT_TEST(testMergeWithInvalidFile);      // Passes
     CPPUNIT_TEST_SUITE_END();
 };
 
-CPPUNIT_TEST_SUITE_NAMED_REGISTRATION(ConversationRepositoryTest,
-                                      ConversationRepositoryTest::name());
+CPPUNIT_TEST_SUITE_NAMED_REGISTRATION(ConversationRepositoryTest, ConversationRepositoryTest::name());
 
 void
 ConversationRepositoryTest::setUp()
@@ -130,8 +136,7 @@ ConversationRepositoryTest::testCreateRepository()
 
     // Assert that repository exists
     CPPUNIT_ASSERT(repository != nullptr);
-    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations"
-                    / repository->id();
+    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations" / repository->id();
     CPPUNIT_ASSERT(std::filesystem::is_directory(repoPath));
 
     // Assert that first commit is signed by alice
@@ -170,8 +175,7 @@ ConversationRepositoryTest::testCreateRepository()
     CPPUNIT_ASSERT(std::filesystem::is_regular_file(deviceCrt));
 
     crt = std::ifstream(deviceCrt);
-    std::string deviceCrtStr((std::istreambuf_iterator<char>(crt)),
-                             std::istreambuf_iterator<char>());
+    std::string deviceCrtStr((std::istreambuf_iterator<char>(crt)), std::istreambuf_iterator<char>());
 
     CPPUNIT_ASSERT(deviceCrtStr == deviceCert);
 }
@@ -204,15 +208,12 @@ ConversationRepositoryTest::testAddSomeMessages()
     CPPUNIT_ASSERT(messages[2].author.email == messages[3].author.email);
     CPPUNIT_ASSERT(messages[2].parents.front() == repository->id());
     // Check sig
-    CPPUNIT_ASSERT(
-        aliceAccount->identity().second->getPublicKey().checkSignature(messages[0].signed_content,
-                                                                       messages[0].signature));
-    CPPUNIT_ASSERT(
-        aliceAccount->identity().second->getPublicKey().checkSignature(messages[1].signed_content,
-                                                                       messages[1].signature));
-    CPPUNIT_ASSERT(
-        aliceAccount->identity().second->getPublicKey().checkSignature(messages[2].signed_content,
-                                                                       messages[2].signature));
+    CPPUNIT_ASSERT(aliceAccount->identity().second->getPublicKey().checkSignature(messages[0].signed_content,
+                                                                                  messages[0].signature));
+    CPPUNIT_ASSERT(aliceAccount->identity().second->getPublicKey().checkSignature(messages[1].signed_content,
+                                                                                  messages[1].signature));
+    CPPUNIT_ASSERT(aliceAccount->identity().second->getPublicKey().checkSignature(messages[2].signed_content,
+                                                                                  messages[2].signature));
 }
 
 void
@@ -305,15 +306,8 @@ ConversationRepositoryTest::addCommit(git_repository* repo,
 #else
     const git_commit* head_ref[1] = {head_commit.get()};
 #endif
-    if (git_commit_create_buffer(&to_sign,
-                                 repo,
-                                 sig.get(),
-                                 sig.get(),
-                                 nullptr,
-                                 commit_msg.c_str(),
-                                 tree.get(),
-                                 1,
-                                 &head_ref[0])
+    if (git_commit_create_buffer(
+            &to_sign, repo, sig.get(), sig.get(), nullptr, commit_msg.c_str(), tree.get(), 1, &head_ref[0])
         < 0) {
         JAMI_ERR("Unable to create commit buffer");
         return {};
@@ -323,12 +317,7 @@ ConversationRepositoryTest::addCommit(git_repository* repo,
     auto to_sign_vec = std::vector<uint8_t>(to_sign.ptr, to_sign.ptr + to_sign.size);
     auto signed_buf = account->identity().first->sign(to_sign_vec);
     std::string signed_str = base64::encode(signed_buf);
-    if (git_commit_create_with_signature(&commit_id,
-                                         repo,
-                                         to_sign.ptr,
-                                         signed_str.c_str(),
-                                         "signature")
-        < 0) {
+    if (git_commit_create_with_signature(&commit_id, repo, to_sign.ptr, signed_str.c_str(), "signature") < 0) {
         JAMI_ERR("Unable to sign commit");
         return {};
     }
@@ -339,8 +328,7 @@ ConversationRepositoryTest::addCommit(git_repository* repo,
         // Move commit to main branch
         git_reference* ref_ptr = nullptr;
         std::string branch_name = "refs/heads/" + branch;
-        if (git_reference_create(&ref_ptr, repo, branch_name.c_str(), &commit_id, true, nullptr)
-            < 0) {
+        if (git_reference_create(&ref_ptr, repo, branch_name.c_str(), &commit_id, true, nullptr) < 0) {
             JAMI_WARN("Unable to move commit to main");
         }
         git_reference_free(ref_ptr);
@@ -348,6 +336,110 @@ ConversationRepositoryTest::addCommit(git_repository* repo,
     return commit_str ? commit_str : "";
 }
 
+std::string
+ConversationRepositoryTest::addMergeCommit(git_repository* repo,
+                                           const std::shared_ptr<JamiAccount> account,
+                                           const std::string& wanted_ref)
+{
+    auto deviceId = DeviceId(std::string(account->currentDeviceId()));
+    auto name = account->getDisplayName();
+    if (name.empty())
+        name = deviceId.toString();
+
+    git_signature* sig_ptr = nullptr;
+    if (git_signature_new(&sig_ptr, name.c_str(), deviceId.to_c_str(), std::time(nullptr), 0) < 0) {
+        return {};
+    }
+    GitSignature sig {sig_ptr, git_signature_free};
+
+    // Get current HEAD (parent 1)
+    git_oid head_oid;
+    if (git_reference_name_to_id(&head_oid, repo, "HEAD") < 0) {
+        JAMI_ERR("Unable to get HEAD commit");
+        return "";
+    }
+
+    git_commit* head_ptr = nullptr;
+    if (git_commit_lookup(&head_ptr, repo, &head_oid) < 0) {
+        JAMI_ERR("Unable to look up HEAD commit");
+        return "";
+    }
+
+    GitCommit head_commit {head_ptr, git_commit_free};
+
+    // Get wanted commit (parent 2)
+    git_oid wanted_oid;
+    if (git_oid_fromstr(&wanted_oid, wanted_ref.c_str()) < 0) {
+        JAMI_ERR("Unable to get wanted commit");
+        return "";
+    }
+
+    git_commit* wanted_ptr = nullptr;
+    if (git_commit_lookup(&wanted_ptr, repo, &wanted_oid) < 0) {
+        JAMI_ERR("Unable to look up wanted commit");
+        return "";
+    }
+    GitCommit wanted_commit {wanted_ptr, git_commit_free};
+
+    // Get current index and tree (same as addCommit)
+    git_index* index_ptr = nullptr;
+    if (git_repository_index(&index_ptr, repo) < 0) {
+        JAMI_ERR("Unable to get repository index");
+        return {};
+    }
+    GitIndex index {index_ptr, git_index_free};
+
+    git_oid tree_id;
+    if (git_index_write_tree(&tree_id, index.get()) < 0) {
+        JAMI_ERR("Unable to write tree from index");
+        return {};
+    }
+    git_tree* tree_ptr = nullptr;
+    if (git_tree_lookup(&tree_ptr, repo, &tree_id) < 0) {
+        JAMI_ERR("Unable to look up tree");
+        return {};
+    }
+    GitTree tree = {tree_ptr, git_tree_free};
+
+    // Create merge message
+    auto commitMsg = fmt::format("Merge commit '{}'", wanted_ref);
+
+    git_buf to_sign = {};
+#if LIBGIT2_VER_MAJOR == 1 && LIBGIT2_VER_MINOR == 8 \
+    && (LIBGIT2_VER_REVISION == 0 || LIBGIT2_VER_REVISION == 1 || LIBGIT2_VER_REVISION == 3)
+    git_commit* const parents[2] = {head_commit.get(), wanted_commit.get()};
+#else
+    const git_commit* parents[2] = {head_commit.get(), wanted_commit.get()};
+#endif
+    if (git_commit_create_buffer(
+            &to_sign, repo, sig.get(), sig.get(), nullptr, commitMsg.c_str(), tree.get(), 2, &parents[0])
+        < 0) {
+        return {};
+    }
+
+    auto to_sign_vec = std::vector<uint8_t>(to_sign.ptr, to_sign.ptr + to_sign.size);
+    auto signed_buf = account->identity().first->sign(to_sign_vec);
+    std::string signed_str = base64::encode(signed_buf);
+    git_oid commit_id;
+    if (git_commit_create_with_signature(&commit_id, repo, to_sign.ptr, signed_str.c_str(), "signature") < 0) {
+        git_buf_dispose(&to_sign);
+        return {};
+    }
+    git_buf_dispose(&to_sign);
+
+    auto commit_str = git_oid_tostr_s(&commit_id);
+    if (commit_str) {
+        // Move to main branch
+        git_reference* ref_ptr = nullptr;
+        if (git_reference_create(&ref_ptr, repo, "refs/heads/main", &commit_id, true, nullptr) < 0) {
+            JAMI_WARN("Unable to move commit to main");
+            return {};
+        }
+        git_reference_free(ref_ptr);
+    }
+    return commit_str ? commit_str : "";
+}
+
 void
 ConversationRepositoryTest::addAll(git_repository* repo)
 {
@@ -370,8 +462,7 @@ ConversationRepositoryTest::testMerge()
 
     // Assert that repository exists
     CPPUNIT_ASSERT(repository != nullptr);
-    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations"
-                    / repository->id();
+    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations" / repository->id();
     CPPUNIT_ASSERT(std::filesystem::is_directory(repoPath));
 
     // Assert that first commit is signed by alice
@@ -405,8 +496,7 @@ ConversationRepositoryTest::testFFMerge()
 
     // Assert that repository exists
     CPPUNIT_ASSERT(repository != nullptr);
-    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations"
-                    / repository->id();
+    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations" / repository->id();
     CPPUNIT_ASSERT(std::filesystem::is_directory(repoPath));
 
     // Assert that first commit is signed by alice
@@ -461,8 +551,7 @@ ConversationRepositoryTest::testMergeProfileWithConflict()
 
     // Assert that repository exists
     CPPUNIT_ASSERT(repository != nullptr);
-    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations"
-                    / repository->id();
+    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations" / repository->id();
     CPPUNIT_ASSERT(std::filesystem::is_directory(repoPath));
 
     // Assert that first commit is signed by alice
@@ -522,8 +611,7 @@ ConversationRepositoryTest::testValidSignatureForCommit()
     // Assert the repository exists
     CPPUNIT_ASSERT(repository != nullptr);
     // Get the path to the conversation repository
-    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations"
-                    / repository->id();
+    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations" / repository->id();
     // Assert that the repository path is a directory
     CPPUNIT_ASSERT(std::filesystem::is_directory(repoPath));
 
@@ -548,10 +636,8 @@ ConversationRepositoryTest::testValidSignatureForCommit()
     // Extract the signature block and signature content from the commit
     git_commit_extract_signature(&extracted_sig, &extracted_sig_data, repo, &commit_id, "signature");
     // Verify the signature of the commit
-    CPPUNIT_ASSERT(repository->isValidUserAtCommit(userDevice,
-                                                   git_oid_tostr_s(&commit_id),
-                                                   extracted_sig,
-                                                   extracted_sig_data));
+    CPPUNIT_ASSERT(
+        repository->isValidUserAtCommit(userDevice, git_oid_tostr_s(&commit_id), extracted_sig, extracted_sig_data));
 
     // Free git objects
     git_commit_free(commit_ptr);
@@ -569,8 +655,7 @@ ConversationRepositoryTest::testInvalidSignatureForCommit()
     // Assert that the repository exists
     CPPUNIT_ASSERT(repository != nullptr);
     // Get the path to the conversation repository
-    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations"
-                    / repository->id();
+    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations" / repository->id();
     // Assert that the repository path is a directory
     CPPUNIT_ASSERT(std::filesystem::is_directory(repoPath));
 
@@ -623,17 +708,16 @@ ConversationRepositoryTest::testInvalidSignatureForCommit()
 
     // Create a signed commit object and place it in a buffer
     git_buf to_sign = {};
-    CPPUNIT_ASSERT(
-        git_commit_create_buffer(&to_sign,
-                                 repo,
-                                 sig,
-                                 sig,
-                                 nullptr,
-                                 "{\"body\":\"malicious intent\",\"type\":\"text/plain\"}",
-                                 tree.get(),
-                                 1,
-                                 &head_ref[0])
-        == 0);
+    CPPUNIT_ASSERT(git_commit_create_buffer(&to_sign,
+                                            repo,
+                                            sig,
+                                            sig,
+                                            nullptr,
+                                            "{\"body\":\"malicious intent\",\"type\":\"text/plain\"}",
+                                            tree.get(),
+                                            1,
+                                            &head_ref[0])
+                   == 0);
     git_signature_free(sig);
 
     // git commit -S
@@ -641,11 +725,7 @@ ConversationRepositoryTest::testInvalidSignatureForCommit()
     // Sign the commit using Bob's private key
     std::vector<unsigned char> signed_buf = bobAccount->identity().first->sign(to_sign_vec);
     std::string signed_str = base64::encode(signed_buf);
-    CPPUNIT_ASSERT(git_commit_create_with_signature(&commit_id,
-                                                    repo,
-                                                    to_sign.ptr,
-                                                    signed_str.c_str(),
-                                                    "signature")
+    CPPUNIT_ASSERT(git_commit_create_with_signature(&commit_id, repo, to_sign.ptr, signed_str.c_str(), "signature")
                    == 0);
 
     // Dispose the signature buffer
@@ -653,8 +733,7 @@ ConversationRepositoryTest::testInvalidSignatureForCommit()
 
     // Move commit to main branch
     git_reference* ref_ptr = nullptr;
-    CPPUNIT_ASSERT(
-        (git_reference_create(&ref_ptr, repo, "refs/heads/main", &commit_id, true, nullptr) == 0));
+    CPPUNIT_ASSERT((git_reference_create(&ref_ptr, repo, "refs/heads/main", &commit_id, true, nullptr) == 0));
 
     CPPUNIT_ASSERT(repo);
 
@@ -670,10 +749,8 @@ ConversationRepositoryTest::testInvalidSignatureForCommit()
     git_buf extracted_sig = {}, extracted_sig_data = {};
     // Extract the signature block and signature content from the commit
     git_commit_extract_signature(&extracted_sig, &extracted_sig_data, repo, &commit_id, "signature");
-    CPPUNIT_ASSERT(!repository->isValidUserAtCommit(userDevice,
-                                                    git_oid_tostr_s(&commit_id),
-                                                    extracted_sig,
-                                                    extracted_sig_data));
+    CPPUNIT_ASSERT(
+        !repository->isValidUserAtCommit(userDevice, git_oid_tostr_s(&commit_id), extracted_sig, extracted_sig_data));
 
     // Free git objects
     git_reference_free(ref_ptr);
@@ -692,17 +769,13 @@ ConversationRepositoryTest::testMalformedCommit()
     bool isMalformed = false;
 
     // Signals for malformed commits in validCommits function
-    confHandlers.insert(
-        libjami::exportable_callback<libjami::ConversationSignal::OnConversationError>(
-            [&](const std::string& accountId,
-                const std::string& conversationId,
-                int code,
-                auto malformedSpec) {
-                if (code == EVALIDFETCH) {
-                    isMalformed = true;
-                }
-                cv.notify_one();
-            }));
+    confHandlers.insert(libjami::exportable_callback<libjami::ConversationSignal::OnConversationError>(
+        [&](const std::string& accountId, const std::string& conversationId, int code, auto malformedSpec) {
+            if (code == EVALIDFETCH) {
+                isMalformed = true;
+            }
+            cv.notify_one();
+        }));
     libjami::registerSignalHandlers(confHandlers);
 
     // Get Alice's account
@@ -712,8 +785,7 @@ ConversationRepositoryTest::testMalformedCommit()
     // Assert that repository exists
     CPPUNIT_ASSERT(repository != nullptr);
     // Get the path to the conversation repository
-    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations"
-                    / repository->id();
+    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations" / repository->id();
     // Assert that the repository path is a directory
     CPPUNIT_ASSERT(std::filesystem::is_directory(repoPath));
 
@@ -738,6 +810,297 @@ ConversationRepositoryTest::testMalformedCommit()
     CPPUNIT_ASSERT(!allCommitsValidated);
 }
 
+void
+ConversationRepositoryTest::testMalformedCommitUri()
+{
+    // Register signals
+    std::map<std::string, std::shared_ptr<libjami::CallbackWrapperBase>> confHandlers;
+
+    // Variable to be set to true on detection of malformed commit
+    bool isMalformed = false;
+
+    // Signals for malformed commits in validCommits function
+    confHandlers.insert(libjami::exportable_callback<libjami::ConversationSignal::OnConversationError>(
+        [&](const std::string& accountId, const std::string& conversationId, int code, auto malformedSpec) {
+            if (code == EVALIDFETCH) {
+                isMalformed = true;
+            }
+            cv.notify_one();
+        }));
+    libjami::registerSignalHandlers(confHandlers);
+
+    // Get Alice's account
+    auto aliceAccount = Manager::instance().getAccount<JamiAccount>(aliceId);
+    // Create a repository associated with Alice's account
+    auto repository = ConversationRepository::createConversation(aliceAccount);
+    // Assert that repository exists
+    CPPUNIT_ASSERT(repository != nullptr);
+    // Get the path to the conversation repository
+    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations" / repository->id();
+    // Assert that the repository path is a directory
+    CPPUNIT_ASSERT(std::filesystem::is_directory(repoPath));
+
+    // Assert that the git repo was opened successfully
+    git_repository* repo;
+    CPPUNIT_ASSERT(git_repository_open(&repo, repoPath.c_str()) == 0);
+
+    // Create malformed add and join commits with valid user InfoHash,
+    // but with invalid "jami:" prefix
+    std::string malformedID = "jami:" + aliceAccount->getUsername();
+    std::string invitedPath = "invited/" + malformedID;
+
+    CPPUNIT_ASSERT(!std::filesystem::exists(repoPath / invitedPath));
+
+    // Simulate an invitation by creating the "invited/" directory with an empty file
+    std::filesystem::create_directories(repoPath / "invited");
+    std::ofstream(repoPath / invitedPath).close();
+    CPPUNIT_ASSERT(std::filesystem::exists(repoPath / invitedPath));
+
+    addAll(repo);
+
+    auto malformedAddUserId = addCommit(repo,
+                                        aliceAccount,
+                                        "main",
+                                        "{\"action\":\"add\",\"type\":\"member\",\"uri\":\"" + malformedID + "\"}");
+    CPPUNIT_ASSERT(!malformedAddUserId.empty());
+
+    auto malformedJoinUserID = addCommit(repo,
+                                         aliceAccount,
+                                         "main",
+                                         "{\"action\":\"join\",\"type\":\"member\",\"uri\":\"" + malformedID + "\"}");
+    CPPUNIT_ASSERT(!malformedJoinUserID.empty());
+
+    // Log the repository
+    auto conversationCommits = repository->log();
+    // Call the validation for all the commits
+    bool allCommitsValidated = repository->validCommits(conversationCommits);
+
+    // Check that the appropriate signal was called
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&] { return isMalformed; }));
+    // Check that the return value was false (i.e. malformed commit detected)
+    CPPUNIT_ASSERT(!allCommitsValidated);
+}
+
+// A join without a previous add should be invalid
+void
+ConversationRepositoryTest::testInvalidJoin()
+{
+    // Register signals
+    std::map<std::string, std::shared_ptr<libjami::CallbackWrapperBase>> confHandlers;
+
+    // Variable to be set to true on detection of malformed commit
+    bool isInvalid = false;
+
+    // Signals for malformed commits in validCommits function
+    confHandlers.insert(libjami::exportable_callback<libjami::ConversationSignal::OnConversationError>(
+        [&](const std::string& accountId, const std::string& conversationId, int code, auto malformedSpec) {
+            if (code == EVALIDFETCH) {
+                isInvalid = true;
+            }
+            cv.notify_one();
+        }));
+    libjami::registerSignalHandlers(confHandlers);
+
+    // Get Alice's account
+    auto aliceAccount = Manager::instance().getAccount<JamiAccount>(aliceId);
+    // Create a repository associated with Alice's account
+    auto repository = ConversationRepository::createConversation(aliceAccount);
+    // Assert that the repository exists
+    CPPUNIT_ASSERT(repository != nullptr);
+    // Get the path to the conversation repository
+    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations" / repository->id();
+    // Assert that the repository path is a directory
+    CPPUNIT_ASSERT(std::filesystem::is_directory(repoPath));
+
+    // Assert that the git repo was opened successfully
+    git_repository* repo;
+    CPPUNIT_ASSERT(git_repository_open(&repo, repoPath.c_str()) == 0);
+
+    std::string userId = aliceAccount->getUsername();
+
+    auto invalidJoinUserID = addCommit(repo,
+                                       aliceAccount,
+                                       "main",
+                                       "{\"action\":\"join\",\"type\":\"member\",\"uri\":\"" + userId + "\"}");
+    CPPUNIT_ASSERT(!invalidJoinUserID.empty());
+
+    // Log the repository
+    auto conversationCommits = repository->log();
+    // Call the validation for all the commits
+    bool allCommitsValidated = repository->validCommits(conversationCommits);
+
+    // Check that the appropriate signal was called
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&] { return isInvalid; }));
+    // Check that the return value was false (i.e. invalid commit detected)
+    CPPUNIT_ASSERT(!allCommitsValidated);
+}
+
+void
+ConversationRepositoryTest::testInvalidFile()
+{
+    // Register signals
+    std::map<std::string, std::shared_ptr<libjami::CallbackWrapperBase>> confHandlers;
+
+    // Variable to be set to true on detection of malformed commit
+    bool isInvalid = false;
+
+    // Signals for malformed commits in validCommits function
+    confHandlers.insert(libjami::exportable_callback<libjami::ConversationSignal::OnConversationError>(
+        [&](const std::string& accountId, const std::string& conversationId, int code, auto malformedSpec) {
+            if (code == EVALIDFETCH) {
+                isInvalid = true;
+            }
+            cv.notify_one();
+        }));
+    libjami::registerSignalHandlers(confHandlers);
+
+    // Get Alice's account
+    auto aliceAccount = Manager::instance().getAccount<JamiAccount>(aliceId);
+    // Create a repository associated with Alice's account
+    auto repository = ConversationRepository::createConversation(aliceAccount);
+    // Assert that repository exists
+    CPPUNIT_ASSERT(repository != nullptr);
+    // Get the path to the conversation repository
+    auto repoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations" / repository->id();
+    // Assert that the repository path is a directory
+    CPPUNIT_ASSERT(std::filesystem::is_directory(repoPath));
+
+    // Assert that the git repo was opened successfully
+    git_repository* repo;
+    CPPUNIT_ASSERT(git_repository_open(&repo, repoPath.c_str()) == 0);
+
+    std::string userId = aliceAccount->getUsername();
+
+    auto invalidFile = repoPath / "invalidFile.txt";
+    std::ofstream(invalidFile).close();
+    addAll(repo);
+
+    auto invalidFileCommitID = addCommit(repo,
+                                         aliceAccount,
+                                         "main",
+                                         "{\"type\":\"other\",\"note\":\"Add invalid file\"}");
+
+    // Log the repository
+    auto conversationCommits = repository->log();
+    // Call the validation for all the commits
+    bool allCommitsValidated = repository->validCommits(conversationCommits);
+
+    // Check that the appropriate signal was called
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&] { return isInvalid; }));
+    // Check that the return value was false (i.e. invalid commit detected)
+    CPPUNIT_ASSERT(!allCommitsValidated);
+}
+
+void
+ConversationRepositoryTest::testMergeWithInvalidFile()
+{
+    // Register signals
+    std::map<std::string, std::shared_ptr<libjami::CallbackWrapperBase>> confHandlers;
+
+    // Variable to be set to true on detection of malformed commit
+    bool isInvalid = false;
+
+    // Get member accounts
+    auto aliceAccount = Manager::instance().getAccount<JamiAccount>(aliceId);
+    auto bobAccount = Manager::instance().getAccount<JamiAccount>(bobId);
+    auto aliceUri = aliceAccount->getUsername();
+    auto bobUri = bobAccount->getUsername();
+
+    auto bobRequestReceived = false;
+
+    std::vector<libjami::SwarmMessage> aliceMessages = {};
+
+    confHandlers.insert(libjami::exportable_callback<libjami::ConversationSignal::OnConversationError>(
+        [&](const std::string& accountId, const std::string& conversationId, int code, auto malformedSpec) {
+            if (code == EVALIDFETCH) {
+                isInvalid = true;
+            }
+            cv.notify_one();
+        }));
+    confHandlers.insert(libjami::exportable_callback<libjami::ConversationSignal::ConversationRequestReceived>(
+        [&](const std::string& accountId,
+            const std::string& /* conversationId */,
+            std::map<std::string, std::string> /*metadatas*/) {
+            if (accountId == bobId) {
+                bobRequestReceived = true;
+            }
+            cv.notify_one();
+        }));
+    confHandlers.insert(libjami::exportable_callback<libjami::ConversationSignal::SwarmMessageReceived>(
+        [&](const std::string& accountId, const std::string& /* conversationId */, libjami::SwarmMessage message) {
+            if (accountId == aliceId) {
+                aliceMessages.emplace_back(message);
+            }
+            cv.notify_one();
+        }));
+
+    libjami::registerSignalHandlers(confHandlers);
+
+    auto convId = libjami::startConversation(aliceId);
+
+    // Alice adds Bob to the conversation
+    libjami::addConversationMember(aliceId, convId, bobUri);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return bobRequestReceived; }));
+
+    auto aliceMsgSize = aliceMessages.size();
+    libjami::acceptConversationRequest(bobId, convId);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return aliceMsgSize + 1 == aliceMessages.size(); }));
+
+    auto convMembers = libjami::getConversationMembers(aliceId, convId);
+    CPPUNIT_ASSERT(convMembers.size() == 2);
+
+    // Alice and Bob exchange messages
+    std::string msgId1 = "", msgId2 = "";
+    aliceAccount->convModule()->sendMessage(convId, "1"s, "", "text/plain", true, {}, [&](bool, std::string commitId) {
+        msgId1 = commitId;
+        cv.notify_one();
+    });
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&] { return !msgId1.empty(); }));
+    bobAccount->convModule()->sendMessage(convId, "2"s, "", "text/plain", true, {}, [&](bool, std::string commitId) {
+        msgId2 = commitId;
+        cv.notify_one();
+    });
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&] { return !msgId2.empty(); }));
+
+    // Retrieve the repository associated with Alice's account
+    auto aliceRepository = std::make_unique<ConversationRepository>(aliceAccount, convId);
+    // Assert that the repository exists
+    CPPUNIT_ASSERT(aliceRepository != nullptr);
+    // Get the path to the conversation repository
+    auto aliceRepoPath = fileutils::get_data_dir() / aliceAccount->getAccountID() / "conversations"
+                         / aliceRepository->id();
+    // Assert that the repository path is a directory
+    CPPUNIT_ASSERT(std::filesystem::is_directory(aliceRepoPath));
+
+    // Assert that Alice's git repo was opened successfully
+    git_repository* aliceRepo;
+    CPPUNIT_ASSERT(git_repository_open(&aliceRepo, aliceRepoPath.c_str()) == 0);
+
+    // Bob adds an unwanted file
+    auto bobRepository = std::make_unique<ConversationRepository>(bobAccount, convId);
+
+    auto bobRepoPath = fileutils::get_data_dir() / bobAccount->getAccountID() / "conversations" / bobRepository->id();
+    CPPUNIT_ASSERT(std::filesystem::is_directory(bobRepoPath));
+
+    git_repository* bobRepo;
+    CPPUNIT_ASSERT(git_repository_open(&bobRepo, bobRepoPath.c_str()) == 0);
+
+    auto invalidBobFile = bobRepoPath / "invalidBobFile.txt";
+    std::ofstream(invalidBobFile).close();
+    addAll(bobRepo);
+
+    // Add a fake merge commit associated with the invalid file
+    auto invalidBobMergeCommitId = addMergeCommit(bobRepo, bobAccount, msgId2);
+
+    // Log Bob's repository
+    auto bobCommits = bobRepository->log();
+
+    bool allCommitsValidated = bobRepository->validCommits(bobCommits);
+
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&] { return isInvalid; }));
+    CPPUNIT_ASSERT(!allCommitsValidated);
+}
+
 } // namespace test
 } // namespace jami
 
