@@ -93,8 +93,7 @@ private:
 };
 
 void
-MediaReceiver::update(Observable<std::shared_ptr<jami::MediaFrame>>*,
-                      const std::shared_ptr<jami::MediaFrame>& frame)
+MediaReceiver::update(Observable<std::shared_ptr<jami::MediaFrame>>*, const std::shared_ptr<jami::MediaFrame>& frame)
 {
     std::unique_lock lock {mtx_};
     if (frame and frame->getFrame())
@@ -155,9 +154,7 @@ private:
                                         const std::string& callId,
                                         const std::vector<libjami::MediaMap> mediaList,
                                         CallData& callData);
-    static void onMediaNegotiationStatus(const std::string& callId,
-                                         const std::string& event,
-                                         CallData& callData);
+    static void onMediaNegotiationStatus(const std::string& callId, const std::string& event, CallData& callData);
 
     // Helpers
     void test_call();
@@ -165,13 +162,9 @@ private:
     static std::string getUserAlias(const std::string& callId);
     // Wait for a signal from the callbacks. Some signals also report the event that
     // triggered the signal a like the StateChange signal.
-    static bool waitForSignal(CallData& callData,
-                              const std::string& signal,
-                              const std::string& expectedEvent = {});
-    static bool attachReceiver(std::shared_ptr<MediaReceiver> receiver,
-                               std::shared_ptr<RtpSession> rtpStream);
-    static bool detachReceiver(std::shared_ptr<MediaReceiver> receiver,
-                               std::shared_ptr<RtpSession> rtpStream);
+    static bool waitForSignal(CallData& callData, const std::string& signal, const std::string& expectedEvent = {});
+    static bool attachReceiver(std::shared_ptr<MediaReceiver> receiver, std::shared_ptr<RtpSession> rtpStream);
+    static bool detachReceiver(std::shared_ptr<MediaReceiver> receiver, std::shared_ptr<RtpSession> rtpStream);
 
 private:
     CallData aliceData_;
@@ -294,8 +287,7 @@ IceSdpParsingTest::onCallStateChange(const std::string&,
 
     {
         std::unique_lock lock {callData.mtx_};
-        callData.signals_.emplace_back(
-            CallData::Signal(libjami::CallSignal::StateChange::name, state));
+        callData.signals_.emplace_back(CallData::Signal(libjami::CallSignal::StateChange::name, state));
     }
 
     if (state == "CURRENT" or state == "OVER" or state == "HUNGUP") {
@@ -304,9 +296,7 @@ IceSdpParsingTest::onCallStateChange(const std::string&,
 }
 
 void
-IceSdpParsingTest::onMediaNegotiationStatus(const std::string& callId,
-                                            const std::string& event,
-                                            CallData& callData)
+IceSdpParsingTest::onMediaNegotiationStatus(const std::string& callId, const std::string& event, CallData& callData)
 {
     auto call = Manager::instance().getCallFromCallID(callId);
     if (not call) {
@@ -331,17 +321,14 @@ IceSdpParsingTest::onMediaNegotiationStatus(const std::string& callId,
 
     {
         std::unique_lock lock {callData.mtx_};
-        callData.signals_.emplace_back(
-            CallData::Signal(libjami::CallSignal::MediaNegotiationStatus::name, event));
+        callData.signals_.emplace_back(CallData::Signal(libjami::CallSignal::MediaNegotiationStatus::name, event));
     }
 
     callData.cv_.notify_one();
 }
 
 bool
-IceSdpParsingTest::waitForSignal(CallData& callData,
-                                 const std::string& expectedSignal,
-                                 const std::string& expectedEvent)
+IceSdpParsingTest::waitForSignal(CallData& callData, const std::string& expectedSignal, const std::string& expectedEvent)
 {
     const std::chrono::seconds TIME_OUT {30};
     std::unique_lock lock {callData.mtx_};
@@ -358,8 +345,7 @@ IceSdpParsingTest::waitForSignal(CallData& callData,
         for (auto it = callData.signals_.begin(); it != callData.signals_.end(); it++) {
             // The predicate is true if the signal names match, and if the
             // expectedEvent is not empty, the events must also match.
-            if (it->name_ == expectedSignal
-                and (expectedEvent.empty() or it->event_ == expectedEvent)) {
+            if (it->name_ == expectedSignal and (expectedEvent.empty() or it->event_ == expectedEvent)) {
                 // Done with this signal.
                 callData.signals_.erase(it);
                 return true;
@@ -370,15 +356,12 @@ IceSdpParsingTest::waitForSignal(CallData& callData,
     });
 
     if (not res) {
-        JAMI_ERR("[%s] waiting for signal/event [%s] timed-out!",
-                 callData.alias_.c_str(),
-                 sigEvent.c_str());
+        JAMI_ERR("[%s] waiting for signal/event [%s] timed-out!", callData.alias_.c_str(), sigEvent.c_str());
 
         JAMI_INFO("[%s] currently has the following signals:", callData.alias_.c_str());
 
         for (auto const& sig : callData.signals_) {
-            JAMI_INFO() << "Signal [" << sig.name_
-                        << (sig.event_.empty() ? "" : ("::" + sig.event_)) << "]";
+            JAMI_INFO() << "Signal [" << sig.name_ << (sig.event_.empty() ? "" : ("::" + sig.event_)) << "]";
         }
     }
 
@@ -386,8 +369,7 @@ IceSdpParsingTest::waitForSignal(CallData& callData,
 }
 
 bool
-IceSdpParsingTest::attachReceiver(std::shared_ptr<MediaReceiver> mediaReceiver,
-                                  std::shared_ptr<RtpSession> rtpSession)
+IceSdpParsingTest::attachReceiver(std::shared_ptr<MediaReceiver> mediaReceiver, std::shared_ptr<RtpSession> rtpSession)
 {
     CPPUNIT_ASSERT(mediaReceiver);
     CPPUNIT_ASSERT(mediaReceiver->mediaType_ == MediaType::MEDIA_AUDIO
@@ -409,8 +391,7 @@ IceSdpParsingTest::attachReceiver(std::shared_ptr<MediaReceiver> mediaReceiver,
 }
 
 bool
-IceSdpParsingTest::detachReceiver(std::shared_ptr<MediaReceiver> mediaReceiver,
-                                  std::shared_ptr<RtpSession> rtpSession)
+IceSdpParsingTest::detachReceiver(std::shared_ptr<MediaReceiver> mediaReceiver, std::shared_ptr<RtpSession> rtpSession)
 {
     CPPUNIT_ASSERT(mediaReceiver);
     CPPUNIT_ASSERT(mediaReceiver->mediaType_ == MediaType::MEDIA_AUDIO
@@ -460,23 +441,14 @@ IceSdpParsingTest::configureTest(CallData& aliceData, CallData& bobData)
             const std::vector<libjami::MediaMap> mediaList) {
             auto user = getUserAlias(callId);
             if (not user.empty())
-                onIncomingCallWithMedia(accountId,
-                                        callId,
-                                        mediaList,
-                                        user == aliceData.alias_ ? aliceData : bobData);
+                onIncomingCallWithMedia(accountId, callId, mediaList, user == aliceData.alias_ ? aliceData : bobData);
         }));
 
-    signalHandlers.insert(
-        libjami::exportable_callback<libjami::CallSignal::StateChange>([&](const std::string& accountId,
-                                                                       const std::string& callId,
-                                                                       const std::string& state,
-                                                                       signed) {
+    signalHandlers.insert(libjami::exportable_callback<libjami::CallSignal::StateChange>(
+        [&](const std::string& accountId, const std::string& callId, const std::string& state, signed) {
             auto user = getUserAlias(callId);
             if (not user.empty())
-                onCallStateChange(accountId,
-                                  callId,
-                                  state,
-                                  user == aliceData.alias_ ? aliceData : bobData);
+                onCallStateChange(accountId, callId, state, user == aliceData.alias_ ? aliceData : bobData);
         }));
 
     signalHandlers.insert(libjami::exportable_callback<libjami::CallSignal::MediaNegotiationStatus>(
@@ -485,9 +457,7 @@ IceSdpParsingTest::configureTest(CallData& aliceData, CallData& bobData)
             const std::vector<std::map<std::string, std::string>>& /* mediaList */) {
             auto user = getUserAlias(callId);
             if (not user.empty())
-                onMediaNegotiationStatus(callId,
-                                         event,
-                                         user == aliceData.alias_ ? aliceData : bobData);
+                onMediaNegotiationStatus(callId, event, user == aliceData.alias_ ? aliceData : bobData);
         }));
 
     libjami::registerSignalHandlers(signalHandlers);
@@ -529,9 +499,8 @@ IceSdpParsingTest::test_call()
     bobAddr.setPort(bobData_.listeningPort_);
 
     aliceData_.callId_ = libjami::placeCallWithMedia(aliceData_.accountId_,
-                                                   bobAddr.toString(true),
-                                                   MediaAttribute::mediaAttributesToMediaMaps(
-                                                       offer));
+                                                     bobAddr.toString(true),
+                                                     MediaAttribute::mediaAttributesToMediaMaps(offer));
     CPPUNIT_ASSERT(not aliceData_.callId_.empty());
 
     JAMI_INFO("ALICE [%s] started a call with BOB [%s] and wait for answer",
@@ -542,16 +511,13 @@ IceSdpParsingTest::test_call()
     std::this_thread::sleep_for(std::chrono::seconds(2));
 
     // Wait for call to be processed.
-    CPPUNIT_ASSERT(
-        waitForSignal(aliceData_, libjami::CallSignal::StateChange::name, StateEvent::RINGING));
+    CPPUNIT_ASSERT(waitForSignal(aliceData_, libjami::CallSignal::StateChange::name, StateEvent::RINGING));
 
     // Wait for incoming call signal.
     CPPUNIT_ASSERT(waitForSignal(bobData_, libjami::CallSignal::IncomingCallWithMedia::name));
 
     // Answer the call.
-    libjami::acceptWithMedia(bobData_.accountId_,
-                           bobData_.callId_,
-                           MediaAttribute::mediaAttributesToMediaMaps(answer));
+    libjami::acceptWithMedia(bobData_.accountId_, bobData_.callId_, MediaAttribute::mediaAttributesToMediaMaps(answer));
 
     // Wait for media negotiation complete signal.
     CPPUNIT_ASSERT(waitForSignal(bobData_,
@@ -559,8 +525,7 @@ IceSdpParsingTest::test_call()
                                  libjami::Media::MediaNegotiationStatusEvents::NEGOTIATION_SUCCESS));
 
     // Wait for the StateChange signal.
-    CPPUNIT_ASSERT(
-        waitForSignal(bobData_, libjami::CallSignal::StateChange::name, StateEvent::CURRENT));
+    CPPUNIT_ASSERT(waitForSignal(bobData_, libjami::CallSignal::StateChange::name, StateEvent::CURRENT));
 
     JAMI_INFO("BOB answered the call [%s]", bobData_.callId_.c_str());
 
@@ -574,8 +539,7 @@ IceSdpParsingTest::test_call()
 
     // Register the media observer to validate media flow.
     CPPUNIT_ASSERT_EQUAL(MEDIA_COUNT, mediaReceivers_.size());
-    auto call = std::dynamic_pointer_cast<SIPCall>(
-        Manager::instance().getCallFromCallID(aliceData_.callId_));
+    auto call = std::dynamic_pointer_cast<SIPCall>(Manager::instance().getCallFromCallID(aliceData_.callId_));
     CPPUNIT_ASSERT(call);
 
     auto rtpList = call->getRtpSessionList();
@@ -607,15 +571,9 @@ IceSdpParsingTest::test_call()
     JAMI_INFO("Hang up BOB's call and wait for ALICE to hang up");
     Manager::instance().hangupCall(bobData_.accountId_, bobData_.callId_);
 
-    CPPUNIT_ASSERT_EQUAL(true,
-                         waitForSignal(aliceData_,
-                                       libjami::CallSignal::StateChange::name,
-                                       StateEvent::HUNGUP));
+    CPPUNIT_ASSERT_EQUAL(true, waitForSignal(aliceData_, libjami::CallSignal::StateChange::name, StateEvent::HUNGUP));
 
-    CPPUNIT_ASSERT_EQUAL(true,
-                         waitForSignal(bobData_,
-                                       libjami::CallSignal::StateChange::name,
-                                       StateEvent::HUNGUP));
+    CPPUNIT_ASSERT_EQUAL(true, waitForSignal(bobData_, libjami::CallSignal::StateChange::name, StateEvent::HUNGUP));
 
     JAMI_INFO("Call terminated on both sides");
 }
