@@ -1,8 +1,6 @@
 #! /usr/bin/env python3
 #
-#  Copyright (C) 2004-2025 Savoir-faire Linux Inc. Inc
-#
-# Author: Guillaume Roguez <guillaume.roguez@savoirfairelinux.com>
+# Copyright (C) 2004-2025 Savoir-faire Linux Inc. Inc
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -194,6 +192,12 @@ class libjamiCtrl(Thread):
         self.currentCallId = callid
         self.onIncomingCall_cb(callid)
 
+    def onCallIncoming(self, callid, state):
+        """ Update state for this call to Incoming """
+
+        self.activeCalls[callid]['State'] = state
+        self.currentCallId = callid
+        self.onIncomingCall_cb(callid)
 
     def onCallHangUp(self, callid, state):
         """ Remove callid from call list """
@@ -252,23 +256,26 @@ class libjamiCtrl(Thread):
 
         self.onCallOver_cb()
         del self.activeCalls[callid]
+        self.currentCallId = None # reset current call as none exists anymore
 
-    def onCallStateChanged_cb(self, callid, state, code):
+    def onCallStateChanged_cb(self, account, callid, state, code):
         pass
 
-    def onCallStateChanged(self, callid, state, code):
+    def onCallStateChanged(self, account, callid, state, code):
         """ On call state changed event, set the values for new calls,
         or delete the call from the list of active calls
         """
-        print(("On call state changed " + callid + " " + state))
+        print(("On call state changed " + str(account) + "; " + str(callid) + "; " + str(state) + "; " + str(code)))
 
         if callid not in self.activeCalls:
             print("This call didn't exist!: " + callid + ". Adding it to the list.")
             callDetails = self.getCallDetails(callid)
-            self.activeCalls[callid] = {'Account': callDetails['ACCOUNTID'],
-                                             'To': callDetails['PEER_NUMBER'],
-                                          'State': state,
-                                          'Code': code }
+            print(callDetails)
+            if callDetails is not None:
+                self.activeCalls[callid] = {'Account': callDetails['ACCOUNTID'],
+                                            'To': callDetails['PEER_NUMBER'],
+                                            'State': state,
+                                            'Code': code }
 
         self.currentCallId = callid
 
@@ -278,6 +285,8 @@ class libjamiCtrl(Thread):
             self.onCallConnecting(callid, state)
         elif state == "RINGING":
             self.onCallRinging(callid, state)
+        elif state == "INCOMING":
+            self.onCallIncoming(callid, state)
         elif state == "CURRENT":
             self.onCallCurrent(callid, state)
         elif state == "HOLD":
@@ -291,8 +300,8 @@ class libjamiCtrl(Thread):
         elif state == "INACTIVE":
             self.onCallInactive(callid,state)
         else:
-            print("unknown state:" + str(state))
-        self.onCallStateChanged_cb(callid, state, code)
+            print("Unknown state:" + str(state))
+        self.onCallStateChanged_cb(account, callid, state, code)
 
     def onConferenceCreated_cb(self):
         pass
