@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Savoir-faire Linux Inc.
- * Author: Mingrui Zhang   <mingrui.zhang@savoirfairelinux.com>
+ * Copyright (C) 2021-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,21 +19,20 @@
 
 #include "qmladapterbase.h"
 
-#include "accountlistmodel.h"
-#include "deviceitemlistmodel.h"
-#include "moderatorlistmodel.h"
-#include "systemtray.h"
-#include "lrcinstance.h"
-#include "utils.h"
+#include "api/accountmodel.h"
 
 #include <QSettings>
 #include <QString>
+#include <QQmlEngine>   // QML registration
+#include <QApplication> // QML registration
 
 class AppSettingsManager;
+class SystemTray;
 
 class AccountAdapter final : public QmlAdapterBase
 {
     Q_OBJECT
+    QML_SINGLETON
 
     Q_PROPERTY(lrc::api::AccountModel* model READ getModel NOTIFY modelChanged)
 
@@ -45,6 +43,8 @@ Q_SIGNALS:
     void modelChanged();
 
 public:
+    static AccountAdapter* create(QQmlEngine*, QJSEngine*);
+
     explicit AccountAdapter(AppSettingsManager* settingsManager,
                             SystemTray* systemTray,
                             LRCInstance* instance,
@@ -81,6 +81,13 @@ public:
                                          const bool& state);
     Q_INVOKABLE QStringList getDefaultModerators(const QString& accountId);
 
+    // New import account / link device functions
+    // import:  (note: Listen for: DeviceAuthStateChanged)
+    Q_INVOKABLE void startImportAccount();
+    Q_INVOKABLE void provideAccountAuthentication(const QString& password = {});
+    Q_INVOKABLE QString getImportErrorMessage(QVariantMap details);
+    Q_INVOKABLE void cancelImportAccount();
+
 Q_SIGNALS:
     // Trigger other components to reconnect account related signals.
     void accountStatusChanged(QString accountId);
@@ -98,11 +105,10 @@ private:
 
     QMetaObject::Connection registeredNameSavedConnection_;
 
+    // The account ID of the last used import account.
+    QString importAccountId_;
+
     AppSettingsManager* settingsManager_;
     SystemTray* systemTray_;
-
-    QScopedPointer<AccountListModel> accountListModel_;
-    QScopedPointer<DeviceItemListModel> deviceItemListModel_;
-    QScopedPointer<ModeratorListModel> moderatorListModel_;
 };
 Q_DECLARE_METATYPE(AccountAdapter*)
