@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Savoir-faire Linux Inc.
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
+ * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,60 +19,32 @@
 
 #pragma once
 
-#include "utils.h"
-
 #include <QMetaEnum>
 #include <QObject>
 #include <QString>
 #include <QStandardPaths>
 #include <QWindow> // for QWindow::AutomaticVisibility
+#include <QSettings>
 
 #include <QTranslator>
 
 extern const QString defaultDownloadPath;
 
 // clang-format off
-#ifdef APPSTORE
-#define KEYS \
-    X(MinimizeOnClose, false) \
-    X(DownloadPath, defaultDownloadPath) \
-    X(ScreenshotPath, {}) \
-    X(EnableNotifications, true) \
-    X(EnableTypingIndicator, true) \
-    X(EnableReadReceipt, true) \
-    X(AcceptTransferBelow, 20) \
-    X(AutoAcceptFiles, true) \
-    X(DisplayHyperlinkPreviews, true) \
-    X(AppTheme, "System") \
-    X(BaseZoom, 1.0) \
-    X(ParticipantsSide, false) \
-    X(HideSelf, true) \
-    X(HideSpectators, false) \
-    X(AutoUpdate, true) \
-    X(PluginAutoUpdate, false) \
-    X(StartMinimized, false) \
-    X(ShowChatviewHorizontally, true) \
-    X(NeverShowMeAgain, false) \
-    X(WindowGeometry, QRectF(qQNaN(), qQNaN(), 0., 0.)) \
-    X(WindowState, QWindow::AutomaticVisibility) \
-    X(EnableExperimentalSwarm, false) \
-    X(LANG, "SYSTEM") \
-    X(PluginStoreEndpoint, "https://plugins.jami.net") \
-    X(PositionShareDuration, 15) \
-    X(PositionShareLimit, true) \
-    X(FlipSelf, true) \
-    X(ShowMardownOption, false) \
-    X(ChatViewEnterIsNewLine, false) \
-    X(ShowSendOption, false)  \
-    X(EnablePtt, false) \
-    X(pttKey, 36)
+
+// Define USE_FRAMELESS_WINDOW_DEFAULT based on the platform
+#ifdef Q_OS_LINUX
+#define USE_FRAMELESS_WINDOW_DEFAULT false
 #else
-#define KEYS \
-    X(MinimizeOnClose, false) \
+#define USE_FRAMELESS_WINDOW_DEFAULT true
+#endif
+
+// Common key-value pairs for both APPSTORE and non-APPSTORE builds
+#define COMMON_KEYS \
+    X(MinimizeOnClose, true) \
     X(DownloadPath, defaultDownloadPath) \
     X(ScreenshotPath, {}) \
     X(EnableNotifications, true) \
-    X(EnableTypingIndicator, true) \
     X(EnableReadReceipt, true) \
     X(AcceptTransferBelow, 20) \
     X(AutoAcceptFiles, true) \
@@ -90,8 +61,9 @@ extern const QString defaultDownloadPath;
     X(NeverShowMeAgain, false) \
     X(WindowGeometry, QRectF(qQNaN(), qQNaN(), 0., 0.)) \
     X(WindowState, QWindow::AutomaticVisibility) \
-    X(EnableExperimentalSwarm, false) \
     X(LANG, "SYSTEM") \
+    X(SpellLang, {}) \
+    X(EnableSpellCheck, true) \
     X(PluginStoreEndpoint, "https://plugins.jami.net") \
     X(PositionShareDuration, 15) \
     X(PositionShareLimit, true) \
@@ -99,11 +71,21 @@ extern const QString defaultDownloadPath;
     X(ShowMardownOption, false) \
     X(ChatViewEnterIsNewLine, false) \
     X(ShowSendOption, false) \
-    X(Donation2023VisibleDate, "2023-11-27 05:00") \
-    X(IsDonationVisible, true) \
-    X(Donation2023EndDate, "2024-01-31 00:00") \
     X(EnablePtt, false) \
-    X(pttKey, 36)
+    X(PttKeys, 32) \
+    X(UseFramelessWindow, USE_FRAMELESS_WINDOW_DEFAULT) \
+    X(EnableCrashReporting, true) \
+    X(EnableAutomaticCrashReporting, false) \
+    X(RaiseWhenCalled, false)
+#if APPSTORE
+#define KEYS COMMON_KEYS
+#else
+// Additional key-value pairs for non-APPSTORE builds including donation
+// related settings.
+#define KEYS COMMON_KEYS \
+    X(Donation2025StartDate, "2025-09-15 00:00") \
+    X(IsDonationVisible, true) \
+    X(Donation2025EndDate, "2025-11-16 00:00")
 #endif
 
 /*
@@ -143,8 +125,9 @@ public:
         default: return {};
         }
     }
+
 private:
-     Settings() = delete;
+    Settings() = delete;
 };
 Q_DECLARE_METATYPE(Settings::Key)
 // clang-format on
@@ -167,9 +150,12 @@ public:
     QString getLanguage();
 
     void loadTranslations();
+    void loadHistory();
 
 Q_SIGNALS:
     void retranslate();
+    void reloadHistory();
+    void localeChanged();
 
 private:
     QSettings* settings_;
