@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Savoir-faire Linux Inc.
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
+ * Copyright (C) 2021-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -144,13 +143,19 @@ CurrentAccount::updateData()
         set_deviceId(accConfig.deviceId);
         set_peerDiscovery(accConfig.peerDiscovery, true);
         set_sendReadReceipt(accConfig.sendReadReceipt, true);
+        set_sendComposing(accConfig.sendComposing, true);
         set_isRendezVous(accConfig.isRendezVous, true);
+        set_dhtPort(accConfig.dhtPort, true);
         set_autoAnswer(accConfig.autoAnswer, true);
+        set_denySecondCall(accConfig.denySecondCall, true);
         set_proxyEnabled(accConfig.proxyEnabled, true);
         set_upnpEnabled(accConfig.upnpEnabled, true);
         set_publishedSameAsLocal(accConfig.publishedSameAsLocal, true);
         set_allowIPAutoRewrite(accConfig.allowIPAutoRewrite, true);
         set_proxyServer(accConfig.proxyServer, true);
+        set_currentProxyServer(accConfig.currentProxyServer, true);
+        set_dhtProxyListUrl(accConfig.dhtProxyListUrl, true);
+        set_proxyListEnabled(accConfig.proxyListEnabled, true);
         set_routeset(accConfig.routeset, true);
         set_username(accConfig.username, true);
         set_hostname(accConfig.hostname, true);
@@ -166,8 +171,8 @@ CurrentAccount::updateData()
         // DHT
         set_PublicInCallsDHT(accConfig.DHT.PublicInCalls, true);
 
-        // RingNS
-        set_uriRingNS(accConfig.RingNS.uri, true);
+        // Nameserver
+        set_uriNameserver(accConfig.Nameserver.uri, true);
 
         // TLS
         set_enableTLS(accConfig.TLS.enable, true);
