@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 2021-2023 Savoir-faire Linux Inc.
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
+ * Copyright (C) 2021-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +23,8 @@
 
 #include <QObject>
 #include <QString>
+#include <QQmlEngine>   // QML registration
+#include <QApplication> // QML registration
 
 #define ACCOUNT_CONFIG_SETTINGS_PROPERTY_BASE(type, prop) \
     PROPERTY_GETTER_BASE(type, prop) \
@@ -97,7 +98,7 @@ private: \
 class CurrentAccount final : public QObject
 {
     Q_OBJECT
-    // Basic settings
+    QML_SINGLETON
 
     QML_RO_PROPERTY(QString, id)
     QML_RO_PROPERTY(QString, uri)
@@ -114,15 +115,21 @@ class CurrentAccount final : public QObject
     QML_RO_PROPERTY(lrc::api::profile::Type, type)
 
     QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(bool, keepAliveEnabled)
+    QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(int, dhtPort)
     QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(bool, peerDiscovery)
     QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(bool, sendReadReceipt)
+    QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(bool, sendComposing)
     QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(bool, isRendezVous)
     QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(bool, autoAnswer)
+    QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(bool, denySecondCall)
     QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(bool, proxyEnabled)
     QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(bool, upnpEnabled)
     QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(bool, publishedSameAsLocal)
     QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(bool, allowIPAutoRewrite)
     QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(QString, proxyServer)
+    QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(QString, currentProxyServer)
+    QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(bool, proxyListEnabled)
+    QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(QString, dhtProxyListUrl)
     QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(QString, routeset)
     QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(QString, username)
     QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(QString, hostname)
@@ -141,8 +148,8 @@ class CurrentAccount final : public QObject
     Q_PROPERTY(bool isLocalModeratorsEnabled READ get_isLocalModeratorsEnabled WRITE
                    set_isLocalModeratorsEnabled NOTIFY isLocalModeratorsEnabledChanged)
 
-    // RingNS setting
-    QML_ACCOUNT_CONFIG_CATEGORY_SETTINGS_PROPERTY(QString, uri, RingNS)
+    // Nameserver setting
+    QML_ACCOUNT_CONFIG_CATEGORY_SETTINGS_PROPERTY(QString, uri, Nameserver)
 
     // DHT settings
     QML_ACCOUNT_CONFIG_CATEGORY_SETTINGS_PROPERTY(bool, PublicInCalls, DHT)
@@ -160,7 +167,6 @@ class CurrentAccount final : public QObject
 
     // SRTP settings
     QML_ACCOUNT_CONFIG_CATEGORY_SETTINGS_PROPERTY(bool, enable, SRTP)
-    QML_ACCOUNT_CONFIG_CATEGORY_SETTINGS_PROPERTY(bool, rtpFallback, SRTP)
     QML_ACCOUNT_CONFIG_CATEGORY_SETTINGS_PROPERTY(lrc::api::account::KeyExchangeProtocol,
                                                   keyExchange,
                                                   SRTP)
@@ -191,7 +197,16 @@ class CurrentAccount final : public QObject
     QML_NEW_ACCOUNT_MODEL_SETTINGS_PROPERTY(bool, autoTransferFromTrusted, AutoAcceptFiles)
     QML_NEW_ACCOUNT_MODEL_SETTINGS_PROPERTY(int, autoTransferSizeThreshold, AcceptTransferBelow)
 
+    // UI Customization settings
+    QML_ACCOUNT_CONFIG_SETTINGS_PROPERTY(QJsonObject, uiCustomization)
+
 public:
+    static CurrentAccount* create(QQmlEngine*, QJSEngine*)
+    {
+        return new CurrentAccount(qApp->property("LRCInstance").value<LRCInstance*>(),
+                                  qApp->property("AppSettingsManager").value<AppSettingsManager*>());
+    }
+
     explicit CurrentAccount(LRCInstance* lrcInstance,
                             AppSettingsManager* settingsManager,
                             QObject* parent = nullptr);
