@@ -1,8 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Savoir-faire Linux Inc.
- * Author: Edric Ladent Milaret <edric.ladent-milaret@savoirfairelinux.com>
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
+ * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,12 +26,14 @@
 #include <QQmlEngine>
 #include <QScreen>
 #include <QWindow>
-
-#include <memory>
+#include <QCommandLineParser>
 
 class ConnectivityMonitor;
-class AppSettingsManager;
 class SystemTray;
+class AppSettingsManager;
+class AccountSettingsManager;
+class CrashReporter;
+class PreviewEngine;
 
 // Provides information about the screen the app is displayed on
 class ScreenInfo : public QObject
@@ -56,8 +55,8 @@ private:
 class MainApplication : public QApplication
 {
     Q_OBJECT
-    Q_DISABLE_COPY(MainApplication)
     QML_RO_PROPERTY(bool, startMinimized)
+
 public:
     explicit MainApplication(int& argc, char** argv);
     ~MainApplication();
@@ -108,7 +107,6 @@ private:
     void setApplicationFont();
     void initQmlLayer();
     void initSystray();
-    void cleanup();
 
 private:
     std::map<Option, QVariant> runOptions_;
@@ -121,8 +119,10 @@ private:
     ConnectivityMonitor* connectivityMonitor_;
     SystemTray* systemTray_;
     AppSettingsManager* settingsManager_;
+    AccountSettingsManager* accountSettingsManager_;
+    PreviewEngine* previewEngine_;
+    CrashReporter* crashReporter_;
 
     ScreenInfo screenInfo_;
-
-    bool isCleanupped;
+    QCommandLineParser parser_;
 };
