@@ -1,11 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Savoir-faire Linux Inc.
- * Author: Edric Ladent Milaret <edric.ladent-milaret@savoirfairelinux.com>
- * Author: Anthony Léonard <anthony.leonard@savoirfairelinux.com>
- * Author: Olivier Soldano <olivier.soldano@savoirfairelinux.com>
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
- * Author: Isa Nanic <isa.nanic@savoirfairelinux.com>
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
+ * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,8 +20,10 @@
 #include "appsettingsmanager.h"
 #include "qtutils.h"
 #include "messageparser.h"
+#include "previewengine.h"
 
 #include <api/datatransfermodel.h>
+#include <api/contact.h>
 
 #include <QApplication>
 #include <QBuffer>
@@ -51,13 +47,19 @@ MessagesAdapter::MessagesAdapter(AppSettingsManager* settingsManager,
     , settingsManager_(settingsManager)
     , messageParser_(new MessageParser(previewEngine, this))
     , filteredMsgListModel_(new FilteredMsgListModel(this))
-    , mediaInteractions_(std::make_unique<MessageListModel>())
+    , mediaInteractions_(std::make_unique<MessageListModel>(nullptr))
     , timestampTimer_(new QTimer(this))
+    , curLocale_(QLocale(settingsManager_->getLanguage()))
 {
     setObjectName(typeid(*this).name());
 
     set_messageListModel(QVariant::fromValue(filteredMsgListModel_));
 
+    connect(settingsManager_,
+            &AppSettingsManager::reloadHistory,
+            &lrcInstance_->accountModel(),
+            &AccountModel::reloadHistory);
+
     connect(lrcInstance_, &LRCInstance::selectedConvUidChanged, this, [this]() {
         set_replyToId("");
         set_editId("");
@@ -68,19 +70,18 @@ MessagesAdapter::MessagesAdapter(AppSettingsManager* settingsManager,
         filteredMsgListModel_->setSourceModel(conversation.interactions.get());
 
         set_currentConvComposingList(conversationTypersUrlToName(conversation.typers));
-        mediaInteractions_.reset(new MessageListModel(this));
-        set_mediaMessageListModel(QVariant::fromValue(mediaInteractions_.get()));
     });
 
     connect(messageParser_, &MessageParser::messageParsed, this, &MessagesAdapter::onMessageParsed);
     connect(messageParser_, &MessageParser::linkInfoReady, this, &MessagesAdapter::onLinkInfoReady);
 
+    connect(settingsManager_, &AppSettingsManager::localeChanged, this, [this]() {
+        curLocale_ = QLocale((settingsManager_->getLanguage()));
+    });
     connect(timestampTimer_, &QTimer::timeout, this, &MessagesAdapter::timestampUpdated);
     timestampTimer_->start(timestampUpdateIntervalMs_);
 
-    connect(lrcInstance_, &LRCInstance::currentAccountIdChanged, this, [this]() {
-        connectConversationModel();
-    });
+    connect(lrcInstance_, &LRCInstance::currentAccountIdChanged, this, &MessagesAdapter::connectConversationModel);
 
     connectConversationModel();
 }
@@ -98,37 +99,13 @@ MessagesAdapter::loadMoreMessages()
     auto convId = lrcInstance_->get_selectedConvUid();
     try {
         const auto& convInfo = lrcInstance_->getConversationFromConvUid(convId, accountId);
-        if (convInfo.isSwarm()) {
-            auto* convModel = lrcInstance_->getCurrentConversationModel();
-            convModel->loadConversationMessages(convId, loadChunkSize_);
-        }
+        if (convInfo.isSwarm())
+            lrcInstance_->getCurrentConversationModel()->loadConversationMessages(convId, loadChunkSize_);
     } catch (const std::exception& e) {
         qWarning() << e.what();
     }
 }
 
-int
-MessagesAdapter::loadConversationUntil(const QString& to)
-{
-    try {
-        if (auto* model = getMsgListSourceModel()) {
-            auto idx = model->indexOfMessage(to);
-            if (idx == -1) {
-                auto accountId = lrcInstance_->get_currentAccountId();
-                auto convId = lrcInstance_->get_selectedConvUid();
-                const auto& convInfo = lrcInstance_->getConversationFromConvUid(convId, accountId);
-                if (convInfo.isSwarm()) {
-                    auto* convModel = lrcInstance_->getCurrentConversationModel();
-                    return convModel->loadConversationUntil(convId, to);
-                }
-            }
-        }
-    } catch (const std::exception& e) {
-        qWarning() << e.what();
-    }
-    return 0;
-}
-
 void
 MessagesAdapter::connectConversationModel()
 {
@@ -160,6 +137,9 @@ MessagesAdapter::connectConversationModel()
                      this,
                      &MessagesAdapter::onMessagesFoundProcessed,
                      Qt::UniqueConnection);
+
+    mediaInteractions_.reset(new MessageListModel(&lrcInstance_->getCurrentAccountInfo(), this));
+    set_mediaMessageListModel(QVariant::fromValue(mediaInteractions_.get()));
 }
 
 void
@@ -179,6 +159,16 @@ MessagesAdapter::sendMessage(const QString& message)
     }
 }
 
+void
+MessagesAdapter::sendMessageToUid(const QString& message, const QString& convUid)
+{
+    try {
+        lrcInstance_->getCurrentConversationModel()->sendMessage(convUid, message, replyToId_);
+    } catch (...) {
+        qDebug() << "Exception during sendMessage:" << message;
+    }
+}
+
 void
 MessagesAdapter::editMessage(const QString& convId, const QString& newBody, const QString& messageId)
 {
@@ -195,25 +185,18 @@ MessagesAdapter::editMessage(const QString& convId, const QString& newBody, cons
 }
 
 void
-MessagesAdapter::removeEmojiReaction(const QString& convId,
-                                     const QString& emoji,
-                                     const QString& messageId)
+MessagesAdapter::removeEmojiReaction(const QString& convId, const QString& emoji, const QString& messageId)
 {
     try {
-        const auto authorUri = lrcInstance_->getCurrentAccountInfo().profileInfo.uri;
         // check if this emoji has already been added by this author
-        auto emojiId = lrcInstance_->getConversationFromConvUid(convId)
-                           .interactions->findEmojiReaction(emoji, authorUri, messageId);
-        editMessage(convId, "", emojiId);
+        editMessage(convId, "", messageId);
     } catch (...) {
         qDebug() << "Exception during removeEmojiReaction():" << messageId;
     }
 }
 
 void
-MessagesAdapter::addEmojiReaction(const QString& convId,
-                                  const QString& emoji,
-                                  const QString& messageId)
+MessagesAdapter::addEmojiReaction(const QString& convId, const QString& emoji, const QString& messageId)
 {
     try {
         lrcInstance_->getCurrentConversationModel()->reactMessage(convId, emoji, messageId);
@@ -229,20 +212,26 @@ MessagesAdapter::sendFile(const QString& message)
     QString fileName = fi.fileName();
     try {
         auto convUid = lrcInstance_->get_selectedConvUid();
-        lrcInstance_->getCurrentConversationModel()->sendFile(convUid,
-                                                              message,
-                                                              fileName,
-                                                              replyToId_);
+        lrcInstance_->getCurrentConversationModel()->sendFile(convUid, message, fileName, replyToId_);
     } catch (...) {
         qDebug() << "Exception during sendFile";
     }
 }
 
 void
-MessagesAdapter::joinCall(const QString& uri,
-                          const QString& deviceId,
-                          const QString& confId,
-                          bool isAudioOnly)
+MessagesAdapter::sendFileToUid(const QString& message, const QString& convUid)
+{
+    QFileInfo fi(message);
+    QString fileName = fi.fileName();
+    try {
+        lrcInstance_->getCurrentConversationModel()->sendFile(convUid, message, fileName, replyToId_);
+    } catch (...) {
+        qDebug() << "Exception during sendFile";
+    }
+}
+
+void
+MessagesAdapter::joinCall(const QString& uri, const QString& deviceId, const QString& confId, bool isAudioOnly)
 {
     lrcInstance_->getCurrentConversationModel()->joinCall(lrcInstance_->get_selectedConvUid(),
                                                           uri,
@@ -267,13 +256,6 @@ MessagesAdapter::copyToDownloads(const QString& interactionId, const QString& di
     }
 }
 
-void
-MessagesAdapter::deleteInteraction(const QString& interactionId)
-{
-    lrcInstance_->getCurrentConversationModel()
-        ->clearInteractionFromConversation(lrcInstance_->get_selectedConvUid(), interactionId);
-}
-
 void
 MessagesAdapter::openUrl(const QString& url)
 {
@@ -299,6 +281,13 @@ MessagesAdapter::openDirectory(const QString& path)
     }
 }
 
+void
+MessagesAdapter::removeFile(const QString& interactionId, const QString& path)
+{
+    auto convUid = lrcInstance_->get_selectedConvUid();
+    lrcInstance_->getCurrentConversationModel()->removeFile(convUid, interactionId, path);
+}
+
 void
 MessagesAdapter::acceptFile(const QString& interactionId)
 {
@@ -322,15 +311,13 @@ MessagesAdapter::onPaste()
         // Save temp data into a temp file.
         QPixmap pixmap = qvariant_cast<QPixmap>(mimeData->imageData());
 
-        auto img_name_hash
-            = QCryptographicHash::hash(QString::number(pixmap.cacheKey()).toLocal8Bit(),
-                                       QCryptographicHash::Sha1);
+        auto img_name_hash = QCryptographicHash::hash(QString::number(pixmap.cacheKey()).toLocal8Bit(),
+                                                      QCryptographicHash::Sha1);
         QString fileName = "img_" + QString(img_name_hash.toHex()) + ".png";
         QString path = QDir::temp().filePath(fileName);
 
         if (!pixmap.save(path, "PNG")) {
-            qDebug().noquote() << "Errors during QPixmap save"
-                               << "\n";
+            qDebug().noquote() << "Errors during QPixmap save" << "\n";
             return;
         }
 
@@ -352,40 +339,6 @@ MessagesAdapter::onPaste()
     }
 }
 
-QString
-MessagesAdapter::getStatusString(int status)
-{
-    switch (static_cast<interaction::Status>(status)) {
-    case interaction::Status::SENDING:
-        return QObject::tr("Sending");
-    case interaction::Status::FAILURE:
-        return QObject::tr("Failure");
-    case interaction::Status::SUCCESS:
-        return QObject::tr("Sent");
-    case interaction::Status::TRANSFER_CREATED:
-        return QObject::tr("Connecting");
-    case interaction::Status::TRANSFER_ACCEPTED:
-        return QObject::tr("Accept");
-    case interaction::Status::TRANSFER_CANCELED:
-        return QObject::tr("Canceled");
-    case interaction::Status::TRANSFER_ERROR:
-    case interaction::Status::TRANSFER_UNJOINABLE_PEER:
-        return QObject::tr("Unable to make contact");
-    case interaction::Status::TRANSFER_ONGOING:
-        return QObject::tr("Ongoing");
-    case interaction::Status::TRANSFER_AWAITING_PEER:
-        return QObject::tr("Waiting for contact");
-    case interaction::Status::TRANSFER_AWAITING_HOST:
-        return QObject::tr("Incoming transfer");
-    case interaction::Status::TRANSFER_TIMEOUT_EXPIRED:
-        return QObject::tr("Timed out waiting for contact");
-    case interaction::Status::TRANSFER_FINISHED:
-        return QObject::tr("Finished");
-    default:
-        return {};
-    }
-}
-
 QVariantMap
 MessagesAdapter::getTransferStats(const QString& msgId, int status)
 {
@@ -400,18 +353,7 @@ QVariant
 MessagesAdapter::dataForInteraction(const QString& interactionId, int role) const
 {
     if (auto* model = getMsgListSourceModel()) {
-        auto idx = model->indexOfMessage(interactionId);
-        if (idx != -1)
-            return model->data(idx, role);
-    }
-    return {};
-}
-
-int
-MessagesAdapter::getIndexOfMessage(const QString& interactionId) const
-{
-    if (auto* model = getMsgListSourceModel()) {
-        return model->indexOfMessage(interactionId);
+        return model->data(interactionId, role);
     }
     return {};
 }
@@ -419,12 +361,9 @@ MessagesAdapter::getIndexOfMessage(const QString& interactionId) const
 void
 MessagesAdapter::userIsComposing(bool isComposing)
 {
-    if (!settingsManager_->getValue(Settings::Key::EnableTypingIndicator).toBool()
-        || lrcInstance_->get_selectedConvUid().isEmpty()) {
+    if (lrcInstance_->get_selectedConvUid().isEmpty())
         return;
-    }
-    lrcInstance_->getCurrentConversationModel()->setIsComposing(lrcInstance_->get_selectedConvUid(),
-                                                                isComposing);
+    lrcInstance_->getCurrentConversationModel()->setIsComposing(lrcInstance_->get_selectedConvUid(), isComposing);
 }
 
 void
@@ -449,6 +388,10 @@ MessagesAdapter::onNewInteraction(const QString& convUid,
 void
 MessagesAdapter::onMessageParsed(const QString& messageId, const QString& parsed)
 {
+    if (messageId.isEmpty()) {
+        Q_EMIT messageParsed(messageId, parsed);
+        return;
+    }
     const QString& convId = lrcInstance_->get_selectedConvUid();
     const QString& accId = lrcInstance_->get_currentAccountId();
     auto& conversation = lrcInstance_->getConversationFromConvUid(convId, accId);
@@ -522,10 +465,10 @@ MessagesAdapter::clearConversationHistory(const QString& accountId, const QStrin
 }
 
 void
-MessagesAdapter::removeConversation(const QString& convUid)
+MessagesAdapter::removeConversation(const QString& convUid, bool keepContact)
 {
     auto& accInfo = lrcInstance_->getCurrentAccountInfo();
-    accInfo.conversationModel->removeConversation(convUid);
+    accInfo.conversationModel->removeConversation(convUid, false, keepContact);
 }
 
 void
@@ -568,19 +511,14 @@ MessagesAdapter::onConversationMessagesLoaded(uint32_t loadingRequestId, const Q
 }
 
 void
-MessagesAdapter::parseMessage(const QString& msgId,
-                              const QString& msg,
-                              bool showPreview,
-                              const QColor& linkColor,
-                              const QColor& backgroundColor)
+MessagesAdapter::parseMessage(
+    const QString& msgId, const QString& msg, bool showPreview, const QColor& linkColor, const QColor& backgroundColor)
 {
     messageParser_->parseMessage(msgId, msg, showPreview, linkColor, backgroundColor);
 }
 
 void
-MessagesAdapter::onComposingStatusChanged(const QString& convId,
-                                          const QString& contactUri,
-                                          bool isComposing)
+MessagesAdapter::onComposingStatusChanged(const QString& convId, const QString& contactUri, bool isComposing)
 {
     Q_UNUSED(contactUri)
     if (lrcInstance_->get_selectedConvUid() == convId) {
@@ -601,7 +539,7 @@ MessagesAdapter::onMessagesFoundProcessed(const QString& accountId,
     bool isSearchInProgress = messageInformation.size();
     if (isSearchInProgress) {
         for (auto it = messageInformation.begin(); it != messageInformation.end(); it++) {
-            mediaInteractions_->insert(qMakePair(it.key(), it.value()));
+            mediaInteractions_->append(it.key(), it.value());
         }
     } else {
         set_mediaMessageListModel(QVariant::fromValue(mediaInteractions_.get()));
@@ -630,9 +568,7 @@ MessagesAdapter::isLocalImage(const QString& mimename)
         QList<QByteArray> supportedFormats = reader.supportedImageFormats();
         auto iterator = std::find_if(supportedFormats.begin(),
                                      supportedFormats.end(),
-                                     [fileFormat](QByteArray format) {
-                                         return format == fileFormat;
-                                     });
+                                     [fileFormat](const QByteArray& format) { return format == fileFormat; });
         if (iterator != supportedFormats.end() && *iterator == "gif") {
             return {{"isAnimatedImage", true}};
         }
@@ -645,11 +581,10 @@ QVariantMap
 MessagesAdapter::getMediaInfo(const QString& msg)
 {
     auto filePath = QFileInfo(msg).absoluteFilePath();
-    static const QString html
-        = "<body style='margin:0;padding:0;'>"
-          "<%1 style='width:100%;height:%2;outline:none;background-color:#f1f3f4;"
-          "object-fit:cover;' "
-          "controls controlsList='nodownload noplaybackrate' src='file://%3' type='%4'/></body>";
+    static const QString html = "<body style='margin:0;padding:0;'>"
+                                "<%1 style='width:100%;height:%2;outline:none;background-color:#f1f3f4;"
+                                "object-fit:cover;' "
+                                "controls controlsList='nodownload noplaybackrate' src='file://%3' type='%4'/></body>";
     QMimeDatabase db;
     QMimeType mime = db.mimeTypeForFile(filePath);
     QVariantMap fileInfo = isLocalImage(mime.name());
@@ -686,9 +621,8 @@ bool
 MessagesAdapter::isRemoteImage(const QString& msg)
 {
     // TODO: test if all these open in the AnimatedImage component
-    const static QRegularExpression
-        imageRe("[^\\s]+(.*?)\\.(jpg|jpeg|png|gif|apng|webp|avif|flif)$",
-                QRegularExpression::CaseInsensitiveOption);
+    const static QRegularExpression imageRe("[^\\s]+(.*?)\\.(jpg|jpeg|png|gif|apng|webp|avif|flif)$",
+                                            QRegularExpression::CaseInsensitiveOption);
     QRegularExpressionMatch match = imageRe.match(msg);
     return match.hasMatch();
 }
@@ -698,18 +632,11 @@ MessagesAdapter::getFormattedTime(const quint64 timestamp)
 {
     const auto currentTime = QDateTime::currentDateTime();
     const auto seconds = currentTime.toSecsSinceEpoch() - timestamp;
-    auto interval = qFloor(seconds / 60);
-
-    if (interval > 1) {
-        auto curLang = settingsManager_->getLanguage();
-        auto curLocal = QLocale(curLang);
+    if (seconds > 60) {
         auto curTime = QDateTime::fromSecsSinceEpoch(timestamp).time();
-        QString timeLocale;
-        timeLocale = curLocal.toString(curTime, curLocal.ShortFormat);
-
-        return timeLocale;
+        return curLocale_.toString(curTime, curLocale_.ShortFormat).toLower();
     }
-    return QObject::tr("just now");
+    return QObject::tr("Just now");
 }
 
 QString
@@ -732,54 +659,28 @@ MessagesAdapter::getFormattedDay(const quint64 timestamp)
     if (timestampDate.daysTo(currentDate) == 1)
         return QObject::tr("Yesterday");
 
-    auto curLang = settingsManager_->getLanguage();
-    auto curLocal = QLocale(curLang);
-    auto curDate = QDateTime::fromSecsSinceEpoch(timestamp).date();
-    QString dateLocale;
-    dateLocale = curLocal.toString(curDate, curLocal.ShortFormat);
-
-    return dateLocale;
+    return curLocale_.toString(timestampDate, curLocale_.ShortFormat);
 }
 
 void
 MessagesAdapter::startSearch(const QString& text, bool isMedia)
 {
-    mediaInteractions_.reset(new MessageListModel(this));
+    auto accountId = lrcInstance_->get_currentAccountId();
+    mediaInteractions_.reset(new MessageListModel(&lrcInstance_->getCurrentAccountInfo(), this));
     set_mediaMessageListModel(QVariant::fromValue(mediaInteractions_.get()));
 
     if (text.isEmpty() && !isMedia)
         return;
 
-    auto accountId = lrcInstance_->get_currentAccountId();
     auto convId = lrcInstance_->get_selectedConvUid();
 
     try {
-        lrcInstance_->getCurrentConversationModel()->getConvMediasInfos(accountId,
-                                                                        convId,
-                                                                        text,
-                                                                        isMedia);
+        lrcInstance_->getCurrentConversationModel()->getConvMediasInfos(accountId, convId, text, isMedia);
     } catch (...) {
         qDebug() << "Exception during startSearch()";
     }
 }
 
-int
-MessagesAdapter::getMessageIndexFromId(const QString& id)
-{
-    const QString& convId = lrcInstance_->get_selectedConvUid();
-    const auto& conversation = lrcInstance_->getConversationFromConvUid(convId);
-    auto allInteractions = conversation.interactions.get();
-    int index = 0;
-    for (auto it = allInteractions->rbegin(); it != allInteractions->rend(); it++) {
-        if (interaction::isDisplayedInChatview(it->second.type)) {
-            if (it->first == id)
-                return index;
-            index++;
-        }
-    }
-    return -1;
-}
-
 MessageListModel*
 MessagesAdapter::getMsgListSourceModel() const
 {
