@@ -1,10 +1,5 @@
-/*!
- * Copyright (C) 2015-2023 Savoir-faire Linux Inc.
- * Author: Edric Ladent Milaret <edric.ladent-milaret@savoirfairelinux.com>
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
- * Author: Isa Nanic <isa.nanic@savoirfairelinux.com
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
- * Author: Aline Gondim Santos <aline.gondimsantos@savoirfairelinux.com>
+/*
+ * Copyright (C) 2015-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,8 +19,9 @@
 
 #include "jamiavatartheme.h"
 #include "lrcinstance.h"
+#include "global.h"
 
-#include <qrencode.h>
+#include <api/contact.h>
 
 #include <QApplication>
 #include <QBitmap>
@@ -51,15 +47,15 @@
 #include <windows.h>
 #endif
 
+#include <BitMatrix.h>
+#include <MultiFormatWriter.h>
+
 // Removes the given argument from the command line arguments, and invokes the callback
 // function with the removed argument if it was found.
 // This is required for custom args as quick_test_main_with_setup() will
 // fail if given an invalid command-line argument.
 void
-Utils::remove_argument(char** argv,
-                       int& argc,
-                       const std::string& arg_to_remove,
-                       std::function<void()> callback)
+Utils::remove_argument(char** argv, int& argc, const std::string& arg_to_remove, std::function<void()> callback)
 {
     // Remove arg_to_remove from argv, as quick_test_main_with_setup() will
     // fail if given an invalid command-line argument.
@@ -73,7 +69,7 @@ Utils::remove_argument(char** argv,
         }
     });
 
-    // If any occurrences were removed...
+    // If any occurrences were removed…
     if (new_end != argv + argc) {
         // Adjust the argument count.
         argc = std::distance(argv, new_end);
@@ -84,7 +80,7 @@ void
 Utils::testVulkanSupport()
 {
 #if defined(Q_OS_WIN)
-    // Checks Vulkan support using the vulkan functions loaded directly
+    // Checks Vulkan support using the Vulkan functions loaded directly
     // from vulkan-1.dll.
     struct DllLoader
     {
@@ -92,7 +88,7 @@ Utils::testVulkanSupport()
             : module(LoadLibraryA(filename.c_str()))
         {
             if (module == nullptr) {
-                throw std::runtime_error("Can't load module.");
+                throw std::runtime_error("Unable to load module.");
             }
         }
         ~DllLoader()
@@ -103,15 +99,13 @@ Utils::testVulkanSupport()
     } vk {"vulkan-1.dll"};
 
     typedef void*(__stdcall * PFN_vkGetInstanceProcAddr)(void*, const char*);
-    auto vkGetInstanceProcAddr = (PFN_vkGetInstanceProcAddr)
-        GetProcAddress(vk.module, "vkGetInstanceProcAddr");
+    auto vkGetInstanceProcAddr = (PFN_vkGetInstanceProcAddr) GetProcAddress(vk.module, "vkGetInstanceProcAddr");
     if (!vkGetInstanceProcAddr) {
         throw std::runtime_error("Missing vkGetInstanceProcAddr proc.");
     }
 
     typedef int(__stdcall * PFN_vkCreateInstance)(int*, void*, void**);
-    auto vkCreateInstance = (PFN_vkCreateInstance) vkGetInstanceProcAddr(vk.module,
-                                                                         "vkCreateInstance");
+    auto vkCreateInstance = (PFN_vkCreateInstance) vkGetInstanceProcAddr(vk.module, "vkCreateInstance");
     if (!vkCreateInstance) {
         throw std::runtime_error("Missing vkCreateInstance proc.");
     }
@@ -120,7 +114,7 @@ Utils::testVulkanSupport()
     int VkInstanceCreateInfo[16] = {1};
     auto result = vkCreateInstance(VkInstanceCreateInfo, 0, &instance);
     if (!instance || result != 0) {
-        throw std::runtime_error("Can't create Vulkan instance.");
+        throw std::runtime_error("Unable to create Vulkan instance.");
     }
 #endif
 }
@@ -152,9 +146,9 @@ Utils::CreateStartupLink(const std::wstring& wstrAppName)
 
 #ifdef JAMI_INSTALL_PREFIX
     desktopPath = JAMI_INSTALL_PREFIX;
-    desktopPath += "/jami/jami.desktop";
+    desktopPath += "/jami/net.jami.Jami.desktop";
 #else
-    desktopPath = "share/jami/jami.desktop";
+    desktopPath = "share/jami/net.jami.Jami.desktop";
     QStringList paths = {"/usr/" + desktopPath,
                          "/usr/local/" + desktopPath,
                          QDir::currentPath() + "/../../install/client-qt/" + desktopPath};
@@ -167,14 +161,13 @@ Utils::CreateStartupLink(const std::wstring& wstrAppName)
 #endif
 
     if (desktopPath.isEmpty() || !(QFile::exists(desktopPath))) {
-        qDebug() << "Could not locate .desktop file at" << desktopPath;
+        qDebug() << "Error while attempting to locate .desktop file at" << desktopPath;
         return false;
     }
 
     qDebug() << "Linking autostart file from" << desktopPath;
 
-    QString desktopFile = QStandardPaths::locate(QStandardPaths::ConfigLocation,
-                                                 "autostart/jami.desktop");
+    QString desktopFile = QStandardPaths::locate(QStandardPaths::ConfigLocation, "autostart/net.jami.Jami.desktop");
     if (!desktopFile.isEmpty()) {
         QFileInfo symlinkInfo(desktopFile);
         if (symlinkInfo.isSymLink()) {
@@ -187,24 +180,22 @@ Utils::CreateStartupLink(const std::wstring& wstrAppName)
             }
         }
     } else {
-        QString autoStartDir = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation)
-                               + "/autostart";
+        QString autoStartDir = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + "/autostart";
 
         if (!QDir(autoStartDir).exists()) {
             if (QDir().mkdir(autoStartDir)) {
                 qDebug() << "Created autostart directory:" << autoStartDir;
             } else {
-                qWarning() << "Could not create autostart directory:" << autoStartDir;
+                qWarning() << "Error while creating autostart directory:" << autoStartDir;
                 return false;
             }
         }
-        desktopFile = autoStartDir + "/jami.desktop";
+        desktopFile = autoStartDir + "/net.jami.Jami.desktop";
     }
 
     QFile srcFile(desktopPath);
     bool result = srcFile.link(desktopFile);
-    qDebug() << desktopFile
-             << (result ? "-> " + desktopPath + " successfully created" : "could not be created");
+    qDebug() << desktopFile << (result ? "-> " + desktopPath + " created successfully" : "unable to be created");
     return result;
 #endif
 }
@@ -216,11 +207,7 @@ Utils::CreateLink(LPCWSTR lpszPathObj, LPCWSTR lpszPathLink)
     HRESULT hres;
     IShellLink* psl;
 
-    hres = CoCreateInstance(CLSID_ShellLink,
-                            NULL,
-                            CLSCTX_INPROC_SERVER,
-                            IID_IShellLink,
-                            (LPVOID*) &psl);
+    hres = CoCreateInstance(CLSID_ShellLink, NULL, CLSCTX_INPROC_SERVER, IID_IShellLink, (LPVOID*) &psl);
     if (SUCCEEDED(hres)) {
         IPersistFile* ppf;
         psl->SetPath(lpszPathObj);
@@ -255,14 +242,13 @@ Utils::DeleteStartupLink(const std::wstring& wstrAppName)
 
 #else
     Q_UNUSED(wstrAppName)
-    QString desktopFile = QStandardPaths::locate(QStandardPaths::ConfigLocation,
-                                                 "autostart/jami.desktop");
+    QString desktopFile = QStandardPaths::locate(QStandardPaths::ConfigLocation, "autostart/net.jami.Jami.desktop");
     if (!desktopFile.isEmpty()) {
         try {
             QFile::remove(desktopFile);
             qDebug() << "Autostart disabled," << desktopFile << "removed";
         } catch (...) {
-            qDebug() << "Could not remove" << desktopFile;
+            qDebug() << "Unable to remove" << desktopFile;
         }
     } else {
         qDebug() << desktopFile << "does not exist";
@@ -282,8 +268,7 @@ Utils::CheckStartupLink(const std::wstring& wstrAppName)
     return PathFileExists(linkPath.c_str());
 #else
     Q_UNUSED(wstrAppName)
-    return (
-        !QStandardPaths::locate(QStandardPaths::ConfigLocation, "autostart/jami.desktop").isEmpty());
+    return (!QStandardPaths::locate(QStandardPaths::ConfigLocation, "autostart/net.jami.Jami.desktop").isEmpty());
 #endif
 }
 
@@ -297,7 +282,7 @@ Utils::removeOldVersions()
      * remove 1. the configuration reg keys for Ring-x64, 2. the startup links for Ring,
      * 3. the winsparkle reg keys. The NSIS uninstall reg keys for Jami-x64 are removed
      * by the MSI installer.
-     * Uninstallation of Ring, either 32 or 64 bit, is left to the user.
+     * Uninstallation of Ring, either 32-bit or 64-bit, is left to the user.
      * The current version of Jami will attempt to kill Ring.exe upon start if a startup
      * link is found.
      */
@@ -386,8 +371,8 @@ Utils::accountPhoto(LRCInstance* instance, const QString& accountId, const QSize
 {
     QImage photo;
     try {
-        auto& accInfo = instance->accountModel().getAccountInfo(
-            accountId.isEmpty() ? instance->get_currentAccountId() : accountId);
+        auto& accInfo = instance->accountModel().getAccountInfo(accountId.isEmpty() ? instance->get_currentAccountId()
+                                                                                    : accountId);
         auto bestName = instance->accountModel().bestNameForAccount(accInfo.id);
         if (!accInfo.profileInfo.avatar.isEmpty()) {
             photo = imageFromBase64String(accInfo.profileInfo.avatar);
@@ -408,62 +393,53 @@ Utils::accountPhoto(LRCInstance* instance, const QString& accountId, const QSize
 }
 
 QImage
-Utils::contactPhoto(LRCInstance* instance,
-                    const QString& contactUri,
-                    const QSize& size,
-                    const QString& accountId)
+Utils::contactPhoto(LRCInstance* instance, const QString& contactUri, const QSize& size, const QString& accountId)
 {
     QImage photo;
     try {
-        auto& accInfo = instance->accountModel().getAccountInfo(
-            accountId.isEmpty() ? instance->get_currentAccountId() : accountId);
-        auto contactInfo = accInfo.contactModel->getContact(contactUri);
+        auto& accInfo = instance->accountModel().getAccountInfo(accountId.isEmpty() ? instance->get_currentAccountId()
+                                                                                    : accountId);
         auto contactPhoto = accInfo.contactModel->avatar(contactUri);
-        auto bestName = accInfo.contactModel->bestNameForContact(contactUri);
-        if (accInfo.profileInfo.type == profile::Type::SIP
-            && contactInfo.profileInfo.type == profile::Type::TEMPORARY) {
-            photo = Utils::fallbackAvatar(QString(), QString());
-        } else if (contactInfo.profileInfo.type == profile::Type::TEMPORARY
-                   && contactInfo.profileInfo.uri.isEmpty()) {
-            photo = Utils::fallbackAvatar(QString(), QString());
-        } else if (!contactPhoto.isEmpty()) {
+        if (!contactPhoto.isEmpty()) {
             photo = imageFromBase64String(contactPhoto);
-            if (photo.isNull()) {
-                auto avatarName = contactInfo.profileInfo.uri == bestName ? QString() : bestName;
-                photo = Utils::fallbackAvatar("jami:" + contactInfo.profileInfo.uri, avatarName);
-            }
+            if (!photo.isNull())
+                return Utils::scaleAndFrame(photo, size);
+        }
+        // If no avatar is found, generate one
+        auto contactInfo = accInfo.contactModel->getContact(contactUri);
+        auto bestName = accInfo.contactModel->bestNameForContact(contactUri);
+        if (accInfo.profileInfo.type == profile::Type::SIP && contactInfo.profileInfo.type == profile::Type::TEMPORARY) {
+            photo = Utils::fallbackAvatar(QString(), QString());
+        } else if (contactInfo.profileInfo.type == profile::Type::TEMPORARY && contactInfo.profileInfo.uri.isEmpty()) {
+            photo = Utils::fallbackAvatar(QString(), QString());
         } else {
             auto avatarName = contactInfo.profileInfo.uri == bestName ? QString() : bestName;
             photo = Utils::fallbackAvatar("jami:" + contactInfo.profileInfo.uri, avatarName);
         }
-    } catch (const std::exception& e) {
+    } catch (const std::exception&) {
         photo = fallbackAvatar("jami:" + contactUri, QString(), size);
     }
     return Utils::scaleAndFrame(photo, size);
 }
 
 QImage
-Utils::conversationAvatar(LRCInstance* instance,
-                          const QString& convId,
-                          const QSize& size,
-                          const QString& accountId)
+Utils::conversationAvatar(LRCInstance* instance, const QString& convId, const QSize& size, const QString& accountId)
 {
     QImage avatar(size, QImage::Format_ARGB32_Premultiplied);
     avatar.fill(Qt::transparent);
     QPainter painter(&avatar);
     painter.setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
     try {
-        auto& accInfo = instance->accountModel().getAccountInfo(
-            accountId.isEmpty() ? instance->get_currentAccountId() : accountId);
+        auto& accInfo = instance->accountModel().getAccountInfo(accountId.isEmpty() ? instance->get_currentAccountId()
+                                                                                    : accountId);
         auto* convModel = accInfo.conversationModel.get();
         auto avatarb64 = convModel->avatar(convId);
         if (!avatarb64.isEmpty()) {
             auto photo = imageFromBase64String(avatarb64, true);
-            if (photo.isNull()) {
-                qWarning() << "Invalid image for conversation " << convId;
-                return photo;
+            if (!photo.isNull()) {
+                return scaleAndFrame(photo, size);
             }
-            return scaleAndFrame(photo, size);
+            qWarning() << "Unable to load image from Base64 data for conversation " << convId;
         }
         // Else, generate an avatar
         auto members = convModel->peersForConversation(convId);
@@ -487,7 +463,7 @@ Utils::conversationAvatar(LRCInstance* instance,
         painter.drawImage(avatar.rect(), peerAAvatar);
         painter.drawImage(avatar.rect(), peerBAvatar);
     } catch (const std::exception& e) {
-        qDebug() << Q_FUNC_INFO << e.what();
+        C_DBG << e.what();
     }
     return avatar;
 }
@@ -495,8 +471,7 @@ Utils::conversationAvatar(LRCInstance* instance,
 QImage
 Utils::tempConversationAvatar(const QSize& size)
 {
-    QString img = QByteArrayFromFile(QStandardPaths::writableLocation(QStandardPaths::CacheLocation)
-                                     + "tmpSwarmImage");
+    QString img = QByteArrayFromFile(getTempSwarmAvatarPath());
     if (img.isEmpty())
         return fallbackAvatar(QString(), QString(), size);
     return scaleAndFrame(imageFromBase64String(img, true), size);
@@ -533,19 +508,22 @@ Utils::getCirclePhoto(const QImage original, int sizePhoto)
     QPainter painter(&target);
     painter.setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
     painter.setBrush(QBrush(Qt::white));
-    auto scaledPhoto = original
-                           .scaled(sizePhoto,
-                                   sizePhoto,
-                                   Qt::KeepAspectRatioByExpanding,
-                                   Qt::SmoothTransformation)
+    auto scaledPhoto = original.scaled(sizePhoto, sizePhoto, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation)
                            .convertToFormat(QImage::Format_ARGB32_Premultiplied);
-    int margin = 0;
+    int marginX = 0;
+    int marginY = 0;
+
     if (scaledPhoto.width() > sizePhoto) {
-        margin = (scaledPhoto.width() - sizePhoto) / 2;
+        marginX = (scaledPhoto.width() - sizePhoto) / 2;
     }
+    if (scaledPhoto.height() > sizePhoto) {
+        marginY = (scaledPhoto.height() - sizePhoto) / 2;
+    }
+
     painter.drawEllipse(0, 0, sizePhoto, sizePhoto);
     painter.setCompositionMode(QPainter::CompositionMode_SourceIn);
-    painter.drawImage(0, 0, scaledPhoto, margin, 0);
+    painter.drawImage(0, 0, scaledPhoto, marginX, marginY);
+
     return target;
 }
 
@@ -572,9 +550,7 @@ Utils::getRealSize(QScreen* screen)
 #ifdef Q_OS_WIN
     DEVMODE dmThisScreen;
     ZeroMemory(&dmThisScreen, sizeof(dmThisScreen));
-    EnumDisplaySettings((const wchar_t*) screen->name().utf16(),
-                        ENUM_CURRENT_SETTINGS,
-                        (DEVMODE*) &dmThisScreen);
+    EnumDisplaySettings((const wchar_t*) screen->name().utf16(), ENUM_CURRENT_SETTINGS, (DEVMODE*) &dmThisScreen);
     return QSize(dmThisScreen.dmPelsWidth, dmThisScreen.dmPelsHeight);
 #else
     Q_UNUSED(screen)
@@ -611,7 +587,26 @@ Utils::getProjectCredits()
         return {};
     }
     QTextStream in(&projectCreditsFile);
-    return in.readAll();
+    return in.readAll().arg(QObject::tr("We would like to thank our contributors, whose efforts "
+                                        "over many years have made this software what it is."),
+                            QObject::tr("Developers"),
+                            QObject::tr("Media"),
+                            QObject::tr("Community Management"),
+                            QObject::tr("Special thanks to"),
+                            QObject::tr("This is a list of people who have made a significant investment "
+                                        "of time, with useful results, into Jami. Any such contributors "
+                                        "who want to be added to the list should contact us."));
+}
+
+QString
+Utils::getAvailableDictionariesJson()
+{
+    QFile availableDictionariesFile(":/misc/available_dictionaries.json");
+    if (!availableDictionariesFile.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        qDebug().noquote() << "Available Dictionaries file failed to load";
+        return {};
+    }
+    return QString(availableDictionariesFile.readAll());
 }
 
 inline QString
@@ -624,8 +619,7 @@ removeEndlines(const QString& str)
 }
 
 lrc::api::profile::Type
-Utils::profileType(const lrc::api::conversation::Info& conv,
-                   const lrc::api::ConversationModel& model)
+Utils::profileType(const lrc::api::conversation::Info& conv, const lrc::api::ConversationModel& model)
 {
     try {
         auto contact = model.owner.contactModel->getContact(conv.participants[0].uri);
@@ -639,8 +633,7 @@ Utils::profileType(const lrc::api::conversation::Info& conv,
 bool
 Utils::isInteractionGenerated(const lrc::api::interaction::Type& type)
 {
-    return type == lrc::api::interaction::Type::CALL
-           || type == lrc::api::interaction::Type::CONTACT;
+    return type == lrc::api::interaction::Type::CALL || type == lrc::api::interaction::Type::CONTACT;
 }
 
 bool
@@ -662,8 +655,7 @@ Utils::isContactValid(const QString& contactUid, const lrc::api::ConversationMod
 bool
 Utils::getReplyMessageBox(QWidget* widget, const QString& title, const QString& text)
 {
-    if (QMessageBox::question(widget, title, text, QMessageBox::Yes | QMessageBox::No)
-        == QMessageBox::Yes)
+    if (QMessageBox::question(widget, title, text, QMessageBox::Yes | QMessageBox::No) == QMessageBox::Yes)
         return true;
     return false;
 }
@@ -674,8 +666,7 @@ Utils::getAvatarColor(const QString& canonicalUri)
     if (canonicalUri.isEmpty()) {
         return JamiAvatarTheme::defaultAvatarColor_;
     }
-    auto h = QString(
-        QCryptographicHash::hash(canonicalUri.toLocal8Bit(), QCryptographicHash::Md5).toHex());
+    auto h = QString(QCryptographicHash::hash(canonicalUri.toLocal8Bit(), QCryptographicHash::Md5).toHex());
     if (h.isEmpty() || h.isNull()) {
         return JamiAvatarTheme::defaultAvatarColor_;
     }
@@ -717,9 +708,7 @@ Utils::fallbackAvatar(const QString& canonicalUri, const QString& name, const QS
         if (unicode >= 0x1F000 && unicode <= 0x1FFFF) {
             // emoticon
             auto letter = QString::fromUcs4(reinterpret_cast<char32_t*>(&unicode), 1);
-            QFont font(QString("Segoe UI Emoji").split(QLatin1Char(',')),
-                       avatar.height() / 2.66667,
-                       QFont::Medium);
+            QFont font(QString("Segoe UI Emoji").split(QLatin1Char(',')), avatar.height() / 2.66667, QFont::Medium);
             painter.setFont(font);
             QRect emojiRect(avatar.rect());
             emojiRect.moveTop(-6);
@@ -727,17 +716,13 @@ Utils::fallbackAvatar(const QString& canonicalUri, const QString& name, const QS
         } else if (unicode >= 0x0000 && unicode <= 0x00FF) {
             // basic Latin
             auto letter = trimmedName.at(0).toUpper();
-            QFont font(QString("Arial").split(QLatin1Char(',')),
-                       avatar.height() / 2.66667,
-                       QFont::Medium);
+            QFont font(QString("Arial").split(QLatin1Char(',')), avatar.height() / 2.66667, QFont::Medium);
             painter.setFont(font);
             painter.setPen(Qt::white);
             painter.drawText(avatar.rect(), QString(letter), QTextOption(Qt::AlignCenter));
         } else {
             auto letter = QString::fromUcs4(reinterpret_cast<char32_t*>(&unicode), 1);
-            QFont font(QString("Arial").split(QLatin1Char(',')),
-                       avatar.height() / 2.66667,
-                       QFont::Medium);
+            QFont font(QString("Arial").split(QLatin1Char(',')), avatar.height() / 2.66667, QFont::Medium);
             painter.setFont(font);
             painter.setPen(Qt::white);
             painter.drawText(avatar.rect(), QString(letter), QTextOption(Qt::AlignCenter));
@@ -806,39 +791,33 @@ Utils::pixmapFromSvg(const QString& svg_resource, const QSize& size)
 }
 
 QImage
-Utils::setupQRCode(QString ringID, int margin)
+Utils::getQRCodeImage(QString data, int margin)
 {
-    auto qrcode = QRcode_encodeString(ringID.toStdString().c_str(),
-                                      0,            // Let the version be decided by libqrencode
-                                      QR_ECLEVEL_L, // Lowest level of error correction
-                                      QR_MODE_8,    // 8-bit data mode
-                                      1);
-    if (not qrcode) {
-        qWarning() << "Failed to generate QR code";
-        return QImage();
-    }
+    try {
+        ZXing::MultiFormatWriter writer(ZXing::BarcodeFormat::QRCode);
+        writer.setEccLevel(0);
+        writer.setMargin(margin);
+        auto bitMatrix = writer.encode(data.toStdString(), 0, 0);
+        int qrwidth = bitMatrix.width();
+        int qrheight = bitMatrix.height();
 
-    int qrwidth = qrcode->width + margin * 2;
-    QImage result(QSize(qrwidth, qrwidth), QImage::Format_Mono);
-    QPainter painter;
-    painter.begin(&result);
-    painter.setClipRect(QRect(0, 0, qrwidth, qrwidth));
-    painter.setPen(QPen(Qt::black, 0.1, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
-    painter.setBrush(Qt::black);
-    painter.fillRect(QRect(0, 0, qrwidth, qrwidth), Qt::white);
-    unsigned char* p;
-    p = qrcode->data;
-    for (int y = 0; y < qrcode->width; y++) {
-        unsigned char* row = (p + (y * qrcode->width));
-        for (int x = 0; x < qrcode->width; x++) {
-            if (*(row + x) & 0x1) {
-                painter.drawRect(margin + x, margin + y, 1, 1);
+        // Create QImage with the QR code data
+        QImage result(qrwidth, qrheight, QImage::Format_Mono);
+        result.fill(1); // Fill with white
+
+        // Copy the bitmap data to QImage
+        for (int y = 0; y < qrheight; y++) {
+            for (int x = 0; x < qrwidth; x++) {
+                if (bitMatrix.get(x, y)) {
+                    result.setPixel(x, y, 0);
+                }
             }
         }
+        return result;
+    } catch (const std::exception& e) {
+        qWarning() << "Failed to generate QR code:" << e.what();
+        return QImage();
     }
-    painter.end();
-    QRcode_free(qrcode);
-    return result;
 }
 
 QByteArray
@@ -850,10 +829,9 @@ Utils::QByteArrayFromFile(const QString& filename)
     }
     if (file.open(QIODevice::ReadOnly)) {
         return file.readAll();
-    } else {
-        qDebug() << "QByteArrayFromFile: can't open file" << filename;
-        return QByteArray();
     }
+    qDebug() << "QByteArrayFromFile: unable to open file" << filename;
+    return {};
 }
 
 QPixmap
@@ -933,3 +911,19 @@ Utils::generateUid()
 {
     return QUuid::createUuid().toString(QUuid::Id128);
 }
+
+QString
+Utils::getTempSwarmAvatarPath()
+{
+    return QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QDir::separator() + "tmpSwarmImage";
+}
+
+QVariantMap
+Utils::mapStringStringToVariantMap(const MapStringString& map)
+{
+    QVariantMap variantMap;
+    for (auto it = map.constBegin(); it != map.constEnd(); ++it) {
+        variantMap.insert(it.key(), it.value());
+    }
+    return variantMap;
+}
