@@ -1,10 +1,5 @@
-/*!
- * Copyright (C) 2015-2023 Savoir-faire Linux Inc.
- * Author: Edric Ladent Milaret <edric.ladent-milaret@savoirfairelinux.com>
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
- * Author: Isa Nanic <isa.nanic@savoirfairelinux.com>
- * Author: Mingrui Zhang   <mingrui.zhang@savoirfairelinux.com>
- * Author: Aline Gondim Santos   <aline.gondimsantos@savoirfairelinux.com>
+/*
+ * Copyright (C) 2015-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,16 +20,18 @@
 #include "lrcinstance.h"
 #include "systemtray.h"
 #include "utils.h"
-#include "version.h"
-
-#include "api/pluginmodel.h"
-#include "api/datatransfermodel.h"
+#include "version_info.h"
+#include "global.h"
+#include <api/datatransfermodel.h>
+#include <api/contact.h>
 
 #include <QApplication>
 #include <QBuffer>
 #include <QClipboard>
 #include <QFileInfo>
 #include <QRegExp>
+#include <QMimeData>
+#include <QMimeDatabase>
 
 UtilsAdapter::UtilsAdapter(AppSettingsManager* settingsManager,
                            SystemTray* systemTray,
@@ -80,16 +77,31 @@ UtilsAdapter::setAppValue(const Settings::Key key, const QVariant& value)
     // If we change the lang preference, reload the translations
     if (key == Settings::Key::LANG) {
         settingsManager_->loadTranslations();
-        Q_EMIT changeLanguage();
         set_isRTL(isRTL());
+        Q_EMIT changeLanguage();
     } else if (key == Settings::Key::BaseZoom)
         Q_EMIT changeFontSize();
-    else if (key == Settings::Key::EnableExperimentalSwarm)
-        Q_EMIT showExperimentalCallSwarm();
+    else if (key == Settings::Key::DisplayHyperlinkPreviews)
+        settingsManager_->loadHistory();
     else if (key == Settings::Key::ShowChatviewHorizontally)
         Q_EMIT chatviewPositionChanged();
     else if (key == Settings::Key::AppTheme)
         Q_EMIT appThemeChanged();
+    else if (key == Settings::Key::UseFramelessWindow)
+        Q_EMIT useFramelessWindowChanged();
+    else if (key == Settings::Key::SpellLang)
+        Q_EMIT spellLanguageChanged();
+    else if (key == Settings::Key::EnableSpellCheck)
+        Q_EMIT enableSpellCheckChanged();
+    else if (key == Settings::Key::RaiseWhenCalled)
+        Q_EMIT raiseWhenCalledChanged();
+#if !APPSTORE
+    // Any donation campaign-related keys can trigger a donation campaign check
+    else if (key == Settings::Key::IsDonationVisible
+             || key == Settings::Key::Donation2025StartDate
+             || key == Settings::Key::Donation2025EndDate)
+        Q_EMIT donationCampaignSettingsChanged();
+#endif
 }
 
 QVariant
@@ -110,10 +122,16 @@ UtilsAdapter::getProjectCredits()
     return Utils::getProjectCredits();
 }
 
+const QString
+UtilsAdapter::getBuildIDStr()
+{
+    return BUILD_VERSION_STRING;
+}
+
 const QString
 UtilsAdapter::getVersionStr()
 {
-    return QString(VERSION_STRING);
+    return APP_VERSION_STRING + "." + CORE_VERSION_STRING;
 }
 
 void
@@ -142,13 +160,19 @@ UtilsAdapter::getStyleSheet(const QString& name, const QString& source)
 }
 
 const QString
-UtilsAdapter::getCachePath()
+UtilsAdapter::getLocalDataPath()
 {
     QDir dataDir(QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation));
     dataDir.cdUp();
     return dataDir.absolutePath() + "/jami";
 }
 
+const QString
+UtilsAdapter::getCachePath()
+{
+    return QStandardPaths::writableLocation(QStandardPaths::CacheLocation);
+}
+
 QString
 UtilsAdapter::getDefaultRecordPath() const
 {
@@ -183,8 +207,7 @@ UtilsAdapter::getBestName(const QString& accountId, const QString& uid)
 {
     const auto& conv = lrcInstance_->getConversationFromConvUid(uid);
     if (!conv.participants.isEmpty())
-        return lrcInstance_->getAccountInfo(accountId).contactModel->bestNameForContact(
-            conv.participants[0].uri);
+        return lrcInstance_->getAccountInfo(accountId).contactModel->bestNameForContact(conv.participants[0].uri);
     return QString();
 }
 
@@ -210,7 +233,7 @@ UtilsAdapter::getConvIdForUri(const QString& accountId, const QString& uri)
             return {};
         return convInfo->get().uid;
     } catch (const std::out_of_range& e) {
-        qDebug() << e.what();
+        C_DBG << e.what();
         return "";
     }
 }
@@ -223,7 +246,7 @@ UtilsAdapter::getPeerUri(const QString& accountId, const QString& uid)
         const auto& convInfo = convModel->getConversationForUid(uid).value();
         return convInfo.get().participants.front().uri;
     } catch (const std::out_of_range& e) {
-        qDebug() << e.what();
+        C_DBG << e.what();
         return "";
     }
 }
@@ -255,7 +278,7 @@ UtilsAdapter::setConversationFilter(const QString& filter)
 int
 UtilsAdapter::getAccountListSize()
 {
-    return lrcInstance_->accountModel().getAccountList().size();
+    return lrcInstance_->accountModel().getAccountCount();
 }
 
 bool
@@ -502,17 +525,6 @@ UtilsAdapter::monitor(const bool& continuous)
     lrcInstance_->monitor(continuous);
 }
 
-void
-UtilsAdapter::clearInteractionsCache(const QString& accountId, const QString& convId)
-{
-    try {
-        auto& accInfo = lrcInstance_->accountModel().getAccountInfo(accountId);
-        auto& convModel = accInfo.conversationModel;
-        convModel->clearInteractionsCache(convId);
-    } catch (...) {
-    }
-}
-
 QVariantMap
 UtilsAdapter::supportedLang()
 {
@@ -553,8 +565,7 @@ QString
 UtilsAdapter::tempCreationImage(const QString& imageId) const
 {
     if (imageId == "temp")
-        return Utils::QByteArrayFromFile(
-            QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + "tmpSwarmImage");
+        return Utils::QByteArrayFromFile(Utils::getTempSwarmAvatarPath());
     if (lrcInstance_->getCurrentConversationModel())
         return lrcInstance_->getCurrentConversationModel()->avatar(imageId);
     return {};
@@ -589,8 +600,7 @@ UtilsAdapter::setTempCreationImageFromImage(const QImage& image, const QString&
     }
     // Save the image
     if (imageId == "temp") {
-        QFile file(QStandardPaths::writableLocation(QStandardPaths::CacheLocation)
-                   + "tmpSwarmImage");
+        QFile file(Utils::getTempSwarmAvatarPath());
         file.open(QIODevice::WriteOnly);
         file.write(ba.toBase64());
         file.close();
@@ -602,17 +612,17 @@ UtilsAdapter::setTempCreationImageFromImage(const QImage& image, const QString&
     }
 }
 
-bool
+int
 UtilsAdapter::getContactPresence(const QString& accountId, const QString& uri)
 {
     try {
         if (lrcInstance_->getAccountInfo(accountId).profileInfo.uri == uri)
-            return true; // It's the same account
+            return 2; // It's the same account
         auto info = lrcInstance_->getAccountInfo(accountId).contactModel->getContact(uri);
-        return info.isPresent;
+        return info.presence;
     } catch (...) {
     }
-    return false;
+    return 0;
 }
 
 QString
@@ -739,7 +749,7 @@ UtilsAdapter::isSystemThemeDark()
 #endif
     return readAppsUseLightThemeRegistry(true);
 #else
-    qWarning("System theme detection is not implemented or is not supported");
+    C_WARN << "System theme detection is not implemented or is not supported";
     return false;
 #endif // WIN32
 #endif // __has_include(<gio/gio.h>)
@@ -799,14 +809,96 @@ bool
 UtilsAdapter::isRTL()
 {
     auto pref = getAppValue(Settings::Key::LANG).toString();
-    pref == "SYSTEM" ? QLocale::system().name() : pref;
-    return pref == "ar" || pref == "he" || pref == "fa" || pref == "ur";
+    pref = pref == "SYSTEM" ? QLocale::system().name() : pref;
+    static const QStringList rtlLanguages {
+        // as defined by ISO 639-1
+        "ar",    // Arabic
+        "he",    // Hebrew
+        "fa",    // Persian (Farsi)
+        "az_IR", // Azerbaijani
+        "ur",    // Urdu
+        "ps",    // Pashto
+        "ku",    // Kurdish
+        "sd",    // Sindhi
+        "dv",    // Dhivehi (Maldivian)
+        "yi",    // Yiddish
+        "am",    // Amharic
+        "ti"     // Tigrinya
+        // Since we haven't requested the Arabic script of Kazakh in Transifex, we cannot include it here.
+        // However we have the Cyrillic script of Kazakh which is LTR (code: "kk").
+    };
+    return rtlLanguages.contains(pref);
 }
 
 bool
 UtilsAdapter::isSystemTrayIconVisible()
 {
-    if (!systemTray_)
-        return false;
-    return systemTray_->geometry() != QRect();
+    return QSystemTrayIcon::isSystemTrayAvailable() && systemTray_;
+}
+
+QString
+UtilsAdapter::base64Encode(const QString& input)
+{
+    QByteArray byteArray = input.toUtf8();
+    return byteArray.toBase64();
+}
+
+bool
+UtilsAdapter::fileExists(const QString& filePath)
+{
+    return QFile::exists(filePath);
+}
+
+QString
+UtilsAdapter::getStandardTempLocation()
+{
+    return QStandardPaths::writableLocation(
+        static_cast<QStandardPaths::StandardLocation>(QStandardPaths::TempLocation));
+}
+
+QString
+UtilsAdapter::getMimeNameForUrl(const QUrl& fileUrl) const
+{
+    QMimeDatabase db;
+    QMimeType mime = db.mimeTypeForUrl(fileUrl);
+    return mime.name();
+}
+
+QUrl
+UtilsAdapter::urlFromLocalPath(const QString& filePath) const
+{
+    return QUrl::fromLocalFile(filePath);
+}
+
+#ifdef BUILD_TESTING
+// Must only be used for testing purposes
+QString
+UtilsAdapter::createDummyImage() const
+{
+    // Create an QImage
+    QImage image(256, 256, QImage::Format_ARGB32);
+    image.fill(QColor(255, 255, 255, 255));
+
+    QByteArray ba;
+    QBuffer bu(&ba);
+    image.save(&bu, "PNG");
+
+    // Save the image to a file
+    QFile file(QDir::tempPath() + "/dummy.png");
+    if (file.open(QIODevice::WriteOnly)) {
+        file.write(ba);
+        file.close();
+        qInfo() << "Dummy image created" << QDir::tempPath() + "/dummy.png";
+        return QDir::tempPath() + "/dummy.png";
+    } else {
+        C_WARN << "An error occurred while creating dummy image.";
+        return "";
+    }
+}
+#endif
+
+bool
+UtilsAdapter::isWayland() const
+{
+    return !qEnvironmentVariableIsEmpty("WAYLAND_DISPLAY");
 }
