@@ -1,10 +1,5 @@
 /*
- * Copyright (C) 2015-2023 Savoir-faire Linux Inc.
- * Author: Edric Ladent Milaret <edric.ladent-milaret@savoirfairelinux.com>
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
- * Author: Isa Nanic <isa.nanic@savoirfairelinux.com>
- * Author: Mingrui Zhang   <mingrui.zhang@savoirfairelinux.com>
- * Author: Aline Gondim Santos   <aline.gondimsantos@savoirfairelinux.com>
+ * Copyright (C) 2015-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,18 +17,23 @@
 
 #pragma once
 
-#include <QApplication>
-#include <QObject>
-
 #include "qmladapterbase.h"
 #include "appsettingsmanager.h"
 #include "qtutils.h"
 
+#include <api/member.h>
+
+#include <QApplication>
+#include <QObject>
+#include <QQmlEngine>   // QML registration
+#include <QApplication> // QML registration
+
 #if __has_include(<gio/gio.h>)
 #include <gio/gio.h>
 #endif
 
 #if defined(WIN32) && __has_include(<winrt/Windows.Foundation.h>)
+#define _SILENCE_CLANG_COROUTINE_MESSAGE
 #include <winrt/Windows.Foundation.h>
 
 #define WATCHSYSTEMTHEME __has_include(<winrt/Windows.UI.ViewManagement.h>)
@@ -65,9 +65,18 @@ bool readAppsUseLightThemeRegistry(bool getValue);
 class UtilsAdapter final : public QmlAdapterBase
 {
     Q_OBJECT
+    QML_SINGLETON
+
     QML_PROPERTY(QStringList, logList)
     QML_RO_PROPERTY(bool, isRTL)
 public:
+    static UtilsAdapter* create(QQmlEngine*, QJSEngine*)
+    {
+        return new UtilsAdapter(qApp->property("AppSettingsManager").value<AppSettingsManager*>(),
+                                qApp->property("SystemTray").value<SystemTray*>(),
+                                qApp->property("LRCInstance").value<LRCInstance*>());
+    }
+
     explicit UtilsAdapter(AppSettingsManager* settingsManager,
                           SystemTray* systemTray,
                           LRCInstance* instance,
@@ -82,10 +91,12 @@ public:
     Q_INVOKABLE void setToDefault(const Settings::Key key);
 
     Q_INVOKABLE const QString getProjectCredits();
+    Q_INVOKABLE const QString getBuildIDStr();
     Q_INVOKABLE const QString getVersionStr();
     Q_INVOKABLE void setClipboardText(QString text);
     Q_INVOKABLE const QString qStringFromFile(const QString& filename);
     Q_INVOKABLE const QString getStyleSheet(const QString& name, const QString& source);
+    Q_INVOKABLE const QString getLocalDataPath();
     Q_INVOKABLE const QString getCachePath();
     Q_INVOKABLE bool createStartupLink();
     Q_INVOKABLE QString GetRingtonePath();
@@ -125,7 +136,6 @@ public:
     Q_INVOKABLE void setDownloadPath(QString dir);
     Q_INVOKABLE void setScreenshotPath(QString dir);
     Q_INVOKABLE void monitor(const bool& continuous);
-    Q_INVOKABLE void clearInteractionsCache(const QString& accountId, const QString& convUid);
     Q_INVOKABLE QVariantMap supportedLang();
     Q_INVOKABLE QString tempCreationImage(const QString& imageId = "temp") const;
     Q_INVOKABLE void setTempCreationImageFromString(const QString& image = "",
@@ -136,7 +146,7 @@ public:
                                                    const QString& imageId = "temp");
 
     // For Swarm details page
-    Q_INVOKABLE bool getContactPresence(const QString& accountId, const QString& uri);
+    Q_INVOKABLE int getContactPresence(const QString& accountId, const QString& uri);
     Q_INVOKABLE QString getContactBestName(const QString& accountId, const QString& uri);
     Q_INVOKABLE lrc::api::member::Role getParticipantRole(const QString& accountId,
                                                           const QString& convId,
@@ -152,13 +162,27 @@ public:
     Q_INVOKABLE bool isRTL();
     Q_INVOKABLE bool isSystemTrayIconVisible();
 
+    Q_INVOKABLE QString base64Encode(const QString& input);
+    Q_INVOKABLE bool fileExists(const QString& filePath);
+    Q_INVOKABLE QString getStandardTempLocation();
+    Q_INVOKABLE QString getMimeNameForUrl(const QUrl& fileUrl) const;
+    Q_INVOKABLE QUrl urlFromLocalPath(const QString& filePath) const;
+
+#ifdef BUILD_TESTING
+    Q_INVOKABLE QString createDummyImage() const;
+#endif
+    Q_INVOKABLE bool isWayland() const;
 Q_SIGNALS:
     void debugMessageReceived(const QString& message);
     void changeFontSize();
     void chatviewPositionChanged();
     void appThemeChanged();
-    void showExperimentalCallSwarm();
     void changeLanguage();
+    void donationCampaignSettingsChanged();
+    void useFramelessWindowChanged();
+    void spellLanguageChanged();
+    void enableSpellCheckChanged();
+    void raiseWhenCalledChanged();
 
 private:
     QClipboard* clipboard_;
