@@ -1,9 +1,5 @@
 /****************************************************************************
- *    Copyright (C) 2017-2024 Savoir-faire Linux Inc.                       *
- *   Author: Nicolas Jäger <nicolas.jager@savoirfairelinux.com>             *
- *   Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>           *
- *   Author: Kateryna Kostiuk <kateryna.kostiuk@savoirfairelinux.com>       *
- *   Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>         *
+ *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
  *   modify it under the terms of the GNU Lesser General Public             *
@@ -33,7 +29,6 @@
 #include "authority/storagehelper.h"
 #include "callbackshandler.h"
 #include "database.h"
-#include "vcard.h"
 
 // old LRC
 #include "api/profile.h"
@@ -55,6 +50,7 @@
 
 namespace lrc {
 
+using namespace authority;
 using namespace api;
 
 class AccountModelPimpl : public QObject
@@ -64,9 +60,7 @@ public:
     AccountModelPimpl(AccountModel& linked,
                       Lrc& lrc,
                       const CallbacksHandler& callbackHandler,
-                      const BehaviorController& behaviorController,
-                      MigrationCb& willMigrateCb,
-                      MigrationCb& didMigrateCb);
+                      const BehaviorController& behaviorController);
     ~AccountModelPimpl();
 
     using AccountInfoDbMap = std::map<QString, std::pair<account::Info, std::shared_ptr<Database>>>;
@@ -75,6 +69,7 @@ public:
     Lrc& lrc;
     const CallbacksHandler& callbacksHandler;
     const BehaviorController& behaviorController;
+    QList<QString> accountIdList;
     AccountInfoDbMap accounts;
 
     // Synchronization tools
@@ -84,10 +79,9 @@ public:
     /**
      * Add the profile information from an account to the db then add it to accounts.
      * @param accountId
-     * @param db an optional migrated database object
      * @note this method get details for an account from the daemon.
      */
-    void addToAccounts(const QString& accountId, std::shared_ptr<Database> db = nullptr);
+    void addToAccounts(const QString& accountId);
 
     /**
      * Remove account from accounts list. Emit accountRemoved.
@@ -107,7 +101,7 @@ public:
     void updateAccountDetails(account::Info& account);
 
     /**
-     * get a modifiable account informations associated to an accountId.
+     * get a modifiable account information associated to an accountId.
      * @param accountId.
      * @return a account::Info& structure.
      */
@@ -123,12 +117,26 @@ public Q_SLOTS:
     void slotAccountStatusChanged(const QString& accountID, const api::account::Status status);
 
     /**
-     * Emit exportOnRingEnded.
+     * Emit deviceAuthStateChanged.
      * @param accountId
-     * @param status
-     * @param pin
+     * @param state
+     * @param details map
      */
-    void slotExportOnRingEnded(const QString& accountID, int status, const QString& pin);
+    void slotDeviceAuthStateChanged(const QString& accountID,
+                                    int state,
+                                    const MapStringString& details);
+
+    /**
+     * Emit addDeviceStateChanged.
+     * @param accountId
+     * @param operationId
+     * @param state
+     * @param details
+     */
+    void slotAddDeviceStateChanged(const QString& accountID,
+                                   uint32_t operationId,
+                                   int state,
+                                   const MapStringString& details);
 
     /**
      * @param accountId
@@ -153,14 +161,16 @@ public Q_SLOTS:
     /**
      * Emit registeredNameFound
      * @param accountId
+     * @param requestedName the name requested
      * @param status
      * @param address
-     * @param name
+     * @param registeredName the name found, have same normalized form as requestedName
      */
     void slotRegisteredNameFound(const QString& accountId,
+                                 const QString& requestedName,
                                  int status,
                                  const QString& address,
-                                 const QString& name);
+                                 const QString& registeredName);
 
     /**
      * Emit migrationEnded
@@ -168,7 +178,6 @@ public Q_SLOTS:
      * @param ok
      */
     void slotMigrationEnded(const QString& accountId, bool ok);
-
     /**
      * Emit accountProfileReceived
      * @param accountId
@@ -178,7 +187,6 @@ public Q_SLOTS:
     void slotAccountProfileReceived(const QString& accountId,
                                     const QString& displayName,
                                     const QString& userPhoto);
-
     /**
      * Emit new position
      * @param accountId
@@ -196,34 +204,23 @@ public Q_SLOTS:
 
 AccountModel::AccountModel(Lrc& lrc,
                            const CallbacksHandler& callbacksHandler,
-                           const BehaviorController& behaviorController,
-                           MigrationCb& willMigrateCb,
-                           MigrationCb& didMigrateCb)
+                           const BehaviorController& behaviorController)
     : QObject(nullptr)
-    , pimpl_(std::make_unique<AccountModelPimpl>(*this,
-                                                 lrc,
-                                                 callbacksHandler,
-                                                 behaviorController,
-                                                 willMigrateCb,
-                                                 didMigrateCb))
+    , pimpl_(std::make_unique<AccountModelPimpl>(*this, lrc, callbacksHandler, behaviorController))
 {}
 
 AccountModel::~AccountModel() {}
 
-QStringList
+const QStringList&
 AccountModel::getAccountList() const
 {
-    QStringList filteredAccountIds;
-    const QStringList accountIds = ConfigurationManager::instance().getAccountList();
+    return pimpl_->accountIdList;
+}
 
-    for (auto const& id : accountIds) {
-        auto account = pimpl_->accounts.find(id);
-        // Do not include accounts flagged for removal
-        if (account != pimpl_->accounts.end() && account->second.first.valid)
-            filteredAccountIds.push_back(id);
-    }
-
-    return filteredAccountIds;
+size_t
+AccountModel::getAccountCount() const
+{
+    return pimpl_->accountIdList.size();
 }
 
 void
@@ -299,20 +296,28 @@ AccountModel::setAlias(const QString& accountId, const QString& alias, bool save
     accountInfo.profileInfo.alias = alias;
 
     if (save)
-        authority::storage::createOrUpdateProfile(accountInfo.id, accountInfo.profileInfo);
+        ConfigurationManager::instance()
+            .updateProfile(accountId,
+                           alias,
+                           "",
+                           "",
+                           5); // flag out of range to avoid updating avatar
     Q_EMIT profileUpdated(accountId);
 }
 
 void
-AccountModel::setAvatar(const QString& accountId, const QString& avatar, bool save)
+AccountModel::setAvatar(const QString& accountId, const QString& avatar, bool save, int flag)
 {
     auto& accountInfo = pimpl_->getAccountInfo(accountId);
     if (accountInfo.profileInfo.avatar == avatar)
         return;
     accountInfo.profileInfo.avatar = avatar;
-
     if (save)
-        authority::storage::createOrUpdateProfile(accountInfo.id, accountInfo.profileInfo);
+        ConfigurationManager::instance().updateProfile(accountId,
+                                                       accountInfo.profileInfo.alias,
+                                                       avatar,
+                                                       "PNG",
+                                                       flag);
     Q_EMIT profileUpdated(accountId);
 }
 
@@ -333,21 +338,41 @@ AccountModel::exportToFile(const QString& accountId,
 }
 
 bool
-AccountModel::exportOnRing(const QString& accountId, const QString& password) const
+AccountModel::provideAccountAuthentication(const QString& accountId,
+                                           const QString& credentialsFromUser) const
 {
-    return ConfigurationManager::instance().exportOnRing(accountId, password);
+    return ConfigurationManager::instance().provideAccountAuthentication(accountId,
+                                                                         credentialsFromUser,
+                                                                         "password");
+}
+
+int32_t
+AccountModel::addDevice(const QString& accountId, const QString& token) const
+{
+    return ConfigurationManager::instance().addDevice(accountId, token);
+}
+
+bool
+AccountModel::confirmAddDevice(const QString& accountId, uint32_t operationId) const
+{
+    return ConfigurationManager::instance().confirmAddDevice(accountId, operationId);
+}
+
+bool
+AccountModel::cancelAddDevice(const QString& accountId, uint32_t operationId) const
+{
+    return ConfigurationManager::instance().cancelAddDevice(accountId, operationId);
 }
 
 void
 AccountModel::removeAccount(const QString& accountId) const
 {
     auto account = pimpl_->accounts.find(accountId);
-    if (account == pimpl_->accounts.end()) {
-        return;
+    if (account != pimpl_->accounts.end()) {
+        account->second.second->close();
     }
 
     // Close db here for its removal
-    account->second.second->close();
     ConfigurationManager::instance().removeAccount(accountId);
 }
 
@@ -366,7 +391,7 @@ AccountModel::getAccountInfo(const QString& accountId) const
 {
     auto accountInfo = pimpl_->accounts.find(accountId);
     if (accountInfo == pimpl_->accounts.end())
-        throw std::out_of_range("AccountModel::getAccountInfo, can't find "
+        throw std::out_of_range("AccountModel::getAccountInfo, unable to find account "
                                 + accountId.toStdString());
 
     return accountInfo->second.first;
@@ -375,29 +400,26 @@ AccountModel::getAccountInfo(const QString& accountId) const
 AccountModelPimpl::AccountModelPimpl(AccountModel& linked,
                                      Lrc& lrc,
                                      const CallbacksHandler& callbacksHandler,
-                                     const BehaviorController& behaviorController,
-                                     MigrationCb& willMigrateCb,
-                                     MigrationCb& didMigrateCb)
+                                     const BehaviorController& behaviorController)
     : linked(linked)
     , lrc {lrc}
     , behaviorController(behaviorController)
     , callbacksHandler(callbacksHandler)
     , username_changed(false)
 {
-    const QStringList accountIds = ConfigurationManager::instance().getAccountList();
+    accountIdList = ConfigurationManager::instance().getAccountList();
 
     // NOTE: If the daemon is down, but dbus answered, id can contains
     // "Remote peer disconnected", "The name is not activable", etc.
     // So avoid to migrate useless directories.
-    for (auto& id : accountIds)
+    for (const auto& id : accountIdList)
         if (id.indexOf(" ") != -1) {
             qWarning() << "Invalid dbus answer. Daemon not running";
             return;
         }
 
-    auto accountDbs = authority::storage::migrateIfNeeded(accountIds, willMigrateCb, didMigrateCb);
-    for (const auto& id : accountIds) {
-        addToAccounts(id, accountDbs.at(accountIds.indexOf(id)));
+    for (const auto& id : accountIdList) {
+        addToAccounts(id);
     }
 
     connect(&callbacksHandler,
@@ -417,9 +439,13 @@ AccountModelPimpl::AccountModelPimpl(AccountModel& linked,
             this,
             &AccountModelPimpl::slotVolatileAccountDetailsChanged);
     connect(&callbacksHandler,
-            &CallbacksHandler::exportOnRingEnded,
-            this,
-            &AccountModelPimpl::slotExportOnRingEnded);
+            &CallbacksHandler::deviceAuthStateChanged,
+            &linked,
+            &AccountModel::deviceAuthStateChanged);
+    connect(&callbacksHandler,
+            &CallbacksHandler::addDeviceStateChanged,
+            &linked,
+            &AccountModel::addDeviceStateChanged);
     connect(&callbacksHandler,
             &CallbacksHandler::nameRegistrationEnded,
             this,
@@ -432,10 +458,6 @@ AccountModelPimpl::AccountModelPimpl(AccountModel& linked,
             &CallbacksHandler::migrationEnded,
             this,
             &AccountModelPimpl::slotMigrationEnded);
-    connect(&callbacksHandler,
-            &CallbacksHandler::accountProfileReceived,
-            this,
-            &AccountModelPimpl::slotAccountProfileReceived);
     connect(&callbacksHandler,
             &CallbacksHandler::newPosition,
             this,
@@ -447,15 +469,23 @@ AccountModelPimpl::~AccountModelPimpl() {}
 void
 AccountModelPimpl::updateAccounts()
 {
-    qDebug() << "Syncing lrc accounts list with the daemon";
     ConfigurationManagerInterface& configurationManager = ConfigurationManager::instance();
-    QStringList accountIds = configurationManager.getAccountList();
+    const auto previousAccountIdListSize = accountIdList.size();
+    accountIdList = configurationManager.getAccountList();
+
+    // If this is just a reordering of the accounts, just notify the view.
+    if (accountIdList.size() == previousAccountIdListSize) {
+        Q_EMIT linked.accountsReordered();
+        return;
+    }
+
+    LC_DBG << "Syncing account list";
 
     // Detect removed accounts
     QStringList toBeRemoved;
     for (auto& it : accounts) {
         auto& accountInfo = it.second.first;
-        if (!accountIds.contains(accountInfo.id)) {
+        if (!accountIdList.contains(accountInfo.id)) {
             qDebug() << QString("detected account removal %1").arg(accountInfo.id);
             toBeRemoved.push_back(accountInfo.id);
         }
@@ -466,7 +496,7 @@ AccountModelPimpl::updateAccounts()
     }
 
     // Detect new accounts
-    for (auto& id : accountIds) {
+    for (auto& id : accountIdList) {
         auto account = accounts.find(id);
         // NOTE: If the daemon is down, but dbus answered, id can contains
         // "Remote peer disconnected", "The name is not activable", etc.
@@ -514,7 +544,7 @@ AccountModelPimpl::getAccountInfo(const QString& accountId)
 {
     auto account = accounts.find(accountId);
     if (account == accounts.end()) {
-        throw std::out_of_range("AccountModelPimpl::getAccountInfo, can't find "
+        throw std::out_of_range("AccountModelPimpl::getAccountInfo, unable to find "
                                 + accountId.toStdString());
     }
     return account->second.first;
@@ -524,7 +554,7 @@ void
 AccountModelPimpl::slotAccountStatusChanged(const QString& accountID,
                                             const api::account::Status status)
 {
-    if (status == api::account::Status::INVALID) {
+    if (status == api::account::Status::STATUS_INVALID) {
         Q_EMIT linked.invalidAccountDetected(accountID);
         return;
     }
@@ -541,11 +571,12 @@ AccountModelPimpl::slotAccountStatusChanged(const QString& accountID,
         if (status != api::account::Status::INITIALIZING
             && accountInfo.status == api::account::Status::INITIALIZING) {
             // Detect when a new account is generated (keys are ready). During
-            // the generation, a Ring account got the "INITIALIZING" status.
+            // the generation, an account got the "INITIALIZING" status.
             // When keys are generated, the status will change.
             // The account is already added and initialized. Just update details from daemon
             updateAccountDetails(accountInfo);
             // This will load swarms as the account was not loaded before.
+            accountInfo.contactModel->initContacts();
             accountInfo.conversationModel->initConversations();
             Q_EMIT linked.accountAdded(accountID);
         } else if (!accountInfo.profileInfo.uri.isEmpty()) {
@@ -564,7 +595,7 @@ AccountModelPimpl::slotAccountDetailsChanged(const QString& accountId,
 {
     auto account = accounts.find(accountId);
     if (account == accounts.end()) {
-        qWarning() << Q_FUNC_INFO << ": can't find " << accountId;
+        qWarning() << Q_FUNC_INFO << ": unable to find " << accountId;
         return;
     }
     auto& accountInfo = account->second.first;
@@ -585,7 +616,7 @@ AccountModelPimpl::slotVolatileAccountDetailsChanged(const QString& accountId,
 {
     auto account = accounts.find(accountId);
     if (account == accounts.end()) {
-        qWarning() << Q_FUNC_INFO << ": can't find " << accountId;
+        LC_DBG << Q_FUNC_INFO << ": unable to find " << accountId;
         return;
     }
     auto& accountInfo = account->second.first;
@@ -599,27 +630,30 @@ AccountModelPimpl::slotVolatileAccountDetailsChanged(const QString& accountId,
     if (new_deviceId != details.end())
         accountInfo.confProperties.deviceId = new_deviceId.value();
 
+    auto currentProxyServer = details.find(libjami::Account::ConfProperties::PROXY_SERVER);
+    if (currentProxyServer != details.end())
+        accountInfo.confProperties.currentProxyServer = currentProxyServer.value();
+
     Q_EMIT linked.profileUpdated(accountId);
 }
 
 void
-AccountModelPimpl::slotExportOnRingEnded(const QString& accountID, int status, const QString& pin)
+AccountModelPimpl::slotDeviceAuthStateChanged(const QString& accountId,
+                                              int state,
+                                              const MapStringString& details)
 {
-    account::ExportOnRingStatus convertedStatus = account::ExportOnRingStatus::INVALID;
-    switch (status) {
-    case 0:
-        convertedStatus = account::ExportOnRingStatus::SUCCESS;
-        break;
-    case 1:
-        convertedStatus = account::ExportOnRingStatus::WRONG_PASSWORD;
-        break;
-    case 2:
-        convertedStatus = account::ExportOnRingStatus::NETWORK_ERROR;
-        break;
-    default:
-        break;
-    }
-    Q_EMIT linked.exportOnRingEnded(accountID, convertedStatus, pin);
+    // implement business logic here
+    // can be bypassed with a signal to signal
+    Q_EMIT linked.deviceAuthStateChanged(accountId, state, details);
+}
+
+void
+AccountModelPimpl::slotAddDeviceStateChanged(const QString& accountId,
+                                             uint32_t operationId,
+                                             int state,
+                                             const MapStringString& details)
+{
+    Q_EMIT linked.addDeviceStateChanged(accountId, operationId, state, details);
 }
 
 void
@@ -627,7 +661,7 @@ AccountModelPimpl::slotNameRegistrationEnded(const QString& accountId,
                                              int status,
                                              const QString& name)
 {
-    account::RegisterNameStatus convertedStatus = account::RegisterNameStatus::INVALID;
+    account::RegisterNameStatus convertedStatus = account::RegisterNameStatus::RNS_INVALID;
     switch (status) {
     case 0: {
         convertedStatus = account::RegisterNameStatus::SUCCESS;
@@ -644,7 +678,7 @@ AccountModelPimpl::slotNameRegistrationEnded(const QString& accountId,
         convertedStatus = account::RegisterNameStatus::WRONG_PASSWORD;
         break;
     case 2:
-        convertedStatus = account::RegisterNameStatus::INVALID_NAME;
+        convertedStatus = account::RegisterNameStatus::RNS_INVALID_NAME;
         break;
     case 3:
         convertedStatus = account::RegisterNameStatus::ALREADY_TAKEN;
@@ -660,17 +694,18 @@ AccountModelPimpl::slotNameRegistrationEnded(const QString& accountId,
 
 void
 AccountModelPimpl::slotRegisteredNameFound(const QString& accountId,
+                                           const QString& requestedName,
                                            int status,
                                            const QString& address,
-                                           const QString& name)
+                                           const QString& registeredName)
 {
-    account::LookupStatus convertedStatus = account::LookupStatus::INVALID;
+    account::LookupStatus convertedStatus = account::LookupStatus::LOOKUP_INVALID;
     switch (status) {
     case 0:
         convertedStatus = account::LookupStatus::SUCCESS;
         break;
     case 1:
-        convertedStatus = account::LookupStatus::INVALID_NAME;
+        convertedStatus = account::LookupStatus::LOOKUP_INVALID_NAME;
         break;
     case 2:
         convertedStatus = account::LookupStatus::NOT_FOUND;
@@ -681,7 +716,11 @@ AccountModelPimpl::slotRegisteredNameFound(const QString& accountId,
     default:
         break;
     }
-    Q_EMIT linked.registeredNameFound(accountId, convertedStatus, address, name);
+    Q_EMIT linked.registeredNameFound(accountId,
+                                      requestedName,
+                                      convertedStatus,
+                                      address,
+                                      registeredName);
 }
 
 void
@@ -700,23 +739,6 @@ AccountModelPimpl::slotMigrationEnded(const QString& accountId, bool ok)
     Q_EMIT linked.migrationEnded(accountId, ok);
 }
 
-void
-AccountModelPimpl::slotAccountProfileReceived(const QString& accountId,
-                                              const QString& displayName,
-                                              const QString& userPhoto)
-{
-    auto account = accounts.find(accountId);
-    if (account == accounts.end())
-        return;
-    auto& accountInfo = account->second.first;
-    accountInfo.profileInfo.avatar = userPhoto;
-    accountInfo.profileInfo.alias = displayName;
-
-    authority::storage::createOrUpdateProfile(accountInfo.id, accountInfo.profileInfo);
-
-    Q_EMIT linked.profileUpdated(accountId);
-}
-
 void
 AccountModelPimpl::slotNewPosition(const QString& accountId,
                                    const QString& peerId,
@@ -728,38 +750,57 @@ AccountModelPimpl::slotNewPosition(const QString& accountId,
 }
 
 void
-AccountModelPimpl::addToAccounts(const QString& accountId, std::shared_ptr<Database> db)
+AccountModelPimpl::slotAccountProfileReceived(const QString& accountId,
+                                              const QString& displayName,
+                                              const QString& userPhoto)
 {
-    if (db == nullptr) {
-        try {
-            auto appPath = authority::storage::getPath();
-            auto dbName = accountId + "/history";
-            db = DatabaseFactory::create<Database>(dbName, appPath);
-            // create the profiles path if necessary
-            QDir profilesDir(appPath + accountId + "/profiles");
-            if (!profilesDir.exists()) {
-                profilesDir.mkpath(".");
-            }
-        } catch (const std::runtime_error& e) {
-            qWarning() << e.what();
-            return;
-        }
-    }
+    LC_WARN << accountId << displayName;
+    auto account = accounts.find(accountId);
+    if (account == accounts.end() || userPhoto.isEmpty())
+        return;
+    // NOTE: This signal is still used for JAMS account where the avatar is
+    // retrieved from the server. In this case we MUST save it.
+    auto& accountInfo = account->second.first;
+    accountInfo.profileInfo.avatar = userPhoto;
+    accountInfo.profileInfo.alias = displayName;
+    storage::vcard::setProfile(accountInfo.id, accountInfo.profileInfo);
+    Q_EMIT linked.profileUpdated(accountId);
+}
 
-    auto it = accounts.emplace(accountId, std::make_pair(account::Info(), db));
+void
+AccountModelPimpl::addToAccounts(const QString& accountId)
+{
+    auto appPath = storage::getPath();
+    auto dbName = accountId + "/history";
 
-    if (!it.second) {
-        qWarning("failed to add new account: id already present in map");
+    // Create and load the database.
+    auto db = std::make_shared<Database>(dbName, appPath);
+    try {
+        db->load();
+    } catch (const std::exception& e) {
+        LC_WARN << e.what();
         return;
     }
 
-    // Init profile
+    // Create the profiles path if necessary.
+    QDir profilesDir(appPath + accountId + "/profiles");
+    if (!profilesDir.exists()) {
+        profilesDir.mkpath(".");
+    }
+
+    auto it = accounts.emplace(accountId, std::make_pair(account::Info(), db));
+    if (!it.second) {
+        LC_WARN << "Failed to add new account: id already present in map";
+        return;
+    }
+
+    // Initialize the profile.
     account::Info& newAccInfo = (it.first)->second.first;
     newAccInfo.id = accountId;
-    newAccInfo.profileInfo.avatar = authority::storage::getAccountAvatar(accountId);
+    newAccInfo.profileInfo.avatar = storage::getAccountAvatar(accountId);
     updateAccountDetails(newAccInfo);
 
-    // Init models for this account
+    // Initialize models for this account.
     newAccInfo.accountModel = &linked;
     newAccInfo.callModel = std::make_unique<CallModel>(newAccInfo,
                                                        lrc,
@@ -792,14 +833,14 @@ AccountModelPimpl::removeFromAccounts(const QString& accountId)
     }
     auto& accountInfo = account->second.first;
     if (accountInfo.profileInfo.type == profile::Type::SIP) {
-        auto accountDir = QDir(authority::storage::getPath() + accountId);
+        auto accountDir = QDir(storage::getPath() + accountId);
         accountDir.removeRecursively();
     }
 
     /* Inform client about account removal. Do *not* free account structures
        before we are sure that the client stopped using it, otherwise we might
        get into use-after-free troubles. */
-    accountInfo.valid = false;
+    accountIdList.removeOne(accountId);
     Q_EMIT linked.accountRemoved(accountId);
 
     // Now we can free them
@@ -828,7 +869,9 @@ account::Info::fromDetails(const MapStringString& details)
     confProperties.mailbox = details[ConfProperties::MAILBOX];
     confProperties.dtmfType = details[ConfProperties::DTMF_TYPE];
     confProperties.autoAnswer = toBool(details[ConfProperties::AUTOANSWER]);
+    confProperties.denySecondCall = toBool(details[ConfProperties::DENYSECONDCALL]);
     confProperties.sendReadReceipt = toBool(details[ConfProperties::SENDREADRECEIPT]);
+    confProperties.sendComposing = toBool(details[ConfProperties::SENDCOMPOSING]);
     confProperties.isRendezVous = toBool(details[ConfProperties::ISRENDEZVOUS]);
     confProperties.activeCallLimit = toInt(details[ConfProperties::ACTIVE_CALL_LIMIT]);
     confProperties.hostname = details[ConfProperties::HOSTNAME];
@@ -852,22 +895,23 @@ account::Info::fromDetails(const MapStringString& details)
     confProperties.upnpEnabled = toBool(details[ConfProperties::UPNP_ENABLED]);
     confProperties.hasCustomUserAgent = toBool(details[ConfProperties::HAS_CUSTOM_USER_AGENT]);
     confProperties.allowIncoming = toBool(details[ConfProperties::ALLOW_CERT_FROM_HISTORY])
-                                   | toBool(details[ConfProperties::ALLOW_CERT_FROM_CONTACT])
-                                   | toBool(details[ConfProperties::ALLOW_CERT_FROM_TRUSTED]);
+                                   || toBool(details[ConfProperties::ALLOW_CERT_FROM_CONTACT])
+                                   || toBool(details[ConfProperties::ALLOW_CERT_FROM_TRUSTED]);
     confProperties.allowIPAutoRewrite = toBool(details[ConfProperties::ACCOUNT_IP_AUTO_REWRITE]);
     confProperties.archivePassword = details[ConfProperties::ARCHIVE_PASSWORD];
     confProperties.archiveHasPassword = toBool(details[ConfProperties::ARCHIVE_HAS_PASSWORD]);
     confProperties.archivePath = details[ConfProperties::ARCHIVE_PATH];
-    confProperties.archivePin = details[ConfProperties::ARCHIVE_PIN];
     confProperties.proxyEnabled = toBool(details[ConfProperties::PROXY_ENABLED]);
     confProperties.proxyServer = details[ConfProperties::PROXY_SERVER];
     confProperties.proxyPushToken = details[ConfProperties::PROXY_PUSH_TOKEN];
+    confProperties.dhtPort = toInt(details[ConfProperties::DHT_PORT]);
     confProperties.peerDiscovery = toBool(details[ConfProperties::DHT_PEER_DISCOVERY]);
     confProperties.accountDiscovery = toBool(details[ConfProperties::ACCOUNT_PEER_DISCOVERY]);
     confProperties.accountPublish = toBool(details[ConfProperties::ACCOUNT_PUBLISH]);
     confProperties.keepAliveEnabled = toBool(details[ConfProperties::KEEP_ALIVE_ENABLED]);
     confProperties.bootstrapListUrl = QString(details[ConfProperties::BOOTSTRAP_LIST_URL]);
     confProperties.dhtProxyListUrl = QString(details[ConfProperties::DHT_PROXY_LIST_URL]);
+    confProperties.proxyListEnabled = toBool(details[ConfProperties::PROXY_LIST_ENABLED]);
     confProperties.defaultModerators = QString(details[ConfProperties::DEFAULT_MODERATORS]);
     confProperties.localModeratorsEnabled = toBool(
         details[ConfProperties::LOCAL_MODERATORS_ENABLED]);
@@ -918,12 +962,11 @@ account::Info::fromDetails(const MapStringString& details)
     confProperties.TLS.disableSecureDlgCheck = toBool(
         details[ConfProperties::TLS::DISABLE_SECURE_DLG_CHECK]);
     // DHT
-    confProperties.DHT.port = toInt(details[ConfProperties::DHT::PORT]);
     confProperties.DHT.PublicInCalls = toBool(details[ConfProperties::DHT::PUBLIC_IN_CALLS]);
     confProperties.DHT.AllowFromTrusted = toBool(details[ConfProperties::DHT::ALLOW_FROM_TRUSTED]);
-    // RingNS
-    confProperties.RingNS.uri = details[ConfProperties::RingNS::URI];
-    confProperties.RingNS.account = details[ConfProperties::RingNS::ACCOUNT];
+    // Nameserver
+    confProperties.Nameserver.uri = details[ConfProperties::Nameserver::URI];
+    confProperties.Nameserver.account = details[ConfProperties::Nameserver::ACCOUNT];
     // Jams
     confProperties.managerUri = details[ConfProperties::MANAGER_URI];
     confProperties.managerUsername = details[ConfProperties::MANAGER_USERNAME];
@@ -943,7 +986,9 @@ account::ConfProperties_t::toDetails() const
     details[ConfProperties::MAILBOX] = this->mailbox;
     details[ConfProperties::DTMF_TYPE] = this->dtmfType;
     details[ConfProperties::AUTOANSWER] = toQString(this->autoAnswer);
+    details[ConfProperties::DENYSECONDCALL] = toQString(this->denySecondCall);
     details[ConfProperties::SENDREADRECEIPT] = toQString(this->sendReadReceipt);
+    details[ConfProperties::SENDCOMPOSING] = toQString(this->sendComposing);
     details[ConfProperties::ISRENDEZVOUS] = toQString(this->isRendezVous);
     details[ConfProperties::ACTIVE_CALL_LIMIT] = toQString(this->activeCallLimit);
     details[ConfProperties::HOSTNAME] = this->hostname;
@@ -968,16 +1013,17 @@ account::ConfProperties_t::toDetails() const
     details[ConfProperties::ARCHIVE_PASSWORD] = this->archivePassword;
     details[ConfProperties::ARCHIVE_HAS_PASSWORD] = toQString(this->archiveHasPassword);
     details[ConfProperties::ARCHIVE_PATH] = this->archivePath;
-    details[ConfProperties::ARCHIVE_PIN] = this->archivePin;
     // ConfProperties::DEVICE_NAME name is set with DeviceModel interface
     details[ConfProperties::PROXY_ENABLED] = toQString(this->proxyEnabled);
     details[ConfProperties::PROXY_SERVER] = this->proxyServer;
     details[ConfProperties::PROXY_PUSH_TOKEN] = this->proxyPushToken;
+    details[ConfProperties::DHT_PORT] = toQString(this->dhtPort);
     details[ConfProperties::DHT_PEER_DISCOVERY] = toQString(this->peerDiscovery);
     details[ConfProperties::ACCOUNT_PEER_DISCOVERY] = toQString(this->accountDiscovery);
     details[ConfProperties::ACCOUNT_PUBLISH] = toQString(this->accountPublish);
     details[ConfProperties::KEEP_ALIVE_ENABLED] = toQString(this->keepAliveEnabled);
     details[ConfProperties::BOOTSTRAP_LIST_URL] = this->bootstrapListUrl;
+    details[ConfProperties::PROXY_LIST_ENABLED] = toQString(this->proxyListEnabled);
     details[ConfProperties::DHT_PROXY_LIST_URL] = this->dhtProxyListUrl;
     details[ConfProperties::DEFAULT_MODERATORS] = this->defaultModerators;
     details[ConfProperties::LOCAL_MODERATORS_ENABLED] = toQString(this->localModeratorsEnabled);
@@ -1027,12 +1073,11 @@ account::ConfProperties_t::toDetails() const
     details[ConfProperties::TLS::DISABLE_SECURE_DLG_CHECK] = toQString(
         this->TLS.disableSecureDlgCheck);
     // DHT
-    details[ConfProperties::DHT::PORT] = toQString(this->DHT.port);
     details[ConfProperties::DHT::PUBLIC_IN_CALLS] = toQString(this->DHT.PublicInCalls);
     details[ConfProperties::DHT::ALLOW_FROM_TRUSTED] = toQString(this->DHT.AllowFromTrusted);
-    // RingNS
-    details[ConfProperties::RingNS::URI] = this->RingNS.uri;
-    details[ConfProperties::RingNS::ACCOUNT] = this->RingNS.account;
+    // Nameserver
+    details[ConfProperties::Nameserver::URI] = this->Nameserver.uri;
+    details[ConfProperties::Nameserver::ACCOUNT] = this->Nameserver.account;
     // Manager
     details[ConfProperties::MANAGER_URI] = this->managerUri;
     details[ConfProperties::MANAGER_USERNAME] = this->managerUsername;
@@ -1045,32 +1090,45 @@ account::ConfProperties_t::toDetails() const
 
 QString
 AccountModel::createNewAccount(profile::Type type,
+                               const MapStringString& config,
                                const QString& displayName,
                                const QString& archivePath,
                                const QString& password,
-                               const QString& pin,
-                               const QString& uri,
-                               const MapStringString& config)
+                               const QString& uri)
 {
+    // Get the template for the account type to prefill the details
     MapStringString details = type == profile::Type::SIP
                                   ? ConfigurationManager::instance().getAccountTemplate("SIP")
                                   : ConfigurationManager::instance().getAccountTemplate("RING");
-    using namespace libjami::Account;
-    details[ConfProperties::TYPE] = type == profile::Type::SIP ? "SIP" : "RING";
-    details[ConfProperties::DISPLAYNAME] = displayName;
-    details[ConfProperties::ALIAS] = displayName;
-    details[ConfProperties::UPNP_ENABLED] = "true";
-    details[ConfProperties::ARCHIVE_PASSWORD] = password;
-    details[ConfProperties::ARCHIVE_PIN] = pin;
-    details[ConfProperties::ARCHIVE_PATH] = archivePath;
-    if (type == profile::Type::SIP)
-        details[ConfProperties::USERNAME] = uri;
+
+    // Add the supplied config to the details
     if (!config.isEmpty()) {
         for (MapStringString::const_iterator it = config.begin(); it != config.end(); it++) {
             details[it.key()] = it.value();
         }
     }
 
+    using namespace libjami::Account;
+
+    // Add the rest of the details if we are not creating an ephemeral account for linking
+    // in which case the ARCHIVE_URL was set to "jami-auth" or the MANAGER_URI was set to
+    // the account manager URI in the case of a remote account manager connection
+    if (details[ConfProperties::ARCHIVE_URL].isEmpty()
+        && details[ConfProperties::MANAGER_URI].isEmpty()) {
+        details[ConfProperties::TYPE] = type == profile::Type::SIP ? "SIP" : "RING";
+        details[ConfProperties::DISPLAYNAME] = displayName;
+        details[ConfProperties::ALIAS] = displayName;
+        details[ConfProperties::UPNP_ENABLED] = "true";
+        details[ConfProperties::ARCHIVE_PASSWORD] = password;
+        details[ConfProperties::ARCHIVE_PATH] = archivePath;
+
+        // Override the username with the provided URI if it's a SIP account
+        if (type == profile::Type::SIP) {
+            details[ConfProperties::USERNAME] = uri;
+        }
+    }
+
+    // Actually add the account and return the account ID
     QString accountId = ConfigurationManager::instance().addAccount(details);
     return accountId;
 }
@@ -1081,20 +1139,24 @@ AccountModel::connectToAccountManager(const QString& username,
                                       const QString& serverUri,
                                       const MapStringString& config)
 {
-    MapStringString details = ConfigurationManager::instance().getAccountTemplate("RING");
+    MapStringString details = config;
     using namespace libjami::Account;
     details[ConfProperties::TYPE] = "RING";
     details[ConfProperties::MANAGER_URI] = serverUri;
     details[ConfProperties::MANAGER_USERNAME] = username;
     details[ConfProperties::ARCHIVE_PASSWORD] = password;
-    if (!config.isEmpty()) {
-        for (MapStringString::const_iterator it = config.begin(); it != config.end(); it++) {
-            details[it.key()] = it.value();
-        }
-    }
+    return createNewAccount(profile::Type::JAMI, details);
+}
 
-    QString accountId = ConfigurationManager::instance().addAccount(details);
-    return accountId;
+QString
+AccountModel::createDeviceImportAccount()
+{
+    // auto details = ConfigurationManager::instance().getAccountTemplate("RING");
+    MapStringString details;
+    using namespace libjami::Account;
+    details[ConfProperties::TYPE] = "RING";
+    details[ConfProperties::ARCHIVE_URL] = "jami-auth";
+    return createNewAccount(profile::Type::JAMI, details);
 }
 
 void
@@ -1120,14 +1182,13 @@ AccountModel::setTopAccount(const QString& accountId)
 QString
 AccountModel::accountVCard(const QString& accountId, bool compressImage) const
 {
-    return authority::storage::vcard::profileToVcard(getAccountInfo(accountId).profileInfo,
-                                                     compressImage);
+    return storage::vcard::profileToVcard(getAccountInfo(accountId).profileInfo, compressImage);
 }
 
 const QString
 AccountModel::bestNameForAccount(const QString& accountID)
 {
-    // Order: Alias, registeredName, uri
+    // Order: alias, registeredName, uri
     auto& accountInfo = getAccountInfo(accountID);
 
     auto alias = accountInfo.profileInfo.alias.simplified();
@@ -1146,7 +1207,7 @@ AccountModel::bestNameForAccount(const QString& accountID)
 const QString
 AccountModel::bestIdForAccount(const QString& accountID)
 {
-    // Order: RegisteredName, uri after best name
+    // Order: registeredName, uri after best name
     //        return empty string if duplicated with best name
     auto& accountInfo = getAccountInfo(accountID);
 
@@ -1215,7 +1276,7 @@ AccountModel::reloadHistory()
 QString
 AccountModel::avatar(const QString& accountId) const
 {
-    return authority::storage::avatar(accountId);
+    return storage::avatar(accountId);
 }
 
 } // namespace lrc
