@@ -1,7 +1,5 @@
 /*
- *  Copyright (C) 2018-2023 Savoir-faire Linux Inc.
- *  Author: Hugo Lefeuvre <hugo.lefeuvre@savoirfairelinux.com>
- *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
+ *  Copyright (C) 2018-2025 Savoir-faire Linux Inc.
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -25,6 +23,8 @@
 #include "directrenderer.h"
 #else
 #include "shmrenderer.h"
+#include <csignal>
+#include <thread>
 #endif
 #include "callbackshandler.h"
 #include "dbus/callmanager.h"
@@ -42,11 +42,7 @@
 
 #include <algorithm> // std::sort
 #include <chrono>
-#include <csignal>
 #include <iomanip> // for std::put_time
-#include <fstream>
-#include <mutex>
-#include <thread>
 #include <string>
 #include <sstream>
 
@@ -328,7 +324,7 @@ void
 AVModel::setDeviceSettings(video::Settings& settings)
 {
     MapStringString newSettings;
-    auto rate = QString::number(settings.rate, 'f', 7);
+    auto rate = QString::number(static_cast<double>(settings.rate), 'f', 7);
     rate = rate.left(rate.length() - 1);
     newSettings["channel"] = settings.channel;
     newSettings["name"] = settings.name;
@@ -357,7 +353,7 @@ AVModel::getDeviceIdFromName(const QString& deviceName) const
         return settings.name == deviceName;
     });
     if (iter == devices.end()) {
-        qWarning() << "Couldn't find device: " << deviceName;
+        LC_WARN << "Unable to find device: " << deviceName;
         return {};
     }
     return *iter;
@@ -399,6 +395,24 @@ AVModel::getAudioOutputDevices() const
     return (QVector<QString>) result;
 }
 
+QString
+AVModel::getNoiseSuppression() const
+{
+    return ConfigurationManager::instance().getNoiseSuppressState();
+}
+
+QString
+AVModel::getEchoCancellation() const
+{
+    return ConfigurationManager::instance().getEchoCancellationState();
+}
+
+bool
+AVModel::getVoiceActivityDetection() const
+{
+    return ConfigurationManager::instance().getVoiceActivityDetectionState();
+}
+
 QVector<QString>
 AVModel::getAudioInputDevices() const
 {
@@ -469,6 +483,44 @@ AVModel::setAudioManager(const QString& name)
     return ConfigurationManager::instance().setAudioManager(name);
 }
 
+void
+AVModel::setNoiseSuppression(const QString& name)
+{
+    QString state = QObject::tr("auto"); // Default is auto
+    if (name == QObject::tr("System (if available)"))
+        state = "system";
+    else if (name == QObject::tr("Built-in"))
+        state = "audioProcessor";
+    else if (name == QObject::tr("Auto (default)"))
+        state = "auto";
+    else if (name == QObject::tr("Disabled"))
+        state = "off";
+
+    return ConfigurationManager::instance().setNoiseSuppressState(state);
+}
+
+void
+AVModel::setEchoCancellation(const QString& name)
+{
+    QString state = "auto"; // Default is auto
+    if (name == QObject::tr("System (if available)"))
+        state = "system";
+    else if (name == QObject::tr("Built-in"))
+        state = "audioProcessor";
+    else if (name == QObject::tr("Auto (default)"))
+        state = "auto";
+    else if (name == QObject::tr("Disabled"))
+        state = "off";
+
+    return ConfigurationManager::instance().setEchoCancellationState(state);
+}
+
+void
+AVModel::setVoiceActivityDetection(bool state)
+{
+    return ConfigurationManager::instance().setVoiceActivityDetectionState(state);
+}
+
 void
 AVModel::setRingtoneDevice(int idx)
 {
@@ -491,7 +543,7 @@ void
 AVModel::stopLocalRecorder(const QString& path) const
 {
     if (path.isEmpty()) {
-        qWarning("stopLocalRecorder: can't stop non existing recording");
+        LC_WARN << "stopLocalRecorder: unable to stop non existing recording";
         return;
     }
 
@@ -560,10 +612,10 @@ AVModel::startPreview(const QString& resource)
     return VideoManager::instance().openVideoInput(resource);
 }
 
-void
+bool
 AVModel::stopPreview(const QString& resource)
 {
-    VideoManager::instance().closeVideoInput(resource);
+    return VideoManager::instance().closeVideoInput(resource);
 }
 
 #ifdef WIN32
@@ -664,7 +716,7 @@ AVModel::getListWindows() const
                                                                      });
 
     if (xcb_connection_has_error(c.get())) {
-        qDebug() << "xcb connection has error";
+        LC_DBG << "xcb connection has error";
         return ret;
     }
 
@@ -690,7 +742,7 @@ AVModel::getListWindows() const
     propertyPtr replyPropList(xcb_get_property_reply(c.get(), propCookieList, &e),
                               [](auto* ptr) { free(ptr); });
     if (e) {
-        qDebug() << "Error: " << e->error_code;
+        LC_DBG << "Error: " << e->error_code;
         free(e);
     }
     if (replyPropList.get()) {
@@ -710,7 +762,7 @@ AVModel::getListWindows() const
                                            free(ptr);
                                        }};
                 if (e) {
-                    qDebug() << "Error: " << e->error_code;
+                    LC_DBG << "Error: " << e->error_code;
                     free(e);
                 }
                 if (replyProp.get()) {
@@ -795,6 +847,54 @@ AVModel::useDirectRenderer() const
 #endif
 }
 
+QString
+AVModel::createMediaPlayer(const QString& resource)
+{
+    return VideoManager::instance().createMediaPlayer(resource);
+}
+
+void
+AVModel::closeMediaPlayer(const QString& resource)
+{
+    VideoManager::instance().closeMediaPlayer(resource);
+}
+
+bool
+AVModel::pausePlayer(const QString& id, bool pause)
+{
+    return VideoManager::instance().pausePlayer(id, pause);
+}
+
+bool
+AVModel::mutePlayerAudio(const QString& id, bool mute)
+{
+    return VideoManager::instance().mutePlayerAudio(id, mute);
+}
+
+bool
+AVModel::playerSeekToTime(const QString& id, int time)
+{
+    return VideoManager::instance().playerSeekToTime(id, time);
+}
+
+qint64
+AVModel::getPlayerPosition(const QString& id)
+{
+    return VideoManager::instance().getPlayerPosition(id);
+}
+
+qint64
+AVModel::getPlayerDuration(const QString& id)
+{
+    return VideoManager::instance().getPlayerDuration(id);
+}
+
+void
+AVModel::setAutoRestart(const QString& id, bool restart)
+{
+    VideoManager::instance().setAutoRestart(id, restart);
+}
+
 AVModelPimpl::AVModelPimpl(AVModel& linked, const CallbacksHandler& callbacksHandler)
     : callbacksHandler(callbacksHandler)
     , linked_(linked)
@@ -826,6 +926,17 @@ AVModelPimpl::AVModelPimpl(AVModel& linked, const CallbacksHandler& callbacksHan
             &AVModelPimpl::onDecodingStopped,
             Qt::DirectConnection);
 
+    // Media player connection
+    connect(&callbacksHandler,
+            &CallbacksHandler::fileOpened,
+            this,
+            [this](const QString& path, MapStringString info) {
+                Q_UNUSED(path);
+                bool hasAudio = info["audio_stream"].toInt() >= 0;
+                bool hasVideo = info["video_stream"].toInt() >= 0;
+                Q_EMIT linked_.fileOpened(hasAudio, hasVideo);
+            });
+
     auto startedPreview = false;
     auto restartRenderers = [&](const QStringList& callList) {
         for (const auto& callId : callList) {
@@ -928,7 +1039,7 @@ AVModelPimpl::getDevice(int type) const
         if (deviceIdx < devices.size())
             result = devices.at(deviceIdx);
     } catch (std::bad_alloc& ba) {
-        qWarning() << "bad_alloc caught: " << ba.what();
+        LC_WARN << "bad_alloc caught: " << ba.what();
         return "";
     }
     return result;
@@ -1001,7 +1112,7 @@ AVModelPimpl::removeRenderer(const QString& id)
     QWriteLocker lk(&renderersMutex_);
     auto it = renderers_.find(id);
     if (it == renderers_.end()) {
-        qWarning() << "Cannot remove renderer. " << id << "not found";
+        LC_DBG << "Unable to remove renderer. " << id << " not found";
         return {};
     }
     auto removed = std::move(it->second);
