@@ -1,7 +1,5 @@
 /******************************************************************************
- *   Copyright (C) 2014-2023 Savoir-faire Linux Inc.                          *
- *   Author : Philippe Groarke <philippe.groarke@savoirfairelinux.com>        *
- *   Author : Alexandre Lision <alexandre.lision@savoirfairelinux.com>        *
+ *   Copyright (C) 2014-2025 Savoir-faire Linux Inc.                          *
  *                                                                            *
  *   This library is free software; you can redistribute it and/or            *
  *   modify it under the terms of the GNU Lesser General Public               *
@@ -77,19 +75,19 @@ public:
                     Q_EMIT this->stunStatusFailure(QString(reason.c_str()));
                 }),
             exportable_callback<ConfigurationSignal::RegistrationStateChanged>(
-                [this](const std::string& accountID,
+                [this](const std::string& accountId,
                        const std::string& registration_state,
                        unsigned detail_code,
                        const std::string& detail_str) {
-                    Q_EMIT this->registrationStateChanged(QString(accountID.c_str()),
+                    Q_EMIT this->registrationStateChanged(QString(accountId.c_str()),
                                                           QString(registration_state.c_str()),
                                                           detail_code,
                                                           QString(detail_str.c_str()));
                 }),
             exportable_callback<ConfigurationSignal::VolatileDetailsChanged>(
-                [this](const std::string& accountID,
+                [this](const std::string& accountId,
                        const std::map<std::string, std::string>& details) {
-                    Q_EMIT this->volatileAccountDetailsChanged(QString(accountID.c_str()),
+                    Q_EMIT this->volatileAccountDetailsChanged(QString(accountId.c_str()),
                                                                convertMap(details));
                 }),
             exportable_callback<ConfigurationSignal::CertificateExpired>(
@@ -106,11 +104,11 @@ public:
                                                        convertStringList(list));
                 }),
             exportable_callback<ConfigurationSignal::CertificateStateChanged>(
-                [this](const std::string& accountID,
+                [this](const std::string& accountId,
                        const std::string& certId,
                        const std::string& state) {
-                    QTimer::singleShot(0, [this, accountID, certId, state] {
-                        Q_EMIT this->certificateStateChanged(QString(accountID.c_str()),
+                    QTimer::singleShot(0, [this, accountId, certId, state] {
+                        Q_EMIT this->certificateStateChanged(QString(accountId.c_str()),
                                                              QString(certId.c_str()),
                                                              QString(state.c_str()));
                     });
@@ -152,11 +150,23 @@ public:
                                                         QString(displayName.c_str()),
                                                         QString(userPhoto.c_str()));
                 }),
-            exportable_callback<ConfigurationSignal::ExportOnRingEnded>(
-                [this](const std::string& accountId, int status, const std::string& pin) {
-                    Q_EMIT this->exportOnRingEnded(QString(accountId.c_str()),
-                                                   status,
-                                                   QString(pin.c_str()));
+            exportable_callback<ConfigurationSignal::AddDeviceStateChanged>(
+                [this](const std::string& accountId,
+                       uint32_t operationId,
+                       int state,
+                       const std::map<std::string, std::string>& details) {
+                    Q_EMIT this->addDeviceStateChanged(QString(accountId.c_str()),
+                                                       operationId,
+                                                       state,
+                                                       convertMap(details));
+                }),
+            exportable_callback<ConfigurationSignal::DeviceAuthStateChanged>(
+                [this](const std::string& accountId,
+                       int state,
+                       const std::map<std::string, std::string>& details) {
+                    Q_EMIT this->deviceAuthStateChanged(QString(accountId.c_str()),
+                                                        state,
+                                                        convertMap(details));
                 }),
             exportable_callback<ConfigurationSignal::NameRegistrationEnded>(
                 [this](const std::string& accountId, int status, const std::string& name) {
@@ -166,10 +176,12 @@ public:
                 }),
             exportable_callback<ConfigurationSignal::RegisteredNameFound>(
                 [this](const std::string& accountId,
+                       const std::string& requestedName,
                        int status,
                        const std::string& address,
                        const std::string& name) {
                     Q_EMIT this->registeredNameFound(QString(accountId.c_str()),
+                                                     QString(requestedName.c_str()),
                                                      status,
                                                      QString(address.c_str()),
                                                      QString(name.c_str()));
@@ -205,10 +217,10 @@ public:
                                               confirmed);
                 }),
             exportable_callback<ConfigurationSignal::ProfileReceived>(
-                [this](const std::string& accountID,
+                [this](const std::string& accountId,
                        const std::string& peer,
                        const std::string& vCard) {
-                    Q_EMIT this->profileReceived(QString(accountID.c_str()),
+                    Q_EMIT this->profileReceived(QString(accountId.c_str()),
                                                  QString(peer.c_str()),
                                                  QString(vCard.c_str()));
                 }),
@@ -259,15 +271,26 @@ public:
                 }),
         };
         conversationsHandlers
-            = {exportable_callback<ConversationSignal::ConversationLoaded>(
+            = {exportable_callback<ConversationSignal::SwarmLoaded>(
                    [this](uint32_t id,
                           const std::string& accountId,
                           const std::string& conversationId,
-                          const std::vector<std::map<std::string, std::string>>& messages) {
-                       Q_EMIT conversationLoaded(id,
-                                                 QString(accountId.c_str()),
-                                                 QString(conversationId.c_str()),
-                                                 convertVecMap(messages));
+                          const std::vector<libjami::SwarmMessage>& messages) {
+                       VectorSwarmMessage vec;
+                       for (const auto& msg : messages) {
+                           vec.push_back({msg.id.c_str(),
+                                          msg.type.c_str(),
+                                          msg.linearizedParent.c_str(),
+                                          convertMap(msg.body),
+                                          convertVecMap(msg.reactions),
+                                          convertVecMap(msg.editions),
+                                          convertMap(msg.status)});
+                       }
+
+                       Q_EMIT swarmLoaded(id,
+                                          QString(accountId.c_str()),
+                                          QString(conversationId.c_str()),
+                                          vec);
                    }),
                exportable_callback<ConversationSignal::MessagesFound>(
                    [this](uint32_t id,
@@ -279,13 +302,55 @@ public:
                                             QString(conversationId.c_str()),
                                             convertVecMap(messages));
                    }),
-               exportable_callback<ConversationSignal::MessageReceived>(
+               exportable_callback<ConversationSignal::SwarmMessageReceived>(
                    [this](const std::string& accountId,
                           const std::string& conversationId,
-                          const std::map<std::string, std::string>& message) {
-                       Q_EMIT messageReceived(QString(accountId.c_str()),
+                          const libjami::SwarmMessage& message) {
+                       ::SwarmMessage msg = {message.id.c_str(),
+                                             message.type.c_str(),
+                                             message.linearizedParent.c_str(),
+                                             convertMap(message.body),
+                                             convertVecMap(message.reactions),
+                                             convertVecMap(message.editions),
+                                             convertMap(message.status)};
+                       Q_EMIT swarmMessageReceived(QString(accountId.c_str()),
+                                                   QString(conversationId.c_str()),
+                                                   msg);
+                   }),
+               exportable_callback<ConversationSignal::SwarmMessageUpdated>(
+                   [this](const std::string& accountId,
+                          const std::string& conversationId,
+                          const libjami::SwarmMessage& message) {
+                       ::SwarmMessage msg = {message.id.c_str(),
+                                             message.type.c_str(),
+                                             message.linearizedParent.c_str(),
+                                             convertMap(message.body),
+                                             convertVecMap(message.reactions),
+                                             convertVecMap(message.editions),
+                                             convertMap(message.status)};
+                       Q_EMIT swarmMessageUpdated(QString(accountId.c_str()),
+                                                  QString(conversationId.c_str()),
+                                                  msg);
+                   }),
+               exportable_callback<ConversationSignal::ReactionAdded>(
+                   [this](const std::string& accountId,
+                          const std::string& conversationId,
+                          const std::string& messageId,
+                          const std::map<std::string, std::string>& reaction) {
+                       Q_EMIT reactionAdded(QString(accountId.c_str()),
+                                            QString(conversationId.c_str()),
+                                            QString(messageId.c_str()),
+                                            convertMap(reaction));
+                   }),
+               exportable_callback<ConversationSignal::ReactionRemoved>(
+                   [this](const std::string& accountId,
+                          const std::string& conversationId,
+                          const std::string& messageId,
+                          const std::string& reactionId) {
+                       Q_EMIT reactionRemoved(QString(accountId.c_str()),
                                               QString(conversationId.c_str()),
-                                              convertMap(message));
+                                              QString(messageId.c_str()),
+                                              QString(reactionId.c_str()));
                    }),
                exportable_callback<ConversationSignal::ConversationProfileUpdated>(
                    [this](const std::string& accountId,
@@ -378,55 +443,95 @@ public Q_SLOTS: // METHODS
                               path.toStdString());
     }
 
-    bool exportOnRing(const QString& accountID, const QString& password)
+    bool provideAccountAuthentication(const QString& accountId,
+                                      const QString& credentialsFromUser,
+                                      const QString scheme = "password")
     {
-        return libjami::exportOnRing(accountID.toStdString(), password.toStdString());
+        return libjami::provideAccountAuthentication(accountId.toStdString(),
+                                                     credentialsFromUser.toStdString(),
+                                                     scheme.toStdString());
     }
 
-    bool exportToFile(const QString& accountID,
+    int32_t addDevice(const QString& accountId, const QString& token)
+    {
+        return libjami::addDevice(accountId.toStdString(), token.toStdString());
+    }
+
+    bool confirmAddDevice(const QString& accountId, uint32_t operationId)
+    {
+        return libjami::confirmAddDevice(accountId.toStdString(), operationId);
+    }
+
+    bool cancelAddDevice(const QString& accountId, uint32_t operationId)
+    {
+        return libjami::cancelAddDevice(accountId.toStdString(), operationId);
+    }
+
+    bool exportToFile(const QString& accountId,
                       const QString& destinationPath,
+                      const QString& scheme = "password",
                       const QString& password = {})
     {
-        return libjami::exportToFile(accountID.toStdString(),
+        return libjami::exportToFile(accountId.toStdString(),
                                      destinationPath.toStdString(),
+                                     scheme.toStdString(),
                                      password.toStdString());
     }
 
-    MapStringString getKnownRingDevices(const QString& accountID)
+    MapStringString getKnownRingDevices(const QString& accountId)
     {
-        MapStringString temp = convertMap(libjami::getKnownRingDevices(accountID.toStdString()));
+        MapStringString temp = convertMap(libjami::getKnownRingDevices(accountId.toStdString()));
         return temp;
     }
 
-    bool lookupName(const QString& accountID, const QString& nameServiceURL, const QString& name)
+    bool lookupName(const QString& accountId, const QString& nameServiceURL, const QString& name)
     {
-        return libjami::lookupName(accountID.toStdString(),
+        return libjami::lookupName(accountId.toStdString(),
                                    nameServiceURL.toStdString(),
                                    name.toStdString());
     }
 
-    bool lookupAddress(const QString& accountID,
+    bool lookupAddress(const QString& accountId,
                        const QString& nameServiceURL,
                        const QString& address)
     {
-        return libjami::lookupAddress(accountID.toStdString(),
+        return libjami::lookupAddress(accountId.toStdString(),
                                       nameServiceURL.toStdString(),
                                       address.toStdString());
     }
 
-    bool registerName(const QString& accountID, const QString& password, const QString& name)
+    bool registerName(const QString& accountId,
+                      const QString& name,
+                      const QString& scheme,
+                      const QString& password)
     {
-        return libjami::registerName(accountID.toStdString(),
-                                     password.toStdString(),
-                                     name.toStdString());
+        return libjami::registerName(accountId.toStdString(),
+                                     name.toStdString(),
+                                     scheme.toStdString(),
+                                     password.toStdString());
     }
 
-    MapStringString getAccountDetails(const QString& accountID)
+    MapStringString getAccountDetails(const QString& accountId)
     {
-        MapStringString temp = convertMap(libjami::getAccountDetails(accountID.toStdString()));
+        MapStringString temp = convertMap(libjami::getAccountDetails(accountId.toStdString()));
         return temp;
     }
 
+    void updateProfile(const QString& accountId,
+                       const QString& displayName,
+                       const QString& avatarPath,
+                       const QString& fileType,
+                       int flag)
+    {
+        // file type is set to PNG by default
+        // it can be changed to JPEG to optimize compression
+        libjami::updateProfile(accountId.toStdString(),
+                               displayName.toStdString(),
+                               avatarPath.toStdString(),
+                               fileType.toStdString(),
+                               flag);
+    }
+
     QStringList getAccountList()
     {
         return convertStringList(libjami::getAccountList());
@@ -473,10 +578,10 @@ public Q_SLOTS: // METHODS
         return temp;
     }
 
-    MapStringString getCodecDetails(const QString& accountID, int payload)
+    MapStringString getCodecDetails(const QString& accountId, int payload)
     {
         MapStringString temp = convertMap(
-            libjami::getCodecDetails(accountID.toStdString().c_str(), payload));
+            libjami::getCodecDetails(accountId.toStdString().c_str(), payload));
         return temp;
     }
 
@@ -486,10 +591,10 @@ public Q_SLOTS: // METHODS
         return QVector<unsigned int>(v.begin(), v.end());
     }
 
-    VectorMapStringString getContacts(const QString& accountID)
+    VectorMapStringString getContacts(const QString& accountId)
     {
         VectorMapStringString temp;
-        for (const auto& x : libjami::getContacts(accountID.toStdString())) {
+        for (const auto& x : libjami::getContacts(accountId.toStdString())) {
             temp.push_back(convertMap(x));
         }
         return temp;
@@ -529,10 +634,10 @@ public Q_SLOTS: // METHODS
         return temp;
     }
 
-    VectorMapStringString getCredentials(const QString& accountID)
+    VectorMapStringString getCredentials(const QString& accountId)
     {
         VectorMapStringString temp;
-        for (auto x : libjami::getCredentials(accountID.toStdString())) {
+        for (auto x : libjami::getCredentials(accountId.toStdString())) {
             temp.push_back(convertMap(x));
         }
         return temp;
@@ -565,6 +670,16 @@ public Q_SLOTS: // METHODS
         return libjami::getNoiseSuppressState().c_str();
     }
 
+    QString getEchoCancellationState()
+    {
+        return libjami::getEchoCancellationState().c_str();
+    }
+
+    bool getVoiceActivityDetectionState()
+    {
+        return libjami::getVoiceActivityDetectionState();
+    }
+
     QString getRecordPath()
     {
         QString temp(libjami::getRecordPath().c_str());
@@ -636,9 +751,9 @@ public Q_SLOTS: // METHODS
         libjami::monitor(continuous);
     }
 
-    void removeAccount(const QString& accountID)
+    void removeAccount(const QString& accountId)
     {
-        libjami::removeAccount(accountID.toStdString());
+        libjami::removeAccount(accountId.toStdString());
     }
 
     bool changeAccountPassword(const QString& id,
@@ -650,14 +765,14 @@ public Q_SLOTS: // METHODS
                                               newPassword.toStdString());
     }
 
-    void sendRegister(const QString& accountID, bool enable)
+    void sendRegister(const QString& accountId, bool enable)
     {
-        libjami::sendRegister(accountID.toStdString(), enable);
+        libjami::sendRegister(accountId.toStdString(), enable);
     }
 
-    void setAccountDetails(const QString& accountID, MapStringString details)
+    void setAccountDetails(const QString& accountId, MapStringString details)
     {
-        libjami::setAccountDetails(accountID.toStdString(), convertMap(details));
+        libjami::setAccountDetails(accountId.toStdString(), convertMap(details));
     }
 
     void setAccountsOrder(const QString& order)
@@ -665,10 +780,10 @@ public Q_SLOTS: // METHODS
         libjami::setAccountsOrder(order.toStdString());
     }
 
-    void setActiveCodecList(const QString& accountID, VectorUInt& list)
+    void setActiveCodecList(const QString& accountId, VectorUInt& list)
     {
         // const std::vector<unsigned int> converted = convertStringList(list);
-        libjami::setActiveCodecList(accountID.toStdString(),
+        libjami::setActiveCodecList(accountId.toStdString(),
                                     std::vector<unsigned>(list.begin(), list.end()));
     }
 
@@ -702,13 +817,13 @@ public Q_SLOTS: // METHODS
         libjami::setAudioRingtoneDevice(index);
     }
 
-    void setCredentials(const QString& accountID, VectorMapStringString credentialInformation)
+    void setCredentials(const QString& accountId, VectorMapStringString credentialInformation)
     {
         std::vector<std::map<std::string, std::string>> temp;
         for (auto x : credentialInformation) {
             temp.push_back(convertMap(x));
         }
-        libjami::setCredentials(accountID.toStdString(), temp);
+        libjami::setCredentials(accountId.toStdString(), temp);
     }
 
     void setHistoryLimit(int days)
@@ -726,6 +841,16 @@ public Q_SLOTS: // METHODS
         libjami::setNoiseSuppressState(state.toStdString());
     }
 
+    void setEchoCancellationState(QString state)
+    {
+        libjami::setEchoCancellationState(state.toStdString());
+    }
+
+    void setVoiceActivityDetectionState(bool state)
+    {
+        libjami::setVoiceActivityDetectionState(state);
+    }
+
     bool isAudioMeterActive(const QString& id)
     {
         return libjami::isAudioMeterActive(id.toStdString());
@@ -756,10 +881,10 @@ public Q_SLOTS: // METHODS
         libjami::setVolume(device.toStdString(), value);
     }
 
-    MapStringString getVolatileAccountDetails(const QString& accountID)
+    MapStringString getVolatileAccountDetails(const QString& accountId)
     {
         MapStringString temp = convertMap(
-            libjami::getVolatileAccountDetails(accountID.toStdString()));
+            libjami::getVolatileAccountDetails(accountId.toStdString()));
         return temp;
     }
 
@@ -779,11 +904,15 @@ public Q_SLOTS: // METHODS
         libjami::removeContact(accountId.toStdString(), uri.toStdString(), ban);
     }
 
-    void revokeDevice(const QString& accountId, const QString& password, const QString& deviceId)
+    void revokeDevice(const QString& accountId,
+                      const QString& deviceId,
+                      const QString& scheme,
+                      const QString& password)
     {
         libjami::revokeDevice(accountId.toStdString(),
-                              password.toStdString(),
-                              deviceId.toStdString());
+                              deviceId.toStdString(),
+                              scheme.toStdString(),
+                              password.toStdString());
     }
 
     void addContact(const QString& accountId, const QString& uri)
@@ -802,10 +931,10 @@ public Q_SLOTS: // METHODS
                                                flag);
     }
 
-    QVector<Message> getLastMessages(const QString& accountID, const uint64_t& base_timestamp)
+    QVector<Message> getLastMessages(const QString& accountId, const uint64_t& base_timestamp)
     {
         QVector<Message> result;
-        for (auto& message : libjami::getLastMessages(accountID.toStdString(), base_timestamp)) {
+        for (auto& message : libjami::getLastMessages(accountId.toStdString(), base_timestamp)) {
             result.append({message.from.c_str(), convertMap(message.payloads), message.received});
         }
         return result;
@@ -823,9 +952,9 @@ public Q_SLOTS: // METHODS
         return libjami::getMessageStatus(id);
     }
 
-    MapStringString getNearbyPeers(const QString& accountID)
+    MapStringString getNearbyPeers(const QString& accountId)
     {
-        return convertMap(libjami::getNearbyPeers(accountID.toStdString()));
+        return convertMap(libjami::getNearbyPeers(accountId.toStdString()));
     }
 
     void connectivityChanged()
@@ -833,9 +962,9 @@ public Q_SLOTS: // METHODS
         libjami::connectivityChanged();
     }
 
-    MapStringString getContactDetails(const QString& accountID, const QString& uri)
+    MapStringString getContactDetails(const QString& accountId, const QString& uri)
     {
-        return convertMap(libjami::getContactDetails(accountID.toStdString(), uri.toStdString()));
+        return convertMap(libjami::getContactDetails(accountId.toStdString(), uri.toStdString()));
     }
 
     void sendFile(const QString& accountId,
@@ -970,55 +1099,63 @@ public Q_SLOTS: // METHODS
                              flags);
     }
 
-    uint32_t loadConversationMessages(const QString& accountId,
-                                      const QString& conversationId,
-                                      const QString& fromId,
-                                      const int size)
+    uint32_t loadConversation(const QString& accountId,
+                              const QString& conversationId,
+                              const QString& fromId,
+                              const int size)
     {
-        return libjami::loadConversationMessages(accountId.toStdString(),
-                                                 conversationId.toStdString(),
-                                                 fromId.toStdString(),
-                                                 size);
-    }
-    uint32_t loadConversationUntil(const QString& accountId,
-                                   const QString& conversationId,
-                                   const QString& fromId,
-                                   const QString& toId)
-    {
-        return libjami::loadConversationUntil(accountId.toStdString(),
-                                              conversationId.toStdString(),
-                                              fromId.toStdString(),
-                                              toId.toStdString());
+        return libjami::loadConversation(accountId.toStdString(),
+                                         conversationId.toStdString(),
+                                         fromId.toStdString(),
+                                         size);
     }
 
-    void setDefaultModerator(const QString& accountID, const QString& peerURI, const bool& state)
+    void setDefaultModerator(const QString& accountId, const QString& peerURI, const bool& state)
     {
-        libjami::setDefaultModerator(accountID.toStdString(), peerURI.toStdString(), state);
+        libjami::setDefaultModerator(accountId.toStdString(), peerURI.toStdString(), state);
     }
 
-    QStringList getDefaultModerators(const QString& accountID)
+    QStringList getDefaultModerators(const QString& accountId)
     {
-        return convertStringList(libjami::getDefaultModerators(accountID.toStdString()));
+        return convertStringList(libjami::getDefaultModerators(accountId.toStdString()));
     }
 
-    void enableLocalModerators(const QString& accountID, const bool& isModEnabled)
+    void enableLocalModerators(const QString& accountId, const bool& isModEnabled)
     {
-        libjami::enableLocalModerators(accountID.toStdString(), isModEnabled);
+        libjami::enableLocalModerators(accountId.toStdString(), isModEnabled);
     }
 
-    bool isLocalModeratorsEnabled(const QString& accountID)
+    bool isLocalModeratorsEnabled(const QString& accountId)
     {
-        return libjami::isLocalModeratorsEnabled(accountID.toStdString());
+        return libjami::isLocalModeratorsEnabled(accountId.toStdString());
     }
 
-    void setAllModerators(const QString& accountID, const bool& allModerators)
+    void setAllModerators(const QString& accountId, const bool& allModerators)
     {
-        libjami::setAllModerators(accountID.toStdString(), allModerators);
+        libjami::setAllModerators(accountId.toStdString(), allModerators);
     }
 
-    bool isAllModerators(const QString& accountID)
+    VectorMapStringString getConnectionList(const QString& accountId, const QString& uid)
     {
-        return libjami::isAllModerators(accountID.toStdString());
+        VectorMapStringString temp;
+        for (auto x : libjami::getConnectionList(accountId.toStdString(), uid.toStdString())) {
+            temp.push_back(convertMap(x));
+        }
+        return temp;
+    }
+
+    VectorMapStringString getChannelList(const QString& accountId, const QString& uid)
+    {
+        VectorMapStringString temp;
+        for (auto x : libjami::getChannelList(accountId.toStdString(), uid.toStdString())) {
+            temp.push_back(convertMap(x));
+        }
+        return temp;
+    }
+
+    bool isAllModerators(const QString& accountId)
+    {
+        return libjami::isAllModerators(accountId.toStdString());
     }
 
     MapStringString conversationInfos(const QString& accountId, const QString& conversationId)
@@ -1052,6 +1189,11 @@ public Q_SLOTS: // METHODS
                                             convertMap(prefs));
     }
 
+    void clearCache(const QString& accountId, const QString& conversationId)
+    {
+        return libjami::clearCache(accountId.toStdString(), conversationId.toStdString());
+    }
+
     uint32_t countInteractions(const QString& accountId,
                                const QString& conversationId,
                                const QString& toId,
@@ -1092,12 +1234,12 @@ Q_SIGNALS: // SIGNALS
     void accountDetailsChanged(const QString& accountId, const MapStringString& details);
     void historyChanged();
     void stunStatusFailure(const QString& reason);
-    void registrationStateChanged(const QString& accountID,
+    void registrationStateChanged(const QString& accountId,
                                   const QString& registration_state,
                                   unsigned detail_code,
                                   const QString& detail_str);
     void stunStatusSuccess(const QString& message);
-    void volatileAccountDetailsChanged(const QString& accountID, MapStringString details);
+    void volatileAccountDetailsChanged(const QString& accountId, MapStringString details);
     void certificatePinned(const QString& certId);
     void certificatePathPinned(const QString& path, const QStringList& certIds);
     void certificateExpired(const QString& certId);
@@ -1105,7 +1247,11 @@ Q_SIGNALS: // SIGNALS
                                  const QString& certId,
                                  const QString& status);
     void knownDevicesChanged(const QString& accountId, const MapStringString& devices);
-    void exportOnRingEnded(const QString& accountId, int status, const QString& pin);
+    void addDeviceStateChanged(const QString& accountId,
+                               uint32_t operationId,
+                               int state,
+                               const MapStringString& details);
+    void deviceAuthStateChanged(const QString& accountId, int state, const MapStringString& details);
     void incomingAccountMessage(const QString& accountId,
                                 const QString& from,
                                 const QString msgId,
@@ -1121,13 +1267,14 @@ Q_SIGNALS: // SIGNALS
     void needsHost(const QString& accountId, const QString& conversationId);
     void nameRegistrationEnded(const QString& accountId, int status, const QString& name);
     void registeredNameFound(const QString& accountId,
+                             const QString& requestedName,
                              int status,
                              const QString& address,
-                             const QString& name);
-    void migrationEnded(const QString& accountID, const QString& result);
-    void contactAdded(const QString& accountID, const QString& uri, bool banned);
-    void contactRemoved(const QString& accountID, const QString& uri, bool banned);
-    void profileReceived(const QString& accountID, const QString& peer, const QString& vCard);
+                             const QString& registeredName);
+    void migrationEnded(const QString& accountId, const QString& result);
+    void contactAdded(const QString& accountId, const QString& uri, bool banned);
+    void contactRemoved(const QString& accountId, const QString& uri, bool banned);
+    void profileReceived(const QString& accountId, const QString& peer, const QString& vCard);
     void dataTransferEvent(const QString& accountId,
                            const QString& conversationId,
                            const QString& interactionId,
@@ -1151,9 +1298,24 @@ Q_SIGNALS: // SIGNALS
                             const QString& accountId,
                             const QString& conversationId,
                             const VectorMapStringString& messages);
-    void messageReceived(const QString& accountId,
+    void swarmLoaded(uint32_t requestId,
+                     const QString& accountId,
+                     const QString& conversationId,
+                     const VectorSwarmMessage& messages);
+    void swarmMessageReceived(const QString& accountId,
+                              const QString& conversationId,
+                              const SwarmMessage& message);
+    void swarmMessageUpdated(const QString& accountId,
+                             const QString& conversationId,
+                             const SwarmMessage& message);
+    void reactionAdded(const QString& accountId,
+                       const QString& conversationId,
+                       const QString& messageId,
+                       const MapStringString& message);
+    void reactionRemoved(const QString& accountId,
                          const QString& conversationId,
-                         const MapStringString& message);
+                         const QString& messageId,
+                         const QString& reactionId);
     void messagesFound(uint32_t requestId,
                        const QString& accountId,
                        const QString& conversationId,
