@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -84,6 +84,7 @@ private:
     std::filesystem::path testDir_;
 
     void testConnectDevice();
+    void testConnectDeviceFromId();
     void testAcceptConnection();
     void testManyChannels();
     void testMultipleChannels();
@@ -113,6 +114,7 @@ private:
     CPPUNIT_TEST_SUITE(ConnectionManagerTest);
     CPPUNIT_TEST(testDeclineICERequest);
     CPPUNIT_TEST(testConnectDevice);
+    CPPUNIT_TEST(testConnectDeviceFromId);
     CPPUNIT_TEST(testIsConnecting);
     CPPUNIT_TEST(testIsConnected);
     CPPUNIT_TEST(testAcceptConnection);
@@ -163,7 +165,13 @@ ConnectionManagerTest::setupHandler(const dht::crypto::Identity& id, const std::
             ret.emplace_back(std::move(cert));
         return ret;
     };
-    // dhtContext.logger = h->logger;
+    dhtContext.certificateStorePkId = [c = h->certStore](const dht::PkId& pk_id) {
+        std::vector<std::shared_ptr<dht::crypto::Certificate>> ret;
+        if (auto cert = c->getCertificate(pk_id.toString()))
+            ret.emplace_back(std::move(cert));
+        return ret;
+    };
+    dhtContext.logger = h->logger;
 
     h->dht = std::make_shared<dht::DhtRunner>();
     h->dht->run(dhtConfig, std::move(dhtContext));
@@ -220,10 +228,10 @@ ConnectionManagerTest::tearDown()
     // wait_for_removal_of({aliceId, bobId});
     //  Stop the io_context and join the ioContextRunner thread
     ioContext->stop();
-
     if (ioContextRunner && ioContextRunner->joinable()) {
         ioContextRunner->join();
     }
+    ioContext.reset();
 
     bootstrap_node.reset();
     alice.reset();
@@ -260,6 +268,38 @@ ConnectionManagerTest::testConnectDevice()
     CPPUNIT_ASSERT(alicConVar.wait_for(lock, 30s, [&] { return isAlicConnected; }));
 }
 
+void
+ConnectionManagerTest::testConnectDeviceFromId()
+{
+    std::condition_variable bobConVar;
+    bool isBobRecvChanlReq = false;
+    bob->connectionManager->onChannelRequest(
+        [&](const std::shared_ptr<dht::crypto::Certificate>&,
+                                         const std::string& name) {
+            std::lock_guard lock {mtx};
+            isBobRecvChanlReq = name == "dummyName";
+            bobConVar.notify_one();
+            return true;
+        });
+
+    std::this_thread::sleep_for(std::chrono::seconds(2));
+    std::condition_variable alicConVar;
+    bool isAlicConnected = false;
+    alice->connectionManager->connectDevice(bob->id.second->getLongId(), "dummyName", [&](std::shared_ptr<ChannelSocket> socket, const DeviceId&) {
+        std::lock_guard lock {mtx};
+        if (socket) {
+            isAlicConnected = true;
+        } else {
+            std::cout << "Connection failed" << std::endl;
+        }
+        alicConVar.notify_one();
+    });
+
+    std::unique_lock lock {mtx};
+    CPPUNIT_ASSERT(bobConVar.wait_for(lock, 30s, [&] { return isBobRecvChanlReq; }));
+    CPPUNIT_ASSERT(alicConVar.wait_for(lock, 30s, [&] { return isAlicConnected; }));
+}
+
 void
 ConnectionManagerTest::testAcceptConnection()
 {
@@ -954,7 +994,6 @@ ConnectionManagerTest::testMultiChannelShutdown()
             connected = true;
             std::error_code ec;
             socket->write(data_sent.data(), data_sent.size(), ec);
-            CPPUNIT_ASSERT(!ec);
         }
     };
 
@@ -989,6 +1028,7 @@ ConnectionManagerTest::testMultiChannelShutdown()
     CPPUNIT_ASSERT_EQUAL(N, successfullyConnected);
     CPPUNIT_ASSERT(successfullyConnected <= accepted);
     CPPUNIT_ASSERT(accepted < 2* successfullyConnected);
+    sockets.clear();
     cv.wait_for(lk, 60s, [&] { return shutdownCount == successfullyConnected; });
     CPPUNIT_ASSERT_EQUAL(successfullyConnected, shutdownCount);
     lk.unlock();
